//
// org.osid.room.RoomManager
//
//     The OSID Java specification for org.osid.room.RoomManager.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.room;


/**
 *  <p>The room manager provides access to room sessions and provides 
 *  interoperability tests for various aspects of this service. The sessions 
 *  included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> RoomLookupSession: </code> a session to lookup rooms </li> 
 *      <li> <code> RoomQuerySession: </code> a session to query rooms </li> 
 *      <li> <code> RoomSearchSession: </code> a session to search rooms </li> 
 *      <li> <code> RoomAdminSession: </code> a session to manage rooms </li> 
 *      <li> <code> RoomNotificationSession: </code> a session to subscribe to 
 *      notifications of room changes </li> 
 *      <li> <code> RoomCampusSession: </code> a session to look up room 
 *      campus mappings </li> 
 *      <li> <code> RoomCampusAssignmentSession: </code> a session to manage 
 *      room campus mappings </li> 
 *      <li> <code> RoomSmartCampusSession: </code> a session to manage smart 
 *      campuses of rooms </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> FloorLookupSession: </code> a session to retrieve floores 
 *      </li> 
 *      <li> <code> FloorQuerySession: </code> a session to query floores 
 *      </li> 
 *      <li> <code> FloorSearchSession: </code> a session to search for 
 *      floores </li> 
 *      <li> <code> FloorAdminSession: </code> a session to create, update and 
 *      delete floores </li> 
 *      <li> <code> FloorNotificationSession: </code> a session to receive 
 *      notifications for changes in floores </li> 
 *      <li> <code> FloorCampusSession: </code> a session to look up floor 
 *      campus mappings </li> 
 *      <li> <code> FloorCampusAssignmentSession: </code> a session to manage 
 *      floor campus mappings </li> 
 *      <li> <code> FloorSmartCampusSession: </code> a session to manage smart 
 *      campuses of floores </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> BuildingLookupSession: </code> a session to retrieve 
 *      buildinges </li> 
 *      <li> <code> BuildingQuerySession: </code> a session to query 
 *      buildinges </li> 
 *      <li> <code> BuildingSearchSession: </code> a session to search for 
 *      buildinges </li> 
 *      <li> <code> BuildingAdminSession: </code> a session to create, update 
 *      and delete buildinges </li> 
 *      <li> <code> BuildingNotificationSession: </code> a session to receive 
 *      notifications for changes in buildinges </li> 
 *      <li> <code> BuildingCampusSession: </code> a session to look up 
 *      building campus mappings </li> 
 *      <li> <code> BuildingCampusAssignmentSession: </code> a session to 
 *      manage building campus mappings </li> 
 *      <li> <code> BuildingSmartCampusSession: </code> a session to manage 
 *      smart campuses of buildinges </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> CampusLookupSession: </code> a session to retrieve campuss 
 *      </li> 
 *      <li> <code> CampusQuerySession: </code> a session to query campuss 
 *      </li> 
 *      <li> <code> CampusSearchSession: </code> a session to search for 
 *      campuss </li> 
 *      <li> <code> CampusAdminSession: </code> a session to create, update 
 *      and delete campuss </li> 
 *      <li> <code> CampusNotificationSession: </code> a session to receive 
 *      notifications for changes in campuss </li> 
 *      <li> <code> CampusHierarchySession: </code> a session to traverse 
 *      hierarchies of campuss </li> 
 *      <li> <code> CampusHierarchyDesignSession: </code> a session to manage 
 *      hierarchies of campuses </li> 
 *  </ul>
 *  
 *  
 *  <p> The room manager also provides a profile for determing the supported 
 *  search types supported by this service. </p>
 */

public interface RoomManager
    extends org.osid.OsidManager,
            org.osid.room.RoomProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the room lookup 
     *  service. 
     *
     *  @return a <code> RoomLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRoomLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRoomLookup() </code> is <code> true. </code> 
     */

    public org.osid.room.RoomLookupSession getRoomLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the room lookup 
     *  service for the given campus. 
     *
     *  @param  campusId the <code> Id </code> of the <code> Campus </code> 
     *  @return a <code> RoomLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Campus </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> campusId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRoomLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRoomLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.room.RoomLookupSession getRoomLookupSessionForCampus(org.osid.id.Id campusId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the room query 
     *  service. 
     *
     *  @return a <code> RoomQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRoomQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRoomQuery() </code> is <code> true. </code> 
     */

    public org.osid.room.RoomQuerySession getRoomQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the room query 
     *  service for the given campus. 
     *
     *  @param  campusId the <code> Id </code> of the <code> Campus </code> 
     *  @return a <code> RoomQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Campus </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> campusId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRoomQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRoomQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.room.RoomQuerySession getRoomQuerySessionForCampus(org.osid.id.Id campusId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the room search 
     *  service. 
     *
     *  @return a <code> RoomSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRoomSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRoomSearch() </code> is <code> true. </code> 
     */

    public org.osid.room.RoomSearchSession getRoomSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the room search 
     *  service for the given campus. 
     *
     *  @param  campusId the <code> Id </code> of the <code> Campus </code> 
     *  @return a <code> RoomSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Campus </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> campusId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRoomSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRoomSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.room.RoomSearchSession getRoomSearchSessionForCampus(org.osid.id.Id campusId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the room 
     *  administration service. 
     *
     *  @return a <code> RoomAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRoomAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRoomAdmin() </code> is <code> true. </code> 
     */

    public org.osid.room.RoomAdminSession getRoomAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the room 
     *  administration service for the given campus. 
     *
     *  @param  campusId the <code> Id </code> of the <code> Campus </code> 
     *  @return a <code> RoomAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Campus </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> campusId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRoomAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRoomAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.room.RoomAdminSession getRoomAdminSessionForCampus(org.osid.id.Id campusId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the room 
     *  notification service. 
     *
     *  @param  roomReceiver the receiver 
     *  @return a <code> RoomNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> roomReceiver </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRoomNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRoomNotification() </code> is <code> true. </code> 
     */

    public org.osid.room.RoomNotificationSession getRoomNotificationSession(org.osid.room.RoomReceiver roomReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the room 
     *  notification service for the given campus. 
     *
     *  @param  roomReceiver the receiver 
     *  @param  campusId the <code> Id </code> of the <code> Campus </code> 
     *  @return a <code> RoomNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Campus </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> roomReceiver </code> or 
     *          <code> campusId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRoomNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRoomNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.room.RoomNotificationSession getRoomNotificationSessionForCampus(org.osid.room.RoomReceiver roomReceiver, 
                                                                                     org.osid.id.Id campusId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving room to campus mappings. 
     *
     *  @return a <code> RoomCampusSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRoomCampus() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRoomCampus() </code> is <code> true. </code> 
     */

    public org.osid.room.RoomCampusSession getRoomCampusSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning room to campus mappings. 
     *
     *  @return a <code> RoomCampusAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRoomCampusAssignment() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRoomCampusAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.room.RoomCampusAssignmentSession getRoomCampusAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the room smart campus for the given 
     *  campus. 
     *
     *  @param  campusId the <code> Id </code> of the campus 
     *  @return a <code> RoomSmartCampusSession </code> 
     *  @throws org.osid.NotFoundException <code> campusId </code> not found 
     *  @throws org.osid.NullArgumentException <code> campusId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRoomSmartCampus() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRoomSmartCampus() </code> is <code> true. </code> 
     */

    public org.osid.room.RoomSmartCampusSession getRoomSmartCampusSession(org.osid.id.Id campusId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the floor lookup 
     *  service. 
     *
     *  @return a <code> FloorLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsFloorLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFloorLookup() </code> is <code> true. </code> 
     */

    public org.osid.room.FloorLookupSession getFloorLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the floor lookup 
     *  service for the given campus. 
     *
     *  @param  campusId the <code> Id </code> of the <code> Floor </code> 
     *  @return a <code> FloorLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Campus </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> campusId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsFloorLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFloorLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.room.FloorLookupSession getFloorLookupSessionForCampus(org.osid.id.Id campusId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the floor query 
     *  service. 
     *
     *  @return a <code> FloorQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsFloorQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFloorQuery() </code> is <code> true. </code> 
     */

    public org.osid.room.FloorQuerySession getFloorQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the floor query 
     *  service for the given campus. 
     *
     *  @param  campusId the <code> Id </code> of the <code> Floor </code> 
     *  @return a <code> FloorQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Campus </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> campusId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsFloorQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFloorQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.room.FloorQuerySession getFloorQuerySessionForCampus(org.osid.id.Id campusId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the floor search 
     *  service. 
     *
     *  @return a <code> FloorSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsFloorSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFloorSearch() </code> is <code> true. </code> 
     */

    public org.osid.room.FloorSearchSession getFloorSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the floor search 
     *  service for the given campus. 
     *
     *  @param  campusId the <code> Id </code> of the <code> Floor </code> 
     *  @return a <code> FloorSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Campus </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> campusId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsFloorSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFloorSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.room.FloorSearchSession getFloorSearchSessionForCampus(org.osid.id.Id campusId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the floor 
     *  administrative service. 
     *
     *  @return a <code> FloorAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsFloorAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFloorAdmin() </code> is <code> true. </code> 
     */

    public org.osid.room.FloorAdminSession getFloorAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the floor 
     *  administrative service for the given campus. 
     *
     *  @param  campusId the <code> Id </code> of the <code> Floor </code> 
     *  @return a <code> FloorAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Campus </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> campusId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsFloorAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFloorAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.room.FloorAdminSession getFloorAdminSessionForCampus(org.osid.id.Id campusId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the floor 
     *  notification service. 
     *
     *  @param  floorReceiver the receiver 
     *  @return a <code> FloorNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> floorReceiver </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsFloorNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFloorNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.room.FloorNotificationSession getFloorNotificationSession(org.osid.room.FloorReceiver floorReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the floor 
     *  notification service for the given campus. 
     *
     *  @param  floorReceiver the receiver 
     *  @param  campusId the <code> Id </code> of the <code> Campus </code> 
     *  @return a <code> FloorNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Campus </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> floorReceiver </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsFloorNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFloorNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.room.FloorNotificationSession getFloorNotificationSessionForCampus(org.osid.room.FloorReceiver floorReceiver, 
                                                                                       org.osid.id.Id campusId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving floor to campus mappings. 
     *
     *  @return a <code> FloorCampusSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsFloorCampus() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFloorCampus() </code> is <code> true. </code> 
     */

    public org.osid.room.FloorCampusSession getFloorCampusSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning floor to campus mappings. 
     *
     *  @return a <code> FloorCampusAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsFloorCampusAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFloorCampusAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.room.FloorCampusAssignmentSession getFloorCampusAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the floor smart campus for the given 
     *  campus. 
     *
     *  @param  campusId the <code> Id </code> of the campus 
     *  @return a <code> FloorSmartCampusSession </code> 
     *  @throws org.osid.NotFoundException <code> campusId </code> not found 
     *  @throws org.osid.NullArgumentException <code> campusId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsFloorSmartCampus() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFloorSmartCampus() </code> is <code> true. </code> 
     */

    public org.osid.room.FloorSmartCampusSession getFloorSmartCampusSession(org.osid.id.Id campusId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the building 
     *  lookup service. 
     *
     *  @return a <code> BuildingLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBuildingLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBuildingLookup() </code> is <code> true. </code> 
     */

    public org.osid.room.BuildingLookupSession getBuildingLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the building 
     *  lookup service for the given campus. 
     *
     *  @param  campusId the <code> Id </code> of the <code> Building </code> 
     *  @return a <code> BuildingLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Campus </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> campusId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBuildingLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBuildingLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.room.BuildingLookupSession getBuildingLookupSessionForCampus(org.osid.id.Id campusId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the building query 
     *  service. 
     *
     *  @return a <code> BuildingQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBuildingQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBuildingQuery() </code> is <code> true. </code> 
     */

    public org.osid.room.BuildingQuerySession getBuildingQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the building query 
     *  service for the given campus. 
     *
     *  @param  campusId the <code> Id </code> of the <code> Building </code> 
     *  @return a <code> BuildingQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Campus </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> campusId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBuildingQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBuildingQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.room.BuildingQuerySession getBuildingQuerySessionForCampus(org.osid.id.Id campusId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the building 
     *  search service. 
     *
     *  @return a <code> BuildingSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBuildingSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBuildingSearch() </code> is <code> true. </code> 
     */

    public org.osid.room.BuildingSearchSession getBuildingSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the building 
     *  search service for the given campus. 
     *
     *  @param  campusId the <code> Id </code> of the <code> Building </code> 
     *  @return a <code> BuildingSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Campus </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> campusId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBuildingSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBuildingSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.room.BuildingSearchSession getBuildingSearchSessionForCampus(org.osid.id.Id campusId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the building 
     *  administrative service. 
     *
     *  @return a <code> BuildingAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBuildingAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBuildingAdmin() </code> is <code> true. </code> 
     */

    public org.osid.room.BuildingAdminSession getBuildingAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the building 
     *  administrative service for the given campus. 
     *
     *  @param  campusId the <code> Id </code> of the <code> Building </code> 
     *  @return a <code> BuildingAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Campus </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> campusId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBuildingAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBuildingAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.room.BuildingAdminSession getBuildingAdminSessionForCampus(org.osid.id.Id campusId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the building 
     *  notification service. 
     *
     *  @param  buildingReceiver the receiver 
     *  @return a <code> BuildingNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> buildingReceiver </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBuildingNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBuildingNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.room.BuildingNotificationSession getBuildingNotificationSession(org.osid.room.BuildingReceiver buildingReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the building 
     *  notification service for the given campus. 
     *
     *  @param  buildingReceiver the receiver 
     *  @param  campusId the <code> Id </code> of the <code> Campus </code> 
     *  @return a <code> BuildingNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Campus </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> buildingReceiver </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBuildingNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBuildingNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.room.BuildingNotificationSession getBuildingNotificationSessionForCampus(org.osid.room.BuildingReceiver buildingReceiver, 
                                                                                             org.osid.id.Id campusId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving building to campus mappings. 
     *
     *  @return a <code> BuildingCampusSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBuildingCampus() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBuildingCampus() </code> is <code> true. </code> 
     */

    public org.osid.room.BuildingCampusSession getBuildingCampusSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning building to campus mappings. 
     *
     *  @return a <code> BuildingCampusAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBuildingCampusAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBuildingCampusAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.room.BuildingCampusAssignmentSession getBuildingCampusAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the building smart campus for the 
     *  given campus. 
     *
     *  @param  campusId the <code> Id </code> of the campus 
     *  @return a <code> BuildingSmartCampusSession </code> 
     *  @throws org.osid.NotFoundException <code> campusId </code> not found 
     *  @throws org.osid.NullArgumentException <code> campusId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBuildingSmartCampus() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBuildingSmartCampus() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.room.BuildingSmartCampusSession getBuildingSmartCampusSession(org.osid.id.Id campusId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the campus lookup 
     *  service. 
     *
     *  @return a <code> CampusLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCampusLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCampusLookup() </code> is <code> true. </code> 
     */

    public org.osid.room.CampusLookupSession getCampusLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the campus query 
     *  service. 
     *
     *  @return a <code> CampusQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCampusQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCampusQuery() </code> is <code> true. </code> 
     */

    public org.osid.room.CampusQuerySession getCampusQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the campus search 
     *  service. 
     *
     *  @return a <code> CampusSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCampusSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCampusSearch() </code> is <code> true. </code> 
     */

    public org.osid.room.CampusSearchSession getCampusSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the campus 
     *  administrative service. 
     *
     *  @return a <code> CampusAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCampusAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCampusAdmin() </code> is <code> true. </code> 
     */

    public org.osid.room.CampusAdminSession getCampusAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the campus 
     *  notification service. 
     *
     *  @param  campusReceiver the receiver 
     *  @return a <code> CampusNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> campusReceiver </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCampusNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCampusNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.room.CampusNotificationSession getCampusNotificationSession(org.osid.room.CampusReceiver campusReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the campus 
     *  hierarchy service. 
     *
     *  @return a <code> CampusHierarchySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCampusHierarchy() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCampusHierarchy() </code> is <code> true. </code> 
     */

    public org.osid.room.CampusHierarchySession getCampusHierarchySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the campus 
     *  hierarchy design service. 
     *
     *  @return a <code> CampusHierarchyDesignSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCampusHierarchyDesign() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCampusHierarchyDesign() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.room.CampusHierarchyDesignSession getCampusHierarchyDesignSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> RoomBatchManager. </code> 
     *
     *  @return a <code> RoomBatchManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRoombatch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRoombatch() </code> is <code> true. </code> 
     */

    public org.osid.room.batch.RoomBatchManager getRoomBatchManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> RoomConstructionManager. </code> 
     *
     *  @return a <code> RoomConstructionManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRoomConstruction() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRoomConstruction() </code> is <code> true. </code> 
     */

    public org.osid.room.construction.RoomConstructionManager getRoomConstructionManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> RoomSquattingManager. </code> 
     *
     *  @return a <code> RoomSquattingManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRoomSquatting() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRoomSquatting() </code> is <code> true. </code> 
     */

    public org.osid.room.squatting.RoomSquattingManager getRoomSquattingManager()
        throws org.osid.OperationFailedException;
}
