//
// org.osid.room.RoomProfile
//
//     The OSID Java specification for org.osid.room.RoomProfile.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.room;


/**
 *  <p>The room profile describes the interoperability among room services. 
 *  </p>
 */

public interface RoomProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any building federation is exposed. Federation is exposed 
     *  when a specific building may be identified, selected and used to 
     *  create a lookup or admin session. Federation is not exposed when a set 
     *  of buildinges appears as a single building. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests for the availability of a room lookup service. 
     *
     *  @return <code> true </code> if room lookup is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRoomLookup();


    /**
     *  Tests if querying rooms is available. 
     *
     *  @return <code> true </code> if room query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRoomQuery();


    /**
     *  Tests if searching for rooms is available. 
     *
     *  @return <code> true </code> if room search is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRoomSearch();


    /**
     *  Tests if searching for rooms is available. 
     *
     *  @return <code> true </code> if room search is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRoomAdmin();


    /**
     *  Tests if room notification is available. 
     *
     *  @return <code> true </code> if room notification is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRoomNotification();


    /**
     *  Tests if a room to campus lookup session is available. 
     *
     *  @return <code> true </code> if room campus lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRoomCampus();


    /**
     *  Tests if a room to campus assignment session is available. 
     *
     *  @return <code> true </code> if room campus assignment is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRoomCampusAssignment();


    /**
     *  Tests if a room smart campus session is available. 
     *
     *  @return <code> true </code> if room smart campus is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRoomSmartCampus();


    /**
     *  Tests for the availability of an floor lookup service. 
     *
     *  @return <code> true </code> if floor lookup is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFloorLookup();


    /**
     *  Tests if querying floores is available. 
     *
     *  @return <code> true </code> if floor query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFloorQuery();


    /**
     *  Tests if searching for floores is available. 
     *
     *  @return <code> true </code> if floor search is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFloorSearch();


    /**
     *  Tests for the availability of a floor administrative service for 
     *  creating and deleting floores. 
     *
     *  @return <code> true </code> if floor administration is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFloorAdmin();


    /**
     *  Tests for the availability of a floor notification service. 
     *
     *  @return <code> true </code> if floor notification is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsFloorNotification();


    /**
     *  Tests if a floor to campus lookup session is available. 
     *
     *  @return <code> true </code> if floor campus lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFloorCampus();


    /**
     *  Tests if a floor to campus assignment session is available. 
     *
     *  @return <code> true </code> if floor campus assignment is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFloorCampusAssignment();


    /**
     *  Tests if a floor smart campus session is available. 
     *
     *  @return <code> true </code> if floor smart campus is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFloorSmartCampus();


    /**
     *  Tests for the availability of an building lookup service. 
     *
     *  @return <code> true </code> if building lookup is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBuildingLookup();


    /**
     *  Tests if querying buildinges is available. 
     *
     *  @return <code> true </code> if building query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBuildingQuery();


    /**
     *  Tests if searching for buildinges is available. 
     *
     *  @return <code> true </code> if building search is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBuildingSearch();


    /**
     *  Tests for the availability of a building administrative service for 
     *  creating and deleting buildinges. 
     *
     *  @return <code> true </code> if building administration is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBuildingAdmin();


    /**
     *  Tests for the availability of a building notification service. 
     *
     *  @return <code> true </code> if building notification is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsBuildingNotification();


    /**
     *  Tests if a building to campus lookup session is available. 
     *
     *  @return <code> true </code> if building campus lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBuildingCampus();


    /**
     *  Tests if a building to campus assignment session is available. 
     *
     *  @return <code> true </code> if building campus assignment is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBuildingCampusAssignment();


    /**
     *  Tests if a building smart campus session is available. 
     *
     *  @return <code> true </code> if building smart campus is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBuildingSmartCampus();


    /**
     *  Tests for the availability of an campus lookup service. 
     *
     *  @return <code> true </code> if campus lookup is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCampusLookup();


    /**
     *  Tests if querying campuses is available. 
     *
     *  @return <code> true </code> if campus query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCampusQuery();


    /**
     *  Tests if searching for campuses is available. 
     *
     *  @return <code> true </code> if campus search is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCampusSearch();


    /**
     *  Tests for the availability of a campus administrative service for 
     *  creating and deleting campuses. 
     *
     *  @return <code> true </code> if campus administration is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCampusAdmin();


    /**
     *  Tests for the availability of a campus notification service. 
     *
     *  @return <code> true </code> if campus notification is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsCampusNotification();


    /**
     *  Tests for the availability of a campus hierarchy traversal service. 
     *
     *  @return <code> true </code> if campus hierarchy traversal is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCampusHierarchy();


    /**
     *  Tests for the availability of a campus hierarchy design service. 
     *
     *  @return <code> true </code> if campus hierarchy design is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsCampusHierarchyDesign();


    /**
     *  Tests for the availability of a room batch service. 
     *
     *  @return <code> true </code> if a room batch service is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsRoomBatch();


    /**
     *  Tests for the availability of a room construction service. 
     *
     *  @return <code> true </code> if a room construction service is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsRoomConstruction();


    /**
     *  Tests for the availability of a room squatting service. 
     *
     *  @return <code> true </code> if a room squatting service is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsRoomSquatting();


    /**
     *  Gets the supported <code> Room </code> record types. 
     *
     *  @return a list containing the supported room record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRoomRecordTypes();


    /**
     *  Tests if the given <code> Room </code> record type is supported. 
     *
     *  @param  roomRecordType a <code> Type </code> indicating a <code> Room 
     *          </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> roomRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRoomRecordType(org.osid.type.Type roomRecordType);


    /**
     *  Gets the supported room search record types. 
     *
     *  @return a list containing the supported room search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRoomSearchRecordTypes();


    /**
     *  Tests if the given room search record type is supported. 
     *
     *  @param  roomSearchRecordType a <code> Type </code> indicating a room 
     *          record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> roomSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRoomSearchRecordType(org.osid.type.Type roomSearchRecordType);


    /**
     *  Gets the supported <code> Floor </code> record types. 
     *
     *  @return a list containing the supported floor record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getFloorRecordTypes();


    /**
     *  Tests if the given <code> Floor </code> record type is supported. 
     *
     *  @param  floorRecordType a <code> Type </code> indicating a <code> 
     *          Floor </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> floorRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFloorRecordType(org.osid.type.Type floorRecordType);


    /**
     *  Gets the supported floor search record types. 
     *
     *  @return a list containing the supported floor search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getFloorSearchRecordTypes();


    /**
     *  Tests if the given floor search record type is supported. 
     *
     *  @param  floorSearchRecordType a <code> Type </code> indicating a floor 
     *          record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> floorSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFloorSearchRecordType(org.osid.type.Type floorSearchRecordType);


    /**
     *  Gets the supported <code> Building </code> record types. 
     *
     *  @return a list containing the supported building record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBuildingRecordTypes();


    /**
     *  Tests if the given <code> Building </code> record type is supported. 
     *
     *  @param  buildingRecordType a <code> Type </code> indicating a <code> 
     *          Building </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> buildingRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBuildingRecordType(org.osid.type.Type buildingRecordType);


    /**
     *  Gets the supported building search record types. 
     *
     *  @return a list containing the supported building search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBuildingSearchRecordTypes();


    /**
     *  Tests if the given building search record type is supported. 
     *
     *  @param  buildingSearchRecordType a <code> Type </code> indicating a 
     *          building record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> buildingSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBuildingSearchRecordType(org.osid.type.Type buildingSearchRecordType);


    /**
     *  Gets the supported <code> Campus </code> record types. 
     *
     *  @return a list containing the supported campus record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCampusRecordTypes();


    /**
     *  Tests if the given <code> Campus </code> record type is supported. 
     *
     *  @param  campusRecordType a <code> Type </code> indicating a <code> 
     *          Campus </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> campusRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCampusRecordType(org.osid.type.Type campusRecordType);


    /**
     *  Gets the supported campus search record types. 
     *
     *  @return a list containing the supported campus search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCampusSearchRecordTypes();


    /**
     *  Tests if the given campus search record type is supported. 
     *
     *  @param  campusSearchRecordType a <code> Type </code> indicating a 
     *          campus record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> campusSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCampusSearchRecordType(org.osid.type.Type campusSearchRecordType);
}
