//
// org.osid.room.RoomQuery
//
//     The OSID Java specification for org.osid.room.RoomQuery.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.room;


/**
 *  <p>This is the query for searching rooms. Each method specifies an <code> 
 *  AND </code> term while multiple invocations of the same method produce a 
 *  nested <code> OR. </code> </p>
 */

public interface RoomQuery
    extends org.osid.OsidObjectQuery,
            org.osid.OsidTemporalQuery,
            org.osid.OsidSubjugateableQuery {


    /**
     *  Sets the building <code> Id </code> for this query to match rooms 
     *  assigned to buildings. 
     *
     *  @param  buildingId a building <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> buildingId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBuildingId(org.osid.id.Id buildingId, boolean match);


    /**
     *  Clears the building <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBuildingIdTerms();


    /**
     *  Tests if a <code> BuildingQuery </code> is available. 
     *
     *  @return <code> true </code> if a building query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBuildingQuery();


    /**
     *  Gets the query for a building query. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the building query 
     *  @throws org.osid.UnimplementedException <code> supportsBuildingQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBuildingQuery() </code> is <code> true. </code> 
     */

    public org.osid.room.BuildingQuery getBuildingQuery();


    /**
     *  Clears the building terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBuildingTerms();


    /**
     *  Sets the floor <code> Id </code> for this query to match rooms 
     *  assigned to campuses. 
     *
     *  @param  floorId a floor <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> floorId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchFloorId(org.osid.id.Id floorId, boolean match);


    /**
     *  Clears the floor <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFloorIdTerms();


    /**
     *  Tests if a floor query is available. 
     *
     *  @return <code> true </code> if a room query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsFloorQuery();


    /**
     *  Gets the query for a floor. 
     *
     *  @return the floor query 
     *  @throws org.osid.UnimplementedException <code> supportsFloorQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsFloorQuery() </code> is <code> true. </code> 
     */

    public org.osid.room.FloorQuery getFloorQuery();


    /**
     *  Clears the floor terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFloorTerms();


    /**
     *  Sets an enclosing room <code> Id. </code> 
     *
     *  @param  roomId an enclosing room <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> roomId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchEnclosingRoomId(org.osid.id.Id roomId, boolean match);


    /**
     *  Clears the enclosing room <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEnclosingRoomIdTerms();


    /**
     *  Tests if an <code> EnclosingRoomQuery </code> is available. 
     *
     *  @return <code> true </code> if an enclosing room query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEnclosingRoomQuery();


    /**
     *  Gets the query for an enclosing room query. Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @return the room query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEnclosingRoomQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEnclosingRoomQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.room.RoomQuery getEnclosingRoomQuery();


    /**
     *  Matches any enclosing room. 
     *
     *  @param  match <code> true </code> for a to match any room enclosed in 
     *          another room,, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyEnclosingRoom(boolean match);


    /**
     *  Clears the enclosing room terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEnclosingRoomTerms();


    /**
     *  Sets a subdivision room <code> Id. </code> 
     *
     *  @param  roomId a subdivision room <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> roomId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSubdivisionId(org.osid.id.Id roomId, boolean match);


    /**
     *  Clears the subdivision room <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSubdivisionIdTerms();


    /**
     *  Tests if a <code> RoomQuery </code> is available. 
     *
     *  @return <code> true </code> if a subdivision room query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubdivisionQuery();


    /**
     *  Gets the query for a subdivision room query. Multiple retrievals 
     *  produce a nested <code> OR </code> term. 
     *
     *  @return the room query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubdivisionRoomQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubdivisionRoomQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.room.RoomQuery getSubdivisionQuery();


    /**
     *  Matches any subdivision room. 
     *
     *  @param  match <code> true </code> for a to match any room containg 
     *          another room,, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnySubdivision(boolean match);


    /**
     *  Clears the subdivision room terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSubdivisionTerms();


    /**
     *  Sets a name. 
     *
     *  @param  name an official name 
     *  @param  stringMatchType a string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> name </code> is not 
     *          of <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> name </code> is <code> 
     *          null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDesignatedName(String name, 
                                    org.osid.type.Type stringMatchType, 
                                    boolean match);


    /**
     *  Matches any designated name. 
     *
     *  @param  match <code> true </code> to match rooms with any designated 
     *          name, <code> false </code> to match rooms with no designated 
     *          name 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDesignatedName(boolean match);


    /**
     *  Clears the designated name terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDesignatedNameTerms();


    /**
     *  Sets a room number. 
     *
     *  @param  number a number 
     *  @param  stringMatchType a string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> number </code> is not 
     *          of <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> number </code> is <code> 
     *          null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRoomNumber(String number, 
                                org.osid.type.Type stringMatchType, 
                                boolean match);


    /**
     *  Matches any room number. 
     *
     *  @param  match <code> true </code> to match rooms with any number, 
     *          <code> false </code> to match rooms with no number 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRoomNumber(boolean match);


    /**
     *  Clears the room number terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRoomNumberTerms();


    /**
     *  Sets a room code. 
     *
     *  @param  code a room code 
     *  @param  stringMatchType a string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> code </code> is not 
     *          of <code> stringMatchType </code> 
     *  @throws org.osid.NullArgumentException <code> code </code> is <code> 
     *          null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCode(String code, org.osid.type.Type stringMatchType, 
                          boolean match);


    /**
     *  Matches any room code. 
     *
     *  @param  match <code> true </code> to match rooms with any code, <code> 
     *          false </code> to match rooms with no code 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCode(boolean match);


    /**
     *  Clears the code terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCodeTerms();


    /**
     *  Matches an area within the given range inclusive. 
     *
     *  @param  low start of range 
     *  @param  high end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> low </code> is 
     *          greater than <code> high </code> 
     *  @throws org.osid.NullArgumentException <code> low </code> or <code> 
     *          high </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchArea(java.math.BigDecimal low, java.math.BigDecimal high, 
                          boolean match);


    /**
     *  Matches any area. 
     *
     *  @param  match <code> true </code> to match rooms with any area, <code> 
     *          false </code> to match rooms with no area assigned 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyArea(boolean match);


    /**
     *  Clears the area terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAreaTerms();


    /**
     *  Matches an occupancy limit within the given range inclusive. 
     *
     *  @param  low start of range 
     *  @param  high end of range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> low </code> is 
     *          greater than <code> high </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchOccupancyLimit(long low, long high, boolean match);


    /**
     *  Matches rooms with any occupancy limit. 
     *
     *  @param  match <code> true </code> to match rooms with any occupancy 
     *          limit, <code> false </code> to match rooms with no limit 
     *          assigned 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyOccupancyLimit(boolean match);


    /**
     *  Clears the occupancy limit terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOccupancyLimitTerms();


    /**
     *  Sets the room <code> Id </code> for this query to match resources 
     *  assigned to rooms. 
     *
     *  @param  roomId a room <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> roomId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchResourceId(org.osid.id.Id roomId, boolean match);


    /**
     *  Clears the resource <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearResourceIdTerms();


    /**
     *  Tests if a resource query is available. 
     *
     *  @return <code> true </code> if a resource query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceQuery();


    /**
     *  Gets the query for a room resource. 
     *
     *  @return the resource query 
     *  @throws org.osid.UnimplementedException <code> supportsResourceQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getResourceQuery();


    /**
     *  Matches rooms with any resource. 
     *
     *  @param  match <code> true </code> to match rooms with any resource, 
     *          <code> false </code> to match rooms with no resources 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyResource(boolean match);


    /**
     *  Clears the resource terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearResourceTerms();


    /**
     *  Sets the building <code> Id </code> for this query to match rooms 
     *  assigned to campuses. 
     *
     *  @param  campusId a campus <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> campusId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCampusId(org.osid.id.Id campusId, boolean match);


    /**
     *  Clears the campus <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCampusIdTerms();


    /**
     *  Tests if a <code> CampusQuery </code> is available. 
     *
     *  @return <code> true </code> if a campus query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCampusQuery();


    /**
     *  Gets the query for a campus query. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the campus query 
     *  @throws org.osid.UnimplementedException <code> supportsCampusQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCampusQuery() </code> is <code> true. </code> 
     */

    public org.osid.room.CampusQuery getCampusQuery();


    /**
     *  Clears the campus terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCampusTerms();


    /**
     *  Gets the room query record corresponding to the given <code> Room 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @param  roomRecordType a room record type 
     *  @return the room query record 
     *  @throws org.osid.NullArgumentException <code> roomRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(roomRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.records.RoomQueryRecord getRoomQueryRecord(org.osid.type.Type roomRecordType)
        throws org.osid.OperationFailedException;
}
