//
// org.osid.room.RoomSearchSession
//
//     The OSID Java specification for org.osid.room.RoomSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.room;


/**
 *  <p>This session provides methods for searching <code> Room </code> 
 *  objects. The search query is constructed using the <code> RoomQuery. 
 *  </code> The room record <code> Type </code> also specifies the record for 
 *  the room query. </p> 
 *  
 *  <p> <code> getRoomsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Campus </code> elements. A more advanced search 
 *  may be performed with <code> getRoomsBySearch(). </code> It accepts a 
 *  <code> RoomSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getRoomsBySearch() </code> returns a <code> 
 *  RoomSearchResults </code> that can be used to access the resulting <code> 
 *  RoomList </code> or be used to perform a search within the result set 
 *  through <code> RoomSearch. </code> </p> 
 *  
 *  <p> Rooms may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> RoomQuery. </code> The 
 *  returns in this session may not be cast directly to these interfaces. </p>
 */

public interface RoomSearchSession
    extends org.osid.room.RoomQuerySession {


    /**
     *  Gets a room search. 
     *
     *  @return the room search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.RoomSearch getRoomSearch();


    /**
     *  Gets a room search order. The <code> RoomSearchOrder </code> is 
     *  supplied to a <code> RoomSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the room search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.RoomSearchOrder getRoomSearchOrder();


    /**
     *  Gets the room search results matching the given search. 
     *
     *  @param  roomQuery the room query 
     *  @param  roomSearch the room search 
     *  @return the room search results 
     *  @throws org.osid.NullArgumentException <code> roomQuery </code> or 
     *          <code> roomSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> roomQuery </code> or 
     *          <code> roomSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.RoomSearchResults getRoomsBySearch(org.osid.room.RoomQuery roomQuery, 
                                                            org.osid.room.RoomSearch roomSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an entry query from an inspector. The inspector is available from 
     *  an <code> RoomSearchResults. </code> 
     *
     *  @param  roomQueryInspector a query inspector 
     *  @return the entry query 
     *  @throws org.osid.NullArgumentException <code> roomQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> roomQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.RoomQuery getRoomQueryFromInspector(org.osid.room.RoomQueryInspector roomQueryInspector);
}
