//
// org.osid.room.batch.RoomBatchAdminSession
//
//     The OSID Java specification for org.osid.room.batch.RoomBatchAdminSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.room.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Rooms </code> in 
 *  bulk. The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Room, </code> a <code> RoomForm </code> is requested using <code> 
 *  getRoomFormsForCreate() </code> specifying the desired floor and record 
 *  <code> Types </code> or none if no record <code> Types </code> are needed. 
 *  Each of the returned <code> RoomForms </code> will indicate that it is to 
 *  be used with a create operation and can be used to examine metdata or 
 *  validate data prior to creation. Once a <code> RoomForm </code> is 
 *  submiited to a create operation, it cannot be reused with another create 
 *  operation unless the first operation was unsuccessful. Each <code> 
 *  RoomForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> RoomForms </code> returned from <code> 
 *  getRoomFormsForCreate() </code> may be linked to the originating request 
 *  through the peer <code> Ids </code> of the <code> RoomForm. </code> In the 
 *  case where there may be duplicates, any <code> RoomForm </code> of the 
 *  same peer <code> Ids </code> may be used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> RoomForms </code> are submitted for create, a 
 *  <code> CreateResponse </code> is returned for each <code> RoomForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire create operation are returned from <code> createRooms(), 
 *  </code> errors specific to an individual <code> RoomForm </code> are 
 *  indicated in the corresponding <code> CreateResponse. </code> <code> 
 *  CreateResponses </code> may be linked to the originating <code> RoomForm 
 *  </code> through the <code> RoomForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> RoomForms </code> are requested to the <code> Room 
 *  </code> <code> Id </code> that is to be updated using <code> 
 *  getRoomFormsForUpdate() </code> where the reference <code> Id </code> in 
 *  the <code> RoomForm </code> may be used to link the request. Similarly, 
 *  the <code> RoomForm </code> has metadata about the data that can be 
 *  updated and it can perform validation before submitting the update. The 
 *  <code> RoomForm </code> can only be used once for a successful update and 
 *  cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> RoomForms </code> are submitted for update, an 
 *  <code> UpdateResponse </code> is returned for each <code> RoomForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire update operation are returned from <code> updateRooms(), 
 *  </code> errors specific to an individual <code> RoomForm </code> are 
 *  indicated in the corresponding <code> UpdateResponse. </code> <code> 
 *  UpdateResponses </code> may be linked to the originating <code> RoomForm 
 *  </code> through the <code> RoomForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Rooms </code> in bulk. To unmap a 
 *  <code> Room </code> from the current <code> Campus, </code> the <code> 
 *  RoomCampusAssignmentSession </code> should be used. These delete 
 *  operations attempt to remove the <code> Room </code> itself thus removing 
 *  it from all known <code> Campus </code> catalogs. Bulk delete operations 
 *  return the results in <code> DeleteResponses. </code> </p>
 */

public interface RoomBatchAdminSession
    extends org.osid.room.RoomAdminSession {


    /**
     *  Gets the room forms for creating a bunch of new rooms. A form is 
     *  returned for each supplied floor. 
     *
     *  @param  floorIds a list of floor <code> Ids </code> 
     *  @param  roomRecordTypes array of room record types to be included in 
     *          each create operation or an empty list if none 
     *  @return the room forms 
     *  @throws org.osid.NotFoundException a <code> floorId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> floorIds </code> or 
     *          <code> roomRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.batch.RoomBatchFormList getRoomFormsForCreate(org.osid.id.IdList floorIds, 
                                                                       org.osid.type.Type[] roomRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Rooms. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  roomForms the room forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> roomForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createRooms(org.osid.room.batch.RoomBatchFormList roomForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the room forms for updating an existing set of rooms. A new room 
     *  form should be requested for each update transaction. 
     *
     *  @param  roomIds the <code> Ids </code> of the <code> Room </code> 
     *  @return the room form 
     *  @throws org.osid.NotFoundException a <code> roomId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> roomIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.batch.RoomBatchFormList getRoomFormsForUpdate(org.osid.id.IdList roomIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing rooms. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  roomForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> roomForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateRooms(org.osid.room.batch.RoomBatchFormList roomForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Rooms </code> in this <code> Campus </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllRooms()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes rooms for the given <code> Ids. </code> 
     *
     *  @param  roomIds the <code> Ids </code> of the rooms to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> roomIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteRooms(org.osid.id.IdList roomIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes rooms on the given floor. 
     *
     *  @param  roomId the <code> Id </code> of a floor 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> floorId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteRoomsForFloor(org.osid.id.Id roomId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes rooms expired before the given date. 
     *
     *  @param  date a date 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteIneffectiveRoomsByDate(org.osid.calendaring.DateTime date)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Room </code> for the purpose of 
     *  creating compatibility. The primary <code> Id </code> of the <code> 
     *  Room </code> is determined by the provider. The new <code> Id </code> 
     *  is an alias to the primary <code> Id. </code> If the alias is a 
     *  pointer to another room, it is reassigned to the given entry <code> 
     *  Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasRooms(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
