//
// org.osid.room.construction.ProjectLookupSession
//
//     The OSID Java specification for org.osid.room.construction.ProjectLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.room.construction;


/**
 *  <p>This session provides methods for retrieving <code> Project </code> 
 *  objects. The <code> Project </code> represents a construction of a 
 *  building. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated campus view: All room methods in this session operate, 
 *      retrieve and pertain to projects defined explicitly in the current 
 *      campus. Using an isolated view is useful for managing projects with 
 *      the <code> ProjectAdminSession. </code> </li> 
 *      <li> federated campus view: All project lookup methods in this session 
 *      operate, retrieve and pertain to all projects defined in this campus 
 *      and any other campuses implicitly available in this campus through 
 *      campus inheritence. </li> 
 *      <li> effective project view: All project lookup methods return 
 *      effective projects. </li> 
 *      <li> any effective project view: projects of any effective date are 
 *      returned. </li> 
 *  </ul>
 *  
 */

public interface ProjectLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Campus </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Campus Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCampusId();


    /**
     *  Gets the <code> Campus </code> associated with this session. 
     *
     *  @return the campus 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.Campus getCampus()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Project </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupProjects();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeProjectView();


    /**
     *  A complete view of the <code> Project </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryProjectView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include projects in campuses which are children of this campus in the 
     *  campus hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCampusView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this campus only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCampusView();


    /**
     *  Only projects whose effective dates are current are returned by 
     *  methods in this session 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveProjectView();


    /**
     *  Projects of any effective dates are returned by all methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveProjectView();


    /**
     *  Gets the <code> Project </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Project </code> may have a different <code> Id </code> than requested, 
     *  such as the case where a duplicate <code> Id </code> was assigned to a 
     *  <code> Project </code> and retained for compatibility. 
     *  
     *  In effective mode, projects are returned that are currently effective. 
     *  In any effective mode, effective projects and those currently expired 
     *  are returned. 
     *
     *  @param  projectId <code> Id </code> of the <code> Project </code> 
     *  @return the project 
     *  @throws org.osid.NotFoundException <code> projectId </code> not found 
     *  @throws org.osid.NullArgumentException <code> projectId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.room.construction.Project getProject(org.osid.id.Id projectId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProjectList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  projects specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Projects </code> may be omitted from the list and 
     *  may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In effective mode, projects are returned that are currently effective. 
     *  In any effective mode, effective projects and those currently expired 
     *  are returned. 
     *
     *  @param  projectIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Project </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> projectIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.ProjectList getProjectsByIds(org.osid.id.IdList projectIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProjectList </code> corresponding to the given project 
     *  genus <code> Type </code> which does not include projects of genus 
     *  types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  projects or an error results. Otherwise, the returned list may contain 
     *  only those projects that are accessible through this session. 
     *  
     *  In effective mode, projects are returned that are currently effective. 
     *  In any effective mode, effective projects and those currently expired 
     *  are returned. 
     *
     *  @param  projectGenusType a project genus type 
     *  @return the returned <code> Project </code> list 
     *  @throws org.osid.NullArgumentException <code> projectGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.ProjectList getProjectsByGenusType(org.osid.type.Type projectGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProjectList </code> corresponding to the given project 
     *  genus <code> Type </code> and include any additional projects with 
     *  genus types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  projects or an error results. Otherwise, the returned list may contain 
     *  only those projects that are accessible through this session. 
     *  
     *  In effective mode, projects are returned that are currently effective. 
     *  In any effective mode, effective projects and those currently expired 
     *  are returned. 
     *
     *  @param  projectGenusType a project genus type 
     *  @return the returned <code> Project </code> list 
     *  @throws org.osid.NullArgumentException <code> projectGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.ProjectList getProjectsByParentGenusType(org.osid.type.Type projectGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProjectList </code> containing the given project record 
     *  <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  projects or an error results. Otherwise, the returned list may contain 
     *  only those projects that are accessible through this session. 
     *  
     *  In effective mode, projects are returned that are currently effective. 
     *  In any effective mode, effective projects and those currently expired 
     *  are returned. 
     *
     *  @param  projectRecordType a project record type 
     *  @return the returned <code> Project </code> list 
     *  @throws org.osid.NullArgumentException <code> projectRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.ProjectList getProjectsByRecordType(org.osid.type.Type projectRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all projects effective during the entire given date 
     *  range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known projects or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  projects that are accessible through this session. 
     *  
     *  In effective mode, projects are returned that are currently effective. 
     *  In any effective mode, effective projects and those currently expired 
     *  are returned. 
     *
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Project </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.ProjectList getProjectsOnDate(org.osid.calendaring.DateTime from, 
                                                                    org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all projects with a genus type and effective during the 
     *  entire given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known projects or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  projects that are accessible through this session. 
     *  
     *  In effective mode, projects are returned that are currently effective. 
     *  In any effective mode, effective projects and those currently expired 
     *  are returned. 
     *
     *  @param  projectGenusType a project genus type 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Project </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> projectGenusType, from 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.ProjectList getProjectsByGenusTypeOnDate(org.osid.type.Type projectGenusType, 
                                                                               org.osid.calendaring.DateTime from, 
                                                                               org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProjectList </code> containing the given building <code> 
     *  . </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  projects or an error results. Otherwise, the returned list may contain 
     *  only those projects that are accessible through this session. 
     *  
     *  In effective mode, projects are returned that are currently effective. 
     *  In any effective mode, effective projects and those currently expired 
     *  are returned. 
     *
     *  @param  buildingId a building <code> Id </code> 
     *  @return the returned <code> Project </code> list 
     *  @throws org.osid.NullArgumentException <code> buildingId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.ProjectList getProjectsForBuilding(org.osid.id.Id buildingId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProjectList </code> containing the given building and 
     *  genus type <code> . </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  projects or an error results. Otherwise, the returned list may contain 
     *  only those projects that are accessible through this session. 
     *  
     *  In effective mode, projects are returned that are currently effective. 
     *  In any effective mode, effective projects and those currently expired 
     *  are returned. 
     *
     *  @param  buildingId a building <code> Id </code> 
     *  @param  projectGenusType a project genus type 
     *  @return the returned <code> Project </code> list 
     *  @throws org.osid.NullArgumentException <code> buildingId </code> or 
     *          <code> projectGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.ProjectList getProjectsByGenusTypeForBuilding(org.osid.id.Id buildingId, 
                                                                                    org.osid.type.Type projectGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all projects for a building effective during the entire 
     *  given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known projects or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  projects that are accessible through this session. 
     *  
     *  In effective mode, projects are returned that are currently effective. 
     *  In any effective mode, effective projects and those currently expired 
     *  are returned. 
     *
     *  @param  buildingId a building <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Project </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> buildingId, from </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.ProjectList getProjectsForBuildingOnDate(org.osid.id.Id buildingId, 
                                                                               org.osid.calendaring.DateTime from, 
                                                                               org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all projects for a building with a genus type and 
     *  effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known projects or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  projects that are accessible through this session. 
     *  
     *  In effective mode, projects are returned that are currently effective. 
     *  In any effective mode, effective projects and those currently expired 
     *  are returned. 
     *
     *  @param  buildingId a building <code> Id </code> 
     *  @param  projectGenusType a project genus type 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Project </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> buildingId, 
     *          projectGenusType, from </code> or <code> to </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.ProjectList getProjectsByGenusTypeForBuildingOnDate(org.osid.id.Id buildingId, 
                                                                                          org.osid.type.Type projectGenusType, 
                                                                                          org.osid.calendaring.DateTime from, 
                                                                                          org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Projects. </code> 
     *  
     *  In plenary mode, the returned list contains all known projects or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  projects that are accessible through this session. 
     *  
     *  In effective mode, projects are returned that are currently effective. 
     *  In any effective mode, effective projects and those currently expired 
     *  are returned. 
     *
     *  @return a list of <code> Projects </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.ProjectList getProjects()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
