//
// org.osid.room.construction.ProjectNotificationSession
//
//     The OSID Java specification for org.osid.room.construction.ProjectNotificationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.room.construction;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> Project </code> objects. This session is intended for consumers 
 *  needing to synchronize their state with this service without the use of 
 *  polling. Notifications are cancelled when this session is closed. </p> 
 *  
 *  <p> Notifications are triggered with changes to the <code> Project </code> 
 *  object itself. Adding and removing rooms result in notifications available 
 *  from the notification session for rooms. </p>
 */

public interface ProjectNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Campus </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Campus Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCampusId();


    /**
     *  Gets the <code> Campus </code> associated with this session. 
     *
     *  @return the campus 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.Campus getCampus()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> Project </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForProjectNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include projects in campuses which are children of this campus in the 
     *  campus hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCampusView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this campus only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCampusView();


    /**
     *  Register for notifications of new projects. <code> 
     *  ProjectReceiver.newProjects() </code> is invoked when a new <code> 
     *  Project </code> is created. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewProjects()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of new projects for a building. <code> 
     *  ProjectReceiver.newProjects() </code> is invoked when a project for 
     *  the building is created. 
     *
     *  @param  buildingId the <code> Id </code> of the <code> Building 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> buildingId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewProjectsByBuilding(org.osid.id.Id buildingId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated projects. <code> 
     *  ProjectReceiver.changedProjects() </code> is invoked when a project is 
     *  changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedProjects()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a updated projectsfor a building. <code> 
     *  ProjectReceiver.changedProjects() </code> is invoked when a project 
     *  for the building is changed. 
     *
     *  @param  buildingId the <code> Id </code> of the <code> Building 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> buildingId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedProjectsByBuilding(org.osid.id.Id buildingId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated project. <code> 
     *  ProjectReceiver.changedProjects() </code> is invoked when the 
     *  specified project is changed. 
     *
     *  @param  projectId the <code> Id </code> of the <code> Project </code> 
     *          to monitor 
     *  @throws org.osid.NullArgumentException <code> projectId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedProject(org.osid.id.Id projectId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted projects. <code> 
     *  ProjectReceiver.deletedProjects() </code> is invoked when a project is 
     *  deleted. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedProjects()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted project for a building. <code> 
     *  ProjectReceiver.deletedProjects() </code> is invoked when a project 
     *  for the building is deleted. 
     *
     *  @param  buildingId the <code> Id </code> of the <code> Building 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> buildingId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedProjectsByBuilding(org.osid.id.Id buildingId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted project. <code> 
     *  ProjectReceiver.deletedProjects() </code> is invoked when the 
     *  specified project is deleted. 
     *
     *  @param  projectId the <code> Id </code> of the <code> Project </code> 
     *          to monitor 
     *  @throws org.osid.NullArgumentException <code> projectId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedProject(org.osid.id.Id projectId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
