//
// org.osid.room.construction.RenovationLookupSession
//
//     The OSID Java specification for org.osid.room.construction.RenovationLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.room.construction;


/**
 *  <p>This session provides methods for retrieving <code> Renovation </code> 
 *  objects. The <code> Renovation </code> represents a work project to a room 
 *  or set of rooms. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated campus view: All renovation methods in this session 
 *      operate, retrieve and pertain to renovations defined explicitly in the 
 *      current campus. Using an isolated view is useful for managing 
 *      renovations with the <code> RenovationAdminSession. </code> </li> 
 *      <li> federated campus view: All renovation lookup methods in this 
 *      session operate, retrieve and pertain to all renovations defined in 
 *      this campus and any other campuses implicitly available in this campus 
 *      through campus inheritence. </li> 
 *      <li> effective renovation view: All renovation lookup methods return 
 *      effective renovations. </li> 
 *      <li> any effective renovation view: Renovations of any effective date 
 *      are returned. </li> 
 *  </ul>
 *  
 */

public interface RenovationLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Campus </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Campus Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCampusId();


    /**
     *  Gets the <code> Campus </code> associated with this session. 
     *
     *  @return the campus 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.Campus getCampus()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Renovation </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupRenovations();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeRenovationView();


    /**
     *  A complete view of the <code> Renovation </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryRenovationView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include renovations in campuses which are children of this campus in 
     *  the campus hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCampusView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this campus only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCampusView();


    /**
     *  Only renovations whose effective dates are current are returned by 
     *  methods in this session 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveRenovationView();


    /**
     *  Renovations of any effective dates are returned by all methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveRenovationView();


    /**
     *  Gets the <code> Renovation </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Renovation </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> Renovation </code> and retained for 
     *  compatibility. 
     *  
     *  In effective mode, renovations are returned that are currently 
     *  effective. In any effective mode, effective renovations and those 
     *  currently expired are returned. 
     *
     *  @param  renovationId <code> Id </code> of the <code> Renovation 
     *          </code> 
     *  @return the renovation 
     *  @throws org.osid.NotFoundException <code> renovationId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> renovationId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.room.construction.Renovation getRenovation(org.osid.id.Id renovationId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RenovationList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  renovations specified in the <code> Id </code> list, in the order of 
     *  the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Renovations </code> may be omitted from the list 
     *  and may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In effective mode, renovations are returned that are currently 
     *  effective. In any effective mode, effective renovations and those 
     *  currently expired are returned. 
     *
     *  @param  renovationIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Renovation </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> renovationIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.RenovationList getRenovationsByIds(org.osid.id.IdList renovationIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RenovationList </code> corresponding to the given 
     *  renovation genus <code> Type </code> which does not include 
     *  renovations of genus types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  renovations or an error results. Otherwise, the returned list may 
     *  contain only those renovations that are accessible through this 
     *  session. 
     *  
     *  In effective mode, renovations are returned that are currently 
     *  effective. In any effective mode, effective renovations and those 
     *  currently expired are returned. 
     *
     *  @param  renovationGenusType a renovation genus type 
     *  @return the returned <code> Renovation </code> list 
     *  @throws org.osid.NullArgumentException <code> renovationGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.RenovationList getRenovationsByGenusType(org.osid.type.Type renovationGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RenovationList </code> corresponding to the given 
     *  renovation genus <code> Type </code> and include any additional 
     *  renovations with genus types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  renovations or an error results. Otherwise, the returned list may 
     *  contain only those renovations that are accessible through this 
     *  session. 
     *  
     *  In effective mode, renovations are returned that are currently 
     *  effective. In any effective mode, effective renovations and those 
     *  currently expired are returned. 
     *
     *  @param  renovationGenusType a renovation genus type 
     *  @return the returned <code> Renovation </code> list 
     *  @throws org.osid.NullArgumentException <code> renovationGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.RenovationList getRenovationsByParentGenusType(org.osid.type.Type renovationGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RenovationList </code> containing the given renovation 
     *  record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  renovations or an error results. Otherwise, the returned list may 
     *  contain only those renovations that are accessible through this 
     *  session. 
     *  
     *  In effective mode, renovations are returned that are currently 
     *  effective. In any effective mode, effective renovations and those 
     *  currently expired are returned. 
     *
     *  @param  renovationRecordType a renovation record type 
     *  @return the returned <code> Renovation </code> list 
     *  @throws org.osid.NullArgumentException <code> renovationRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.RenovationList getRenovationsByRecordType(org.osid.type.Type renovationRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all renovations effective during the entire given date 
     *  range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known renovations or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  renovations that are accessible through this session. 
     *  
     *  In effective mode, renovations are returned that are currently 
     *  effective. In any effective mode, effective renovations and those 
     *  currently expired are returned. 
     *
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> RenovationList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.RenovationList getRenovationsOnDate(org.osid.calendaring.DateTime from, 
                                                                          org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all renovations of a genus type effective during the 
     *  entire given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known renovations or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  renovations that are accessible through this session. 
     *  
     *  In effective mode, renovations are returned that are currently 
     *  effective. In any effective mode, effective renovations and those 
     *  currently expired are returned. 
     *
     *  @param  renovationGenusType a renovation genus type 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> RenovationList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> renovationGenusType, 
     *          from </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.RenovationList getRenovationsByGenusTypeOnDate(org.osid.type.Type renovationGenusType, 
                                                                                     org.osid.calendaring.DateTime from, 
                                                                                     org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all renovations corresponding to a room <code> Id. 
     *  </code> 
     *  
     *  In plenary mode, the returned list contains all known renovations or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  renovations that are accessible through this session. 
     *  
     *  In effective mode, renovations are returned that are currently 
     *  effective. In any effective mode, effective renovations and those 
     *  currently expired are returned. 
     *
     *  @param  roomId the <code> Id </code> of the room 
     *  @return the returned <code> RenovationList </code> 
     *  @throws org.osid.NullArgumentException <code> roomId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.RenovationList getRenovationsForRoom(org.osid.id.Id roomId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all renovations corresponding to a room and renovation 
     *  genus type. 
     *  
     *  In plenary mode, the returned list contains all known renovations or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  renovations that are accessible through this session. 
     *  
     *  In effective mode, renovations are returned that are currently 
     *  effective. In any effective mode, effective renovations and those 
     *  currently expired are returned. 
     *
     *  @param  roomId a room <code> Id </code> 
     *  @param  renovationGenusType a renovation genus type 
     *  @return the returned <code> RenovationList </code> 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> roomId </code> or <code> 
     *          renovationGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.RenovationList getRenovationsByGenusTypeForRoom(org.osid.id.Id roomId, 
                                                                                      org.osid.type.Type renovationGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all renovations for a room with an effective during the 
     *  entire given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known renovations or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  renovations that are accessible through this session. 
     *  
     *  In effective mode, renovations are returned that are currently 
     *  effective. In any effective mode, effective renovations and those 
     *  currently expired are returned. 
     *
     *  @param  roomId a room <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> RenovationList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> roomId, from </code> or 
     *          <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.RenovationList getRenovationsForRoomOnDate(org.osid.id.Id roomId, 
                                                                                 org.osid.calendaring.DateTime from, 
                                                                                 org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all renovations for a room and of a renovation genus 
     *  type effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known renovations or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  renovations that are accessible through this session. 
     *  
     *  In effective mode, renovations are returned that are currently 
     *  effective. In any effective mode, effective renovations and those 
     *  currently expired are returned. 
     *
     *  @param  roomId a room <code> Id </code> 
     *  @param  renovationGenusType a renovation genus type 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> RenovationList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> roomId, 
     *          renovationGenusType, from </code> or <code> to </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.RenovationList getRenovationsByGenusTypeForRoomOnDate(org.osid.id.Id roomId, 
                                                                                            org.osid.type.Type renovationGenusType, 
                                                                                            org.osid.calendaring.DateTime from, 
                                                                                            org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all renovations on a floor <code> Id. </code> 
     *  
     *  In plenary mode, the returned list contains all known renovations or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  renovations that are accessible through this session. 
     *  
     *  In effective mode, renovations are returned that are currently 
     *  effective. In any effective mode, effective renovations and those 
     *  currently expired are returned. 
     *
     *  @param  floorId the <code> Id </code> of the floor 
     *  @return the returned <code> RenovationList </code> 
     *  @throws org.osid.NullArgumentException <code> floorId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.RenovationList getRenovationsForFloor(org.osid.id.Id floorId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all renovations on a floor and of a renovation genus 
     *  type. 
     *  
     *  In plenary mode, the returned list contains all known renovations or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  renovations that are accessible through this session. 
     *  
     *  In effective mode, renovations are returned that are currently 
     *  effective. In any effective mode, effective renovations and those 
     *  currently expired are returned. 
     *
     *  @param  floorId a floor <code> Id </code> 
     *  @param  renovationGenusType a renovation genus type 
     *  @return the returned <code> RenovationList </code> 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> floorId </code> or 
     *          <code> renovationGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.RenovationList getRenovationsByGenusTypeForFloor(org.osid.id.Id floorId, 
                                                                                       org.osid.type.Type renovationGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all renovations on a floor with an effective during the 
     *  entire given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known renovations or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  renovations that are accessible through this session. 
     *  
     *  In effective mode, renovations are returned that are currently 
     *  effective. In any effective mode, effective renovations and those 
     *  currently expired are returned. 
     *
     *  @param  floorId a floor <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> RenovationList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> floorId, from, </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.RenovationList getRenovationsForFloorOnDate(org.osid.id.Id floorId, 
                                                                                  org.osid.calendaring.DateTime from, 
                                                                                  org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all renovations on a floor and of a renovation genus 
     *  type effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known renovations or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  renovations that are accessible through this session. 
     *  
     *  In effective mode, renovations are returned that are currently 
     *  effective. In any effective mode, effective renovations and those 
     *  currently expired are returned. 
     *
     *  @param  floorId a floor <code> Id </code> 
     *  @param  renovationGenusType a renovation genus type 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> RenovationList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> floorId, 
     *          renovationGenusType, from, </code> or <code> to </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.RenovationList getRenovationsByGenusTypeForFloorOnDate(org.osid.id.Id floorId, 
                                                                                             org.osid.type.Type renovationGenusType, 
                                                                                             org.osid.calendaring.DateTime from, 
                                                                                             org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all renovations in a building. 
     *  
     *  In plenary mode, the returned list contains all known renovations or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  renovations that are accessible through this session. 
     *  
     *  In effective mode, renovations are returned that are currently 
     *  effective. In any effective mode, effective renovations and those 
     *  currently expired are returned. 
     *
     *  @param  buildingId the <code> Id </code> of the building 
     *  @return the returned <code> RenovationList </code> 
     *  @throws org.osid.NullArgumentException <code> buildingId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.RenovationList getRenovationsForBuilding(org.osid.id.Id buildingId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all renovations in a building and of a renovation genus 
     *  type. 
     *  
     *  In plenary mode, the returned list contains all known renovations or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  renovations that are accessible through this session. 
     *  
     *  In effective mode, renovations are returned that are currently 
     *  effective. In any effective mode, effective renovations and those 
     *  currently expired are returned. 
     *
     *  @param  buildingId a building <code> Id </code> 
     *  @param  renovationGenusType a renovation genus type 
     *  @return the returned <code> RenovationList </code> 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> buildingId </code> or 
     *          <code> renovationGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.RenovationList getRenovationsByGenusTypeForBuilding(org.osid.id.Id buildingId, 
                                                                                          org.osid.type.Type renovationGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all renovations in a building with an effective during 
     *  the entire given date range inclusive but not confined to the date 
     *  range. 
     *  
     *  In plenary mode, the returned list contains all known renovations or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  renovations that are accessible through this session. 
     *  
     *  In effective mode, renovations are returned that are currently 
     *  effective. In any effective mode, effective renovations and those 
     *  currently expired are returned. 
     *
     *  @param  buildingId a building <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> RenovationList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> buildingId, from </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.RenovationList getRenovationsForBuildingOnDate(org.osid.id.Id buildingId, 
                                                                                     org.osid.calendaring.DateTime from, 
                                                                                     org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all renovations in a building and of a renovation genus 
     *  type effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known renovations or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  renovations that are accessible through this session. 
     *  
     *  In effective mode, renovations are returned that are currently 
     *  effective. In any effective mode, effective renovations and those 
     *  currently expired are returned. 
     *
     *  @param  buildingId a building <code> Id </code> 
     *  @param  renovationGenusType a renovation genus type 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> RenovationList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> buildingId, 
     *          renovationGenusType, from </code> or <code> to </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.RenovationList getRenovationsByGenusTypeForBuildingOnDate(org.osid.id.Id buildingId, 
                                                                                                org.osid.type.Type renovationGenusType, 
                                                                                                org.osid.calendaring.DateTime from, 
                                                                                                org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Renovations. </code> 
     *  
     *  In plenary mode, the returned list contains all known renovations or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  renovations that are accessible through this session. 
     *  
     *  In effective mode, renovations are returned that are currently 
     *  effective. In any effective mode, effective renovations and those 
     *  currently expired are returned. 
     *
     *  @return a list of <code> Renovations </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.construction.RenovationList getRenovations()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
