//
// org.osid.room.construction.RoomConstructionProfile
//
//     The OSID Java specification for org.osid.room.construction.RoomConstructionProfile.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.room.construction;


/**
 *  <p>The room construction profile describes the interoperability among room 
 *  construction services. </p>
 */

public interface RoomConstructionProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any project federation is exposed. Federation is exposed when 
     *  a specific project may be identified, selected and used to create a 
     *  lookup or admin session. Federation is not exposed when a set of 
     *  projects appears as a single project. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests for the availability of an renovation lookup service. 
     *
     *  @return <code> true </code> if renovation lookup is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRenovationLookup();


    /**
     *  Tests if querying renovationes is available. 
     *
     *  @return <code> true </code> if renovation query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRenovationQuery();


    /**
     *  Tests if searching for renovationes is available. 
     *
     *  @return <code> true </code> if renovation search is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRenovationSearch();


    /**
     *  Tests for the availability of a renovation administrative service for 
     *  creating and deleting renovationes. 
     *
     *  @return <code> true </code> if renovation administration is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRenovationAdmin();


    /**
     *  Tests for the availability of a renovation notification service. 
     *
     *  @return <code> true </code> if renovation notification is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsRenovationNotification();


    /**
     *  Tests if a renovation to campus lookup session is available. 
     *
     *  @return <code> true </code> if renovation campus lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRenovationCampus();


    /**
     *  Tests if a renovation to campus assignment session is available. 
     *
     *  @return <code> true </code> if renovation campus assignment is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRenovationCampusAssignment();


    /**
     *  Tests if a renovation smart campus session is available. 
     *
     *  @return <code> true </code> if renovation smart campus is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRenovationSmartCampus();


    /**
     *  Tests for the availability of an project lookup service. 
     *
     *  @return <code> true </code> if project lookup is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProjectLookup();


    /**
     *  Tests if querying projects is available. 
     *
     *  @return <code> true </code> if project query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProjectQuery();


    /**
     *  Tests if searching for projects is available. 
     *
     *  @return <code> true </code> if project search is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProjectSearch();


    /**
     *  Tests for the availability of a project administrative service for 
     *  creating and deleting projects. 
     *
     *  @return <code> true </code> if project administration is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProjectAdmin();


    /**
     *  Tests for the availability of a project notification service. 
     *
     *  @return <code> true </code> if project notification is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsProjectNotification();


    /**
     *  Tests if a project to campus lookup session is available. 
     *
     *  @return <code> true </code> if project campus lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProjectCampus();


    /**
     *  Tests if a project to campus assignment session is available. 
     *
     *  @return <code> true </code> if project campus assignment is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProjectCampusAssignment();


    /**
     *  Tests if a project smart campus session is available. 
     *
     *  @return <code> true </code> if project smart campus is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProjectSmartCampus();


    /**
     *  Tests if a service to manage construction in bulk is available. 
     *
     *  @return <code> true </code> if a room construction batch service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRoomConstructionBatch();


    /**
     *  Gets the supported <code> Renovation </code> record types. 
     *
     *  @return a list containing the supported renovation record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRenovationRecordTypes();


    /**
     *  Tests if the given <code> Renovation </code> record type is supported. 
     *
     *  @param  renovationRecordType a <code> Type </code> indicating a <code> 
     *          Renovation </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> renovationRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRenovationRecordType(org.osid.type.Type renovationRecordType);


    /**
     *  Gets the supported renovation search record types. 
     *
     *  @return a list containing the supported renovation search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRenovationSearchRecordTypes();


    /**
     *  Tests if the given renovation search record type is supported. 
     *
     *  @param  renovationSearchRecordType a <code> Type </code> indicating a 
     *          renovation record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          renovationSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRenovationSearchRecordType(org.osid.type.Type renovationSearchRecordType);


    /**
     *  Gets the supported <code> Project </code> record types. 
     *
     *  @return a list containing the supported project record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getProjectRecordTypes();


    /**
     *  Tests if the given <code> Project </code> record type is supported. 
     *
     *  @param  projectRecordType a <code> Type </code> indicating a <code> 
     *          Project </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> projectRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProjectRecordType(org.osid.type.Type projectRecordType);


    /**
     *  Gets the supported project search record types. 
     *
     *  @return a list containing the supported project search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getProjectSearchRecordTypes();


    /**
     *  Tests if the given project search record type is supported. 
     *
     *  @param  projectSearchRecordType a <code> Type </code> indicating a 
     *          project record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> projectSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProjectSearchRecordType(org.osid.type.Type projectSearchRecordType);
}
