//
// org.osid.room.squatting.DeedAdminSession
//
//     The OSID Java specification for org.osid.room.squatting.DeedAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.room.squatting;


/**
 *  <p>This session creates, updates, and deletes <code> Deeds. </code> The 
 *  data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Deed, </code> a <code> DeedForm </code> is requested using <code> 
 *  getDeedFormForCreate() </code> specifying the desired record <code> Types 
 *  </code> or none if no record <code> Types </code> are needed. The returned 
 *  <code> DeedForm </code> will indicate that it is to be used with a create 
 *  operation and can be used to examine metdata or validate data prior to 
 *  creation. Once the <code> DeedForm </code> is submiited to a create 
 *  operation, it cannot be reused with another create operation unless the 
 *  first operation was unsuccessful. Each <code> DeedForm </code> corresponds 
 *  to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> DeedForms </code> are requested to the <code> Deed 
 *  </code> <code> Id </code> that is to be updated using <code> 
 *  getDeedFormForUpdate(). </code> Similarly, the <code> DeedForm </code> has 
 *  metadata about the data that can be updated and it can perform validation 
 *  before submitting the update. The <code> DeedForm </code> can only be used 
 *  once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Deeds. </code> To unmap a <code> 
 *  Deed </code> from the current <code> Campus, </code> the <code> 
 *  DeedCampusAssignmentSession </code> should be used. These delete 
 *  operations attempt to remove the <code> Deed </code> itself thus removing 
 *  it from all known <code> Campus </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface DeedAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Campus </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Campus Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCampusId();


    /**
     *  Gets the <code> Campus </code> associated with this session. 
     *
     *  @return the campus 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.Campus getCampus()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> Deeds. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> Deed </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may not wish to offer create operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Deed </code> creation is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateDeeds();


    /**
     *  Tests if this user can create a single <code> Deed </code> using the 
     *  desired record interface types. While <code> 
     *  RoomSquattingManager.getDeedRecordTypes() </code> can be used to 
     *  examine which record interfaces are supported, this method tests which 
     *  record(s) are required for creating a specific <code> Deed. </code> 
     *  Providing an empty array tests if a <code> Deed </code> can be created 
     *  with no records. 
     *
     *  @param  deedRecordTypes array of deed record types 
     *  @return <code> true </code> if <code> Deed </code> creation using the 
     *          specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> deedRecordTypes </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateDeedWithRecordTypes(org.osid.type.Type[] deedRecordTypes);


    /**
     *  Gets the deed form for creating new deeds. A new form should be 
     *  requested for each create transaction. 
     *
     *  @param  buildingId the <code> Id </code> of the building 
     *  @param  resourceId the <code> Id </code> of the owner resource 
     *  @param  deedRecordTypes array of deed record types 
     *  @return the deed form 
     *  @throws org.osid.NotFoundException <code> buildngId </code> or <code> 
     *          resourceId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> buildngId, resourceId 
     *          </code> , or <code> deedRecordTypes </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get from for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.DeedForm getDeedFormForCreate(org.osid.id.Id buildingId, 
                                                                 org.osid.id.Id resourceId, 
                                                                 org.osid.type.Type[] deedRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Deed. </code> 
     *
     *  @param  deedForm the form for this <code> Deed </code> 
     *  @return the new <code> Deed </code> 
     *  @throws org.osid.IllegalStateException <code> deedForm </code> already 
     *          used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> deedForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> deedForm </code> did not 
     *          originate from <code> getDeedFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.Deed createDeed(org.osid.room.squatting.DeedForm deedForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Deeds. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> Deed </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may not wish to offer update operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Deed </code> modification is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateDeeds();


    /**
     *  Gets the deed form for updating an existing deed. A new deed form 
     *  should be requested for each update transaction. 
     *
     *  @param  deedId the <code> Id </code> of the <code> Deed </code> 
     *  @return the deed form 
     *  @throws org.osid.NotFoundException <code> deedId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> deedId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.DeedForm getDeedFormForUpdate(org.osid.id.Id deedId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing deed. 
     *
     *  @param  deedForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> deedForm </code> already 
     *          used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> deedForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> deedForm </code> did not 
     *          originate from <code> getDeedFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateDeed(org.osid.room.squatting.DeedForm deedForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Deeds </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> Deed </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may not wish to offer delete operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Deed </code> deletion is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteDeeds();


    /**
     *  Deletes a <code> Deed. </code> 
     *
     *  @param  deedId the <code> Id </code> of the <code> Deed </code> to 
     *          remove 
     *  @throws org.osid.NotFoundException <code> deedId </code> not found 
     *  @throws org.osid.NullArgumentException <code> deedId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteDeed(org.osid.id.Id deedId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Deeds. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Deed </code> aliasing is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageDeedAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Deed </code> for the purpose of 
     *  creating compatibility. The primary <code> Id </code> of the <code> 
     *  Deed </code> is determined by the provider. The new <code> Id </code> 
     *  performs as an alias to the primary <code> Id. </code> If the alias is 
     *  a pointer to another deed, it is reassigned to the given deed <code> 
     *  Id. </code> 
     *
     *  @param  deedId the <code> Id </code> of a <code> Deed </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> deedId </code> not found 
     *  @throws org.osid.NullArgumentException <code> deedId </code> or <code> 
     *          aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasDeed(org.osid.id.Id deedId, org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
