//
// org.osid.room.squatting.DeedSmartCampusSession
//
//     The OSID Java specification for org.osid.room.squatting.DeedSmartCampusSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.room.squatting;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. A <code> DeedQuery </code> can be retrieved from this session 
 *  and mapped to this <code> Campus </code> to create a virtual collection of 
 *  <code> Deeds. </code> The deeds may be sequenced using the <code> 
 *  DeedSearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> Campus </code> has a default query that matches any deed 
 *  and a default search order that specifies no sequencing. The queries may 
 *  be examined using a <code> DeedQueryInspector. </code> The query may be 
 *  modified by converting the inspector back to a <code> DeedQuery. </code> 
 *  </p>
 */

public interface DeedSmartCampusSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Campus </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Campus Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCampusId();


    /**
     *  Gets the <code> Campus </code> associated with this session. 
     *
     *  @return the <code> Campus </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.Campus getCampus()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart campuses. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart campus management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartCampuses();


    /**
     *  Gets a deed query. 
     *
     *  @return the deed query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.DeedQuery getDeedQuery();


    /**
     *  Gets a deed search order. 
     *
     *  @return the deed search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.DeedSearchOrder getDeedSearchOrder();


    /**
     *  Applies a deed query to this campus. 
     *
     *  @param  deedQuery the deed query 
     *  @throws org.osid.NullArgumentException <code> deedQuery </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> deedQuery </code> not of 
     *          this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyDeedQuery(org.osid.room.squatting.DeedQuery deedQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a deed query inspector for this campus. 
     *
     *  @return the deed query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.DeedQueryInspector inspectDeedQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a deed search order to this campus. 
     *
     *  @param  deedSearchOrder the deed search order 
     *  @throws org.osid.NullArgumentException <code> deedSearchOrder </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> deedSearchOrder </code> 
     *          did not originate from <code> getDeedSearchOrder() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyDeedSequencing(org.osid.room.squatting.DeedSearchOrder deedSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a deed query from an inspector. 
     *
     *  @param  deedQueryInspector a query inspector 
     *  @return the deed query 
     *  @throws org.osid.NullArgumentException <code> deedQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> deedQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.DeedQuery getDeedQueryFromInspector(org.osid.room.squatting.DeedQueryInspector deedQueryInspector);
}
