//
// org.osid.room.squatting.LeaseLookupSession
//
//     The OSID Java specification for org.osid.room.squatting.LeaseLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.room.squatting;


/**
 *  <p>This session provides methods for retrieving <code> Lease </code> 
 *  objects. The <code> Lease </code> represents a relationship to a room. 
 *  </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated campus view: All lease methods in this session operate, 
 *      retrieve and pertain to leases defined explicitly in the current 
 *      campus. Using an isolated view is useful for managing leases with the 
 *      <code> LeaseAdminSession. </code> </li> 
 *      <li> federated campus view: All lease lookup methods in this session 
 *      operate, retrieve and pertain to all leases defined in this campus and 
 *      any other campuses implicitly available in this campus through campus 
 *      inheritence. </li> 
 *      <li> effective lease view: All lease lookup methods return effective 
 *      leases. </li> 
 *      <li> any effective lease view: Leases of any effective date are 
 *      returned. </li> 
 *  </ul>
 *  
 */

public interface LeaseLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Campus </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Campus Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCampusId();


    /**
     *  Gets the <code> Campus </code> associated with this session. 
     *
     *  @return the campus 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.Campus getCampus()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Lease </code> lookups. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not offer lookup operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupLeases();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeLeaseView();


    /**
     *  A complete view of the <code> Lease </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryLeaseView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include leases in campuses which are children of this campus in the 
     *  campus hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedCampusView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this campus only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedCampusView();


    /**
     *  Only leases whose effective dates are current are returned by methods 
     *  in this session 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveLeaseView();


    /**
     *  Leases of any effective dates are returned by all methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveLeaseView();


    /**
     *  Gets the <code> Lease </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Lease </code> may have a different <code> Id </code> than requested, 
     *  such as the case where a duplicate <code> Id </code> was assigned to a 
     *  <code> Lease </code> and retained for compatibility. 
     *  
     *  In effective mode, leases are returned that are currently effective. 
     *  In any effective mode, effective leases and those currently expired 
     *  are returned. 
     *
     *  @param  leaseId <code> Id </code> of the <code> Lease </code> 
     *  @return the lease 
     *  @throws org.osid.NotFoundException <code> leaseId </code> not found 
     *  @throws org.osid.NullArgumentException <code> leaseId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.room.squatting.Lease getLease(org.osid.id.Id leaseId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> LeaseList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  leases specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Leases </code> may be omitted from the list and 
     *  may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In effective mode, leases are returned that are currently effective. 
     *  In any effective mode, effective leases and those currently expired 
     *  are returned. 
     *
     *  @param  leaseIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Lease </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> leaseIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.LeaseList getLeasesByIds(org.osid.id.IdList leaseIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> LeaseList </code> corresponding to the given lease genus 
     *  <code> Type </code> which does not include leases of genus types 
     *  derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  leases or an error results. Otherwise, the returned list may contain 
     *  only those leases that are accessible through this session. 
     *  
     *  In effective mode, leases are returned that are currently effective. 
     *  In any effective mode, effective leases and those currently expired 
     *  are returned. 
     *
     *  @param  leaseGenusType a lease genus type 
     *  @return the returned <code> Lease </code> list 
     *  @throws org.osid.NullArgumentException <code> leaseGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.LeaseList getLeasesByGenusType(org.osid.type.Type leaseGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> LeaseList </code> corresponding to the given lease genus 
     *  <code> Type </code> and include any additional leases with genus types 
     *  derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  leases or an error results. Otherwise, the returned list may contain 
     *  only those leases that are accessible through this session. 
     *  
     *  In effective mode, leases are returned that are currently effective. 
     *  In any effective mode, effective leases and those currently expired 
     *  are returned. 
     *
     *  @param  leaseGenusType a lease genus type 
     *  @return the returned <code> Lease </code> list 
     *  @throws org.osid.NullArgumentException <code> leaseGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.LeaseList getLeasesByParentGenusType(org.osid.type.Type leaseGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> LeaseList </code> containing the given lease record 
     *  <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  leases or an error results. Otherwise, the returned list may contain 
     *  only those leases that are accessible through this session. 
     *  
     *  In effective mode, leases are returned that are currently effective. 
     *  In any effective mode, effective leases and those currently expired 
     *  are returned. 
     *
     *  @param  leaseRecordType a lease record type 
     *  @return the returned <code> Lease </code> list 
     *  @throws org.osid.NullArgumentException <code> leaseRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.LeaseList getLeasesByRecordType(org.osid.type.Type leaseRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all leases effective during the entire given date range 
     *  inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known leases or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  leases that are accessible through this session. 
     *  
     *  In effective mode, leases are returned that are currently effective. 
     *  In any effective mode, effective leases and those currently expired 
     *  are returned. 
     *
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> LeaseList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.LeaseList getLeasesOnDate(org.osid.calendaring.DateTime from, 
                                                             org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all leases of a genus type effective during the entire 
     *  given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known leases or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  leases that are accessible through this session. 
     *  
     *  In effective mode, leases are returned that are currently effective. 
     *  In any effective mode, effective leases and those currently expired 
     *  are returned. 
     *
     *  @param  leaseGenusType a lease genus type 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> LeaseList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> leaseGenusType, from 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.LeaseList getLeasesByGenusTypeOnDate(org.osid.type.Type leaseGenusType, 
                                                                        org.osid.calendaring.DateTime from, 
                                                                        org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all leases corresponding to a room <code> Id. </code> 
     *  
     *  In plenary mode, the returned list contains all known leases or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  leases that are accessible through this session. 
     *  
     *  In effective mode, leases are returned that are currently effective. 
     *  In any effective mode, effective leases and those currently expired 
     *  are returned. 
     *
     *  @param  roomId the <code> Id </code> of the room 
     *  @return the returned <code> LeaseList </code> 
     *  @throws org.osid.NullArgumentException <code> roomId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.LeaseList getLeasesForRoom(org.osid.id.Id roomId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all leases for a room and a lease genus type <code> . 
     *  </code> 
     *  
     *  In plenary mode, the returned list contains all known leases or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  leases that are accessible through this session. 
     *  
     *  In effective mode, leases are returned that are currently effective. 
     *  In any effective mode, effective leases and those currently expired 
     *  are returned. 
     *
     *  @param  roomId a room <code> Id </code> 
     *  @param  leaseGenusType a lease genus type 
     *  @return the returned <code> LeaseList </code> 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> roomId </code> or <code> 
     *          leaseGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.LeaseList getLeasesByGenusTypeForRoom(org.osid.id.Id roomId, 
                                                                         org.osid.type.Type leaseGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all leases for a room effective during the entire given 
     *  date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known leases or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  leases that are accessible through this session. 
     *  
     *  In effective mode, leases are returned that are currently effective. 
     *  In any effective mode, effective leases and those currently expired 
     *  are returned. 
     *
     *  @param  roomId a room <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> LeaseList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> roomId, from </code> or 
     *          <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.LeaseList getLeasesForRoomOnDate(org.osid.id.Id roomId, 
                                                                    org.osid.calendaring.DateTime from, 
                                                                    org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all leases for a room and of a lease genus type 
     *  effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known leases or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  leases that are accessible through this session. 
     *  
     *  In effective mode, leases are returned that are currently effective. 
     *  In any effective mode, effective leases and those currently expired 
     *  are returned. 
     *
     *  @param  roomId a room <code> Id </code> 
     *  @param  leaseGenusType a lease genus type 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> LeaseList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> roomId, leaseGenusType, 
     *          from </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.LeaseList getLeasesByGenusTypeForRoomOnDate(org.osid.id.Id roomId, 
                                                                               org.osid.type.Type leaseGenusType, 
                                                                               org.osid.calendaring.DateTime from, 
                                                                               org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all leases for a tenant corresponding to a room <code> 
     *  Id. </code> 
     *  
     *  In plenary mode, the returned list contains all known leases or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  leases that are accessible through this session. 
     *  
     *  In effective mode, leases are returned that are currently effective. 
     *  In any effective mode, effective leases and those currently expired 
     *  are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned <code> LeaseList </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.LeaseList getLeasesForTenant(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all leases corresponding to a tenant <code> Id </code> 
     *  and of a lease genus type. 
     *  
     *  In plenary mode, the returned list contains all known leases or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  leases that are accessible through this session. 
     *  
     *  In effective mode, leases are returned that are currently effective. 
     *  In any effective mode, effective leases and those currently expired 
     *  are returned. 
     *
     *  @param  resourceId a resourceId <code> Id </code> 
     *  @param  leaseGenusType a lease genus type 
     *  @return the returned <code> LeaseList </code> 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> or 
     *          <code> leaseGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.LeaseList getLeasesByGenusTypeForTenant(org.osid.id.Id resourceId, 
                                                                           org.osid.type.Type leaseGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all leases for a tenant effective during the entire 
     *  given date range inclusive but not confined to the date range. <code> 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  leases or an error results. Otherwise, the returned list may contain 
     *  only those leases that are accessible through this session. 
     *  
     *  In effective mode, leases are returned that are currently effective. 
     *  In any effective mode, effective leases and those currently expired 
     *  are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> LeaseList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, from, 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.LeaseList getLeasesForTenantOnDate(org.osid.id.Id resourceId, 
                                                                      org.osid.calendaring.DateTime from, 
                                                                      org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all leases for a tenant and of a lease genus type 
     *  effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known leases or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  leases that are accessible through this session. 
     *  
     *  In effective mode, leases are returned that are currently effective. 
     *  In any effective mode, effective leases and those currently expired 
     *  are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  leaseGenusType a lease genus type 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> LeaseList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, 
     *          leaseGenusType, from, </code> or <code> to </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.LeaseList getLeasesByGenusTypeForTenantOnDate(org.osid.id.Id resourceId, 
                                                                                 org.osid.type.Type leaseGenusType, 
                                                                                 org.osid.calendaring.DateTime from, 
                                                                                 org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all leases corresponding to a room and tenant. 
     *  
     *  In plenary mode, the returned list contains all known leases or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  leases that are accessible through this session. 
     *  
     *  In effective mode, leases are returned that are currently effective. 
     *  In any effective mode, effective leases and those currently expired 
     *  are returned. 
     *
     *  @param  roomId the <code> Id </code> of the room 
     *  @param  resourceId a tenant <code> Id </code> 
     *  @return the returned <code> LeaseList </code> 
     *  @throws org.osid.NullArgumentException <code> roomId </code> or <code> 
     *          resourceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.LeaseList getLeasesForRoomAndTenant(org.osid.id.Id roomId, 
                                                                       org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all leases for a room, resource, and of a lease genus 
     *  type. 
     *  
     *  In plenary mode, the returned list contains all known leases or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  leases that are accessible through this session. 
     *  
     *  In effective mode, leases are returned that are currently effective. 
     *  In any effective mode, effective leases and those currently expired 
     *  are returned. 
     *
     *  @param  roomId a room <code> Id </code> 
     *  @param  resourceId a tenant <code> Id </code> 
     *  @param  leaseGenusType a lease genus type 
     *  @return the returned <code> LeaseList </code> 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> roomId, resourceId, 
     *          </code> or <code> leaseGenusType </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.LeaseList getLeasesByGenusTypeForRoomAndTenant(org.osid.id.Id roomId, 
                                                                                  org.osid.id.Id resourceId, 
                                                                                  org.osid.type.Type leaseGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all leases for a room and tenant effective during the 
     *  entire given date range inclusive but not confined to the date range. 
     *  <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  leases or an error results. Otherwise, the returned list may contain 
     *  only those leases that are accessible through this session. 
     *  
     *  In effective mode, leases are returned that are currently effective. 
     *  In any effective mode, effective leases and those currently expired 
     *  are returned. 
     *
     *  @param  roomId a room <code> Id </code> 
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> LeaseList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> roomId, resourceId, 
     *          from, </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.LeaseList getLeasesForRoomAndTenantOnDate(org.osid.id.Id roomId, 
                                                                             org.osid.id.Id resourceId, 
                                                                             org.osid.calendaring.DateTime from, 
                                                                             org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all leases for a room, tenant, and of a lease genus 
     *  type effective during the entire given date range inclusive but not 
     *  confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known leases or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  leases that are accessible through this session. 
     *  
     *  In effective mode, leases are returned that are currently effective. 
     *  In any effective mode, effective leases and those currently expired 
     *  are returned. 
     *
     *  @param  roomId a room <code> Id </code> 
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  leaseGenusType a lease genus type 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> LeaseList </code> 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> roomId, resourceId, 
     *          leaseGenusType, from, </code> or <code> to </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.LeaseList getLeasesByGenusTypeForRoomAndTenantOnDate(org.osid.id.Id roomId, 
                                                                                        org.osid.id.Id resourceId, 
                                                                                        org.osid.type.Type leaseGenusType, 
                                                                                        org.osid.calendaring.DateTime from, 
                                                                                        org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Leases. </code> 
     *  
     *  In plenary mode, the returned list contains all known leases or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  leases that are accessible through this session. 
     *  
     *  In effective mode, leases are returned that are currently effective. 
     *  In any effective mode, effective leases and those currently expired 
     *  are returned. 
     *
     *  @return a list of <code> Leases </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.room.squatting.LeaseList getLeases()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
