//
// org.osid.room.squatting.RoomSquattingProfile
//
//     The OSID Java specification for org.osid.room.squatting.RoomSquattingProfile.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.room.squatting;


/**
 *  <p>The room squatting profile describes the interoperability among room 
 *  squatting services. </p>
 */

public interface RoomSquattingProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any deed federation is exposed. Federation is exposed when a 
     *  specific deed may be identified, selected and used to create a lookup 
     *  or admin session. Federation is not exposed when a set of deeds 
     *  appears as a single deed. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests for the availability of an lease lookup service. 
     *
     *  @return <code> true </code> if lease lookup is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLeaseLookup();


    /**
     *  Tests if querying leasees is available. 
     *
     *  @return <code> true </code> if lease query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLeaseQuery();


    /**
     *  Tests if searching for leasees is available. 
     *
     *  @return <code> true </code> if lease search is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLeaseSearch();


    /**
     *  Tests for the availability of a lease administrative service for 
     *  creating and deleting leasees. 
     *
     *  @return <code> true </code> if lease administration is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLeaseAdmin();


    /**
     *  Tests for the availability of a lease notification service. 
     *
     *  @return <code> true </code> if lease notification is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsLeaseNotification();


    /**
     *  Tests if a lease to campus lookup session is available. 
     *
     *  @return <code> true </code> if lease campus lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLeaseCampus();


    /**
     *  Tests if a lease to campus assignment session is available. 
     *
     *  @return <code> true </code> if lease campus assignment is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLeaseCampusAssignment();


    /**
     *  Tests if a lease smart campus session is available. 
     *
     *  @return <code> true </code> if lease smart campus is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLeaseSmartCampus();


    /**
     *  Tests for the availability of an deed lookup service. 
     *
     *  @return <code> true </code> if deed lookup is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDeedLookup();


    /**
     *  Tests if querying deeds is available. 
     *
     *  @return <code> true </code> if deed query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDeedQuery();


    /**
     *  Tests if searching for deeds is available. 
     *
     *  @return <code> true </code> if deed search is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDeedSearch();


    /**
     *  Tests for the availability of a deed administrative service for 
     *  creating and deleting deeds. 
     *
     *  @return <code> true </code> if deed administration is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDeedAdmin();


    /**
     *  Tests for the availability of a deed notification service. 
     *
     *  @return <code> true </code> if deed notification is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsDeedNotification();


    /**
     *  Tests if a deed to campus lookup session is available. 
     *
     *  @return <code> true </code> if deed campus lookup session is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDeedCampus();


    /**
     *  Tests if a deed to campus assignment session is available. 
     *
     *  @return <code> true </code> if deed campus assignment is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDeedCampusAssignment();


    /**
     *  Tests if a deed smart campus session is available. 
     *
     *  @return <code> true </code> if deed smart campus is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDeedSmartCampus();


    /**
     *  Tests if a service to manage squatters in bulk is available. 
     *
     *  @return <code> true </code> if a room batch squatting service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRoomSquattingBatch();


    /**
     *  Gets the supported <code> Lease </code> record types. 
     *
     *  @return a list containing the supported lease record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getLeaseRecordTypes();


    /**
     *  Tests if the given <code> Lease </code> record type is supported. 
     *
     *  @param  leaseRecordType a <code> Type </code> indicating a <code> 
     *          Lease </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> leaseRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLeaseRecordType(org.osid.type.Type leaseRecordType);


    /**
     *  Gets the supported lease search record types. 
     *
     *  @return a list containing the supported lease search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getLeaseSearchRecordTypes();


    /**
     *  Tests if the given lease search record type is supported. 
     *
     *  @param  leaseSearchRecordType a <code> Type </code> indicating a lease 
     *          record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> leaseSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsLeaseSearchRecordType(org.osid.type.Type leaseSearchRecordType);


    /**
     *  Gets the supported <code> Deed </code> record types. 
     *
     *  @return a list containing the supported deed record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getDeedRecordTypes();


    /**
     *  Tests if the given <code> Deed </code> record type is supported. 
     *
     *  @param  deedRecordType a <code> Type </code> indicating a <code> Deed 
     *          </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> deedRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDeedRecordType(org.osid.type.Type deedRecordType);


    /**
     *  Gets the supported deed search record types. 
     *
     *  @return a list containing the supported deed search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getDeedSearchRecordTypes();


    /**
     *  Tests if the given deed search record type is supported. 
     *
     *  @param  deedSearchRecordType a <code> Type </code> indicating a deed 
     *          record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> deedSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDeedSearchRecordType(org.osid.type.Type deedSearchRecordType);
}
