//
// org.osid.rules.RulesProxyManager
//
//     The OSID Java specification for org.osid.rules.RulesProxyManager.
//
// Copyright (C) 2009 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.rules;


/**
 *  <p>The rules manager provides access to rules sessions and provides 
 *  interoperability tests for various aspects of this service. These methods 
 *  accept a <code> Proxy. </code> The sessions included in this manager are: 
 *  </p> 
 *  
 *  <ul>
 *      <li> <code> RulesSession: </code> a session for evaluating and 
 *      executing rules </li> 
 *      <li> <code> RuleLookupSession: </code> a session to lookup rules </li> 
 *      <li> <code> RuleSearchSession: </code> a session to query rules </li> 
 *      <li> <code> RuleSearchSession: </code> a session to search rules </li> 
 *      <li> <code> RuleAdminSession: </code> a session to manage rules </li> 
 *      <li> <code> RuleNotificationSession: </code> a session to subscribe to 
 *      notifications of new rules </li> 
 *      <li> <code> RuleEngineSession </code> a session to retrieve rule 
 *      engine mappings </li> 
 *      <li> <code> RuleEngineAssignmentSession </code> a session to manage 
 *      rule engine mappings </li> 
 *      <li> <code> RuleSmartEngineSession </code> a session to manage dynamic 
 *      engines </li> 
 *      <li> <code> EngineLookupSession: </code> a session to retrieve engine 
 *      objects </li> 
 *      <li> <code> EngineSearchSession: </code> a session to query engines 
 *      </li> 
 *      <li> <code> EngineSearchSession: </code> a session to search for 
 *      engines </li> 
 *      <li> <code> EngineAdminSession: </code> a session to create, update 
 *      and delete engines </li> 
 *      <li> <code> EngineNotificationSession: </code> a session to receive 
 *      notifications for changes in engines </li> 
 *      <li> <code> EngineHierarchyTraversalSession: </code> a session to 
 *      traverse hierarchies of engines </li> 
 *      <li> <code> EngineHierarchyDesignSession: </code> a session to manage 
 *      hierarchies of engines </li> 
 *  </ul>
 *  
 *  
 *  <p> The rules manager also provides a profile for determing the supported 
 *  search types supported by this service. </p>
 */

public interface RulesProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.rules.RulesProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the rule 
     *  evaluation service. 
     *
     *  @param  proxy the proxy 
     *  @return a <code> RulesSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRules() </code> 
     *          is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRules() </code> is <code> true. </code> 
     */

    public org.osid.rules.RulesSession getRulesSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the rule 
     *  evaluation service for the given engine. 
     *
     *  @param  engineId the <code> Id </code> of an <code> Engine </code> 
     *  @param  proxy the proxy 
     *  @return a <code> RulesSession </code> 
     *  @throws org.osid.NotFoundException no <code> Engine </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> engineId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRules() </code> 
     *          or <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRules() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.rules.RulesSession getRulesSessionForEngine(org.osid.id.Id engineId, 
                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the rule lookup 
     *  service. 
     *
     *  @param  proxy the proxy 
     *  @return a <code> RuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRuleLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRuleLookup() </code> is <code> true. </code> 
     */

    public org.osid.rules.RuleLookupSession getRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the rule lookup 
     *  service for the given engine. 
     *
     *  @param  engineId the <code> Id </code> of an <code> Engine </code> 
     *  @param  proxy the proxy 
     *  @return a <code> RuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Engine </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> engineId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRuleLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.rules.RuleLookupSession getRuleLookupSessionForEngine(org.osid.id.Id engineId, 
                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the rule query 
     *  service. 
     *
     *  @param  proxy the proxy 
     *  @return a <code> RuleQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRuleQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRuleQuery() </code> is <code> true. </code> 
     */

    public org.osid.rules.RuleQuerySession getRuleQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the rule query 
     *  service for the given engine. 
     *
     *  @param  engineId the <code> Id </code> of an <code> Engine </code> 
     *  @param  proxy the proxy 
     *  @return a <code> RuleQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Engine </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> engineId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRuleQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRuleQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.rules.RuleQuerySession getRuleQuerySessionForEngine(org.osid.id.Id engineId, 
                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the rule search 
     *  service. 
     *
     *  @param  proxy the proxy 
     *  @return a <code> RuleSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRuleSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRuleSearch() </code> is <code> true. </code> 
     */

    public org.osid.rules.RuleSearchSession getRuleSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the rule search 
     *  service for the given engine. 
     *
     *  @param  engineId the <code> Id </code> of an <code> Engine </code> 
     *  @param  proxy the proxy 
     *  @return a <code> RuleSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Engine </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> engindId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRuleSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRuleSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.rules.RuleSearchSession getRuleSearchSessionForEngine(org.osid.id.Id engineId, 
                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the rule 
     *  administration service. 
     *
     *  @param  proxy the proxy 
     *  @return a <code> RuleAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRuleAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRuleAdmin() </code> is <code> true. </code> 
     */

    public org.osid.rules.RuleAdminSession getRuleAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the rule 
     *  administration service for the given engine. 
     *
     *  @param  engineId the <code> Id </code> of the <code> Rule </code> 
     *  @param  proxy the proxy 
     *  @return a <code> RuleAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Engine </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> engindId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRuleAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRuleAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.rules.RuleAdminSession getRuleAdminSessionForEngine(org.osid.id.Id engineId, 
                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the rule 
     *  notification service. 
     *
     *  @param  ruleReceiver the receiver 
     *  @param  proxy the proxy 
     *  @return a <code> RuleNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> ruleReceiver </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRuleNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRuleNotification() </code> is <code> true. </code> 
     */

    public org.osid.rules.RuleNotificationSession getRuleNotificationSession(org.osid.rules.RuleReceiver ruleReceiver, 
                                                                             org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the rule 
     *  notification service for the given engine. 
     *
     *  @param  ruleReceiver the receiver 
     *  @param  engineId the <code> Id </code> of an <code> Engine </code> 
     *  @param  proxy the proxy 
     *  @return a <code> RuleNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Engine </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> ruleReceiver, engineId 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRuleNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRuleNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.rules.RuleNotificationSession getRuleNotificationSessionForEngine(org.osid.rules.RuleReceiver ruleReceiver, 
                                                                                      org.osid.id.Id engineId, 
                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup rule/engine mappings. 
     *
     *  @param  proxy the proxy 
     *  @return a <code> RuleEngineSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRuleEngine() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRuleEngine() </code> is <code> true. </code> 
     */

    public org.osid.rules.RuleEngineSession getRuleEngineSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning rules to 
     *  engines. 
     *
     *  @param  proxy the proxy 
     *  @return a <code> RuleEngineAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRuleEngineAssignment() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRuleEngineAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.rules.RuleEngineAssignmentSession getRuleEngineAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the rule smart 
     *  engine service for the given engine. 
     *
     *  @param  engineId the <code> Id </code> of the <code> Rule </code> 
     *  @param  proxy the proxy 
     *  @return a <code> RuleSmartEngineSession </code> 
     *  @throws org.osid.NotFoundException no <code> Engine </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> engindId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRuleSmartEngine() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRuleSmartEngine() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.rules.RuleSmartEngineSession getRuleSmartEngineSession(org.osid.id.Id engineId, 
                                                                           org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the engine lookup 
     *  service. 
     *
     *  @param  proxy the proxy 
     *  @return an <code> EngineLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEngineLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEngineLookup() </code> is <code> true. </code> 
     */

    public org.osid.rules.EngineLookupSession getEngineLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the engine query 
     *  service. 
     *
     *  @param  proxy the proxy 
     *  @return an <code> EngineQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEngineQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEngineQuery() </code> is <code> true. </code> 
     */

    public org.osid.rules.EngineQuerySession getEngineQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the engine search 
     *  service. 
     *
     *  @param  proxy the proxy 
     *  @return an <code> EngineSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEngineSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEngineSearch() </code> is <code> true. </code> 
     */

    public org.osid.rules.EngineSearchSession getEngineSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the engine 
     *  administrative service. 
     *
     *  @param  proxy the proxy 
     *  @return an <code> EngineAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEngineAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEngineAdmin() </code> is <code> true. </code> 
     */

    public org.osid.rules.EngineAdminSession getEngineAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the engine 
     *  notification service. 
     *
     *  @param  engineReceiver the receiver 
     *  @param  proxy the proxy 
     *  @return an <code> EngineNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> engineReceiver </code> 
     *          or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEngineNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEngineNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.rules.EngineNotificationSession getEngineNotificationSession(org.osid.rules.EngineReceiver engineReceiver, 
                                                                                 org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the engine 
     *  hierarchy service. 
     *
     *  @param  proxy the proxy 
     *  @return an <code> EngineHierarchySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEngineHierarchy() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEngineHierarchy() </code> is <code> true. </code> 
     */

    public org.osid.rules.EngineHierarchySession getEngineHierarchySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the engine 
     *  hierarchy design service. 
     *
     *  @param  proxy the proxy 
     *  @return an <code> EngineHierarchyDesignSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEngineHierarchyDesign() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEngineHierarchyDesign() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.rules.EngineHierarchyDesignSession getEngineHierarchyDesignSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> RulesCheckProxyManager. </code> 
     *
     *  @return a <code> RulesCheckProxyManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRulesCheckManager() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRulesCheckManager() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.rules.check.RulesCheckProxyManager getRulesCheckProxyManager()
        throws org.osid.OperationFailedException;
}
