//
// org.osid.rules.check.AgendaQuery
//
//     The OSID Java specification for org.osid.rules.check.AgendaQuery.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.rules.check;


/**
 *  <p>This is the query for searching agendas. Each method match specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface AgendaQuery
    extends org.osid.OsidObjectQuery {


    /**
     *  Sets the instruction <code> Id </code> for this query. 
     *
     *  @param  qualifierId the instruction <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> instructionId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchInstructionId(org.osid.id.Id qualifierId, boolean match);


    /**
     *  Clears the instruction <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearInstructionIdTerms();


    /**
     *  Tests if an <code> InstructionQuery </code> is available. 
     *
     *  @return <code> true </code> if an instruction query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInstructionQuery();


    /**
     *  Gets the query for an instruction. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the instruction query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInstructionQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInstructionQuery() </code> is <code> true. </code> 
     */

    public org.osid.rules.check.InstructionQuery getInstructionQuery();


    /**
     *  Matches agendas that have any instruction. 
     *
     *  @param  match <code> true </code> to match agendas with any 
     *          instruction, <code> false </code> to match agendas with no 
     *          instruction 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyInstruction(boolean match);


    /**
     *  Clears the instruction query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearInstructionTerms();


    /**
     *  Sets the engine <code> Id </code> for this query to match agendas 
     *  assigned to engines. 
     *
     *  @param  engineId the engine <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> engineId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchEngineId(org.osid.id.Id engineId, boolean match);


    /**
     *  Clears the engine <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEngineIdTerms();


    /**
     *  Tests if a <code> EngineQuery </code> is available. 
     *
     *  @return <code> true </code> if an engine query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEngineQuery();


    /**
     *  Gets the query for an engine. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the engine query 
     *  @throws org.osid.UnimplementedException <code> supportsEngineQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEngineQuery() </code> is <code> true. </code> 
     */

    public org.osid.rules.EngineQuery getEngineQuery();


    /**
     *  Clears the engine query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEngineTerms();


    /**
     *  Gets the agenda query record corresponding to the given <code> Agenda 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @param  agendaRecordType an agenda record type 
     *  @return the agenda query record 
     *  @throws org.osid.NullArgumentException <code> agendaRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(agendaRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.records.AgendaQueryRecord getAgendaQueryRecord(org.osid.type.Type agendaRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
