//
// org.osid.rules.check.CheckQuery
//
//     The OSID Java specification for org.osid.rules.check.CheckQuery.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.rules.check;


/**
 *  <p>This is the query for searching checks. Each method match specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface CheckQuery
    extends org.osid.OsidRuleQuery {


    /**
     *  Matches fail checks. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchFailCheck(boolean match);


    /**
     *  Clears the fail check query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFailCheckTerms();


    /**
     *  Matches time checks with start dates within the given range inclusive. 
     *
     *  @param  from starting date 
     *  @param  to ending date 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTimeCheckStartDate(org.osid.calendaring.DateTime from, 
                                        org.osid.calendaring.DateTime to, 
                                        boolean match);


    /**
     *  Matches any time check with a start date. 
     *
     *  @param  match <code> true </code> to match any time checks with a 
     *          start date, <code> false </code> to match checks with no start 
     *          date 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyTimeCheckStartDate(boolean match);


    /**
     *  Clears the time check start date query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTimeCheckStartDateTerms();


    /**
     *  Matches time checks with end dates within the given range inclusive. 
     *
     *  @param  from starting date 
     *  @param  to ending date 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTimeCheckEndDate(org.osid.calendaring.DateTime from, 
                                      org.osid.calendaring.DateTime to, 
                                      boolean match);


    /**
     *  Matches any time check with an end date. 
     *
     *  @param  match <code> true </code> to match any time checks with an end 
     *          date, <code> false </code> to match checks with no end date 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyTimeCheckEndDate(boolean match);


    /**
     *  Clears the time check end date query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTimeCheckEndDateTerms();


    /**
     *  Matches time checks with dates overlapping the given date range. 
     *
     *  @param  from starting date 
     *  @param  to ending date 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTimeCheckDate(org.osid.calendaring.DateTime from, 
                                   org.osid.calendaring.DateTime to, 
                                   boolean match);


    /**
     *  Clears the time check date query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTimeCheckDateTerms();


    /**
     *  Sets the event <code> Id </code> for this query. 
     *
     *  @param  eventId the event <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> eventId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTimeCheckEventId(org.osid.id.Id eventId, boolean match);


    /**
     *  Clears the event <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTimeCheckEventIdTerms();


    /**
     *  Tests if an <code> EventQuery </code> is available. 
     *
     *  @return <code> true </code> if an event query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTimeCheckEventQuery();


    /**
     *  Gets the query for an event. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the event query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTimeCheckEventQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTimeCheckEventQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.calendaring.EventQuery getTimeCheckEventQuery();


    /**
     *  Matches any time check with an event. 
     *
     *  @param  match <code> true </code> to match any time checks with an 
     *          event, <code> false </code> to match checks with no events 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyTimeCheckEvent(boolean match);


    /**
     *  Clears the event query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTimeCheckEventTerms();


    /**
     *  Sets the cyclic event <code> Id </code> for this query. 
     *
     *  @param  cyclicEventId the cyclic event <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> cyclicEventId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTimeCheckCyclicEventId(org.osid.id.Id cyclicEventId, 
                                            boolean match);


    /**
     *  Clears the cyclic event <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTimeCheckCyclicEventIdTerms();


    /**
     *  Tests if a <code> CyclicEventQuery </code> is available. 
     *
     *  @return <code> true </code> if a cyclic event query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTimeCheckCyclicEventQuery();


    /**
     *  Gets the query for a cyclic event. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the cyclic event query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTimeCheckCyclicEventQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTimeCheckCyclicEventQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.calendaring.cycle.CyclicEventQuery getTimeCheckCyclicEventQuery();


    /**
     *  Matches any time check with a cyclic event. 
     *
     *  @param  match <code> true </code> to match any time checks with a 
     *          cyclic event, <code> false </code> to match checks with no 
     *          cyclic events 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyTimeCheckCyclicEvent(boolean match);


    /**
     *  Clears the cyclic event query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTimeCheckCyclicEventTerms();


    /**
     *  Sets the block <code> Id </code> for this query. 
     *
     *  @param  blockId the block <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> blockId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchHoldCheckBlockId(org.osid.id.Id blockId, boolean match);


    /**
     *  Clears the block <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearHoldCheckBlockIdTerms();


    /**
     *  Tests if a <code> BlockQuery </code> is available. 
     *
     *  @return <code> true </code> if a block query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsHoldCheckBlockQuery();


    /**
     *  Gets the query for a block. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the block query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsHoldCheckBlockQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsHoldCheckBlockQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.hold.BlockQuery getHoldCheckBlockQuery();


    /**
     *  Matches any hold check with a block. 
     *
     *  @param  match <code> true </code> to match any hold checks with a 
     *          block, <code> false </code> to match checks with no blocks 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyHoldCheckBlock(boolean match);


    /**
     *  Clears the block query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearHoldCheckBlockTerms();


    /**
     *  Sets the audit <code> Id </code> for this query. 
     *
     *  @param  auditId the audit <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> audirId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchInquiryCheckAuditId(org.osid.id.Id auditId, boolean match);


    /**
     *  Clears the audit <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearInquiryCheckAuditIdTerms();


    /**
     *  Tests if an <code> AuditQuery </code> is available. 
     *
     *  @return <code> true </code> if an audit query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInquiryCheckAuditQuery();


    /**
     *  Gets the query for an audit. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the audit query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInquiryCheckAuditQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInquiryCheckAuditQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.inquiry.AuditQuery getInquiryCheckAuditQuery();


    /**
     *  Matches any inquiry check with an audit. 
     *
     *  @param  match <code> true </code> to match any inqiiry checks with an 
     *          audit, <code> false </code> to match checks with no audits 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyInquiryCheckAudit(boolean match);


    /**
     *  Clears the audit query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearInquiryCheckAuditTerms();


    /**
     *  Sets the agenda <code> Id </code> for this query. 
     *
     *  @param  agendaId the agenda <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> agendaId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchProcessCheckAgendaId(org.osid.id.Id agendaId, 
                                          boolean match);


    /**
     *  Clears the agenda <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProcessCheckAgendaIdTerms();


    /**
     *  Tests if an <code> AgendaQuery </code> is available. 
     *
     *  @return <code> true </code> if an agenda query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcessCheckAgendaQuery();


    /**
     *  Gets the query for an agenda. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the agenda query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcessCheckAgendaQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessCheckAgendaQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.rules.check.AgendaQuery getProcessCheckAgendaQuery();


    /**
     *  Matches any process check with an agenda. 
     *
     *  @param  match <code> true </code> to match any process checks with an 
     *          agenda, <code> false </code> to match checks with no agendas 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyProcessCheckAgenda(boolean match);


    /**
     *  Clears the agenda query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProcessCheckAgendaTerms();


    /**
     *  Sets the engine <code> Id </code> for this query to match checks 
     *  assigned to engines. 
     *
     *  @param  engineId the engine <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> engineId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchEngineId(org.osid.id.Id engineId, boolean match);


    /**
     *  Clears the engine <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEngineIdTerms();


    /**
     *  Tests if a <code> EngineQuery </code> is available. 
     *
     *  @return <code> true </code> if an engine query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEngineQuery();


    /**
     *  Gets the query for an engine. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the engine query 
     *  @throws org.osid.UnimplementedException <code> supportsEngineQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEngineQuery() </code> is <code> true. </code> 
     */

    public org.osid.rules.EngineQuery getEngineQuery();


    /**
     *  Clears the engine query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEngineTerms();


    /**
     *  Gets the check query record corresponding to the given <code> Check 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @param  checkRecordType a check record type 
     *  @return the check query record 
     *  @throws org.osid.NullArgumentException <code> checkRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(checkRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.records.CheckQueryRecord getCheckQueryRecord(org.osid.type.Type checkRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
