//
// org.osid.rules.check.CheckQueryInspector
//
//     The OSID Java specification for org.osid.rules.check.CheckQueryInspector.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.rules.check;


/**
 *  <p>This is the query inspector for examining check queries. </p>
 */

public interface CheckQueryInspector
    extends org.osid.OsidRuleQueryInspector {


    /**
     *  Gets the fail check query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.BooleanTerm[] getFailCheckTerms();


    /**
     *  Gets the time check start date query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getTimeCheckStartDateTerms();


    /**
     *  Gets the time check end date query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getTimeCheckEndDateTerms();


    /**
     *  Gets the time check date query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.DateTimeRangeTerm[] getTimeCheckDateTerms();


    /**
     *  Gets the event <code> Id </code> query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getTimeCheckEventIdTerms();


    /**
     *  Gets the event query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.EventQueryInspector[] getTimeCheckEventTerms();


    /**
     *  Gets the cyclic event <code> Id </code> query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getTimeCheckCyclicEventIdTerms();


    /**
     *  Gets the cyclic event query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.cycle.CyclicEventQueryInspector[] getTimeCheckCyclicEventTerms();


    /**
     *  Gets the block <code> Id </code> query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getHoldCheckBlockIdTerms();


    /**
     *  Gets the block query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.hold.BlockQueryInspector[] getHoldCheckBlockTerms();


    /**
     *  Gets the audit <code> Id </code> query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getInquiryCheckAuditIdTerms();


    /**
     *  Gets the audit query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.inquiry.AuditQueryInspector[] getInquiryCheckAuditTerms();


    /**
     *  Gets the agenda <code> Id </code> query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getProcessCheckAgendaIdTerms();


    /**
     *  Gets the agenda query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.AgendaQueryInspector[] getProcessCheckAgendaTerms();


    /**
     *  Gets the engine <code> Id </code> query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.terms.IdTerm[] getEngineIdTerms();


    /**
     *  Gets the engine query terms. 
     *
     *  @return the query terms 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.EngineQueryInspector[] getEngineTerms();


    /**
     *  Gets the check query inspector record corresponding to the given 
     *  <code> Check </code> record <code> Type. </code> 
     *
     *  @param  checkRecordType a check record type 
     *  @return the check query inspector record 
     *  @throws org.osid.NullArgumentException <code> checkRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(checkRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.records.CheckQueryInspectorRecord getCheckQueryInspectorRecord(org.osid.type.Type checkRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
