//
// org.osid.rules.check.CheckResult
//
//     The OSID Java specification for org.osid.rules.check.CheckResult.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.rules.check;


/**
 *  <p>The results of an evaluation. A <code> CheckResult </code> is issued 
 *  for every <code> Check </code> evaluated and is considered successful if 
 *  <code> hasFailed() </code> is false. <code> Checks </code> not evaluated 
 *  because the <code> Check </code> was not applicable due to the <code> 
 *  Instruction </code> do not produce a <code> CheckResult. </code> Results 
 *  for <code> Checks </code> evaluated as part of a dependent <code> Agenda 
 *  </code> are included. </p>
 */

public interface CheckResult
    extends org.osid.OsidResult {


    /**
     *  Gets the instruction <code> Id </code> for this result. 
     *
     *  @return the instruction <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getInstructionId();


    /**
     *  Gets the instruction for this result. 
     *
     *  @return the instruction 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.Instruction getInstruction()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if the corresponding <code> Check </code> has failed. Failed 
     *  checks resulting in warnings should return <code> false. </code> 
     *
     *  @return <code> true </code> if this check failed, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasFailed();


    /**
     *  Tests if the informational message should be displayed as a warning. 
     *
     *  @return <code> true </code> if this check is a warning, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isWarning();


    /**
     *  Gets a message which may be the cause of the failure, a warning 
     *  message, or the weather. 
     *
     *  @return a message 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getMessage();


    /**
     *  Gets the check result record corresponding to the given <code> 
     *  CheckResult </code> record <code> Type. </code> This method is used to 
     *  retrieve an object implementing the requested record. The <code> 
     *  checkResultRecordType </code> may be the <code> Type </code> returned 
     *  in <code> getRecordTypes() </code> or any of its parents in a <code> 
     *  Type </code> hierarchy where <code> 
     *  hasRecordType(checkResultRecordType) </code> is <code> true </code> . 
     *
     *  @param  checkResultRecordType the type of check result record to 
     *          retrieve 
     *  @return the check result record 
     *  @throws org.osid.NullArgumentException <code> checkresultRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(checkResultRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.records.CheckResultRecord getCheckResultRecord(org.osid.type.Type checkResultRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
