//
// org.osid.rules.check.InstructionForm
//
//     The OSID Java specification for org.osid.rules.check.InstructionForm.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.rules.check;


/**
 *  <p>This is the form for creating and updating <code> Instructions. </code> 
 *  Like all <code> OsidForm </code> objects, various data elements may be set 
 *  here for use in the create and update methods in the <code> 
 *  InstructionAdminSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  </p>
 */

public interface InstructionForm
    extends org.osid.OsidRelationshipForm,
            org.osid.OsidEnablerForm {


    /**
     *  Gets the metadata for the message. 
     *
     *  @return metadata for the message 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getMessageMetadata();


    /**
     *  Sets the message. 
     *
     *  @param  message the new message 
     *  @throws org.osid.InvalidArgumentException <code> message </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @throws org.osid.NullArgumentException <code> message </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setMessage(String message);


    /**
     *  Removes the message. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMessage();


    /**
     *  Gets the metadata for the warning flag. 
     *
     *  @return metadata for the warning flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getWarningMetadata();


    /**
     *  Sets the warning flag. 
     *
     *  @param  warning the new warning flag 
     *  @throws org.osid.InvalidArgumentException <code> warning </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setWarning(boolean warning);


    /**
     *  Removes the warning flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearWarning();


    /**
     *  Gets the metadata for the continue-on-fail flag. 
     *
     *  @return metadata for the continue-on-fail flag 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getContinueOnFailMetadata();


    /**
     *  Sets the continue-on-fail flag. 
     *
     *  @param  cof the new continue-on-fail flag 
     *  @throws org.osid.InvalidArgumentException <code> cof </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setContinueOnFail(boolean cof);


    /**
     *  Removes the continue-on-fail flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearContinueOnFail();


    /**
     *  Gets the <code> InstructionFormRecord </code> corresponding to the 
     *  given instruction record <code> Type. </code> 
     *
     *  @param  instructionRecordType an instruction record type 
     *  @return the instruction form record 
     *  @throws org.osid.NullArgumentException <code> instructionRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(instructionRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.records.InstructionFormRecord getInstructionFormRecord(org.osid.type.Type instructionRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
