//
// org.osid.rules.check.InstructionNotificationSession
//
//     The OSID Java specification for org.osid.rules.check.InstructionNotificationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.rules.check;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> Instruction </code> objects in this <code> Engine. </code> This 
 *  session is intended for consumers needing to synchronize their state with 
 *  this service without the use of polling. Notifications are cancelled when 
 *  this session is closed. </p> 
 *  
 *  <p> The two views defined in this session correspond to the views in the 
 *  <code> InstructionLookupSession. </code> </p>
 */

public interface InstructionNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Engine </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Engine Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getEngineId();


    /**
     *  Gets the <code> Engine </code> associated with this session. 
     *
     *  @return the engine 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.Engine getEngine()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> Instruction </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForInstructionNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include instructions in engines which are children of this engine in 
     *  the engine hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedEngineView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts notifications to this engine only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedEngineView();


    /**
     *  Register for notifications of new instructions. <code> 
     *  InstructionReceiver.newInstructions() </code> is invoked when a new 
     *  <code> Instruction </code> appears in this engine. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewInstructions()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new instructions related to the given 
     *  agenda. <code> InstructionReceiver.newInstructions() </code> is 
     *  invoked when a new <code> Instruction </code> appears in this engine. 
     *
     *  @param  agendaId the <code> Id </code> of the <code> Agenda </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> agendaId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewInstructionsForAgenda(org.osid.id.Id agendaId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new instructions related to the given 
     *  agenda. <code> InstructionReceiver.newInstructions() </code> is 
     *  invoked when a new <code> Instruction </code> appears in this engine. 
     *
     *  @param  checkId the <code> Id </code> of the <code> Check </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> checkId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewInstructionsForCheck(org.osid.id.Id checkId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated instructions. <code> 
     *  InstructionReceiver.changedInstructions() </code> is invoked when an 
     *  instruction in this engine is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedInstructions()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated instructions related to the 
     *  given agenda. <code> InstructionReceiver.changedInstructions() </code> 
     *  is invoked when an instruction related to the agenda in this engine is 
     *  changed. 
     *
     *  @param  agendaId the <code> Id </code> of the <code> Agenda </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> agendaId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedInstructionsForAgenda(org.osid.id.Id agendaId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated instructions related to the 
     *  given check. <code> InstructionReceiver.changedInstructions() </code> 
     *  is invoked when an instruction related to the check in this engine is 
     *  changed. 
     *
     *  @param  checkId the <code> Id </code> of the <code> Check </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> checkId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedInstructionsForCheck(org.osid.id.Id checkId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated instruction. <code> 
     *  InstructionReceiver.changedInstructions() </code> is invoked when the 
     *  specified instruction in this engine is changed. 
     *
     *  @param  instructionId the <code> Id </code> of the <code> Instruction 
     *          </code> to monitor 
     *  @throws org.osid.NotFoundException an instruction was not found in 
     *          this engine identified by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> instructionId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedInstruction(org.osid.id.Id instructionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted instructions. <code> 
     *  InstructionReceiver.deletedInstructions() </code> is invoked when an 
     *  instruction is deleted or removed from this engine. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedInstructions()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted instruction for an agenda. 
     *  <code> InstructionReceiver.deletedInstructions() </code> is invoked 
     *  when the related instruction is deleted or removed from this engine. 
     *
     *  @param  agendaId the <code> Id </code> of the <code> Agenda </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> agendaId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedInstructionsForAgenda(org.osid.id.Id agendaId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted instruction for a check. <code> 
     *  InstructionReceiver.deletedInstructions() </code> is invoked when the 
     *  related instruction is deleted or removed from this engine. 
     *
     *  @param  checkId the <code> Id </code> of the <code> Check </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> checkId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedInstructionsForCheck(org.osid.id.Id checkId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted instruction. <code> 
     *  InstructionReceiver.deletedInstructions() </code> is invoked when the 
     *  specified instruction is deleted or removed from this engine. 
     *
     *  @param  instructionId the <code> Id </code> of the <code> Instruction 
     *          </code> to monitor 
     *  @throws org.osid.NotFoundException an instruction was not found 
     *          identified by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> instructionId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedInstruction(org.osid.id.Id instructionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
