//
// org.osid.rules.check.InstructionQuery
//
//     The OSID Java specification for org.osid.rules.check.InstructionQuery.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.rules.check;


/**
 *  <p>This is the query for searching instructions. Each method match 
 *  specifies an <code> AND </code> term while multiple invocations of the 
 *  same method produce a nested <code> OR. </code> </p>
 */

public interface InstructionQuery
    extends org.osid.OsidRelationshipQuery,
            org.osid.OsidEnablerQuery {


    /**
     *  Sets the agenda <code> Id </code> for this query. 
     *
     *  @param  agendaId the agenda <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> agendaId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAgendaId(org.osid.id.Id agendaId, boolean match);


    /**
     *  Clears the agenda <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAgendaIdTerms();


    /**
     *  Tests if an <code> AgendaQuery </code> is available. 
     *
     *  @return <code> true </code> if an agenda query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAgendaQuery();


    /**
     *  Gets the query for an agenda. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the agenda query 
     *  @throws org.osid.UnimplementedException <code> supportsAgendaQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgendaQuery() </code> is <code> true. </code> 
     */

    public org.osid.rules.check.AgendaQuery getAgendaQuery();


    /**
     *  Clears the agenda query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAgendaTerms();


    /**
     *  Sets the check <code> Id </code> for this query. 
     *
     *  @param  checkId the check <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> checkId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCheckId(org.osid.id.Id checkId, boolean match);


    /**
     *  Clears the check <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCheckIdTerms();


    /**
     *  Tests if a <code> CheckQuery </code> is available. 
     *
     *  @return <code> true </code> if a check query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCheckQuery();


    /**
     *  Gets the query for a check. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the check query 
     *  @throws org.osid.UnimplementedException <code> supportsCheckQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCheckQuery() </code> is <code> true. </code> 
     */

    public org.osid.rules.check.CheckQuery getCheckQuery();


    /**
     *  Clears the check query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCheckTerms();


    /**
     *  Matches messages. 
     *
     *  @param  message text to match 
     *  @param  stringMatchType the string match type 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> message or 
     *          stringMatchType </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          supportsStringMatchType(stringMatchType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchMessage(String message, 
                             org.osid.type.Type stringMatchType, boolean match);


    /**
     *  Matches instructions that have any message. 
     *
     *  @param  match <code> true </code> to match instructions with any 
     *          message, <code> false </code> to match instructions with no 
     *          message 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyMessage(boolean match);


    /**
     *  Clears the message query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMessageTerms();


    /**
     *  Matches warning instructions. 
     *
     *  @param  match <code> true </code> to match warning instructions, 
     *          <code> false </code> to match hard error instructions 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchWarning(boolean match);


    /**
     *  Clears the warning query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearWarningTerms();


    /**
     *  Matches continue-on-fail instructions. 
     *
     *  @param  match <code> true </code> to match continue-on-fail 
     *          instructions, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchContinueOnFail(boolean match);


    /**
     *  Clears the continue-on-fail query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearContinueOnFailTerms();


    /**
     *  Sets the engine <code> Id </code> for this query to match instructions 
     *  assigned to engines. 
     *
     *  @param  engineId the engine <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> engineId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchEngineId(org.osid.id.Id engineId, boolean match);


    /**
     *  Clears the engine <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEngineIdTerms();


    /**
     *  Tests if a <code> EngineQuery </code> is available. 
     *
     *  @return <code> true </code> if an engine query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEngineQuery();


    /**
     *  Gets the query for an engine. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the engine query 
     *  @throws org.osid.UnimplementedException <code> supportsEngineQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEngineQuery() </code> is <code> true. </code> 
     */

    public org.osid.rules.EngineQuery getEngineQuery();


    /**
     *  Clears the engine query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearEngineTerms();


    /**
     *  Gets the instruction query record corresponding to the given <code> 
     *  Instruction </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  instructionRecordType an instruction record type 
     *  @return the instruction query record 
     *  @throws org.osid.NullArgumentException <code> instructionRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(instructionRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.records.InstructionQueryRecord getInstructionQueryRecord(org.osid.type.Type instructionRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
