//
// org.osid.rules.check.InstructionQuerySession
//
//     The OSID Java specification for org.osid.rules.check.InstructionQuerySession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.rules.check;


/**
 *  <p>This session provides methods for searching among <code> Instruction 
 *  </code> objects. The search query is constructed using the <code> 
 *  InstructionQuery. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated engine view: searches include instructions in engines 
 *      of which this engine is an ancestor in the engine hierarchy </li> 
 *      <li> isolated engine view: searches are restricted to instructions in 
 *      this engine </li> 
 *  </ul>
 *  
 *  
 *  <p> Instructions may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> 
 *  InstructionQuery. </code> </p>
 */

public interface InstructionQuerySession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Engine </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Engine Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getEngineId();


    /**
     *  Gets the <code> Engine </code> associated with this session. 
     *
     *  @return the engine 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.Engine getEngine()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Instruction </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if search methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSearchInstructions();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include instructions in engines which are children of this engine in 
     *  the engine hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedEngineView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this engine only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedEngineView();


    /**
     *  Gets an instruction query. 
     *
     *  @return the instruction query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.InstructionQuery getInstructionQuery();


    /**
     *  Gets a list of <code> Instructions </code> matching the given 
     *  instruction query. 
     *
     *  @param  instructionQuery the instruction query 
     *  @return the returned <code> InstructionList </code> 
     *  @throws org.osid.NullArgumentException <code> instructionQuery </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> instructionQuery </code> 
     *          is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.InstructionList getInstructionsByQuery(org.osid.rules.check.InstructionQuery instructionQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
