//
// org.osid.rules.check.InstructionSearchOrder
//
//     The OSID Java specification for org.osid.rules.check.InstructionSearchOrder.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.rules.check;


/**
 *  <p>An interface for specifying the ordering of search results. </p>
 */

public interface InstructionSearchOrder
    extends org.osid.OsidRelationshipSearchOrder,
            org.osid.OsidEnablerSearchOrder {


    /**
     *  Orders the results by agenda. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByAgenda(org.osid.SearchOrderStyle style);


    /**
     *  Tests if an agenda search order is available. 
     *
     *  @return <code> true </code> if an agenda search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAgendaSearchOrder();


    /**
     *  Gets the agenda search order. 
     *
     *  @return the agenda search order 
     *  @throws org.osid.IllegalStateException <code> 
     *          supportsAgendaSearchOrder() </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.AgendaSearchOrder getAgendaSearchOrder();


    /**
     *  Orders the results by check. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByCheck(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a check search order is available. 
     *
     *  @return <code> true </code> if a check search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCheckSearchOrder();


    /**
     *  Gets the check search order. 
     *
     *  @return the check search order 
     *  @throws org.osid.IllegalStateException <code> 
     *          supportsCheckSearchOrder() </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.CheckSearchOrder getCheckSearchOrder();


    /**
     *  Orders the results by message. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByMessage(org.osid.SearchOrderStyle style);


    /**
     *  Orders the results by the warning flag. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByWarning(org.osid.SearchOrderStyle style);


    /**
     *  Orders the results by the continue-on-fail flag. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByContinueOnFail(org.osid.SearchOrderStyle style);


    /**
     *  Gets the instruction search order record corresponding to the given 
     *  instruction record <code> Type. </code> Multiple retrievals return the 
     *  same underlying object. 
     *
     *  @param  instructionRecordType an instruction record type 
     *  @return the instruction search order record 
     *  @throws org.osid.NullArgumentException <code> instructionRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(instructionRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.records.InstructionSearchOrderRecord getInstructionSearchOrderRecord(org.osid.type.Type instructionRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
