//
// org.osid.rules.check.InstructionSmartEngineSession
//
//     The OSID Java specification for org.osid.rules.check.InstructionSmartEngineSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.rules.check;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. An <code> InstructionQuery </code> can be retrieved from this 
 *  session and engineped to this <code> Engine </code> to create a virtual 
 *  collection of <code> Instructions. </code> The instructions may be 
 *  sequenced using the <code> InstructionSearchOrder </code> from this 
 *  session. </p> 
 *  
 *  <p> This <code> Engine </code> has a default query that matches any 
 *  instruction and a default search order that specifies no sequencing. The 
 *  queries may be examined using an <code> InstructionQueryInspector. </code> 
 *  The query may be modified by converting the inspector back to an <code> 
 *  InstructionQuery. </code> </p>
 */

public interface InstructionSmartEngineSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Engine </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Engine Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getEngineId();


    /**
     *  Gets the <code> Engine </code> associated with this session. 
     *
     *  @return the engine 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.Engine getEngine()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart engines. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart engine management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartEngines();


    /**
     *  Gets an instruction query. 
     *
     *  @return the instruction query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.InstructionQuery getInstructionQuery();


    /**
     *  Gets an instruction search order. 
     *
     *  @return the instruction search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.InstructionSearchOrder getInstructionSearchOrder();


    /**
     *  Applies an instruction query to this engine. 
     *
     *  @param  instructionQuery the instruction query 
     *  @throws org.osid.NullArgumentException <code> instructionQuery </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> instructionQuery </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyInstructionQuery(org.osid.rules.check.InstructionQuery instructionQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an instruction query inspector for this engine. 
     *
     *  @return the instruction query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.InstructionQueryInspector inspecInstructionQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies an instruction search order to this engine. 
     *
     *  @param  instructionSearchOrder the instruction search order 
     *  @throws org.osid.NullArgumentException <code> instructionSearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> instructionSearchOrder 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyInstructionSequencing(org.osid.rules.check.InstructionSearchOrder instructionSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an instruction query from an inspector. 
     *
     *  @param  instructionQueryInspector an instruction query inspector 
     *  @return the instruction query 
     *  @throws org.osid.NullArgumentException <code> 
     *          instructionQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> instructionQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.rules.check.InstructionQuery getInstructionQueryFromInspector(org.osid.rules.check.InstructionQueryInspector instructionQueryInspector);
}
