//
// org.osid.rules.check.RulesCheckManager
//
//     The OSID Java specification for org.osid.rules.check.RulesCheckManager.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.rules.check;


/**
 *  <p>The check manager provides access to rules sessions and provides 
 *  interoperability tests for various aspects of this service. The sessions 
 *  included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> EvaluationSession: </code> a session for evaluating 
 *      agendas </li> 
 *      <li> <code> ProcessingSession: </code> a session for processing 
 *      agendas </li> 
 *      <li> <code> AgendaLookupSession: </code> a session to retrieve agendas 
 *      </li> 
 *      <li> <code> AgendaQuerySession: </code> a session to query for agendas 
 *      </li> 
 *      <li> <code> AgendaSearchSession: </code> a session to search for 
 *      agendas </li> 
 *      <li> <code> AgendaAdminSession: </code> a session to create and delete 
 *      agendas </li> 
 *      <li> <code> AgendaNotificationSession: </code> a session to receive 
 *      notifications pertaining to agenda changes </li> 
 *      <li> <code> AgendaEngineSession: </code> a session to looking mappings 
 *      of agendas to engines </li> 
 *      <li> <code> AgendaEngineAssignmentSession: </code> a session to manage 
 *      agenda to engine mappings </li> 
 *      <li> <code> AgendaEngineAssignmentSession: </code> a session to manage 
 *      dynamic engines of agendas </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> InstructionLookupSession: </code> a session to retrieve 
 *      instructions </li> 
 *      <li> <code> InstructionQuerySession: </code> a session to query for 
 *      instructions </li> 
 *      <li> <code> InstructionSearchSession: </code> a session to search for 
 *      instructions </li> 
 *      <li> <code> InstructionAdminSession: </code> a session to create and 
 *      delete instructions </li> 
 *      <li> <code> InstructionNotificationSession: </code> a session to 
 *      receive notifications pertaining to instruction changes </li> 
 *      <li> <code> InstructionEngineSession: </code> a session to look up 
 *      instruction engine mappings </li> 
 *      <li> <code> InstructionEngineAssignmentSession: </code> a session to 
 *      manage instruction to engine mappings </li> 
 *      <li> <code> InstructionSmartEngineSession: </code> a session to manage 
 *      dynamic engines of instructions </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> CheckLookupSession: </code> a session to retrieve checks 
 *      </li> 
 *      <li> <code> CheckQuerySession: </code> a session to query for checks 
 *      </li> 
 *      <li> <code> CheckSearchSession: </code> a session to search for checks 
 *      </li> 
 *      <li> <code> CheckAdminSession: </code> a session to create and delete 
 *      checks </li> 
 *      <li> <code> CheckNotificationSession: </code> a session to receive 
 *      notifications pertaining to check changes </li> 
 *      <li> <code> CheckEngineSession: </code> a session to look up check 
 *      engine mappings </li> 
 *      <li> <code> CheckEngineAssignmentSession: </code> a session to manage 
 *      check to engine mappings </li> 
 *      <li> <code> CheckSmartEngineSession: </code> a session to manage 
 *      dynamic engines of checks </li> 
 *  </ul>
 *  
 */

public interface RulesCheckManager
    extends org.osid.OsidManager,
            org.osid.rules.check.RulesCheckProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the evaluation 
     *  service to evaluate an agenda. 
     *
     *  @return an <code> EvaluationSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEvaluation() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEvaluation() </code> is <code> true. </code> 
     */

    public org.osid.rules.check.EvaluationSession getEvaluationSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the evaluation 
     *  service for the given engine. 
     *
     *  @param  engineId the <code> Id </code> of the engine 
     *  @return an <code> EvaluationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Engine </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> engineId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEvaluation() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEvaluation() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.rules.check.EvaluationSession getEvaluationSessionForEngine(org.osid.id.Id engineId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the processing 
     *  service to run checks. 
     *
     *  @return a <code> ProcessingSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProcessing() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessing() </code> is <code> true. </code> 
     */

    public org.osid.rules.check.ProcessingSession getProcessingSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the processing 
     *  service for the given engine. 
     *
     *  @param  engineId the <code> Id </code> of the engine 
     *  @return a <code> ProcessingSession </code> 
     *  @throws org.osid.NotFoundException no <code> Engine </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> engineId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProcessing() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessing() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.rules.check.ProcessingSession getProcessingSessionForEngine(org.osid.id.Id engineId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the agenda lookup 
     *  service. 
     *
     *  @return an <code> AgendaLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAgendaLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgendaLookup() </code> is <code> true. </code> 
     */

    public org.osid.rules.check.AgendaLookupSession getAgendaLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the agenda lookup 
     *  service for the given engine. 
     *
     *  @param  engineId the <code> Id </code> of the <code> Engine </code> 
     *  @return an <code> AgendaLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Engine </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> engineId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAgendaLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgendaLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.rules.check.AgendaLookupSession getAgendaLookupSessionForEngine(org.osid.id.Id engineId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the agenda query 
     *  service. 
     *
     *  @return an <code> AgendaQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAgendaQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgendaQuery() </code> is <code> true. </code> 
     */

    public org.osid.rules.check.AgendaQuerySession getAgendaQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the agenda query 
     *  service for the given engine. 
     *
     *  @param  engineId the <code> Id </code> of the <code> Engine </code> 
     *  @return an <code> AgendaQuerySession </code> 
     *  @throws org.osid.NotFoundException no engine found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> engineId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAgendaQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgendaQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.rules.check.AgendaQuerySession getAgendaQuerySessionForEngine(org.osid.id.Id engineId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the agenda search 
     *  service. 
     *
     *  @return an <code> AgendaSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAgendaSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgendaSearch() </code> is <code> true. </code> 
     */

    public org.osid.rules.check.AgendaSearchSession getAgendaSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the agenda search 
     *  service for the given engine. 
     *
     *  @param  engineId the <code> Id </code> of the <code> Engine </code> 
     *  @return an <code> AgendaSearchSession </code> 
     *  @throws org.osid.NotFoundException no engine found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> engineId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAgendaSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgendaSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.rules.check.AgendaSearchSession getAgendaSearchSessionForEngine(org.osid.id.Id engineId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the agenda 
     *  administration service. 
     *
     *  @return an <code> AgendaAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAgendaAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgendaAdmin() </code> is <code> true. </code> 
     */

    public org.osid.rules.check.AgendaAdminSession getAgendaAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the agenda 
     *  administration service for the given engine. 
     *
     *  @param  engineId the <code> Id </code> of the <code> Engine </code> 
     *  @return an <code> AgendaAdminSession </code> 
     *  @throws org.osid.NotFoundException no engine found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> engineId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAgendaAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgendaAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.rules.check.AgendaAdminSession getAgendaAdminSessionForEngine(org.osid.id.Id engineId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the agenda 
     *  notification service. 
     *
     *  @param  agendaReceiver the notification callback 
     *  @return an <code> AgendaNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> agendaReceiver </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAgendaNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgendaNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.rules.check.AgendaNotificationSession getAgendaNotificationSession(org.osid.rules.check.AgendaReceiver agendaReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the agenda 
     *  notification service for the given engine. 
     *
     *  @param  agendaReceiver the notification callback 
     *  @param  engineId the <code> Id </code> of the <code> Engine </code> 
     *  @return an <code> AgendaNotificationSession </code> 
     *  @throws org.osid.NotFoundException no engine found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> agendaReceiver </code> 
     *          or <code> engineId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAgendaNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgendaNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.rules.check.AgendaNotificationSession getAgendaNotificationSessionForEngine(org.osid.rules.check.AgendaReceiver agendaReceiver, 
                                                                                                org.osid.id.Id engineId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup agenda/engine mappings. 
     *
     *  @return an <code> AgendaEngineSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsAgendaEngine() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgendaEngine() </code> is <code> true. </code> 
     */

    public org.osid.rules.check.AgendaEngineSession getAgendaEngineSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning agendas 
     *  to engines. 
     *
     *  @return an <code> AgendaEngineAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAgendaEngineAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgendaEngineAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.rules.check.AgendaEngineAssignmentSession getAgendaEngineAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage agenda smart engines. 
     *
     *  @param  engineId the <code> Id </code> of the <code> Engine </code> 
     *  @return an <code> AgendaSmartEngineSession </code> 
     *  @throws org.osid.NotFoundException no <code> Engine </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> engineId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAgendaSmartEngine() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAgendaSmartEngine() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.rules.check.AgendaSmartEngineSession getAgendaSmartEngineSession(org.osid.id.Id engineId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the instruction 
     *  lookup service. 
     *
     *  @return an <code> InstructionLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInstructionLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInstructionLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.rules.check.InstructionLookupSession getInstructionLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the instruction 
     *  lookup service for the given engine. 
     *
     *  @param  engineId the <code> Id </code> of the engine 
     *  @return an <code> InstructionLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Engine </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> engineId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInstructionLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInstructionLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.rules.check.InstructionLookupSession getInstructionLookupSessionForEngine(org.osid.id.Id engineId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the instruction 
     *  query service. 
     *
     *  @return an <code> InstructionQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInstructionQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInstructionQuery() </code> is <code> true. </code> 
     */

    public org.osid.rules.check.InstructionQuerySession getInstructionQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the instruction 
     *  query service for the given engine. 
     *
     *  @param  engineId the <code> Id </code> of the <code> Engine </code> 
     *  @return an <code> InstructionQuerySession </code> 
     *  @throws org.osid.NotFoundException no engine found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> engineId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInstructionQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInstructionQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.rules.check.InstructionQuerySession getInstructionQuerySessionForEngine(org.osid.id.Id engineId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the instruction 
     *  search service. 
     *
     *  @return an <code> InstructionSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInstructionSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInstructionSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.rules.check.InstructionSearchSession getInstructionSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the instruction 
     *  search service for the given engine. 
     *
     *  @param  engineId the <code> Id </code> of the <code> Engine </code> 
     *  @return an <code> InstructionSearchSession </code> 
     *  @throws org.osid.NotFoundException no engine found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> engineId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInstructionSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInstructionSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.rules.check.InstructionSearchSession getInstructionSearchSessionForEngine(org.osid.id.Id engineId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the instruction 
     *  administration service. 
     *
     *  @return an <code> InstructionAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInstructionAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInstructionAdmin() </code> is <code> true. </code> 
     */

    public org.osid.rules.check.InstructionAdminSession getInstructionAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the instruction 
     *  administration service for the given engine. 
     *
     *  @param  engineId the <code> Id </code> of the <code> Engine </code> 
     *  @return an <code> InstructionAdminSession </code> 
     *  @throws org.osid.NotFoundException no engine found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> engineId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInstructionAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInstructionAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.rules.check.InstructionAdminSession getInstructionAdminSessionForEngine(org.osid.id.Id engineId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the instruction 
     *  notification service. 
     *
     *  @param  instructionReceiver the notification callback 
     *  @return an <code> InstructionNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> instructionReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInstructionNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInstructionNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.rules.check.InstructionNotificationSession getInstructionNotificationSession(org.osid.rules.check.InstructionReceiver instructionReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the instruction 
     *  notification service for the given engine. 
     *
     *  @param  instructionReceiver the notification callback 
     *  @param  engineId the <code> Id </code> of the <code> Engine </code> 
     *  @return an <code> InstructionNotificationSession </code> 
     *  @throws org.osid.NotFoundException no engine found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> instructionReceiver 
     *          </code> or <code> engineId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInstructionNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInstructionNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.rules.check.InstructionNotificationSession getInstructionNotificationSessionForEngine(org.osid.rules.check.InstructionReceiver instructionReceiver, 
                                                                                                          org.osid.id.Id engineId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup instruction/engine 
     *  checks. 
     *
     *  @return an <code> InstructionEngineSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInstructionEngine() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInstructionEngine() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.rules.check.InstructionEngineSession getInstructionEngineSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning 
     *  instructions to engines. 
     *
     *  @return an <code> InstructionEngineAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInstructionEngineAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInstructionEngineAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.rules.check.InstructionEngineAssignmentSession getInstructionEngineAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage locatin smart engines. 
     *
     *  @param  engineId the <code> Id </code> of the <code> Engine </code> 
     *  @return an <code> InstructionSmartEngineSession </code> 
     *  @throws org.osid.NotFoundException no engine found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> engineId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInstructionSmartEngine() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInstructionSmartEngine() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.rules.check.InstructionSmartEngineSession getInstructionSmartEngineSession(org.osid.id.Id engineId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the check lookup 
     *  service. 
     *
     *  @return a <code> CheckLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCheckLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCheckLookup() </code> is <code> true. </code> 
     */

    public org.osid.rules.check.CheckLookupSession getCheckLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the check lookup 
     *  service for the given engine. 
     *
     *  @param  engineId the <code> Id </code> of the <code> Engine </code> 
     *  @return a <code> CheckLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Engine </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> engineId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCheckLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCheckLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.rules.check.CheckLookupSession getCheckLookupSessionForEngine(org.osid.id.Id engineId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the check query 
     *  service. 
     *
     *  @return a <code> CheckQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCheckQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCheckQuery() </code> is <code> true. </code> 
     */

    public org.osid.rules.check.CheckQuerySession getCheckQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the check query 
     *  service for the given engine. 
     *
     *  @param  engineId the <code> Id </code> of the <code> Engine </code> 
     *  @return a <code> CCheckQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Engine </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> engineId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCheckQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCheckQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.rules.check.CheckQuerySession getCheckQuerySessionForEngine(org.osid.id.Id engineId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the check search 
     *  service. 
     *
     *  @return a <code> CheckSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCheckSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCheckSearch() </code> is <code> true. </code> 
     */

    public org.osid.rules.check.CheckSearchSession getCheckSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the check search 
     *  service for the given engine. 
     *
     *  @param  engineId the <code> Id </code> of the <code> Engine </code> 
     *  @return a <code> CheckSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Engine </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> engineId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCheckSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCheckSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.rules.check.CheckSearchSession getCheckSearchSessionForEngine(org.osid.id.Id engineId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the check 
     *  administrative service. 
     *
     *  @return a <code> CheckAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCheckAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCheckAdmin() </code> is <code> true. </code> 
     */

    public org.osid.rules.check.CheckAdminSession getCheckAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the check 
     *  administrative service for the given engine. 
     *
     *  @param  engineId the <code> Id </code> of the <code> Engine </code> 
     *  @return a <code> CheckAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Engine </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> engineId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCheckAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCheckAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.rules.check.CheckAdminSession getCheckAdminSessionForEngine(org.osid.id.Id engineId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the check 
     *  notification service. 
     *
     *  @param  checkReceiver the notification callback 
     *  @return a <code> CheckNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> checkReceiver </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCheckNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCheckNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.rules.check.CheckNotificationSession getCheckNotificationSession(org.osid.rules.check.CheckReceiver checkReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the check 
     *  notification service for the given engine. 
     *
     *  @param  checkReceiver the notification callback 
     *  @param  engineId the <code> Id </code> of the <code> Engine </code> 
     *  @return a <code> CheckNotificationSession </code> 
     *  @throws org.osid.NotFoundException no engine found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> checkReceiver </code> or 
     *          <code> engineId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCheckNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCheckNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.rules.check.CheckNotificationSession getCheckNotificationSessionForEngine(org.osid.rules.check.CheckReceiver checkReceiver, 
                                                                                              org.osid.id.Id engineId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup check/engine mappings. 
     *
     *  @return a <code> CheckEngineSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsCheckEngine() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCheckEngine() </code> is <code> true. </code> 
     */

    public org.osid.rules.check.CheckEngineSession getCheckEngineSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning 
     *  competencies to engines. 
     *
     *  @return a <code> CheckEngineAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCheckEngineAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCheckEngineAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.rules.check.CheckEngineAssignmentSession getCheckEngineAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage check smart engines. 
     *
     *  @param  engineId the <code> Id </code> of the <code> Engine </code> 
     *  @return a <code> CheckSmartEngineSession </code> 
     *  @throws org.osid.NotFoundException no <code> Engine </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> engineId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCheckSmartEngine() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCheckSmartEngine() </code> is <code> true. </code> 
     */

    public org.osid.rules.check.CheckSmartEngineSession getCheckSmartEngineSession(org.osid.id.Id engineId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;
}
