//
// org.osid.rules.check.RulesCheckProfile
//
//     The OSID Java specification for org.osid.rules.check.RulesCheckProfile.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.rules.check;


/**
 *  <p>The rules check profile describes the interoperability among rules 
 *  check services. </p>
 */

public interface RulesCheckProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any engine federation is exposed. Federation is exposed when 
     *  a specific engine may be identified, selected and used to create a 
     *  lookup or admin session. Federation is not exposed when a set of 
     *  engines appears as a single engine. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if an agenda evaluation service is supported for the current 
     *  agent. 
     *
     *  @return <code> true </code> if an evaluation service is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEvaluation();


    /**
     *  Tests if an agenda processing service is supported . 
     *
     *  @return <code> true </code> if a processing service is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcessing();


    /**
     *  Tests if looking up agendas is supported. 
     *
     *  @return <code> true </code> if agenda lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAgendaLookup();


    /**
     *  Tests if querying agendas is supported. 
     *
     *  @return <code> true </code> if agenda query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAgendaQuery();


    /**
     *  Tests if searching agendas is supported. 
     *
     *  @return <code> true </code> if agenda search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAgendaSearch();


    /**
     *  Tests if agenda administrative service is supported. 
     *
     *  @return <code> true </code> if agenda administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAgendaAdmin();


    /**
     *  Tests if an agenda notification service is supported. 
     *
     *  @return <code> true </code> if agenda notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAgendaNotification();


    /**
     *  Tests if an agenda engine lookup service is supported. 
     *
     *  @return <code> true </code> if an agenda engine lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAgendaEngine();


    /**
     *  Tests if an agenda engine service is supported. 
     *
     *  @return <code> true </code> if agenda to engine assignment service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAgendaEngineAssignment();


    /**
     *  Tests if an agenda smart engine lookup service is supported. 
     *
     *  @return <code> true </code> if an agenda smart engine service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAgendaSmartEngine();


    /**
     *  Tests if looking up instructions is supported. 
     *
     *  @return <code> true </code> if instruction lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInstructionLookup();


    /**
     *  Tests if querying instructions is supported. 
     *
     *  @return <code> true </code> if instruction query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInstructionQuery();


    /**
     *  Tests if searching instructions is supported. 
     *
     *  @return <code> true </code> if instruction search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInstructionSearch();


    /**
     *  Tests if instruction <code> </code> administrative service is 
     *  supported. 
     *
     *  @return <code> true </code> if instruction administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInstructionAdmin();


    /**
     *  Tests if an instruction <code> </code> notification service is 
     *  supported. 
     *
     *  @return <code> true </code> if instruction notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInstructionNotification();


    /**
     *  Tests if an instruction engine lookup service is supported. 
     *
     *  @return <code> true </code> if an instruction engine lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInstructionEngine();


    /**
     *  Tests if an instruction engine assignment service is supported. 
     *
     *  @return <code> true </code> if an instruction to engine assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInstructionEngineAssignment();


    /**
     *  Tests if an instruction smart engine service is supported. 
     *
     *  @return <code> true </code> if an instruction smart engine service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInstructionSmartEngine();


    /**
     *  Tests if looking up checks is supported. 
     *
     *  @return <code> true </code> if check lookup is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCheckLookup();


    /**
     *  Tests if querying checks is supported. 
     *
     *  @return <code> true </code> if check query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCheckQuery();


    /**
     *  Tests if searching checks is supported. 
     *
     *  @return <code> true </code> if check search is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCheckSearch();


    /**
     *  Tests if check administrative service is supported. 
     *
     *  @return <code> true </code> if check administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCheckAdmin();


    /**
     *  Tests if a check notification service is supported. 
     *
     *  @return <code> true </code> if check notification is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCheckNotification();


    /**
     *  Tests if a check engine lookup service is supported. 
     *
     *  @return <code> true </code> if a check engine lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCheckEngine();


    /**
     *  Tests if a check engine service is supported. 
     *
     *  @return <code> true </code> if check to engine assignment service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCheckEngineAssignment();


    /**
     *  Tests if a check smart engine lookup service is supported. 
     *
     *  @return <code> true </code> if a check smart engine service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCheckSmartEngine();


    /**
     *  Gets the supported <code> Agenda </code> record types. 
     *
     *  @return a list containing the supported <code> Agenda </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAgendaRecordTypes();


    /**
     *  Tests if the given <code> Agenda </code> record type is supported. 
     *
     *  @param  agendaRecordType a <code> Type </code> indicating an <code> 
     *          Agenda </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> agendaRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAgendaRecordType(org.osid.type.Type agendaRecordType);


    /**
     *  Gets the supported <code> Agenda </code> search record types. 
     *
     *  @return a list containing the supported <code> Agenda </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAgendaSearchRecordTypes();


    /**
     *  Tests if the given <code> Agenda </code> search record type is 
     *  supported. 
     *
     *  @param  agendaSearchRecordType a <code> Type </code> indicating an 
     *          <code> Agenda </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> agendaSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAgendaSearchRecordType(org.osid.type.Type agendaSearchRecordType);


    /**
     *  Gets the supported <code> Instruction </code> record types. 
     *
     *  @return a list containing the supported <code> Instruction </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getInstructionRecordTypes();


    /**
     *  Tests if the given <code> Instruction </code> record type is 
     *  supported. 
     *
     *  @param  instructionRecordType a <code> Type </code> indicating an 
     *          <code> Instruction </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> instructionRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInstructionRecordType(org.osid.type.Type instructionRecordType);


    /**
     *  Gets the supported <code> Instruction </code> search types. 
     *
     *  @return a list containing the supported <code> Instruction </code> 
     *          search types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getInstructionSearchRecordTypes();


    /**
     *  Tests if the given <code> Instruction </code> search type is 
     *  supported. 
     *
     *  @param  instructionSearchRecordType a <code> Type </code> indicating 
     *          an <code> Instruction </code> search type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          instructionSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInstructionSearchRecordType(org.osid.type.Type instructionSearchRecordType);


    /**
     *  Gets the supported <code> Check </code> record types. 
     *
     *  @return a list containing the supported <code> Check </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCheckRecordTypes();


    /**
     *  Tests if the given <code> Check </code> record type is supported. 
     *
     *  @param  checkRecordType a <code> Type </code> indicating a <code> 
     *          Check </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> checkRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCheckRecordType(org.osid.type.Type checkRecordType);


    /**
     *  Gets the supported <code> Check </code> search record types. 
     *
     *  @return a list containing the supported <code> Check </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCheckSearchRecordTypes();


    /**
     *  Tests if the given <code> Check </code> search record type is 
     *  supported. 
     *
     *  @param  checkSearchRecordType a <code> Type </code> indicating a 
     *          <code> Check </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> checkSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCheckSearchRecordType(org.osid.type.Type checkSearchRecordType);


    /**
     *  Gets the supported <code> CheckResult </code> record types. 
     *
     *  @return a list containing the supported <code> CheckResult </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getCheckResultRecordTypes();


    /**
     *  Tests if the given <code> CheckResult </code> record type is 
     *  supported. 
     *
     *  @param  checkResultRecordType a <code> Type </code> indicating a 
     *          <code> CheckResult </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> checkResultRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCheckResultRecordType(org.osid.type.Type checkResultRecordType);
}
