/**
 * <p>The Open Service Interface Definitions for the org.osid.rules.check
 * service.</p>
 * 
 * <p>The Rules Check OSID provides a means for managing and evaluating a 
 * series of <code> Checks </code> that comprise a business process. Inspired 
 * by the fine work at Kuali Student, this service manages the go/no-go 
 * business requirements that are often used within other OSID Providers. </p> 
 * <h4> Checks </h4> 
 * 
 * <p> A <code> Check </code> is an <code> OsidRule </code> that is to be 
 * evaluated. <code> Check </code> defines a few simple rules that can be 
 * managed directly. </p> 
 * 
 * <ul>
 *     <li> time based check using dates </li> 
 *     <li> time based check using <code> Events </code> </li> 
 *     <li> time based checks using <code> CyclicEvents </code> </li> 
 *     <li> checks for Blocks in the Hold OSID </li> 
 *     <li> checks for Audits in the Inquiry OSID </li> 
 *     <li> checks for other processes </li> 
 * </ul>
 * 
 * 
 * <p> Other kinds of checks can be defined using the <code> CheckRecord 
 * </code> or by referencing an external <code> Rule </code> . </p> 
 * <h4> Agendas </h4> 
 * 
 * <p> An <code> Agenda </code> represents a process and has a related set of 
 * <code> Checks </code> to perform. OSID Consumers can simply reference an 
 * <code> Agenda </code> <code> Id </code> . </p> 
 * <h4> Instructions </h4> 
 * 
 * <p> <code> Instructions </code> are <code> OsidRelationships </code> used 
 * to relate a <code> Check </code> to an <code> Agenda. </code> <code> 
 * Checks, </code> once defined, can be reused among multiple <code> Agendas. 
 * </code> The <code> Instruction </code> provides the relationship along with 
 * information about how the <code> Check </code> is to be applied such as 
 * sequencing managed in the <code> InstructionAdminSession, </code> failed 
 * check messages, and processing control. </p> 
 * 
 * <p> <code> Instructions </code> are also <code> OsidEnablers </code> 
 * managing the applicability of a Check. The <code> Instruction </code> may 
 * apply a Check at certain times, to certain <code> Demographics </code> of 
 * the target object <code> , </code> or based on a custom <code> Rule </code> 
 * . </p> 
 * <h4> Evaluation </h4> 
 * 
 * <p> In addition to retrieving all the <code> Instructions </code> for an 
 * <code> Agenda </code> in the <code> InstructionLookupSession, </code> the 
 * Rules Check OSID provides two additional services. </p> 
 * 
 * <ul>
 *     <li> <code> ProcessingSession: </code> Retrieves a pertinent set of 
 *     <code> Instructions </code> filtering out those <code> Instructions 
 *     </code> not applicable to the target <code> Demographic </code> or 
 *     date. </li> 
 *     <li> <code> EvaluationSession: </code> Performs the evaluation of 
 *     applicable <code> Checks </code> in an Agenda and returns a set of 
 *     statuses and messages. The eveluation accepts a <code> Condition 
 *     </code> to supply additional data required by he <code> Check </code> 
 *     as specified by the <code> Check </code> <code> Rule. </code> </li> 
 * </ul>
 * 
 * <h4> Engine Cataloging </h4> 
 * 
 * <p> <code> Checks, </code> <code> Instructions, </code> and <code> Agendas 
 * </code> are organized into federatable <code> OsidCatalogs </code> called 
 * <code> Engines. </code> </p>
 * 
 * <br/><hr/><br/>
 * 
 * <p>Copyright &copy; 2011 Ingenescus. All Rights Reserved. </p>
 * 
 * <p>This Work is being provided by the copyright holder(s) subject to the 
 * following license. By obtaining, using and/or copying this Work, you agree 
 * that you have read, understand, and will comply with the following terms 
 * and conditions. </p> 
 * 
 * <p> Permission to use, copy and distribute unmodified versions of this 
 * Work, for any purpose, without fee or royalty is hereby granted, provided 
 * that you include the above copyright notices and the terms of this license 
 * on ALL copies of the Work or portions thereof. </p> 
 * 
 * <p> You may modify or create Derivatives of this Work only for your 
 * internal purposes. You shall not distribute or transfer any such Derivative 
 * of this Work to any location or to any third party. For the purposes of 
 * this license, "Derivative" shall mean any derivative of the Work as defined 
 * in the United States Copyright Act of 1976, such as a translation or 
 * modification. </p> 
 * 
 * <p> This Work and the information contained herein is provided on an "AS 
 * IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT 
 * NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR 
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT 
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN 
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN 
 * CONNECTION WITH THE WORK OR THE USE OR OTHER DEALINGS IN THE WORK. </p> 
 * 
 * <p> The export of software employing encryption technology may require a 
 * specific license from the United States Government. It is the 
 * responsibility of any person or organization contemplating export to obtain 
 * such a license before exporting this Work. </p>
 */

package org.osid.rules.check;
