//
// org.osid.search.EngineQuery
//
//     The OSID Java specification for org.osid.search.EngineQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.search;


/**
 *  <p>This is the query for searching for engines. Each method specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface EngineQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the engine <code> Id </code> for this query to match engines that 
     *  have the specified engine as an ancestor. 
     *
     *  @param  engineId an engine <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for negative match 
     *  @throws org.osid.NullArgumentException <code> engineId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorEngineId(org.osid.id.Id engineId, boolean match);


    /**
     *  Clears all ancestor engine <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorEngineIdTerms();


    /**
     *  Tests if an <code> EngineQuery </code> is available. 
     *
     *  @return <code> true </code> if an engine query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorEngineQuery();


    /**
     *  Gets the query for an engine. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the engine query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorEngineQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorEngineQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.search.EngineQuery getAncestorEngineQuery();


    /**
     *  Matches engines with any ancestor. 
     *
     *  @param  match <code> true </code> to match engine with any ancestor, 
     *          <code> false </code> to match root engines 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorEngine(boolean match);


    /**
     *  Clears all ancestor engine terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorEngineTerms();


    /**
     *  Sets the engine <code> Id </code> for this query to match engines that 
     *  have the specified engine as a descendant. 
     *
     *  @param  engineId an engine <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for negative match 
     *  @throws org.osid.NullArgumentException <code> engineId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantEngineId(org.osid.id.Id engineId, boolean match);


    /**
     *  Clears all descendant engine <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantEngineIdTerms();


    /**
     *  Tests if an <code> EngineQuery </code> is available. 
     *
     *  @return <code> true </code> if an engine query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantEngineQuery();


    /**
     *  Gets the query for an engine. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the engine query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantEngineQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantEngineQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.search.EngineQuery getDescendantEngineQuery();


    /**
     *  Matches engines with any descendant. 
     *
     *  @param  match <code> true </code> to match engine with any descendant, 
     *          <code> false </code> to match leaf engines 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantEngine(boolean match);


    /**
     *  Clears all descendant engine terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantEngineTerms();


    /**
     *  Gets the engine query record corresponding to the given <code> Engine 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested boolean <code> OR </code> term. 
     *
     *  @param  engineRecordType an engine record type 
     *  @return the engine query record 
     *  @throws org.osid.NullArgumentException <code> engineRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(engineRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.search.records.EngineQueryRecord getEngineQueryRecord(org.osid.type.Type engineRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
