//
// org.osid.sequencing.AntimatroidQuery
//
//     The OSID Java specification for org.osid.sequencing.AntimatroidQuery.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INPUT OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.sequencing;


/**
 *  <p>This is the query for searching antimatroids. Each method match 
 *  specifies an <code> AND </code> term while multiple invocations of the 
 *  same method produce a nested <code> OR. </code> </p>
 */

public interface AntimatroidQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the chain <code> Id </code> for this query. 
     *
     *  @param  chainId the chain <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> chainId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchChainId(org.osid.id.Id chainId, boolean match);


    /**
     *  Clears the chain <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearChainIdTerms();


    /**
     *  Tests if a <code> ChainQuery </code> is available. 
     *
     *  @return <code> true </code> if an input query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInputQuery();


    /**
     *  Gets the query for a chain. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the chain query 
     *  @throws org.osid.UnimplementedException <code> supportsChainQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsChainQuery() </code> is <code> true. </code> 
     */

    public org.osid.sequencing.ChainQuery getChainQuery();


    /**
     *  Matches action groups with any chain. 
     *
     *  @param  match <code> true </code> to match antimatroids with any 
     *          chain, <code> false </code> to match antimatroids with no 
     *          chains 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyChain(boolean match);


    /**
     *  Clears the chain query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearChainTerms();


    /**
     *  Sets the antimatroid <code> Id </code> for this query to match 
     *  antimatroids that have the specified antimatroid as an ancestor. 
     *
     *  @param  antimatroidId an antimatroid <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for negative match 
     *  @throws org.osid.NullArgumentException <code> antimatroidId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorAntimatroidId(org.osid.id.Id antimatroidId, 
                                           boolean match);


    /**
     *  Clears the ancestor antimatroid <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorAntimatroidIdTerms();


    /**
     *  Tests if an <code> AntimatroidQuery </code> is available. 
     *
     *  @return <code> true </code> if an antimatroid query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorAntimatroidQuery();


    /**
     *  Gets the query for an antimatroid. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the antimatroid query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorAntimatroidQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorAntimatroidQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.sequencing.AntimatroidQuery getAncestorAntimatroidQuery();


    /**
     *  Matches antimatroids with any ancestor. 
     *
     *  @param  match <code> true </code> to match antimatroids with any 
     *          ancestor, <code> false </code> to match root antimatroids 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorAntimatroid(boolean match);


    /**
     *  Clears the ancestor antimatroid query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorAntimatroidTerms();


    /**
     *  Sets the antimatroid <code> Id </code> for this query to match 
     *  antimatroids that have the specified antimatroid as a descendant. 
     *
     *  @param  antimatroidId an antimatroid <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for negative match 
     *  @throws org.osid.NullArgumentException <code> antimatroidId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantAntimatroidId(org.osid.id.Id antimatroidId, 
                                             boolean match);


    /**
     *  Clears the descendant antimatroid <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantAntimatroidIdTerms();


    /**
     *  Tests if an <code> AntimatroidQuery </code> is available. 
     *
     *  @return <code> true </code> if an antimatroid query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantAntimatroidQuery();


    /**
     *  Gets the query for an antimatroid/ Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the antimatroid query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantAntimatroidQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantAntimatroidQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.sequencing.AntimatroidQuery getDescendantAntimatroidQuery();


    /**
     *  Matches antimatroids with any descendant. 
     *
     *  @param  match <code> true </code> to match antimatroids with any 
     *          descendant, <code> false </code> to match leaf antimatroids 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantAntimatroid(boolean match);


    /**
     *  Clears the descendant antimatroid query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantAntimatroidTerms();


    /**
     *  Gets the antimatroid query record corresponding to the given <code> 
     *  Antimatroid </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  antimatroidRecordType an antimatroid record type 
     *  @return the antimatroid query record 
     *  @throws org.osid.NullArgumentException <code> antimatroidRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(antimatroidRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.sequencing.records.AntimatroidQueryRecord getAntimatroidQueryRecord(org.osid.type.Type antimatroidRecordType)
        throws org.osid.OperationFailedException;
}
