//
// org.osid.sequencing.ChainQuery
//
//     The OSID Java specification for org.osid.sequencing.ChainQuery.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INPUT OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.sequencing;


/**
 *  <p>This is the query for searching chains. Each method match specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface ChainQuery
    extends org.osid.OsidObjectQuery {


    /**
     *  Matches fifo chains. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchFifo(boolean match);


    /**
     *  Clears the fifo query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearFifoTerms();


    /**
     *  Sets the element <code> Id </code> for this query. 
     *
     *  @param  elementId the element <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> elementId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchElement(org.osid.id.Id elementId, boolean match);


    /**
     *  Matches chains with any element. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyElement(boolean match);


    /**
     *  Clears the element query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearElementTerms();


    /**
     *  Sets the action group <code> Id </code> for this query to match 
     *  sequencinglers assigned to action groups. 
     *
     *  @param  actionGroupId the action group <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> actionGroupId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAntimatroidId(org.osid.id.Id actionGroupId, boolean match);


    /**
     *  Clears the antimatroid <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAntimatroidIdTerms();


    /**
     *  Tests if an <code> AntimatroidQuery </code> is available. 
     *
     *  @return <code> true </code> if an antimatroid query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAntimatroidQuery();


    /**
     *  Gets the query for an antimatroid. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the antimatroid query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAntimatroidQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAntimatroidQuery() </code> is <code> true. </code> 
     */

    public org.osid.sequencing.AntimatroidQuery getAntimatroidQuery();


    /**
     *  Clears the antimatroid query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAntimatroidTerms();


    /**
     *  Gets the query record corresponding to the given <code> Chain </code> 
     *  record <code> Type. </code> Multiple record retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @param  chainRecordType a chain record type 
     *  @return the chain query record 
     *  @throws org.osid.NullArgumentException <code> chainRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(chainRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.sequencing.records.ChainQueryRecord getChainQueryRecord(org.osid.type.Type chainRecordType)
        throws org.osid.OperationFailedException;
}
