//
// org.osid.sequencing.ElementAdminSession
//
//     The OSID Java specification for org.osid.sequencing.ElementAdminSession.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INPUT OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.sequencing;


/**
 *  <p>This session provides methods to add and remove elements from a chain. 
 *  </p>
 */

public interface ElementAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Antimatroid </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Antimatroid Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAntimatroidId();


    /**
     *  Gets the <code> Antimatroid </code> associated with this session. 
     *
     *  @return the antimatroid 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.sequencing.Antimatroid getAntimatroid()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can add and remove eleemnts to a chain. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known performing any update will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer these operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if managing elements is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageElements();


    /**
     *  Adds an element to a chain, 
     *
     *  @param  chainId the <code> Id </code> of the chain 
     *  @param  id the <code> Id </code> of the element to add 
     *  @throws org.osid.AlreadyExistsException <code> id </code> already in 
     *          <code> chainId </code> 
     *  @throws org.osid.NotFoundException <code> chainId </code> or <code> id 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> chainId </code> or 
     *          <code> id </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void addElement(org.osid.id.Id chainId, org.osid.id.Id id)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds a list of ordered elements to a chain. 
     *
     *  @param  chainId the <code> Id </code> of the chain 
     *  @param  ids the <code> Ids </code> of the elements to add 
     *  @throws org.osid.AlreadyExistsException an <code> id </code> already 
     *          in <code> chainId </code> 
     *  @throws org.osid.NotFoundException <code> chainId </code> or an <code> 
     *          id </code> not found 
     *  @throws org.osid.NullArgumentException <code> chainIds </code> or 
     *          <code> id </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void addElements(org.osid.id.Id chainId, org.osid.id.IdList ids)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an element from a chain. 
     *
     *  @param  chainId the <code> Id </code> of the chain 
     *  @param  id the <code> Id </code> of the element to remove 
     *  @throws org.osid.NotFoundException <code> chainId </code> or <code> id 
     *          </code> not found, or <code> id </code> is not in <code> 
     *          chainId </code> 
     *  @throws org.osid.NullArgumentException <code> chainId </code> or 
     *          <code> id </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void removeElement(org.osid.id.Id chainId, org.osid.id.Id id)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
