//
// org.osid.sequencing.SequencingManager
//
//     The OSID Java specification for org.osid.sequencing.SequencingManager.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INPUT OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.sequencing;


/**
 *  <p>The sequencing manager provides access to sequencing sessions and 
 *  provides interoperability tests for various aspects of this service. The 
 *  sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> ElementLookupSession </code> : a session for retrieving 
 *      elements in a chain </li> 
 *      <li> <code> ElementAdminSession </code> : a session for managing 
 *      elements in a chain </li> 
 *      <li> <code> SequencingSession </code> : a session for sequencing 
 *      elements in a chain </li> 
 *      <li> <code> ChainLookupSession: </code> a session to retrieve chains 
 *      </li> 
 *      <li> <code> ChainQuerySession: </code> a session to query for chains 
 *      </li> 
 *      <li> <code> ChainSearchSession: </code> a session to search for chains 
 *      </li> 
 *      <li> <code> ChainAdminSession: </code> a session to create and delete 
 *      chains </li> 
 *      <li> <code> ChainNotificationSession: </code> a session to receive 
 *      notifications pertaining to chain changes </li> 
 *      <li> <code> ChainAntimatroidsSession: </code> a session to look up 
 *      chain antimatroids mappings </li> 
 *      <li> <code> ChainAntimatroidAssignmentSession: </code> a session to 
 *      manage chain to antimatroid mappings </li> 
 *      <li> <code> ChainSmartAntimatroidSession: </code> a session to manage 
 *      dynamic antimatroids of chains </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> AntimatroidLookupSession: </code> a session to retrieve 
 *      antimatroids </li> 
 *      <li> <code> AntimatroidQuerySession: </code> a session to search for 
 *      antimatroids </li> 
 *      <li> <code> AntimatroidSearchSession: </code> a session to search for 
 *      antimatroids </li> 
 *      <li> <code> AntimatroidAdminSession: </code> a session to create and 
 *      delete antimatroids </li> 
 *      <li> <code> AntimatroidNotificationSession: </code> a session to 
 *      receive notifications pertaining to antimatroid changes </li> 
 *      <li> <code> AntimatroidHierarchySession: </code> a session to traverse 
 *      a hierarchy of antimatroid </li> 
 *      <li> <code> AntimatroidHierarchyDesignSession: </code> a session to 
 *      manage an antimatroid hierarchy </li> 
 *  </ul>
 *  
 */

public interface SequencingManager
    extends org.osid.OsidManager,
            org.osid.sequencing.SequencingProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the element lookup 
     *  service. 
     *
     *  @return an <code> ElementLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsElementLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsElementLookup() </code> is <code> true. </code> 
     */

    public org.osid.sequencing.ElementLookupSession getElementLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the element lookup 
     *  service for the given antimatroid. 
     *
     *  @param  antimatroidId the <code> Id </code> of the antimatroid 
     *  @return an <code> ElementLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Antimatroid </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> antimatroidId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsElementLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsElementLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.sequencing.ElementLookupSession getElementLookupSessionForAntimatroid(org.osid.id.Id antimatroidId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the element admin 
     *  service. 
     *
     *  @return an <code> ElementAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsElementAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsElementAdmin() </code> is <code> true. </code> 
     */

    public org.osid.sequencing.ElementAdminSession getElementAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the element admin 
     *  service for the given antimatroid. 
     *
     *  @param  antimatroidId the <code> Id </code> of the antimatroid 
     *  @return an <code> ElementAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Antimatroid </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> antimatroidId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsElementAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsElementAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.sequencing.ElementAdminSession getElementAdminSessionForAntimatroid(org.osid.id.Id antimatroidId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the element 
     *  sequencing service. 
     *
     *  @return a <code> SequencingSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsSequencingn() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSequencing() </code> is <code> true. </code> 
     */

    public org.osid.sequencing.SequencingSession getSequencingSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the element 
     *  sequencing service for the given antimatroid. 
     *
     *  @param  antimatroidId the <code> Id </code> of the antimatroid 
     *  @return a <code> SequencingSession </code> 
     *  @throws org.osid.NotFoundException no <code> Antimatroid </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> antimatroidId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsSequencing() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSequencing() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.sequencing.SequencingSession getSequencingSessionForAntimatroid(org.osid.id.Id antimatroidId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the chain lookup 
     *  service. 
     *
     *  @return a <code> ChainLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsChainLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsChainLookup() </code> is <code> true. </code> 
     */

    public org.osid.sequencing.ChainLookupSession getChainLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the chain lookup 
     *  service for the given antimatroid. 
     *
     *  @param  antimatroidId the <code> Id </code> of the antimatroid 
     *  @return a <code> ChainLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Antimatroid </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> antimatroidId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsChainLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsChainLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.sequencing.ChainLookupSession getChainLookupSessionForAntimatroid(org.osid.id.Id antimatroidId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the chain query 
     *  service. 
     *
     *  @return a <code> ChainQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsChainQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsChainQuery() </code> is <code> true. </code> 
     */

    public org.osid.sequencing.ChainQuerySession getChainQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the chain query 
     *  service for the given antimatroid. 
     *
     *  @param  antimatroidId the <code> Id </code> of the <code> Antimatroid 
     *          </code> 
     *  @return a <code> ChainQuerySession </code> 
     *  @throws org.osid.NotFoundException no antimatroid found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> antimatroidId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsChainQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsChainQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.sequencing.ChainQuerySession getChainQuerySessionForAntimatroid(org.osid.id.Id antimatroidId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the chain search 
     *  service. 
     *
     *  @return a <code> ChainSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsChainSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsChainSearch() </code> is <code> true. </code> 
     */

    public org.osid.sequencing.ChainSearchSession getChainSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the chain search 
     *  service for the given antimatroid. 
     *
     *  @param  antimatroidId the <code> Id </code> of the <code> Antimatroid 
     *          </code> 
     *  @return a <code> ChainSearchSession </code> 
     *  @throws org.osid.NotFoundException no antimatroid found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> antimatroidId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsChainSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsChainSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.sequencing.ChainSearchSession getChainSearchSessionForAntimatroid(org.osid.id.Id antimatroidId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the chain 
     *  administration service. 
     *
     *  @return a <code> ChainAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsChainAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsChainAdmin() </code> is <code> true. </code> 
     */

    public org.osid.sequencing.ChainAdminSession getChainAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the chain 
     *  administration service for the given antimatroid. 
     *
     *  @param  antimatroidId the <code> Id </code> of the <code> Dostributor 
     *          </code> 
     *  @return a <code> ChainAdminSession </code> 
     *  @throws org.osid.NotFoundException no antimatroid found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> antimatroidId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsChainAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsChainAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.sequencing.ChainAdminSession getChainAdminSessionForInput(org.osid.id.Id antimatroidId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the chain 
     *  notification service. 
     *
     *  @param  chainReceiver the notification callback 
     *  @return a <code> ChainNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> chainReceiver </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsChainNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsChainNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.sequencing.ChainNotificationSession getChainNotificationSession(org.osid.sequencing.ChainReceiver chainReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the chain 
     *  notification service for the given antimatroid. 
     *
     *  @param  chainReceiver the notification callback 
     *  @param  antimatroidId the <code> Id </code> of the <code> Antimatroid 
     *          </code> 
     *  @return a <code> ChainNotificationSession </code> 
     *  @throws org.osid.NotFoundException no antimatroid found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> chainReceiver </code> or 
     *          <code> antimatroidId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsChainNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsChainNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.sequencing.ChainNotificationSession getChainNotificationSessionForAntimatroid(org.osid.sequencing.ChainReceiver chainReceiver, 
                                                                                                  org.osid.id.Id antimatroidId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup chain/antimatroid 
     *  mappings. 
     *
     *  @return a <code> ChainAntimatroidSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsChainAntimatroid() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsChainAntimatroid() </code> is <code> true. </code> 
     */

    public org.osid.sequencing.ChainAntimatroidSession getChainAntimatroidSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning chains 
     *  to antimatroids. 
     *
     *  @return a <code> ChainAntimatroidAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsChainAntimatroidAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsChainAntimatroidAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.sequencing.ChainAntimatroidAssignmentSession getChainAntimatroidAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage locatin smart 
     *  antimatroids. 
     *
     *  @param  antimatroidId the <code> Id </code> of the <code> Antimatroid 
     *          </code> 
     *  @return a <code> ChainSmartAntimatroidSession </code> 
     *  @throws org.osid.NotFoundException no antimatroid found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> antimatroidId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsChainSmartAntimatroid() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsChainSmartAntimatroid() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.sequencing.ChainSmartAntimatroidSession getChainSmartAntimatroidSession(org.osid.id.Id antimatroidId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the antimatroid 
     *  lookup service. 
     *
     *  @return a <code> AntimatroidLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAntimatroidLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAntimatroidLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.sequencing.AntimatroidLookupSession getAntimatroidLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the antimatroid 
     *  query service. 
     *
     *  @return an <code> AntimatroidQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAntimatroidQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAntimatroidQuery() </code> is <code> true. </code> 
     */

    public org.osid.sequencing.AntimatroidQuerySession getAntimatroidQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the antimatroid 
     *  search service. 
     *
     *  @return an <code> AntimatroidSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAntimatroidSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAntimatroidSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.sequencing.AntimatroidSearchSession getAntimatroidSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the antimatroid 
     *  administrative service. 
     *
     *  @return an <code> AntimatroidAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAntimatroidAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAntimatroidAdmin() </code> is <code> true. </code> 
     */

    public org.osid.sequencing.AntimatroidAdminSession getAntimatroidAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the antimatroid 
     *  notification service. 
     *
     *  @param  antimatroidReceiver the notification callback 
     *  @return an <code> AntimatroidNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> antimatroidReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAntimatroidNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAntimatroidNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.sequencing.AntimatroidNotificationSession getAntimatroidNotificationSession(org.osid.sequencing.AntimatroidReceiver antimatroidReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the antimatroid 
     *  hierarchy service. 
     *
     *  @return an <code> AntimatroidHierarchySession </code> for antimatroids 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAntimatroidHierarchy() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAntimatroidHierarchy() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.sequencing.AntimatroidHierarchySession getAntimatroidHierarchySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the antimatroid 
     *  hierarchy design service. 
     *
     *  @return an <code> HierarchyDesignSession </code> for antimatroids 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAntimatroidHierarchyDesign() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAntimatroidHierarchyDesign() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.sequencing.AntimatroidHierarchyDesignSession getAntimatroidHierarchyDesignSession()
        throws org.osid.OperationFailedException;
}
