//
// org.osid.sequencing.SequencingProfile
//
//     The OSID Java specification for org.osid.sequencing.SequencingProfile.
//
// Copyright (C) 2013 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN INPUT OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.sequencing;


/**
 *  <p>The sequencing profile describes the interoperability among sequencing 
 *  services. </p>
 */

public interface SequencingProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any action group federation is exposed. Federation is exposed 
     *  when a specific action group may be identified, selected and used to 
     *  create a lookup or admin session. Federation is not exposed when a set 
     *  of action groups appears as a single action group. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if looking up elements is supported. 
     *
     *  @return <code> true </code> if element lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsElementLookup();


    /**
     *  Tests if managing elements is supported. 
     *
     *  @return <code> true </code> if element management is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsElementAdmin();


    /**
     *  Tests if sequencing elements is supported. 
     *
     *  @return <code> true </code> if element sequencing is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSequencing();


    /**
     *  Tests if looking up chains is supported. 
     *
     *  @return <code> true </code> if chain lookup is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsChainLookup();


    /**
     *  Tests if querying chains is supported. 
     *
     *  @return <code> true </code> if chain query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsChainQuery();


    /**
     *  Tests if searching chains is supported. 
     *
     *  @return <code> true </code> if chain search is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsChainSearch();


    /**
     *  Tests if chain <code> </code> administrative service is supported. 
     *
     *  @return <code> true </code> if chain administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsChainAdmin();


    /**
     *  Tests if a chain <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if chain notification is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsChainNotification();


    /**
     *  Tests if a chain antimatroid lookup service is supported. 
     *
     *  @return <code> true </code> if a chain antimatroid lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsChainAntimatroid();


    /**
     *  Tests if a chain antimatroid assignment service is supported. 
     *
     *  @return <code> true </code> if a chain to antimatroid assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsChainAntimatroidAssignment();


    /**
     *  Tests if a chain smart antimatroid service is supported. 
     *
     *  @return <code> true </code> if a chain smart antimatroid service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsChainSmartAntimatroid();


    /**
     *  Tests if looking up antimatroids is supported. 
     *
     *  @return <code> true </code> if antimatroid lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAntimatroidLookup();


    /**
     *  Tests if querying antimatroids is supported. 
     *
     *  @return <code> true </code> if an antimatroid query service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAntimatroidQuery();


    /**
     *  Tests if searching antimatroids is supported. 
     *
     *  @return <code> true </code> if antimatroid search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAntimatroidSearch();


    /**
     *  Tests if antimatroid administrative service is supported. 
     *
     *  @return <code> true </code> if antimatroid administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAntimatroidAdmin();


    /**
     *  Tests if an antimatroid <code> </code> notification service is 
     *  supported. 
     *
     *  @return <code> true </code> if antimatroid notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAntimatroidNotification();


    /**
     *  Tests for the availability of an antimatroid hierarchy traversal 
     *  service. 
     *
     *  @return <code> true </code> if antimatroid hierarchy traversal is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsAntimatroidHierarchy();


    /**
     *  Tests for the availability of an antimatroid hierarchy design service. 
     *
     *  @return <code> true </code> if antimatroid hierarchy design is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAntimatroidHierarchyDesign();


    /**
     *  Gets the supported <code> Chain </code> record types. 
     *
     *  @return a list containing the supported <code> Chain </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getChainRecordTypes();


    /**
     *  Tests if the given <code> Chain </code> record type is supported. 
     *
     *  @param  chainRecordType a <code> Type </code> indicating a <code> 
     *          Chain </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> chainRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsChainRecordType(org.osid.type.Type chainRecordType);


    /**
     *  Gets the supported <code> Chain </code> search types. 
     *
     *  @return a list containing the supported <code> Chain </code> search 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getChainSearchRecordTypes();


    /**
     *  Tests if the given <code> Chain </code> search type is supported. 
     *
     *  @param  chainSearchRecordType a <code> Type </code> indicating a 
     *          <code> Chain </code> search type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> chainSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsChainSearchRecordType(org.osid.type.Type chainSearchRecordType);


    /**
     *  Gets the supported <code> Antimatroid </code> record types. 
     *
     *  @return a list containing the supported <code> Antimatroid </code> 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAntimatroidRecordTypes();


    /**
     *  Tests if the given <code> Antimatroid </code> record type is 
     *  supported. 
     *
     *  @param  antimatroidRecordType a <code> Type </code> indicating an 
     *          <code> Antimatroid </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> antimatroidRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAntimatroidRecordType(org.osid.type.Type antimatroidRecordType);


    /**
     *  Gets the supported <code> Antimatroid </code> search record types. 
     *
     *  @return a list containing the supported <code> Antimatroid </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getAntimatroidSearchRecordTypes();


    /**
     *  Tests if the given <code> Antimatroid </code> search record type is 
     *  supported. 
     *
     *  @param  antimatroidSearchRecordType a <code> Type </code> indicating 
     *          an <code> Antimatroid </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          antimatroidSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAntimatroidSearchRecordType(org.osid.type.Type antimatroidSearchRecordType);
}
