//
// org.osid.subscription.DispatchAdminSession
//
//     The OSID Java specification for org.osid.subscription.DispatchAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.subscription;


/**
 *  <p>This session creates, updates, and deletes <code> Dispatches. </code> 
 *  The data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Dispatch, </code> a <code> DispatchForm </code> is requested using <code> 
 *  getDispatchFormForCreate() </code> specifying the desired relationship 
 *  peers and record <code> Types </code> or none if no record <code> Types 
 *  </code> are needed. The returned <code> DispatchForm </code> will indicate 
 *  that it is to be used with a create operation and can be used to examine 
 *  metdata or validate data prior to creation. Once the <code> DispatchForm 
 *  </code> is submiited to a create operation, it cannot be reused with 
 *  another create operation unless the first operation was unsuccessful. Each 
 *  <code> DispatchForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> DispatchForms </code> are requested to the <code> 
 *  Dispatch </code> <code> Id </code> that is to be updated using <code> 
 *  getDispatchFormForUpdate(). </code> Similarly, the <code> DispatchForm 
 *  </code> has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> DispatchForm </code> 
 *  can only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Dispatches. </code> To unmap a 
 *  <code> Dispatch </code> from the current <code> Publisher, </code> the 
 *  <code> DispatchPublisherAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> Dispatch </code> itself 
 *  thus removing it from all known <code> Publisher </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface DispatchAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Publisher </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Publisher Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPublisherId();


    /**
     *  Gets the <code> Publisher </code> associated with this session. 
     *
     *  @return the publisher 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.Publisher getPublisher()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> Dispatches. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> Dispatch </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not wish to offer create operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Dispatch </code> creation is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateDispatches();


    /**
     *  Tests if this user can create a single <code> Dispatch </code> using 
     *  the desired record interface types. While <code> 
     *  SubscriptionManager.getDispatchRecordTypes() </code> can be used to 
     *  examine which record interfaces are supported, this method tests which 
     *  record(s) are required for creating a specific <code> Dispatch. 
     *  </code> Providing an empty array tests if a <code> Dispatch </code> 
     *  can be created with no records. 
     *
     *  @param  dispatchRecordTypes array of dispatch record types 
     *  @return <code> true </code> if <code> Dispatch </code> creation using 
     *          the specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> dispatchRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateDispatchWithRecordTypes(org.osid.type.Type[] dispatchRecordTypes);


    /**
     *  Gets the dispatch form for creating new dispatches. A new form should 
     *  be requested for each create transaction. 
     *
     *  @param  dispatchRecordTypes array of dispatch record types 
     *  @return the dispatch form 
     *  @throws org.osid.NullArgumentException <code> dispatchRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get from for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.DispatchForm getDispatchFormForCreate(org.osid.type.Type[] dispatchRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Dispatch. </code> 
     *
     *  @param  dispatchForm the form for this <code> Dispatch </code> 
     *  @return the new <code> Dispatch </code> 
     *  @throws org.osid.IllegalStateException <code> dispatchForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> dispatchForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> dispatchForm </code> did 
     *          not originate from <code> getDispatchFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.Dispatch createDispatch(org.osid.subscription.DispatchForm dispatchForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Dispatches. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> Dispatch </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not wish to offer update operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Dispatch </code> modification 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateDispatches();


    /**
     *  Gets the dispatch form for updating an existing dispatch. A new 
     *  dispatch form should be requested for each update transaction. 
     *
     *  @param  dispatchId the <code> Id </code> of the <code> Dispatch 
     *          </code> 
     *  @return the dispatch form 
     *  @throws org.osid.NotFoundException <code> dispatchId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> dispatchId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.DispatchForm getDispatchFormForUpdate(org.osid.id.Id dispatchId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing dispatch. 
     *
     *  @param  dispatchForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> dispatchForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> dispatchId </code> or 
     *          <code> dispatchForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> dispatchForm </code> did 
     *          not originate from <code> getDispatchFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateDispatch(org.osid.subscription.DispatchForm dispatchForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Dispatches </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> Dispatch </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not wish to offer delete operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Dispatch </code> deletion is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteDispatches();


    /**
     *  Deletes a <code> Dispatch. </code> 
     *
     *  @param  dispatchId the <code> Id </code> of the <code> Dispatch 
     *          </code> to remove 
     *  @throws org.osid.NotFoundException <code> dispatchId </code> not found 
     *  @throws org.osid.NullArgumentException <code> dispatchId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteDispatch(org.osid.id.Id dispatchId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Dispatches. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Dispatch </code> aliasing is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageDispatchAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Dispatch </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Dispatch </code> is determined by the provider. The new <code> Id 
     *  </code> performs as an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another dispatch, it is reassigned to the given 
     *  dispatch <code> Id. </code> 
     *
     *  @param  dispatchId the <code> Id </code> of a <code> Dispatch </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> dispatchId </code> not found 
     *  @throws org.osid.NullArgumentException <code> dispatchId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasDispatch(org.osid.id.Id dispatchId, 
                              org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
