//
// org.osid.subscription.DispatchSearchSession
//
//     The OSID Java specification for org.osid.subscription.DispatchSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.subscription;


/**
 *  <p>This session provides methods for searching <code> Dispatch </code> 
 *  objects. The search query is constructed using the <code> DispatchQuery. 
 *  </code> The dispatch record <code> Type </code> also specifies the record 
 *  for the dispatch query. </p> 
 *  
 *  <p> <code> getDispatchesByQuery() </code> is the basic search method and 
 *  returns a list of <code> Dispatch </code> elements. A more advanced search 
 *  may be performed with <code> getDispatchesBySearch(). </code> It accepts a 
 *  <code> DispatchSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getDispatchesBySearch() </code> returns a <code> 
 *  DispatchSearchResults </code> that can be used to access the resulting 
 *  <code> DispatchList </code> or be used to perform a search within the 
 *  result set through <code> DispatchSearch. </code> </p> 
 *  
 *  <p> Dispatches may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> DispatchQuery. 
 *  </code> The returns in this session may not be cast directly to these 
 *  interfaces. </p>
 */

public interface DispatchSearchSession
    extends org.osid.subscription.DispatchQuerySession {


    /**
     *  Gets a dispatch search. 
     *
     *  @return the dispatch search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.DispatchSearch getDispatchSearch();


    /**
     *  Gets a dispatch search order. The <code> DispatchSearchOrder </code> 
     *  is supplied to a <code> DispatchSearch </code> to specify the ordering 
     *  of results. 
     *
     *  @return the dispatch search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.DispatchSearchOrder getDispatchSearchOrder();


    /**
     *  Gets the search results matching the given search. 
     *
     *  @param  dispatchQuery the dispatch query 
     *  @param  dispatchSearch the dispatch search 
     *  @return the dispatch search results 
     *  @throws org.osid.NullArgumentException <code> dispatchQuery </code> or 
     *          <code> dispatchSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> dispatchQuery </code> or 
     *          <code> dispatchSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.DispatchSearchResults getDispatchesBySearch(org.osid.subscription.DispatchQuery dispatchQuery, 
                                                                             org.osid.subscription.DispatchSearch dispatchSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an entry query from an inspector. The inspector is available from 
     *  an <code> DispatchSearchResults. </code> 
     *
     *  @param  dispatchQueryInspector a query inspector 
     *  @return the entry query 
     *  @throws org.osid.NullArgumentException <code> dispatchQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> dispatchQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.DispatchQuery getDispatchQueryFromInspector(org.osid.subscription.DispatchQueryInspector dispatchQueryInspector);
}
