//
// org.osid.subscription.MySubscriptionAdminSession
//
//     The OSID Java specification for org.osid.subscription.MySubscriptionAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.subscription;


/**
 *  <p>This session creates and removes subscriptions foe the authenticated 
 *  <code> Agent. </code> The data for create and update is provided by the 
 *  consumer via the form object. </p>
 */

public interface MySubscriptionAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Publisher </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Publisher Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPublisherId();


    /**
     *  Gets the <code> Publisher </code> associated with this session. 
     *
     *  @return the publisher 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.Publisher getPublisher()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create hournal entries. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known creating a <code> Subscription </code> will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer create operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Subscription </code> creation 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSubscribe();


    /**
     *  Tests if this user can create a single <code> Subscription </code> 
     *  using the desired record types. While <code> 
     *  SubscriptionManager.getSubscriptionRecordTypes() </code> can be used 
     *  to examine which records are supported, this method tests which 
     *  record(s) are required for creating a specific <code> Subscription. 
     *  </code> Providing an empty array tests if a <code> Subscription 
     *  </code> can be created with no records. 
     *
     *  @param  subscriptionRecordTypes array of subscription record types 
     *  @return <code> true </code> if <code> Subscription </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> subscriptionRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSubscribeWithRecordTypes(org.osid.type.Type[] subscriptionRecordTypes);


    /**
     *  Gets the subscription form for creating new entries. A new form should 
     *  be requested for each create transaction. 
     *
     *  @param  dispatchId the <code> Id </code> for the dispatch 
     *  @param  subscriptionRecordTypes array of subscription record types 
     *  @return the subscription form 
     *  @throws org.osid.NotFoundException <code> dispatchId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> dispatchId </code> or 
     *          <code> subscriptionRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          recod types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.SubscriptionForm getSubscriptionFormForCreate(org.osid.id.Id dispatchId, 
                                                                               org.osid.type.Type[] subscriptionRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Subscription. </code> 
     *
     *  @param  subscriptionForm the form for this <code> Subscription </code> 
     *  @return the new <code> Subscription </code> 
     *  @throws org.osid.IllegalStateException <code> subscriptionForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> subscriptionForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> subscriptionForm </code> 
     *          did not originate from <code> getSubscriptionFormForCreate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.Subscription subscribe(org.osid.subscription.SubscriptionForm subscriptionForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update subscriptions. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known updating a <code> Subscription </code> will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer update operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Subscription </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateMySubscriptions();


    /**
     *  Gets the subscription form for updating an existing subscription. A 
     *  new subscription form should be requested for each update transaction. 
     *
     *  @param  subscriptionId the <code> Id </code> of the <code> 
     *          Subscription </code> 
     *  @return the subscription form 
     *  @throws org.osid.NotFoundException <code> subscriptionId </code> is 
     *          not found for this user 
     *  @throws org.osid.NullArgumentException <code> subscriptionId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.SubscriptionForm getSubscriptionFormForUpdate(org.osid.id.Id subscriptionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing subscription. 
     *
     *  @param  subscriptionForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> subscriptionForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> subscriptionId </code> 
     *          or <code> subscriptionForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> subscriptionForm </code> 
     *          did not originate from <code> getSubscriptionFormForUpdate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateMySubscription(org.osid.subscription.SubscriptionForm subscriptionForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete their own subscriptions. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting an <code> Subscription </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may not wish to offer delete operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if <code> Subscription </code> deletion 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUnsubscribe();


    /**
     *  Deletes an <code> Subscription. </code> 
     *
     *  @param  subscriptionId the <code> Id </code> of the <code> 
     *          Subscription </code> to remove 
     *  @throws org.osid.NotFoundException <code> subscriber </code> not 
     *          subscribed <code> to subscriptionId </code> 
     *  @throws org.osid.NullArgumentException <code> subscriptionId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unsubscribe(org.osid.id.Id subscriptionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
