//
// org.osid.subscription.PublisherQuery
//
//     The OSID Java specification for org.osid.subscription.PublisherQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.subscription;


/**
 *  <p>This is the query for searching for publishers. Each method specifies 
 *  an <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface PublisherQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the subscription <code> Id </code> for this query to match 
     *  subscriptions assigned to publishers. 
     *
     *  @param  subscriptionId a subscription <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> subscriptionId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSubscriptionId(org.osid.id.Id subscriptionId, 
                                    boolean match);


    /**
     *  Clears the subscription <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSubscriptionIdTerms();


    /**
     *  Tests if a subscription query is available. 
     *
     *  @return <code> true </code> if a subscription query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubscriptionQuery();


    /**
     *  Gets the query for a publisher. 
     *
     *  @return the subscription query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubscriptionQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubscriptionQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.subscription.SubscriptionQuery getSubscriptionQuery();


    /**
     *  Matches publishers with any subscription. 
     *
     *  @param  match <code> true </code> to match publishers with any 
     *          subscription, <code> false </code> to match publishers with no 
     *          subscriptions 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnySubscription(boolean match);


    /**
     *  Clears the subscription terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSubscriptionTerms();


    /**
     *  Sets the dispatch <code> Id </code> for this query to match 
     *  subscriptions assigned to dispatches. 
     *
     *  @param  dispatchId a dispatch <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> dispatchId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDispatchId(org.osid.id.Id dispatchId, boolean match);


    /**
     *  Clears the dispatch <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDispatchIdTerms();


    /**
     *  Tests if a <code> DispatchQuery </code> is available. 
     *
     *  @return <code> true </code> if a dispatch query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDispatchQuery();


    /**
     *  Gets the query for a dispatch query. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the dispatch query 
     *  @throws org.osid.UnimplementedException <code> supportsDispatchQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDispatchQuery() </code> is <code> true. </code> 
     */

    public org.osid.subscription.DispatchQuery getDispatchQuery();


    /**
     *  Matches publishers with any dispatch. 
     *
     *  @param  match <code> true </code> to match publishers with any 
     *          dispatch, <code> false </code> to match publishers with no 
     *          dispatches 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDispatch(boolean match);


    /**
     *  Clears the dispatch terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDispatchTerms();


    /**
     *  Sets the publisher <code> Id </code> for this query to match 
     *  publishers that have the specified publisher as an ancestor. 
     *
     *  @param  publisherId a publisher <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> publisherId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorPublisherId(org.osid.id.Id publisherId, 
                                         boolean match);


    /**
     *  Clears the ancestor publisher <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorPublisherIdTerms();


    /**
     *  Tests if a <code> PublisherQuery </code> is available. 
     *
     *  @return <code> true </code> if a publisher query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorPublisherQuery();


    /**
     *  Gets the query for a publisher. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the publisher query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorPublisherQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorPublisherQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.subscription.PublisherQuery getAncestorPublisherQuery();


    /**
     *  Matches publishers with any ancestor. 
     *
     *  @param  match <code> true </code> to match publishers with any 
     *          ancestor, <code> false </code> to match root publishers 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorPublisher(boolean match);


    /**
     *  Clears the ancestor publisher terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorPublisherTerms();


    /**
     *  Sets the publisher <code> Id </code> for this query to match 
     *  publishers that have the specified publisher as a descendant. 
     *
     *  @param  publisherId a publisher <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> publisherId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantPublisherId(org.osid.id.Id publisherId, 
                                           boolean match);


    /**
     *  Clears the descendant publisher <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantPublisherIdTerms();


    /**
     *  Tests if a <code> PublisherQuery </code> is available. 
     *
     *  @return <code> true </code> if a publisher query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantPublisherQuery();


    /**
     *  Gets the query for a publisher. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the publisher query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantPublisherQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantPublisherQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.subscription.PublisherQuery getDescendantPublisherQuery();


    /**
     *  Matches publishers with any descendant. 
     *
     *  @param  match <code> true </code> to match publishers with any 
     *          descendant, <code> false </code> to match leaf publishers 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantPublisher(boolean match);


    /**
     *  Clears the descendant publisher terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantPublisherTerms();


    /**
     *  Gets the publisher query record corresponding to the given <code> 
     *  Publisher </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested boolean <code> OR </code> term. 
     *
     *  @param  publisherRecordType a publisher record type 
     *  @return the publisher query record 
     *  @throws org.osid.NullArgumentException <code> publisherRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(publisherRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.records.PublisherQueryRecord getPublisherQueryRecord(org.osid.type.Type publisherRecordType)
        throws org.osid.OperationFailedException;
}
