//
// org.osid.subscription.PublisherSearchSession
//
//     The OSID Java specification for org.osid.subscription.PublisherSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.subscription;


/**
 *  <p>This session provides methods for searching <code> Publisher </code> 
 *  objects. The search query is constructed using the <code> PublisherQuery. 
 *  </code> The publisher record <code> Type </code> also specifies the record 
 *  for the publisher query. </p> 
 *  
 *  <p> <code> getPublishersByQuery() </code> is the basic search method and 
 *  returns a list of <code> Publisher </code> elements. A more advanced 
 *  search may be performed with <code> getPublishersBySearch(). </code> It 
 *  accepts a <code> PublisherSearch </code> in addition to the query for the 
 *  purpose of specifying additional options affecting the entire search, such 
 *  as ordering. <code> getPublishersBySearch() </code> returns a <code> 
 *  PublisherSearchResults </code> that can be used to access the resulting 
 *  <code> PublisherList </code> or be used to perform a search within the 
 *  result set through <code> PublisherSearch. </code> </p> 
 *  
 *  <p> Publishers may have a query record indicated by their respective 
 *  record types. The query record is accessed via the <code> PublisherQuery. 
 *  </code> The returns in this session may not be cast directly to these 
 *  interfaces. </p>
 */

public interface PublisherSearchSession
    extends org.osid.subscription.PublisherQuerySession {


    /**
     *  Gets a publisher search. 
     *
     *  @return the publisher search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.PublisherSearch getPublisherSearch();


    /**
     *  Gets a publisher search order. The <code> PublisherSearchOrder </code> 
     *  is supplied to a <code> PublisherSearch </code> to specify the 
     *  ordering of results. 
     *
     *  @return the publisher search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.PublisherSearchOrder getPublisherSearchOrder();


    /**
     *  Gets the search results matching the given search. 
     *
     *  @param  publisherQuery the publisher query 
     *  @param  publisherSearch the publisher search 
     *  @return the publisher search results 
     *  @throws org.osid.NullArgumentException <code> publisherQuery </code> 
     *          or <code> publisherSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> publisherQuery </code> or 
     *          <code> publisherSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.PublisherSearchResults getPublishersBySearch(org.osid.subscription.PublisherQuery publisherQuery, 
                                                                              org.osid.subscription.PublisherSearch publisherSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an entry query from an inspector. The inspector is available from 
     *  an <code> PublisherSearchResults. </code> 
     *
     *  @param  publisherQueryInspector a query inspector 
     *  @return the entry query 
     *  @throws org.osid.NullArgumentException <code> publisherQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> publisherQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.PublisherQuery getPublisherQueryFromInspector(org.osid.subscription.PublisherQueryInspector publisherQueryInspector);
}
