//
// org.osid.subscription.SubscriptionAdminSession
//
//     The OSID Java specification for org.osid.subscription.SubscriptionAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.subscription;


/**
 *  <p>This session creates, updates, and deletes <code> Subscriptions. 
 *  </code> The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Subscription, </code> a <code> SubscriptionForm </code> is requested using 
 *  <code> getSubscriptionFormForCreate() </code> specifying the desired 
 *  relationship peers and record <code> Types </code> or none if no record 
 *  <code> Types </code> are needed. The returned <code> SubscriptionForm 
 *  </code> will indicate that it is to be used with a create operation and 
 *  can be used to examine metdata or validate data prior to creation. Once 
 *  the <code> SubscriptionForm </code> is submiited to a create operation, it 
 *  cannot be reused with another create operation unless the first operation 
 *  was unsuccessful. Each <code> SubscriptionForm </code> corresponds to an 
 *  attempted transaction. </p> 
 *  
 *  <p> For updates, <code> SubscriptionForms </code> are requested to the 
 *  <code> Subscription </code> <code> Id </code> that is to be updated using 
 *  <code> getSubscriptionFormForUpdate(). </code> Similarly, the <code> 
 *  SubscriptionForm </code> has metadata about the data that can be updated 
 *  and it can perform validation before submitting the update. The <code> 
 *  SubscriptionForm </code> can only be used once for a successful update and 
 *  cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Subscriptions. </code> To unmap a 
 *  <code> Subscription </code> from the current <code> Publisher, </code> the 
 *  <code> SubscriptionPublisherAssignmentSession </code> should be used. 
 *  These delete operations attempt to remove the <code> Subscription </code> 
 *  itself thus removing it from all known <code> Publisher </code> catalogs. 
 *  </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface SubscriptionAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Publisher </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Publisher Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPublisherId();


    /**
     *  Gets the <code> Publisher </code> associated with this session. 
     *
     *  @return the publisher 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.Publisher getPublisher()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create hournal entries. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known creating a <code> Subscription </code> will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer create operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Subscription </code> creation 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateSubscriptions();


    /**
     *  Tests if this user can create a single <code> Subscription </code> 
     *  using the desired record interface types. While <code> 
     *  SubscriptionManager.getSubscriptionRecordTypes() </code> can be used 
     *  to examine which record interfaces are supported, this method tests 
     *  which record(s) are required for creating a specific <code> 
     *  Subscription. </code> Providing an empty array tests if a <code> 
     *  Subscription </code> can be created with no records. 
     *
     *  @param  subscriptionRecordTypes array of subscription record types 
     *  @return <code> true </code> if <code> Subscription </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> subscriptionRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateSubscriptionWithRecordTypes(org.osid.type.Type[] subscriptionRecordTypes);


    /**
     *  Gets the subscription form for creating new entries. A new form should 
     *  be requested for each create transaction. 
     *
     *  @param  dispatchId the <code> Id </code> for the dispatch 
     *  @param  resourceId the <code> Id </code> for the resource 
     *  @param  subscriptionRecordTypes array of subscription record types 
     *  @return the subscription form 
     *  @throws org.osid.NotFoundException <code> dispatchId </code> or <code> 
     *          resourceId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> dispatchId, resourceId, 
     *          </code> or <code> subscriptionRecordTypes </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get from for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.SubscriptionForm getSubscriptionFormForCreate(org.osid.id.Id dispatchId, 
                                                                               org.osid.id.Id resourceId, 
                                                                               org.osid.type.Type[] subscriptionRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Subscription. </code> 
     *
     *  @param  subscriptionForm the form for this <code> Subscription </code> 
     *  @return the new <code> Subscription </code> 
     *  @throws org.osid.IllegalStateException <code> subscriptionForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> subscriptionForm </code> 
     *          did not originate from <code> getSubscriptionFormForCreate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.Subscription createSubscription(org.osid.subscription.SubscriptionForm subscriptionForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update subscriptions. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known updating a <code> Subscription </code> will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer update operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Subscription </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateSubscriptions();


    /**
     *  Gets the subscription form for updating an existing subscription. A 
     *  new subscription form should be requested for each update transaction. 
     *
     *  @param  subscriptionId the <code> Id </code> of the <code> 
     *          Subscription </code> 
     *  @return the subscription form 
     *  @throws org.osid.NotFoundException <code> subscriptionId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> subscriptionId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.SubscriptionForm getSubscriptionFormForUpdate(org.osid.id.Id subscriptionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing subscription. 
     *
     *  @param  subscriptionForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> subscriptionForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> subscriptionId </code> 
     *          or <code> subscriptionForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> subscriptionForm </code> 
     *          did not originate from <code> getSubscriptionFormForUpdate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateSubscription(org.osid.subscription.SubscriptionForm subscriptionForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete subscriptions. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known deleting an <code> Subscription </code> will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not wish to offer delete operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Subscription </code> deletion 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteSubscriptions();


    /**
     *  Deletes an <code> Subscription. </code> 
     *
     *  @param  subscriptionId the <code> Id </code> of the <code> 
     *          Subscription </code> to remove 
     *  @throws org.osid.NotFoundException <code> subscriptionId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> subscriptionId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteSubscription(org.osid.id.Id subscriptionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Comnents. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Subscription </code> aliasing 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSubscriptionAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Subscription </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Subscription </code> is determined by the provider. The new 
     *  <code> Id </code> performs as an alias to the primary <code> Id. 
     *  </code> If the alias is a pointer to another subscription, it is 
     *  reassigned to the given subscription <code> Id. </code> 
     *
     *  @param  subscriptionId the <code> Id </code> of a <code> Subscription 
     *          </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> subscriptionId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> subscriptionId </code> 
     *          or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasSubscription(org.osid.id.Id subscriptionId, 
                                  org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
