//
// org.osid.subscription.SubscriptionLookupSession
//
//     The OSID Java specification for org.osid.subscription.SubscriptionLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.subscription;


/**
 *  <p>This session defines methods for retrieving subscriptions. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated publisher view: All subscription methods in this session 
 *      operate, retrieve and pertain to subscriptions defined explicitly in 
 *      the current publisher. Using an isolated view is useful for managing 
 *      subscriptions with the <code> SubscriptionAdminSession. </code> </li> 
 *      <li> federated publisher view: All subscription lookup methods in this 
 *      session operate, retrieve and pertain to all subscriptions defined in 
 *      this publisher and any other publishers implicitly available in this 
 *      publisher through publisher inheritence. </li> 
 *      <li> effective subscription view: All subscription lookup methods 
 *      return subscriptions where the current date falls in between the 
 *      effective dates inclusive. </li> 
 *      <li> any effective subscription view: Subscriptions of any effective 
 *      date are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedPublisherView() </code> and <code> 
 *  useIsolatedPublisherView() </code> behave as a radio group and one should 
 *  be selected before invoking any lookup methods. </p>
 */

public interface SubscriptionLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Publisher </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Publisher Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPublisherId();


    /**
     *  Gets the <code> Publisher </code> associated with this session. 
     *
     *  @return the publisher 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.Publisher getPublisher()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can lookup subscriptions. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer these operations. 
     *
     *  @return <code> false </code> if subscription lookup methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupSubscriptions();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeSubscriptionView();


    /**
     *  A complete view of the <code> Subscription </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenarySubscriptionView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include entries in publishers which are children of this publisher in 
     *  the publisher hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedPublisherView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this publisher only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedPublisherView();


    /**
     *  Only subscriptions whose effective dates are current are returned by 
     *  methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveSubscriptionView();


    /**
     *  All subscriptions of any effective dates are returned by methods in 
     *  this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveSubscriptionView();


    /**
     *  Gets the <code> Subscription </code> specified by its <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Subscription </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> Subscription </code> and retained for 
     *  compatibility. 
     *  
     *  In effective mode, subscriptions are returned that are currently 
     *  effective. In any effective mode, effective subscriptions and those 
     *  currently expired are returned. 
     *
     *  @param  subscriptionId the <code> Id </code> of the <code> 
     *          Subscription </code> to retrieve 
     *  @return the returned <code> Subscription </code> 
     *  @throws org.osid.NotFoundException no <code> Subscription </code> 
     *          found with the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> subscriptionId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.Subscription getSubscription(org.osid.id.Id subscriptionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SubscriptionList </code> corresponding to the given 
     *  <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  entries specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible entries may be omitted from the list and may present the 
     *  elements in any order including returning a unique set. 
     *  
     *  In effective mode, subscriptions are returned that are currently 
     *  effective. In any effective mode, effective subscriptions and those 
     *  currently expired are returned. 
     *
     *  @param  subscriptionIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Subscription list </code> 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> subscriptionIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.SubscriptionList getSubscriptionsByIds(org.osid.id.IdList subscriptionIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SubscriptionList </code> corresponding to the given 
     *  subscription genus <code> Type </code> which does not include 
     *  subscriptions of genus types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  subscriptions or an error results. Otherwise, the returned list may 
     *  contain only those subscriptions that are accessible through this 
     *  session. 
     *  
     *  In effective mode, subscriptions are returned that are currently 
     *  effective. In any effective mode, effective subscriptions and those 
     *  currently expired are returned. 
     *
     *  @param  subscriptionGenusType a subscription genus type 
     *  @return the returned <code> Subscription </code> list 
     *  @throws org.osid.NullArgumentException <code> subscriptionGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.SubscriptionList getSubscriptionsByGenusType(org.osid.type.Type subscriptionGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SubscriptionList </code> corresponding to the given 
     *  subscription genus <code> Type </code> and include any additional 
     *  subscriptions with genus types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  subscriptions or an error results. Otherwise, the returned list may 
     *  contain only those subscriptions that are accessible through this 
     *  session. 
     *  
     *  In effective mode, subscriptions are returned that are currently 
     *  effective. In any effective mode, effective subscriptions and those 
     *  currently expired are returned. 
     *
     *  @param  subscriptionGenusType a subscription genus type 
     *  @return the returned <code> Subscriptions </code> list 
     *  @throws org.osid.NullArgumentException <code> subscriptionGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.SubscriptionList getSubscriptionsByParentGenusType(org.osid.type.Type subscriptionGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SubscriptionList </code> containing the given 
     *  subscription record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  subscriptions or an error results. Otherwise, the returned list may 
     *  contain only those subscriptions that are accessible through this 
     *  session. 
     *  
     *  In effective mode, subscriptions are returned that are currently 
     *  effective. In any effective mode, effective subscriptions and those 
     *  currently expired are returned. 
     *
     *  @param  subscriptionRecordType a subscription record type 
     *  @return the returned <code> Subscriptions </code> list 
     *  @throws org.osid.NullArgumentException <code> subscriptionRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.SubscriptionList getSubscriptionsByRecordType(org.osid.type.Type subscriptionRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SubscriptionList </code> effective during the entire 
     *  given date range inclusive but not confined to the date range. <code> 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  subscriptions or an error results. Otherwise, the returned list may 
     *  contain only those subscriptions that are accessible through this 
     *  session. 
     *  
     *  In effective mode, subscriptions are returned that are currently 
     *  effective. In any effective mode, effective subscriptions and those 
     *  currently expired are returned. 
     *
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Subscriptions </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.SubscriptionList getSubscriptionsOnDate(org.osid.calendaring.DateTime from, 
                                                                         org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> SubscriptionList </code> of a subscription genus type 
     *  and effective during the entire given date range inclusive but not 
     *  confined to the date range. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  subscriptions or an error results. Otherwise, the returned list may 
     *  contain only those subscriptions that are accessible through this 
     *  session. 
     *  
     *  In effective mode, subscriptions are returned that are currently 
     *  effective. In any effective mode, effective subscriptions and those 
     *  currently expired are returned. 
     *
     *  @param  subscriptionGenusType a subscription genus type 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Subscriptions </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> subscriptionGenusType, 
     *          from, </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.SubscriptionList getSubscriptionsByGenusTypeOnDate(org.osid.type.Type subscriptionGenusType, 
                                                                                    org.osid.calendaring.DateTime from, 
                                                                                    org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of subscriptions corresponding to a subscriber <code> Id. 
     *  </code> 
     *  
     *  In plenary mode, the returned list contains all known subscriptions or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  entries that are accessible through this session. 
     *  
     *  In effective mode, subscriptions are returned that are currently 
     *  effective. In any effective mode, effective subscriptions and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId the <code> Id </code> of the resource 
     *  @return the returned <code> SubscriptionList </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.SubscriptionList getSubscriptionsForSubscriber(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all subscriptions corresponding to a subscriber <code> 
     *  Id </code> and effective during the entire given date range inclusive 
     *  but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known subscriptions or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  entries that are accessible through this session. 
     *  
     *  In effective mode, subscriptions are returned that are currently 
     *  effective. In any effective mode, effective subscriptions and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  from from date 
     *  @param  to to date 
     *  @return the returned <code> SubscriptionList </code> 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, from </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.SubscriptionList getSubscriptionsForSubscriberOnDate(org.osid.id.Id resourceId, 
                                                                                      org.osid.calendaring.DateTime from, 
                                                                                      org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of subscriptions of the given genus type corresponding to 
     *  a subscriber <code> Id. </code> 
     *  
     *  In plenary mode, the returned list contains all known subscriptions or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  entries that are accessible through this session. 
     *  
     *  In effective mode, subscriptions are returned that are currently 
     *  effective. In any effective mode, effective subscriptions and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId the <code> Id </code> of the resource 
     *  @param  subscriptionGenusType a subscription genus type 
     *  @return the returned <code> SubscriptionList </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> or 
     *          <code> subscriptionGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.SubscriptionList getSubscriptionsByGenusTypeForSubscriber(org.osid.id.Id resourceId, 
                                                                                           org.osid.type.Type subscriptionGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all subscriptions of the given genus type corresponding 
     *  to a subscriber <code> Id </code> and effective during the entire 
     *  given date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known subscriptions or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  entries that are accessible through this session. 
     *  
     *  In effective mode, subscriptions are returned that are currently 
     *  effective. In any effective mode, effective subscriptions and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  subscriptionGenusType a subscription genus type 
     *  @param  from from date 
     *  @param  to to date 
     *  @return the returned <code> SubscriptionList </code> 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, 
     *          subscriptionGenusType, from </code> or <code> to </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.SubscriptionList getSubscriptionsByGenusTypeForSubscriberOnDate(org.osid.id.Id resourceId, 
                                                                                                 org.osid.type.Type subscriptionGenusType, 
                                                                                                 org.osid.calendaring.DateTime from, 
                                                                                                 org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all subscriptions corresponding to a dispatch <code> 
     *  Id. </code> 
     *  
     *  In plenary mode, the returned list contains all known subscriptions or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  entries that are accessible through this session. 
     *  
     *  In effective mode, subscriptions are returned that are currently 
     *  effective. In any effective mode, effective subscriptions and those 
     *  currently expired are returned. 
     *
     *  @param  dispatchId the <code> Id </code> of the dispatch 
     *  @return the returned <code> SubscriptionList </code> 
     *  @throws org.osid.NullArgumentException <code> dispatchId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.SubscriptionList getSubscriptionsForDispatch(org.osid.id.Id dispatchId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all subscriptions corresponding to a dispatch <code> Id 
     *  </code> and effective during the entire given date range inclusive but 
     *  not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known subscriptions or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  entries that are accessible through this session. 
     *  
     *  In effective mode, subscriptions are returned that are currently 
     *  effective. In any effective mode, effective subscriptions and those 
     *  currently expired are returned. 
     *
     *  @param  dispatchId a dispatch <code> Id </code> 
     *  @param  from from date 
     *  @param  to to date 
     *  @return the returned <code> SubscriptionList </code> 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> dispatchId, from </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.SubscriptionList getSubscriptionsForDispatchOnDate(org.osid.id.Id dispatchId, 
                                                                                    org.osid.calendaring.DateTime from, 
                                                                                    org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all subscriptions of the given genus type corresponding 
     *  to a dispatch <code> Id. </code> 
     *  
     *  In plenary mode, the returned list contains all known subscriptions or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  entries that are accessible through this session. 
     *  
     *  In effective mode, subscriptions are returned that are currently 
     *  effective. In any effective mode, effective subscriptions and those 
     *  currently expired are returned. 
     *
     *  @param  dispatchId the <code> Id </code> of the dispatch 
     *  @param  subscriptionGenusType a subscription genus type 
     *  @return the returned <code> SubscriptionList </code> 
     *  @throws org.osid.NullArgumentException <code> dispatchId </code> or 
     *          <code> subscriptionGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.SubscriptionList getSubscriptionsByGenusTypeForDispatch(org.osid.id.Id dispatchId, 
                                                                                         org.osid.type.Type subscriptionGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all subscriptions of the given genus type corresponding 
     *  to a dispatch <code> Id </code> and effective during the entire given 
     *  date range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known subscriptions or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  entries that are accessible through this session. 
     *  
     *  In effective mode, subscriptions are returned that are currently 
     *  effective. In any effective mode, effective subscriptions and those 
     *  currently expired are returned. 
     *
     *  @param  dispatchId a dispatch <code> Id </code> 
     *  @param  subscriptionGenusType a subscription genus type 
     *  @param  from from date 
     *  @param  to to date 
     *  @return the returned <code> SubscriptionList </code> 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> dispatchId, 
     *          subscriptionGenusType, from </code> or <code> to </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.SubscriptionList getSubscriptionsByGenusTypeForDispatchOnDate(org.osid.id.Id dispatchId, 
                                                                                               org.osid.type.Type subscriptionGenusType, 
                                                                                               org.osid.calendaring.DateTime from, 
                                                                                               org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all subscriptions corresponding to a susbcriber and 
     *  dispatch <code> Id. </code> 
     *  
     *  In plenary mode, the returned list contains all known subscriptions or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  entries that are accessible through this session. 
     *  
     *  In effective mode, subscriptions are returned that are currently 
     *  effective. In any effective mode, effective subscriptions and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId the <code> Id </code> of the resource 
     *  @param  dispatchId the <code> Id </code> of the dispatch 
     *  @return the returned <code> SubscriptionList </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> or 
     *          <code> dispatchId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.SubscriptionList getSubscriptionsForSubscriberAndDispatch(org.osid.id.Id resourceId, 
                                                                                           org.osid.id.Id dispatchId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all subscriptions corresponding to a subscriber and 
     *  dispatch <code> Id </code> and effective during the entire given date 
     *  range inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known subscriptions or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  entries that are accessible through this session. 
     *  
     *  In effective mode, subscriptions are returned that are currently 
     *  effective. In any effective mode, effective subscriptions and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId the <code> Id </code> of the resource 
     *  @param  dispatchId a dispatch <code> Id </code> 
     *  @param  from from date 
     *  @param  to to date 
     *  @return the returned <code> SubscriptionList </code> 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, dispatchI, 
     *          from </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.SubscriptionList getSubscriptionsForSubscriberAndDispatchOnDate(org.osid.id.Id resourceId, 
                                                                                                 org.osid.id.Id dispatchId, 
                                                                                                 org.osid.calendaring.DateTime from, 
                                                                                                 org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all subscriptions of the given genus type corresponding 
     *  to a susbcriber and dispatch <code> Id. </code> 
     *  
     *  In plenary mode, the returned list contains all known subscriptions or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  entries that are accessible through this session. 
     *  
     *  In effective mode, subscriptions are returned that are currently 
     *  effective. In any effective mode, effective subscriptions and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId the <code> Id </code> of the resource 
     *  @param  dispatchId the <code> Id </code> of the dispatch 
     *  @param  subscriptionGenusType a subscription genus type 
     *  @return the returned <code> SubscriptionList </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, dispatchId 
     *          </code> or <code> subscriptionGenusType </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.SubscriptionList getSubscriptionsByGenusTypeForSubscriberAndDispatch(org.osid.id.Id resourceId, 
                                                                                                      org.osid.id.Id dispatchId, 
                                                                                                      org.osid.type.Type subscriptionGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of all subscriptions of the given genus type corresponding 
     *  to a subscriber and dispatch <code> Id </code> and effective during 
     *  the entire given date range inclusive but not confined to the date 
     *  range. 
     *  
     *  In plenary mode, the returned list contains all known subscriptions or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  entries that are accessible through this session. 
     *  
     *  In effective mode, subscriptions are returned that are currently 
     *  effective. In any effective mode, effective subscriptions and those 
     *  currently expired are returned. 
     *
     *  @param  resourceId the <code> Id </code> of the resource 
     *  @param  dispatchId a dispatch <code> Id </code> 
     *  @param  subscriptionGenusType a subscription genus type 
     *  @param  from from date 
     *  @param  to to date 
     *  @return the returned <code> SubscriptionList </code> 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, dispatch, 
     *          subscriptionGenusType, from </code> or <code> to </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.SubscriptionList getSubscriptionsByGenusTypeForSubscriberAndDispatchOnDate(org.osid.id.Id resourceId, 
                                                                                                            org.osid.id.Id dispatchId, 
                                                                                                            org.osid.type.Type subscriptionGenusType, 
                                                                                                            org.osid.calendaring.DateTime from, 
                                                                                                            org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all subscriptions. 
     *  
     *  In plenary mode, the returned list contains all known entries or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  entries that are accessible through this session. 
     *  
     *  In effective mode, subscriptions are returned that are currently 
     *  effective. In any effective mode, effective subscriptions and those 
     *  currently expired are returned. 
     *
     *  @return a list of subscriptions 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.SubscriptionList getSubscriptions()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
