//
// org.osid.subscription.SubscriptionManager
//
//     The OSID Java specification for org.osid.subscription.SubscriptionManager.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.subscription;


/**
 *  <p>The subscription manager provides access to subscription sessions and 
 *  provides interoperability tests for various aspects of this service. The 
 *  sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> MySubscriptionSession: </code> a session to look up 
 *      subscriptions </li> 
 *      <li> <code> MySubscriptionAdminSession: </code> a session to manage 
 *      subscriptions </li> 
 *      <li> <code> SubscriptionLookupSession: </code> a session to lookup 
 *      subscriptions </li> 
 *      <li> <code> SubscriptionQuerySession: </code> a session to query 
 *      subscriptions </li> 
 *      <li> <code> SubscriptionSearchSession: </code> a session to search 
 *      subscriptions </li> 
 *      <li> <code> SubscriptionAdminSession: </code> a session to manage 
 *      subscriptions </li> 
 *      <li> <code> SubscriptionNotificationSession: </code> a session to 
 *      subscribe to notifications of subscription changes </li> 
 *      <li> <code> SubscriptionPublisherSession: </code> a session to look up 
 *      subscription publisher mappings </li> 
 *      <li> <code> SubscriptionPublisherAssignmentSession: </code> a session 
 *      to manage subscription publisher mappings </li> 
 *      <li> <code> SubscriptionSmartPublisherSession: </code> a session to 
 *      manage smart publishers of subscriptions </li> 
 *      <li> <code> DispatchLookupSession: </code> a session to retrieve 
 *      dispatches </li> 
 *      <li> <code> DispatchQuerySession: </code> a session to query 
 *      dispatches </li> 
 *      <li> <code> DispatchSearchSession: </code> a session to search for 
 *      dispatches </li> 
 *      <li> <code> DispatchAdminSession: </code> a session to create, update 
 *      and delete dispatches </li> 
 *      <li> <code> DispatchNotificationSession: </code> a session to receive 
 *      notifications for changes in dispatches </li> 
 *      <li> <code> DispatchPublisherSession: </code> a session to look up 
 *      dispatch publisher mappings </li> 
 *      <li> <code> DispatchPublisherAssignmentSession: </code> a session to 
 *      manage dispatch publisher mappings </li> 
 *      <li> <code> DispatchSmartPublisherSession: </code> a session to manage 
 *      smart publishers of dispatches </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> PublisherLookupSession: </code> a session to retrieve 
 *      publishers </li> 
 *      <li> <code> PublisherQuerySession: </code> a session to query 
 *      publishers </li> 
 *      <li> <code> PublisherSearchSession: </code> a session to search for 
 *      publishers </li> 
 *      <li> <code> PublisherAdminSession: </code> a session to create, update 
 *      and delete publishers </li> 
 *      <li> <code> PublisherNotificationSession: </code> a session to receive 
 *      notifications for changes in publishers </li> 
 *      <li> <code> PublisherHierarchySession: </code> a session to traverse 
 *      hierarchies of publishers </li> 
 *      <li> <code> PublisherHierarchyDesignSession: </code> a session to 
 *      manage hierarchies of publishers </li> 
 *  </ul>
 *  
 *  
 *  <p> The subscription manager also provides a profile for determing the 
 *  supported search types supported by this service. </p>
 */

public interface SubscriptionManager
    extends org.osid.OsidManager,
            org.osid.subscription.SubscriptionProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the subscription 
     *  lookup service for the authenticated agent. 
     *
     *  @return a <code> My </code> S <code> ubscriptionSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsMySubscription() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMySubscription() </code> is <code> true. </code> 
     */

    public org.osid.subscription.MySubscriptionSession getMySubscriptionSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the subscription 
     *  lookup service for the authenticated agent for the given publisher. 
     *
     *  @param  publisherId the <code> Id </code> of the <code> Publisher 
     *          </code> 
     *  @return a <code> MySubscriptionSession </code> 
     *  @throws org.osid.NotFoundException no <code> Publisher </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> publisherId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsMySubscription() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMySubscription() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.subscription.MySubscriptionSession getMySubscriptionSessionForPublisher(org.osid.id.Id publisherId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the subscription 
     *  administrative service for the authenticated agent. 
     *
     *  @return a <code> My </code> S <code> ubscriptionSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsMySubscriptionAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMySubscriptionAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.subscription.MySubscriptionAdminSession getMySubscriptionAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the subscription 
     *  administrative service for the authenticated agent for the given 
     *  publisher. 
     *
     *  @param  publisherId the <code> Id </code> of the <code> Publisher 
     *          </code> 
     *  @return a <code> MySubscriptionSession </code> 
     *  @throws org.osid.NotFoundException no <code> Publisher </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> publisherId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsMySubscriptionAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsMySubscriptionAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.subscription.MySubscriptionAdminSession getMySubscriptionAdminSessionForPublisher(org.osid.id.Id publisherId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the subscription 
     *  lookup service. 
     *
     *  @return a <code> SubscriptionLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubscriptionLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubscriptionLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.subscription.SubscriptionLookupSession getSubscriptionLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the subscription 
     *  lookup service for the given publisher. 
     *
     *  @param  publisherId the <code> Id </code> of the <code> Publisher 
     *          </code> 
     *  @return a <code> SubscriptionLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Publisher </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> publisherId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubscriptionLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubscriptionLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.subscription.SubscriptionLookupSession getSubscriptionLookupSessionForPublisher(org.osid.id.Id publisherId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the subscription 
     *  query service. 
     *
     *  @return a <code> SubscriptionQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubscriptionQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubscriptionQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.subscription.SubscriptionQuerySession getSubscriptionQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the subscription 
     *  query service for the given publisher. 
     *
     *  @param  publisherId the <code> Id </code> of the <code> Publisher 
     *          </code> 
     *  @return a <code> SubscriptionQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Publisher </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> publisherId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubscriptionQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubscriptionQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.subscription.SubscriptionQuerySession getSubscriptionQuerySessionForPublisher(org.osid.id.Id publisherId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the subscription 
     *  search service. 
     *
     *  @return a <code> SubscriptionSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubscriptionSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubscriptionSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.subscription.SubscriptionSearchSession getSubscriptionSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the subscription 
     *  search service for the given publisher. 
     *
     *  @param  publisherId the <code> Id </code> of the <code> Publisher 
     *          </code> 
     *  @return a <code> SubscriptionSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Publisher </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> publisherId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubscriptionSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubscriptionSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.subscription.SubscriptionSearchSession getSubscriptionSearchSessionForPublisher(org.osid.id.Id publisherId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the subscription 
     *  administration service. 
     *
     *  @return a <code> SubscriptionAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubscriptionAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubscriptionAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.subscription.SubscriptionAdminSession getSubscriptionAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the subscription 
     *  administration service for the given publisher. 
     *
     *  @param  publisherId the <code> Id </code> of the <code> Publisher 
     *          </code> 
     *  @return a <code> SubscriptionAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Publisher </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> publisherId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubscriptionAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubscriptionAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.subscription.SubscriptionAdminSession getSubscriptionAdminSessionForPublisher(org.osid.id.Id publisherId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the subscription 
     *  notification service. 
     *
     *  @param  subscriptionReceiver the receiver 
     *  @return a <code> SubscriptionNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> subscriptionReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubscriptionNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubscriptionNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.subscription.SubscriptionNotificationSession getSubscriptionNotificationSession(org.osid.subscription.SubscriptionReceiver subscriptionReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the subscription 
     *  notification service for the given publisher. 
     *
     *  @param  subscriptionReceiver the receiver 
     *  @param  publisherId the <code> Id </code> of the <code> Publisher 
     *          </code> 
     *  @return a <code> SubscriptionNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Publisher </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> subscriptionReceiver 
     *          </code> or <code> publisherId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubscriptionNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubscriptionNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.subscription.SubscriptionNotificationSession getSubscriptionNotificationSessionForPublisher(org.osid.subscription.SubscriptionReceiver subscriptionReceiver, 
                                                                                                                org.osid.id.Id publisherId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving subscription to publisher mappings. 
     *
     *  @return a <code> SubscriptionPublisherSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubscriptionPublisher() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubscriptionPublisher() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.subscription.SubscriptionPublisherSession getSubscriptionPublisherSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning subscription to publisher mappings. 
     *
     *  @return a <code> SubscriptionPublisherAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubscriptionPublisherAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubscriptionPublisherAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.subscription.SubscriptionPublisherAssignmentSession getSubscriptionPublisherAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the subscription smart publisher for 
     *  the given publisher. 
     *
     *  @param  publisherId the <code> Id </code> of the publisher 
     *  @return a <code> SubscriptionSmartPublisherSession </code> 
     *  @throws org.osid.NotFoundException <code> publisherId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> publisherId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubscriptionSmartPublisher() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubscriptionSmartPublisher() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.subscription.SubscriptionSmartPublisherSession getSubscriptionSmartPublisherSession(org.osid.id.Id publisherId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the dispatch 
     *  lookup service. 
     *
     *  @return a <code> DispatchLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDispatchLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDispatchLookup() </code> is <code> true. </code> 
     */

    public org.osid.subscription.DispatchLookupSession getDispatchLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the dispatch 
     *  lookup service for the given publisher. 
     *
     *  @param  publisherId the <code> Id </code> of the <code> Dispatch 
     *          </code> 
     *  @return a <code> DispatchLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Publisher </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> publisherId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDispatchLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDispatchLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.subscription.DispatchLookupSession getDispatchLookupSessionForPublisher(org.osid.id.Id publisherId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the dispatch query 
     *  service. 
     *
     *  @return a <code> DispatchQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsDispatchQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDispatchQuery() </code> is <code> true. </code> 
     */

    public org.osid.subscription.DispatchQuerySession getDispatchQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the dispatch query 
     *  service for the given publisher. 
     *
     *  @param  publisherId the <code> Id </code> of the <code> Dispatch 
     *          </code> 
     *  @return a <code> DispatchQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Publisher </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> publisherId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsDispatchQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDispatchQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.subscription.DispatchQuerySession getDispatchQuerySessionForPublisher(org.osid.id.Id publisherId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the dispatch 
     *  search service. 
     *
     *  @return a <code> DispatchSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDispatchSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDispatchSearch() </code> is <code> true. </code> 
     */

    public org.osid.subscription.DispatchSearchSession getDispatchSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the dispatch 
     *  search service for the given publisher. 
     *
     *  @param  publisherId the <code> Id </code> of the <code> Dispatch 
     *          </code> 
     *  @return a <code> DispatchSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Publisher </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> publisherId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDispatchSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDispatchSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.subscription.DispatchSearchSession getDispatchSearchSessionForPublisher(org.osid.id.Id publisherId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the dispatch 
     *  administrative service. 
     *
     *  @return a <code> DispatchAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsDispatchAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDispatchAdmin() </code> is <code> true. </code> 
     */

    public org.osid.subscription.DispatchAdminSession getDispatchAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the dispatch 
     *  administrative service for the given publisher. 
     *
     *  @param  publisherId the <code> Id </code> of the <code> Dispatch 
     *          </code> 
     *  @return a <code> DispatchAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Publisher </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> publisherId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsDispatchAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDispatchAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.subscription.DispatchAdminSession getDispatchAdminSessionForPublisher(org.osid.id.Id publisherId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the dispatch 
     *  notification service. 
     *
     *  @param  dispatchReceiver the receiver 
     *  @return a <code> DispatchNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> dispatchReceiver </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDispatchNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDispatchNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.subscription.DispatchNotificationSession getDispatchNotificationSession(org.osid.subscription.DispatchReceiver dispatchReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the dispatch 
     *  notification service for the given publisher. 
     *
     *  @param  dispatchReceiver the receiver 
     *  @param  publisherId the <code> Id </code> of the <code> Publisher 
     *          </code> 
     *  @return a <code> DispatchNotificationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Publisher </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> dispatchReceiver </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDispatchNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDispatchNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.subscription.DispatchNotificationSession getDispatchNotificationSessionForPublisher(org.osid.subscription.DispatchReceiver dispatchReceiver, 
                                                                                                        org.osid.id.Id publisherId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving dispatch to publisher mappings. 
     *
     *  @return a <code> DispatchPublisherSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDispatchPublisher() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDispatchPublisher() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.subscription.DispatchPublisherSession getDispatchPublisherSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning dispatch to publisher mappings. 
     *
     *  @return a <code> DispatchPublisherAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDispatchPublisherAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDispatchPublisherAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.subscription.DispatchPublisherAssignmentSession getDispatchPublisherAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session associated with the dispatch smart publisher for the 
     *  given publisher. 
     *
     *  @param  publisherId the <code> Id </code> of the publisher 
     *  @return a <code> DispatchSmartPublisherSession </code> 
     *  @throws org.osid.NotFoundException <code> publisherId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> publisherId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDispatchSmartPublisher() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDispatchSmartPublisher() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.subscription.DispatchSmartPublisherSession getDispatchSmartPublisherSession(org.osid.id.Id publisherId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the publisher 
     *  lookup service. 
     *
     *  @return a <code> PublisherLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPublisherLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPublisherLookup() </code> is <code> true. </code> 
     */

    public org.osid.subscription.PublisherLookupSession getPublisherLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the publisher 
     *  query service. 
     *
     *  @return a <code> PublisherQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPublisherQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPublisherQuery() </code> is <code> true. </code> 
     */

    public org.osid.subscription.PublisherQuerySession getPublisherQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the publisher 
     *  search service. 
     *
     *  @return a <code> PublisherSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPublisherSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPublisherSearch() </code> is <code> true. </code> 
     */

    public org.osid.subscription.PublisherSearchSession getPublisherSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the publisher 
     *  administrative service. 
     *
     *  @return a <code> PublisherAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPublisherAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPublisherAdmin() </code> is <code> true. </code> 
     */

    public org.osid.subscription.PublisherAdminSession getPublisherAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the publisher 
     *  notification service. 
     *
     *  @param  publisherReceiver the receiver 
     *  @return a <code> PublisherNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> publisherReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPublisherNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPublisherNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.subscription.PublisherNotificationSession getPublisherNotificationSession(org.osid.subscription.PublisherReceiver publisherReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the publisher 
     *  hierarchy service. 
     *
     *  @return a <code> PublisherHierarchySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPublisherHierarchy() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPublisherHierarchy() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.subscription.PublisherHierarchySession getPublisherHierarchySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the publisher 
     *  hierarchy design service. 
     *
     *  @return a <code> PublisherHierarchyDesignSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPublisherHierarchyDesign() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPublisherHierarchyDesign() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.subscription.PublisherHierarchyDesignSession getPublisherHierarchyDesignSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> SubscriptionBatchManager. </code> 
     *
     *  @return a <code> SubscriptionBatchManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubscriptionbatch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubscriptionbatch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.subscription.batch.SubscriptionBatchManager getSubscriptionBatchManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> SubscriptionRulesManager. </code> 
     *
     *  @return a <code> SubscriptionRulesManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubscriptionRules() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubscriptionRules() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.subscription.rules.SubscriptionRulesManager getSubscriptionRulesManager()
        throws org.osid.OperationFailedException;
}
