//
// org.osid.subscription.SubscriptionNotificationSession
//
//     The OSID Java specification for org.osid.subscription.SubscriptionNotificationSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.subscription;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> Subscription </code> objects. This session is intended for 
 *  consumers needing to synchronize their state with this service without the 
 *  use of polling. Notifications are cancelled when this session is closed. 
 *  </p>
 */

public interface SubscriptionNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Publisher </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Publisher Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPublisherId();


    /**
     *  Gets the <code> Publisher </code> associated with this session. 
     *
     *  @return the publisher 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.Publisher getPublisher()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> Subscription </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForSubscriptionNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include entries in publishers which are children of this publisher in 
     *  the publisher hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedPublisherView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this publisher only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedPublisherView();


    /**
     *  Reliable notifications are desired. In reliable mode, notifications 
     *  are to be acknowledged using <code> 
     *  acknowledgeSubscriptionNotification() </code> . 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void reliableSubscriptionNotifications();


    /**
     *  Unreliable notifications are desired. In unreliable mode, 
     *  notifications do not need to be acknowledged. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void unreliableSubscriptionNotifications();


    /**
     *  Acknowledge a subscription notification. 
     *
     *  @param  notificationId the <code> Id </code> of the notification 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void acknowledgeSubscriptionNotification(org.osid.id.Id notificationId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new subscriptions. <code> 
     *  SubscriptionReceiver.newSubscriptions() </code> is invoked when a new 
     *  <code> Subscription </code> is created. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewSubscriptions()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new subscriptions of the given genus 
     *  type. <code> SubscriptionReceiver.newSubscriptions() </code> is 
     *  invoked when a new <code> Subscription </code> is created. 
     *
     *  @param  subscriptionGenusType a subscription genus type 
     *  @throws org.osid.NullArgumentException <code> subscriptionGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewSubscriptionsByGenusType(org.osid.type.Type subscriptionGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new subscriptions for the given resource 
     *  <code> Id. </code> <code> SubscriptionReceiver.newSubscriptions() 
     *  </code> is invoked when a new <code> Subscription </code> is created. 
     *
     *  @param  resourceId the <code> Id </code> of the reference to monitor 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewSubscriptionsForSubscriber(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new subscriptions for the given 
     *  reference <code> Id. </code> <code> 
     *  SubscriptionReceiver.newSubscriptions() </code> is invoked when a new 
     *  <code> Subscription </code> is created. 
     *
     *  @param  dispatchId the <code> Id </code> of the dispatch to monitor 
     *  @throws org.osid.NullArgumentException <code> dispatchId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewSubscriptionsForDispatch(org.osid.id.Id dispatchId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated subscriptions. <code> 
     *  SubscriptionReceiver.changedSubscriptions() </code> is invoked when a 
     *  subscription is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedSubscriptions()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated subscriptions of the given genus 
     *  type. <code> SubscriptionReceiver.changedSubscriptions() </code> is 
     *  invoked when a subscription is changed. 
     *
     *  @param  subscriptionGenusType a subscription genus type 
     *  @throws org.osid.NullArgumentException <code> subscriptionGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedSubscriptionsByGenusType(org.osid.type.Type subscriptionGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of changed subscriptions for the given 
     *  resource <code> Id. </code> <code> 
     *  SubscriptionReceiver.changedSubscriptions() </code> is invoked when a 
     *  <code> Subscription </code> for the resource is changed. 
     *
     *  @param  resourceId the <code> Id </code> of the resource to monitor 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedSubscriptionsForSubscriber(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of changed subscriptions for the given 
     *  dispatch <code> Id. </code> <code> 
     *  SubscriptionReceiver.changedSubscription() </code> is invoked when a 
     *  <code> Subscription </code> for the dispatch is changed. 
     *
     *  @param  dispatchId the <code> Id </code> of the dispatch to monitor 
     *  @throws org.osid.NullArgumentException <code> dispatchId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedSubscriptionsForDispatch(org.osid.id.Id dispatchId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated subscription. <code> 
     *  SubscriptionReceiver.changedSubscriptions() </code> is invoked when 
     *  the specified subscription is changed. 
     *
     *  @param  subscriptionId the <code> Id </code> of the <code> 
     *          Subscription </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> subscriptionId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedSubscription(org.osid.id.Id subscriptionId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted subscriptions. <code> 
     *  SubscriptionReceiver.deletedSubscriptions() </code> is invoked when a 
     *  subscription is deleted. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedSubscriptions()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted subscriptions of the given genus 
     *  type. <code> SubscriptionReceiver.deletedSubscriptions() </code> is 
     *  invoked when a subscription is deleted. 
     *
     *  @param  subscriptionGenusType a subscription genus type 
     *  @throws org.osid.NullArgumentException <code> subscriptionGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedSubscriptionsByGenusType(org.osid.type.Type subscriptionGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of changed subscriptions for the given 
     *  subscriber <code> Id. </code> <code> 
     *  SubscriptionReceiver.deletedSubscriptions() </code> is invoked when a 
     *  <code> Subscription </code> for the resource is deleted. 
     *
     *  @param  resourceId the <code> Id </code> of the resource to monitor 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedSubscriptionsForSubscriber(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of changed subscriptions for the given 
     *  dispatch <code> Id. </code> <code> 
     *  SubscriptionReceiver.deletedSubscriptions() </code> is invoked when a 
     *  <code> Subscription </code> for the dispatch is deleted. 
     *
     *  @param  dispatchId the <code> Id </code> of the dispatch to monitor 
     *  @throws org.osid.NullArgumentException <code> dispatchId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedSubscriptionsForDispatch(org.osid.id.Id dispatchId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted subscription. <code> 
     *  SubscriptionReceiver.deletedSubscriptions() </code> is invoked when 
     *  the specified subscription is deleted. 
     *
     *  @param  subscriptionId the <code> Id </code> of the <code> 
     *          Subscription </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> subscriptionId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedSubscription(org.osid.id.Id subscriptionId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
