//
// org.osid.subscription.SubscriptionSmartPublisherSession
//
//     The OSID Java specification for org.osid.subscription.SubscriptionSmartPublisherSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.subscription;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  catalogs. A <code> SubscriptionQuery </code> can be retrieved from this 
 *  session and mapped to this <code> Publisher </code> to create a virtual 
 *  collection of <code> Subscriptions. </code> The subscriptions may be 
 *  sequenced using the <code> SubscriptionSearchOrder </code> from this 
 *  session. </p> 
 *  
 *  <p> This <code> Publisher </code> has a default query that matches any 
 *  subscription and a default search order that specifies no sequencing. The 
 *  queries may be examined using a <code> SubscriptionQueryInspector. </code> 
 *  The query may be modified by converting the inspector back to a <code> 
 *  SubscriptionQuery. </code> </p>
 */

public interface SubscriptionSmartPublisherSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Publisher </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Publisher Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPublisherId();


    /**
     *  Gets the <code> Publisher </code> associated with this session. 
     *
     *  @return the <code> Publisher </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.Publisher getPublisher()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart publishers. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart publisher management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartPublishers();


    /**
     *  Gets a subscription query. 
     *
     *  @return the subscription query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.SubscriptionQuery getSubscriptionQuery();


    /**
     *  Gets a subscription search order. 
     *
     *  @return the subscription search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.SubscriptionSearchOrder getSubscriptionSearchOrder();


    /**
     *  Applies a subscription query to this publisher. 
     *
     *  @param  subscriptionQuery the subscription query 
     *  @throws org.osid.NullArgumentException <code> subscriptionQuery 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> subscriptionQuery </code> 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applySubscriptionQuery(org.osid.subscription.SubscriptionQuery subscriptionQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a subscription query inspector for this publisher. 
     *
     *  @return the subscriptions query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.SubscriptionQueryInspector inspectSubscriptionQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a subscription search order to this publisher. 
     *
     *  @param  subscriptionSearchOrder the subscription search order 
     *  @throws org.osid.NullArgumentException <code> subscriptionSearchOrder 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> subscriptionSearchOrder 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applySubscriptionSequencing(org.osid.subscription.SubscriptionSearchOrder subscriptionSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a subscription query from an inspector. 
     *
     *  @param  subscriptionQueryInspector a query inspector 
     *  @return the subscription query 
     *  @throws org.osid.NullArgumentException <code> 
     *          subscriptionQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          subscriptionQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.SubscriptionQuery getSubscriptionQueryFromInspector(org.osid.subscription.SubscriptionQueryInspector subscriptionQueryInspector);
}
