//
// org.osid.subscription.rules.SubscriptionEnablerAdminSession
//
//     The OSID Java specification for org.osid.subscription.rules.SubscriptionEnablerAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.subscription.rules;


/**
 *  <p>This session creates and removes subscription enablers. The data for 
 *  create and update is provided via the <code> SubscriptionEnablerForm. 
 *  </code> </p>
 */

public interface SubscriptionEnablerAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Publisher </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Publisher Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPublisherId();


    /**
     *  Gets the <code> Publisher </code> associated with this session. 
     *
     *  @return the publisher 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.Publisher getPublisher()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create subscription enablers. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> SubscriptionEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer create 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> SubscriptionEnabler </code> 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateSubscriptionEnabler();


    /**
     *  Tests if this user can create a single <code> SubscriptionEnabler 
     *  </code> using the desired record types. While <code> 
     *  SubscriptionRulesManager.getSubscriptionEnablerRecordTypes() </code> 
     *  can be used to examine which records are supported, this method tests 
     *  which record(s) are required for creating a specific <code> 
     *  SubscriptionEnabler. </code> Providing an empty array tests if a 
     *  <code> SubscriptionEnabler </code> can be created with no records. 
     *
     *  @param  subscriptionEnablerRecordTypes array of subscription enabler 
     *          record types 
     *  @return <code> true </code> if <code> SubscriptionEnabler </code> 
     *          creation using the specified record <code> Types </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          subscriptionEnablerRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateSubscriptionEnablerWithRecordTypes(org.osid.type.Type[] subscriptionEnablerRecordTypes);


    /**
     *  Gets the subscription enabler form for creating new subscription 
     *  enablers. A new form should be requested for each create transaction. 
     *
     *  @param  subscriptionEnablerRecordTypes array of subscription enabler 
     *          record types 
     *  @return the subscription enabler form 
     *  @throws org.osid.NullArgumentException <code> 
     *          subscriptionEnablerRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.rules.SubscriptionEnablerForm getSubscriptionEnablerFormForCreate(org.osid.type.Type[] subscriptionEnablerRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> SubscriptionEnabler. </code> 
     *
     *  @param  subscriptionEnablerForm the form for this <code> 
     *          SubscriptionEnabler </code> 
     *  @return the new <code> SubscriptionEnabler </code> 
     *  @throws org.osid.IllegalStateException <code> subscriptionEnablerForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> subscriptionEnablerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> subscriptionEnablerForm 
     *          </code> did not originate from <code> 
     *          getSubscriptionEnablerFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.rules.SubscriptionEnabler createSubscriptionEnabler(org.osid.subscription.rules.SubscriptionEnablerForm subscriptionEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update subscription enablers. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> SubscriptionEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer update 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> SubscriptionEnabler </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateSubscriptionEnablers();


    /**
     *  Gets the subscription enabler form for updating an existing 
     *  subscription enabler. A new subscription enabler form should be 
     *  requested for each update transaction. 
     *
     *  @param  subscriptionEnablerId the <code> Id </code> of the <code> 
     *          SubscriptionEnabler </code> 
     *  @return the subscription enabler form 
     *  @throws org.osid.NotFoundException <code> subscriptionEnablerId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> subscriptionEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.rules.SubscriptionEnablerForm getSubscriptionEnablerFormForUpdate(org.osid.id.Id subscriptionEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing subscription enabler. 
     *
     *  @param  subscriptionEnablerForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> subscriptionEnablerForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> subscriptionEnablerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> subscriptionEnablerForm 
     *          </code> did not originate from <code> 
     *          getSubscriptionEnablerFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateSubscriptionEnabler(org.osid.subscription.rules.SubscriptionEnablerForm subscriptionEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete subscription enablers. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> SubscriptionEnabler 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer delete 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> SubscriptionEnabler </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteSubscriptionEnablers();


    /**
     *  Deletes a <code> SubscriptionEnabler. </code> 
     *
     *  @param  subscriptionEnablerId the <code> Id </code> of the <code> 
     *          SubscriptionEnabler </code> to remove 
     *  @throws org.osid.NotFoundException <code> subscriptionEnablerId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> subscriptionEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteSubscriptionEnabler(org.osid.id.Id subscriptionEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for 
     *  subscription enablers. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> SubscriptionEnabler </code> 
     *          aliasing is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSubscriptionEnablerAliases();


    /**
     *  Adds an <code> Id </code> to a <code> SubscriptionEnabler </code> for 
     *  the purpose of creating compatibility. The primary <code> Id </code> 
     *  of the <code> SubscriptionEnabler </code> is determined by the 
     *  provider. The new <code> Id </code> performs as an alias to the 
     *  primary <code> Id </code> . If the alias is a pointer to another 
     *  subscription enabler. it is reassigned to the given subscription 
     *  enabler <code> Id. </code> 
     *
     *  @param  subscriptionEnablerId the <code> Id </code> of a <code> 
     *          SubscriptionEnabler </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> subscriptionEnablerId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> subscriptionEnablerId 
     *          </code> or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasSubscriptionEnabler(org.osid.id.Id subscriptionEnablerId, 
                                         org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
