//
// org.osid.subscription.rules.SubscriptionEnablerPublisherAssignmentSession
//
//     The OSID Java specification for org.osid.subscription.rules.SubscriptionEnablerPublisherAssignmentSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.subscription.rules;


/**
 *  <p>This session provides methods to re-assign <code> SubscriptionEnabler 
 *  </code> to <code> Publisher </code> mappings. A <code> SubscriptionEnabler 
 *  </code> may appear in multiple <code> Publisher </code> objects and 
 *  removing the last reference to a <code> SubscriptionEnabler </code> is the 
 *  equivalent of deleting it. Each <code> Subscription </code> may have its 
 *  own authorizations governing who is allowed to operate on it. </p> 
 *  
 *  <p> Adding a reference of a <code> SubscriptionEnabler </code> to another 
 *  <code> Publisher </code> is not a copy operation (eg: does not change its 
 *  <code> Id </code> ). </p>
 */

public interface SubscriptionEnablerPublisherAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter subscription enabler/publisher mappings. 
     *  A return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignSubscriptionEnablers();


    /**
     *  Tests if this user can alter subscription enabler/publisher mappings. 
     *  A return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @param  publisherId the <code> Id </code> of the <code> Publisher 
     *          </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> publisherId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignSubscriptionEnablersToPublisher(org.osid.id.Id publisherId);


    /**
     *  Gets a list of publishers including and under the given publisher node 
     *  in which any publisher enabler can be assigned. 
     *
     *  @param  publisherId the <code> Id </code> of the <code> Publisher 
     *          </code> 
     *  @return list of assignable subscription <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> publisherId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignablePublisherIds(org.osid.id.Id publisherId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of publishers including and under the given publisher node 
     *  in which a specific publisher enabler can be assigned. 
     *
     *  @param  publisherId the <code> Id </code> of the <code> Publisher 
     *          </code> 
     *  @param  subscriptionEnablerId the <code> Id </code> of the <code> 
     *          SubscriptionEnabler </code> 
     *  @return list of assignable publisher <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> publisherId </code> or 
     *          <code> subscriptionEnablerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignablePublisherIdsForSubscriptionEnabler(org.osid.id.Id publisherId, 
                                                                              org.osid.id.Id subscriptionEnablerId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> SubscriptionEnabler </code> to a <code> 
     *  Publisher. </code> 
     *
     *  @param  subscriptionEnablerId the <code> Id </code> of the <code> 
     *          SubscriptionEnabler </code> 
     *  @param  publisherId the <code> Id </code> of the <code> Publisher 
     *          </code> 
     *  @throws org.osid.AlreadyExistsException <code> subscriptionEnablerId 
     *          </code> is already assigned to <code> publisherId </code> 
     *  @throws org.osid.NotFoundException <code> subscriptionEnablerId 
     *          </code> or <code> publisherId </code> not found 
     *  @throws org.osid.NullArgumentException <code> subscriptionEnablerId 
     *          </code> or <code> publisherId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignSubscriptionEnablerToPublisher(org.osid.id.Id subscriptionEnablerId, 
                                                     org.osid.id.Id publisherId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> SubscriptionEnabler </code> from a <code> Publisher. 
     *  </code> 
     *
     *  @param  subscriptionEnablerId the <code> Id </code> of the <code> 
     *          SubscriptionEnabler </code> 
     *  @param  publisherId the <code> Id </code> of the <code> Publisher 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> subscriptionEnablerId 
     *          </code> or <code> publisherId </code> not found or <code> 
     *          subscriptionEnablerId </code> not assigned to <code> 
     *          publisherId </code> 
     *  @throws org.osid.NullArgumentException <code> subscriptionEnablerId 
     *          </code> or <code> publisherId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignSubscriptionEnablerFromPublisher(org.osid.id.Id subscriptionEnablerId, 
                                                         org.osid.id.Id publisherId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves a <code> SubscriptionEnabler </code> from one <code> Publisher 
     *  </code> to another. Mappings to other <code> Publishers </code> are 
     *  unaffected. 
     *
     *  @param  subscriptionEnablerId the <code> Id </code> of the <code> 
     *          SubscriptionEnabler </code> 
     *  @param  fromPublisherId the <code> Id </code> of the current <code> 
     *          Publisher </code> 
     *  @param  toPublisherId the <code> Id </code> of the destination <code> 
     *          Publisher </code> 
     *  @throws org.osid.NotFoundException <code> subscriptionEnablerId, 
     *          fromPublisherId, </code> or <code> toPublisherId </code> not 
     *          found or <code> subscriptionEnablerId </code> not mapped to 
     *          <code> fromPublisherId </code> 
     *  @throws org.osid.NullArgumentException <code> subscriptionEnablerId, 
     *          fromPublisherId, </code> or <code> toPublisherId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void reassignSubscriptionEnablerToPublisher(org.osid.id.Id subscriptionEnablerId, 
                                                       org.osid.id.Id fromPublisherId, 
                                                       org.osid.id.Id toPublisherId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
