//
// org.osid.subscription.rules.SubscriptionEnablerRuleLookupSession
//
//     The OSID Java specification for org.osid.subscription.rules.SubscriptionEnablerRuleLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.subscription.rules;


/**
 *  <p>This session provides methods to retrieve <code> SubscriptionEnabler 
 *  </code> to <code> Subscription </code> mappings. A <code> Subscription 
 *  </code> with multiple <code> SubscriptionEnablers </code> means any 
 *  positive rule evaluation across the enablers result in an enabled <code> 
 *  Subscription. </code> </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated publisher view: All methods in this session operate, 
 *      retrieve and pertain subscription enablers defined explicitly in the 
 *      current publisher. </li> 
 *      <li> federated publisher view: All methods in this session operate, 
 *      retrieve and pertain to all subscription enablers defined in this 
 *      publisher and any other publisher enablers implicitly available in 
 *      this publisher through publisher inheritence. </li> 
 *  </ul>
 *  
 */

public interface SubscriptionEnablerRuleLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Publisher </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Publisher Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPublisherId();


    /**
     *  Gets the <code> Publisher </code> associated with this session. 
     *
     *  @return the publisher 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.Publisher getPublisher()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform lookups of subscription 
     *  enabler/subscription mappings. A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  lookup methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if looking up mappings is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupSubscriptionEnablerRules();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeSubscriptionEnablerRuleView();


    /**
     *  A complete view of the <code> SubscriptionEnabler </code> and <code> 
     *  Subscription </code> returns is desired. Methods will return what is 
     *  requested or result in an error. This view is used when greater 
     *  precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenarySubscriptionEnablerRuleView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include subscription enablers in publishers which are children of this 
     *  publisher in the publisher hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedPublisherView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this publisher only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedPublisherView();


    /**
     *  Gets the <code> SubscriptionEnabler Id </code> associated with a 
     *  <code> Subscription. </code> 
     *
     *  @param   subscriptionId <code> Id </code> of the <code> Subscription 
     *          </code> 
     *  @return the subscription enabler <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> subscriptionId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> subscriptionId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getSubscriptionEnablerIdsForSubscription(org.osid.id.Id  subscriptionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> SubscriptionEnabler </code> associated with a <code> 
     *  Subscription. </code> 
     *
     *  @param  subscriptionId <code> Id </code> of the <code> Subscription 
     *          </code> 
     *  @return the subscription enablers 
     *  @throws org.osid.NotFoundException <code> subscriptionId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> subscriptionId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.rules.SubscriptionEnablerList getSubscriptionEnablersForSubscription(org.osid.id.Id subscriptionId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Subscription </code> <code> Ids </code> mapped to a 
     *  <code> SubscriptionEnabler. </code> 
     *
     *  @param  subscriptionEnablerId <code> Id </code> of a <code> 
     *          SubscriptionEnabler </code> 
     *  @return list of subscription <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> subscriptionEnablerId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> subscriptionEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getSubscriptionIdsBySubscriptionEnabler(org.osid.id.Id subscriptionEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Subscriptions </code> mapped to a <code> 
     *  SubscriptionEnabler. </code> 
     *
     *  @param  subscriptionEnablerId <code> Id </code> of a <code> 
     *          SubscriptionEnabler </code> 
     *  @return list of subscriptions 
     *  @throws org.osid.NotFoundException <code> subscriptionEnablerId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> subscriptionEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.SubscriptionList getSubscriptionsBySubscriptionEnabler(org.osid.id.Id subscriptionEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
