//
// org.osid.subscription.rules.SubscriptionEnablerSearchSession
//
//     The OSID Java specification for org.osid.subscription.rules.SubscriptionEnablerSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.subscription.rules;


/**
 *  <p>This session provides methods for searching among <code> 
 *  SubscriptionEnabler </code> objects. The search query is constructed using 
 *  the <code> SubscriptionEnableryQuery. </code> </p> 
 *  
 *  <p> <code> getSubscriptionEnablersByQuery() </code> is the basic search 
 *  method and returns a list of <code> SubscriptionEnablers. </code> A more 
 *  advanced search may be performed with <code> 
 *  getSubscriptionEnablersBySearch(). </code> It accepts a <code> 
 *  SubscriptionEnablerSearch </code> in addition to the query for the purpose 
 *  of specifying additional options affecting the entire search, such as 
 *  ordering. <code> getSubscriptionEnablersBySearch() </code> returns a 
 *  <code> SubscriptionEnablerSearchResults </code> that can be used to access 
 *  the resulting <code> SubscriptionEnablerList </code> or be used to perform 
 *  a search within the result set through <code> SubscriptionEnablerSearch. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated subscription view: searches include subscription 
 *      enablers in subscriptions of which this subscription is an ancestor in 
 *      the subscription hierarchy </li> 
 *      <li> isolated subscription view: searches are restricted to 
 *      subscription enablers in this subscription </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> SubscriptionEnablers </code> may have a query record indicated 
 *  by their respective record types. The query record is accessed via the 
 *  <code> SubscriptionEnablerQuery. </code> </p>
 */

public interface SubscriptionEnablerSearchSession
    extends org.osid.subscription.rules.SubscriptionEnablerQuerySession {


    /**
     *  Gets a subscription enabler search. 
     *
     *  @return the subscription enabler search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.rules.SubscriptionEnablerSearch getSubscriptionEnablerSearch();


    /**
     *  Gets a subscription enabler search order. The <code> 
     *  SubscriptionEnablerSearchOrder </code> is supplied to a <code> 
     *  SubscriptionEnablerSearch </code> to specify the ordering of results. 
     *
     *  @return the subscription enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.rules.SubscriptionEnablerSearchOrder getSubscriptionEnablerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  subscriptionEnablerQuery the subscription enabler query 
     *  @param  subscriptionEnablerSearch the subscription enabler search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> subscriptionEnablerQuery 
     *          </code> or <code> subscriptionEnablerSearch </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> subscriptionEnablerQuery 
     *          </code> or <code> subscriptionEnablerSearch </code> is not of 
     *          this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.rules.SubscriptionEnablerSearchResults getSubscriptionEnablersBySearch(org.osid.subscription.rules.SubscriptionEnablerQuery subscriptionEnablerQuery, 
                                                                                                        org.osid.subscription.rules.SubscriptionEnablerSearch subscriptionEnablerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a subscription enabler query from an inspector. The inspector is 
     *  available from a <code> SubscriptionEnablerSearchResults. </code> 
     *
     *  @param  subscriptionEnablerQueryInspector a subscription enabler query 
     *          inspector 
     *  @return the subscription enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          subscriptionEnablerQueryInspector </code> is <code> null 
     *          </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          subscriptionEnablerQueryInspector </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.subscription.rules.SubscriptionEnablerQuery getSubscriptionEnablerQueryFromInspector(org.osid.subscription.rules.SubscriptionEnablerQueryInspector subscriptionEnablerQueryInspector);
}
