//
// org.osid.subscription.rules.SubscriptionRulesProfile
//
//     The OSID Java specification for org.osid.subscription.rules.SubscriptionRulesProfile.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.subscription.rules;


/**
 *  <p>The subscription rules profile describes the interoperability among 
 *  subscription rules services. </p>
 */

public interface SubscriptionRulesProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any broker federation is exposed. Federation is exposed when 
     *  a specific broker may be identified, selected and used to create a 
     *  lookup or admin session. Federation is not exposed when a set of 
     *  brokers appears as a single broker. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if looking up subscription enablers is supported. 
     *
     *  @return <code> true </code> if subscription enabler lookup is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubscriptionEnablerLookup();


    /**
     *  Tests if querying subscription enablers is supported. 
     *
     *  @return <code> true </code> if subscription enabler query is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubscriptionEnablerQuery();


    /**
     *  Tests if searching subscription enablers is supported. 
     *
     *  @return <code> true </code> if subscription enabler search is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubscriptionEnablerSearch();


    /**
     *  Tests if a subscription enabler administrative service is supported. 
     *
     *  @return <code> true </code> if subscription enabler administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubscriptionEnablerAdmin();


    /**
     *  Tests if a subscription enabler notification service is supported. 
     *
     *  @return <code> true </code> if subscription enabler notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubscriptionEnablerNotification();


    /**
     *  Tests if a subscription enabler publisher lookup service is supported. 
     *
     *  @return <code> true </code> if a publisher enabler subscription lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubscriptionEnablerPublisher();


    /**
     *  Tests if a subscription enabler publisher service is supported. 
     *
     *  @return <code> true </code> if subscription enabler publisher 
     *          assignment service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubscriptionEnablerPublisherAssignment();


    /**
     *  Tests if a subscription enabler subscription lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if a subscription enabler subscription 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubscriptionEnablerSmartSubscription();


    /**
     *  Tests if a subscription enabler rule lookup service is supported. 
     *
     *  @return <code> true </code> if a subscription enabler rule lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubscriptionEnablerRuleLookup();


    /**
     *  Tests if a subscription enabler rule application service is supported. 
     *
     *  @return <code> true </code> if subscription enabler rule application 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubscriptionEnablerRuleApplication();


    /**
     *  Gets the supported <code> SubscriptionEnabler </code> record types. 
     *
     *  @return a list containing the supported <code> SubscriptionEnabler 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSubscriptionEnablerRecordTypes();


    /**
     *  Tests if the given <code> SubscriptionEnabler </code> record type is 
     *  supported. 
     *
     *  @param  subscriptionEnablerRecordType a <code> Type </code> indicating 
     *          a <code> SubscriptionEnabler </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          subscriptionEnablerRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubscriptionEnablerRecordType(org.osid.type.Type subscriptionEnablerRecordType);


    /**
     *  Gets the supported <code> SubscriptionEnabler </code> search record 
     *  types. 
     *
     *  @return a list containing the supported <code> SubscriptionEnabler 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getSubscriptionEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> SubscriptionEnabler </code> search record 
     *  type is supported. 
     *
     *  @param  subscriptionEnablerSearchRecordType a <code> Type </code> 
     *          indicating a <code> SubscriptionEnabler </code> search record 
     *          type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          subscriptionEnablerSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSubscriptionEnablerSearchRecordType(org.osid.type.Type subscriptionEnablerSearchRecordType);
}
