//
// org.osid.subscription.rules.SubscriptionRulesProxyManager
//
//     The OSID Java specification for org.osid.subscription.rules.SubscriptionRulesProxyManager.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.subscription.rules;


/**
 *  <p>The subscription rules proxy manager provides access to subscription 
 *  rules sessions and provides interoperability tests for various aspects of 
 *  this service. Methods in this manager pass a <code> Proxy </code> for 
 *  passing information from server environments. The sessions included in 
 *  this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> SubscriptionEnablerLookupSession: </code> a session to 
 *      retrieve subscription enablers </li> 
 *      <li> <code> SubscriptionEnablerQuerySession: </code> a session to 
 *      query for subscription enablers </li> 
 *      <li> <code> SubscriptionEnablerSearchSession: </code> a session to 
 *      search for subscription enablers </li> 
 *      <li> <code> SubscriptionEnablerAdminSession: </code> a session to 
 *      create and delete subscription enablers </li> 
 *      <li> <code> SubscriptionEnablerNotificationSession: </code> a session 
 *      to receive notifications pertaining to subscription enabler changes 
 *      </li> 
 *      <li> <code> SubscriptionEnablerPublisherSession: </code> a session to 
 *      look up subscription enabler publisher mappings </li> 
 *      <li> <code> SubscriptionEnablerPublisherAssignmentSession: </code> a 
 *      session to manage subscription enabler to publisher mappings </li> 
 *      <li> <code> SubscriptionEnablerSmartPublisherSession: </code> a 
 *      session to manage dynamic publishers of subscription enablers </li> 
 *      <li> <code> SubscriptionEnablerRuleLookupSession: </code> a session to 
 *      look up subscription enabler to subscription mappings </li> 
 *      <li> <code> SubscriptionEnablerRuleApplicationSession: </code> a 
 *      session to apply subscription enablers to subscriptions </li> 
 *  </ul>
 *  
 */

public interface SubscriptionRulesProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.subscription.rules.SubscriptionRulesProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the subscription 
     *  enabler lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> SubscriptionEnablerLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubscriptionEnablerLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubscriptionEnablerLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.subscription.rules.SubscriptionEnablerLookupSession getSubscriptionEnablerLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the subscription 
     *  enabler lookup service for the given publisher. 
     *
     *  @param  publisherId the <code> Id </code> of the <code> Publisher 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> SubscriptionEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Publisher </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> publisherId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubscriptionEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubscriptionEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.subscription.rules.SubscriptionEnablerLookupSession getSubscriptionEnablerLookupSessionForPublisher(org.osid.id.Id publisherId, 
                                                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the subscription 
     *  enabler query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> SubscriptionEnablerQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubscriptionEnablerQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubscriptionEnablerQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.subscription.rules.SubscriptionEnablerQuerySession getSubscriptionEnablerQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the subscription 
     *  enabler query service for the given publisher. 
     *
     *  @param  publisherId the <code> Id </code> of the <code> Publisher 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> SubscriptionEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Publisher </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> publisherId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubscriptionEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubscriptionEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.subscription.rules.SubscriptionEnablerQuerySession getSubscriptionEnablerQuerySessionForPublisher(org.osid.id.Id publisherId, 
                                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the subscription 
     *  enabler search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> SubscriptionEnablerSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubscriptionEnablerSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubscriptionEnablerSearch() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.subscription.rules.SubscriptionEnablerSearchSession getSubscriptionEnablerSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the subscription 
     *  enablers earch service for the given publisher. 
     *
     *  @param  publisherId the <code> Id </code> of the <code> Publisher 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> SubscriptionEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Publisher </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> publisherId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubscriptionEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubscriptionEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.subscription.rules.SubscriptionEnablerSearchSession getSubscriptionEnablerSearchSessionForPublisher(org.osid.id.Id publisherId, 
                                                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the subscription 
     *  enabler administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> SubscriptionEnablerAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubscriptionEnablerAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubscriptionEnablerAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.subscription.rules.SubscriptionEnablerAdminSession getSubscriptionEnablerAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the subscription 
     *  enabler administration service for the given publisher. 
     *
     *  @param  publisherId the <code> Id </code> of the <code> Publisher 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> SubscriptionEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Publisher </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> publisherId or proxy is 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubscriptionEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubscriptionEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.subscription.rules.SubscriptionEnablerAdminSession getSubscriptionEnablerAdminSessionForPublisher(org.osid.id.Id publisherId, 
                                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the subscription 
     *  enabler notification service. 
     *
     *  @param  subscriptionEnablerReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> SubscriptionEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          subscriptionEnablerReceiver </code> or <code> proxy </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubscriptionEnablerNotification() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubscriptionEnablerNotification() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.subscription.rules.SubscriptionEnablerNotificationSession getSubscriptionEnablerNotificationSession(org.osid.subscription.rules.SubscriptionEnablerReceiver subscriptionEnablerReceiver, 
                                                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the subscription 
     *  enabler notification service for the given publisher. 
     *
     *  @param  subscriptionEnablerReceiver the notification callback 
     *  @param  publisherId the <code> Id </code> of the <code> Publisher 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> SubscriptionEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no publisher found by the given 
     *          <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          subscriptionEnablerReceiver, publisherId, </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubscriptionEnablerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubscriptionEnablerNotification() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.subscription.rules.SubscriptionEnablerNotificationSession getSubscriptionEnablerNotificationSessionForPublisher(org.osid.subscription.rules.SubscriptionEnablerReceiver subscriptionEnablerReceiver, 
                                                                                                                                    org.osid.id.Id publisherId, 
                                                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup subscription 
     *  enabler/publisher mappings for subscription enablers. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> SubscriptionEnablerSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubscriptionEnablerPublisher() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubscriptionEnablerPublisher() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.subscription.rules.SubscriptionEnablerPublisherSession getSubscriptionEnablerPublisherSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning 
     *  subscription enablers to publishers 
     *
     *  @param  proxy a proxy 
     *  @return a <code> SubscriptionEnablerPublisherAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubscriptionEnablerPublisherAssignment() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubscriptionEnablerPublisherAssignment() </code> 
     *              is <code> true. </code> 
     */

    public org.osid.subscription.rules.SubscriptionEnablerPublisherAssignmentSession getSubscriptionEnablerPublisherAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage subscription enabler 
     *  smart publishers. 
     *
     *  @param  publisherId the <code> Id </code> of the <code> Publisher 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> SubscriptionEnablerSmartPublisherSession </code> 
     *  @throws org.osid.NotFoundException no <code> Publisher </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> publisherId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubscriptionEnablerSmartPublisher() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubscriptionEnablerSmarPublisher() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.subscription.rules.SubscriptionEnablerSmartPublisherSession getSubscriptionEnablerSmartPublisherSession(org.osid.id.Id publisherId, 
                                                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the subscription 
     *  enabler mapping lookup service for looking up the rules applied to the 
     *  subscription. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> SubscriptionEnablerRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubscriptionEnablerRuleLookup() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubscriptionEnablerRuleLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.subscription.rules.SubscriptionEnablerRuleLookupSession getSubscriptionEnablerRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the subscription 
     *  enabler mapping lookup service for the given subscription for looking 
     *  up rules applied to a subscription. 
     *
     *  @param  publisherId the <code> Id </code> of the <code> Publisher 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> SubscriptionEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Publisher </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> publisherId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubscriptionEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubscriptionEnablerRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.subscription.rules.SubscriptionEnablerRuleLookupSession getSubscriptionEnablerRuleLookupSessionForPublisher(org.osid.id.Id publisherId, 
                                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the subscription 
     *  enabler assignment service to apply enablers to subscriptions. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> SubscriptionEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubscriptionEnablerRuleApplication() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubscriptionEnablerRuleApplication() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.subscription.rules.SubscriptionEnablerRuleApplicationSession getSubscriptionEnablerRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the subscription 
     *  enabler assignment service for the given subscription to apply 
     *  enablers to subscriptions. 
     *
     *  @param  publisherId the <code> Id </code> of the <code> Publisher 
     *          </code> 
     *  @param  proxy a proxy 
     *  @return a <code> SubscriptionEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Publisher </code> found 
     *          by the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> publisherId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSubscriptionEnablerRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSubscriptionEnablerRuleApplication() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.subscription.rules.SubscriptionEnablerRuleApplicationSession getSubscriptionEnablerRuleApplicationSessionForPublisher(org.osid.id.Id publisherId, 
                                                                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;
}
