//
// org.osid.topology.Edge
//
//     The OSID Java specification for org.osid.topology.Edge.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.topology;


/**
 *  <p>A <code> Edge </code> represents relationship between two nodes. </p>
 */

public interface Edge
    extends org.osid.OsidRelationship {


    /**
     *  Tests if this is a directional edge. 
     *
     *  @return <code> true </code> if this edge is directional, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isDirectional();


    /**
     *  Tests if this directional edge is bi-directional. 
     *
     *  @return <code> true </code> if this edge is directional and 
     *          bi-directional, <code> false </code> otherwise 
     *  @throws org.osid.IllegalStateException <code> isDirectional() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isBiDirectional();


    /**
     *  Gets the cost of this edge. 
     *
     *  @return a number representing the cost of this edge 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getCost();


    /**
     *  Gets the distance of this edge. 
     *
     *  @return a number representing the distance of this edge 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getDistance();


    /**
     *  Gets the source node of this edge. If the edge is uni-directional, the 
     *  source node is the node at the beginning of the edge, otherwise it may 
     *  be relative to the means of traversal of the graph. 
     *
     *  @return the source node <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getSourceNodeId();


    /**
     *  Gets the <code> Id </code> of the source node of this edge. If the 
     *  edge is uni-directional, the source node is the node at the beginning 
     *  of the edge, otherwise it may be relative to the means of traversal of 
     *  the graph. 
     *
     *  @return the source node 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.Node getSourceNode()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the destination node of this edge. If 
     *  the edge is uni-directional, the destination node is the node at the 
     *  end of the edge, otherwise it may be relative to the means of 
     *  traversal of the graph. 
     *
     *  @return the detsination node <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDestinationNodeId();


    /**
     *  Gets the destination node of this edge. If the edge is 
     *  uni-directional, the destination node is the node at the end of the 
     *  edge, otherwise it may be relative to the means of traversal of the 
     *  graph. 
     *
     *  @return the detsination node 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.Node getDestinationNode()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the edge record corresponding to the given <code> Edge </code> 
     *  record <code> Type. </code> This method is used to retrieve an object 
     *  implementing the requested record. The <code> edgeRecordType </code> 
     *  may be the <code> Type </code> returned in <code> getRecordTypes() 
     *  </code> or any of its parents in a <code> Type </code> hierarchy where 
     *  <code> hasRecordType(edgeRecordType) </code> is <code> true </code> . 
     *
     *  @param  edgeRecordType the type of edge record to retrieve 
     *  @return the edge record 
     *  @throws org.osid.NullArgumentException <code> edgeRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(edgeRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.records.EdgeRecord getEdgeRecord(org.osid.type.Type edgeRecordType)
        throws org.osid.OperationFailedException;
}
