//
// org.osid.topology.EdgeForm
//
//     The OSID Java specification for org.osid.topology.EdgeForm.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.topology;


/**
 *  <p>This is the form for creating and updating <code> Edges. </code> Like 
 *  all <code> OsidForm </code> objects, various data elements may be set here 
 *  for use in the create and update methods in the <code> EdgeAdminSession. 
 *  </code> For each data element that may be set, metadata may be examined to 
 *  provide display hints or data constraints. </p>
 */

public interface EdgeForm
    extends org.osid.OsidRelationshipForm {


    /**
     *  Gets the metadata for a directional edges. 
     *
     *  @return metadata for the directionality 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDirectionalMetadata();


    /**
     *  Sets the directional flag. 
     *
     *  @param  direction <code> true </code> to set the edge as directional, 
     *          <code> false </code> to set the edge as non-directional 
     *  @throws org.osid.InvalidArgumentException <code> direction </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setDirectional(boolean direction);


    /**
     *  Removes the directional flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDirectional();


    /**
     *  Gets the metadata for an edge direction. 
     *
     *  @return metadata for the direction 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getBiDirectionalMetadata();


    /**
     *  Sets the direction. 
     *
     *  @param  direction <code> true </code> to set the edge as 
     *          bi-directional, <code> false </code> to set the edge as 
     *          uni-directional 
     *  @throws org.osid.InvalidArgumentException <code> direction </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setBiDirectional(boolean direction);


    /**
     *  Removes the bi-directional flag. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBiDirectional();


    /**
     *  Gets the metadata for an edge cost. 
     *
     *  @return metadata for the cost 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getCostMetadata();


    /**
     *  Sets the edge cost. 
     *
     *  @param  cost the new cost 
     *  @throws org.osid.InvalidArgumentException <code> cost </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setCost(java.math.BigDecimal cost);


    /**
     *  Removes the edge cost. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCost();


    /**
     *  Gets the metadata for an edge distance. 
     *
     *  @return metadata for the distance 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getDistanceMetadata();


    /**
     *  Sets the distance. 
     *
     *  @param  distance the new distance 
     *  @throws org.osid.InvalidArgumentException <code> distance </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setDistance(java.math.BigDecimal distance);


    /**
     *  Removes the edge distance. 
     *
     *  @throws org.osid.NoAccessException <code> Metadata.isRequired() 
     *          </code> is <code> true </code> or <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDistance();


    /**
     *  Gets the <code> EdgeFormRecord </code> corresponding to the given edge 
     *  record <code> Type. </code> 
     *
     *  @param  edgeRecordType a edge record type 
     *  @return the edge form record 
     *  @throws org.osid.NullArgumentException <code> edgeRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(edgeRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.records.EdgeFormRecord getEdgeFormRecord(org.osid.type.Type edgeRecordType)
        throws org.osid.OperationFailedException;
}
