//
// org.osid.topology.EdgeQuery
//
//     The OSID Java specification for org.osid.topology.EdgeQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.topology;


/**
 *  <p>This is the query for searching edges. Each method match specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface EdgeQuery
    extends org.osid.OsidRelationshipQuery {


    /**
     *  Sets the node <code> Id </code> for this query to match edges assigned 
     *  to nodes. 
     *
     *  @param  nodeId the node <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> nodeId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSourceNodeId(org.osid.id.Id nodeId, boolean match);


    /**
     *  Clears the node <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSourceNodeIdTerms();


    /**
     *  Tests if a <code> NodeQuery </code> is available. 
     *
     *  @return <code> true </code> if a node query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsSourceNodeQuery();


    /**
     *  Gets the query for a node. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the node query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsSourceNodeQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsSourceNodeQuery() </code> is <code> true. </code> 
     */

    public org.osid.topology.NodeQuery getSourceNodeQuery();


    /**
     *  Clears the node terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSourceNodeTerms();


    /**
     *  Sets the related node <code> Id </code> for this query to match edges 
     *  assigned to nodes. 
     *
     *  @param  nodeId the node <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> nodeId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDestinationNodeId(org.osid.id.Id nodeId, boolean match);


    /**
     *  Clears the related node <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDestinationNodeIdTerms();


    /**
     *  Tests if a <code> NodeQuery </code> is available. 
     *
     *  @return <code> true </code> if a node query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDestinationNodeQuery();


    /**
     *  Gets the query for a related node. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the node query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDestinationNodeQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDestinationNodeQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.topology.NodeQuery getDestinationNodeQuery();


    /**
     *  Clears the related node terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDestinationNodeTerms();


    /**
     *  Matches edges between the same node. 
     *
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchSameNode(boolean match);


    /**
     *  Clears the same node terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearSameNodeTerms();


    /**
     *  Matches directional edges. 
     *
     *  @param  match <code> true </code> to match directional edges, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDirectional(boolean match);


    /**
     *  Clears the directional terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDirectionalTerms();


    /**
     *  Matches bi-directional edges. 
     *
     *  @param  match <code> true </code> to match bi-directional edges, 
     *          <code> false </code> to match uni-directional edges 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchBiDirectional(boolean match);


    /**
     *  Clears the directional terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearBiDirectionalTerms();


    /**
     *  Matches edges that have the specified cost inclusive. 
     *
     *  @param  from starting range 
     *  @param  to ending range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCost(java.math.BigDecimal from, java.math.BigDecimal to, 
                          boolean match);


    /**
     *  Matches edges that has any cost assigned. 
     *
     *  @param  match <code> true </code> to match edges with any cost, <code> 
     *          false </code> to match edges with no cost assigned 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCost(boolean match);


    /**
     *  Clears the cost terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCostTerms();


    /**
     *  Matches edges that have the specified distance inclusive. 
     *
     *  @param  from starting range 
     *  @param  to ending range 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.InvalidArgumentException <code> to </code> is less 
     *          than <code> from </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDistance(java.math.BigDecimal from, 
                              java.math.BigDecimal to, boolean match);


    /**
     *  Matches edges that has any distance assigned. 
     *
     *  @param  match <code> true </code> to match edges with any distance, 
     *          <code> false </code> to match edges with no distance assigned 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDistance(boolean match);


    /**
     *  Clears the distance terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDistanceTerms();


    /**
     *  Sets the graph <code> Id </code> for this query to match edges 
     *  assigned to graphs. 
     *
     *  @param  graphId the graph <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> graphId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchGraphId(org.osid.id.Id graphId, boolean match);


    /**
     *  Clears the graph <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGraphIdTerms();


    /**
     *  Tests if a <code> GraphQuery </code> is available. 
     *
     *  @return <code> true </code> if a graph query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGraphQuery();


    /**
     *  Gets the query for a graph. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the graph query 
     *  @throws org.osid.UnimplementedException <code> supportsGraphQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGraphQuery() </code> is <code> true. </code> 
     */

    public org.osid.topology.GraphQuery getGraphQuery();


    /**
     *  Clears the graph terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearGraphTerms();


    /**
     *  Gets the edge query record corresponding to the given <code> Edge 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @param  edgeRecordType an edge record type 
     *  @return the edge query record 
     *  @throws org.osid.NullArgumentException <code> edgeRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(edgeRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.records.EdgeQueryRecord getEdgeQueryRecord(org.osid.type.Type edgeRecordType)
        throws org.osid.OperationFailedException;
}
