//
// org.osid.topology.GraphAdminSession
//
//     The OSID Java specification for org.osid.topology.GraphAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.topology;


/**
 *  <p>This session creates, updates, and deletes <code> Graphs. </code> The 
 *  data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Graph, </code> a <code> GraphForm </code> is requested using <code> 
 *  getGraphFormForCreate() </code> specifying the desired record <code> Types 
 *  </code> or none if no record <code> Types </code> are needed. The returned 
 *  <code> GraphForm </code> will indicate that it is to be used with a create 
 *  operation and can be used to examine metdata or validate data prior to 
 *  creation. Once the <code> GraphForm </code> is submiited to a create 
 *  operation, it cannot be reused with another create operation unless the 
 *  first operation was unsuccessful. Each <code> GraphForm </code> 
 *  corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> GraphForms </code> are requested to the <code> 
 *  Graph </code> <code> Id </code> that is to be updated using <code> 
 *  getGraphFormForUpdate(). </code> Similarly, the <code> GraphForm </code> 
 *  has metadata about the data that can be updated and it can perform 
 *  validation before submitting the update. The <code> GraphForm </code> can 
 *  only be used once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Graphs. </code> </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface GraphAdminSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can create <code> Graphs. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> Graph. </code> will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may not wish to offer create operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Graph </code> creation is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateGraphs();


    /**
     *  Tests if this user can create a single <code> Graph </code> using the 
     *  desired record types. While <code> 
     *  TopologyManager.getGraphRecordTypes() </code> can be used to examine 
     *  which records are supported, this method tests which record(s) are 
     *  required for creating a specific <code> Graph. </code> Providing an 
     *  empty array tests if a <code> Graph </code> can be created with no 
     *  records. 
     *
     *  @param  graphRecordTypes array of graph record types 
     *  @return <code> true </code> if <code> Graph </code> creation using the 
     *          specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> graphRecordTypes </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateGraphWithRecordTypes(org.osid.type.Type[] graphRecordTypes);


    /**
     *  Gets the graph form for creating new graphs. A new form should be 
     *  requested for each create transaction. 
     *
     *  @param  graphRecordTypes array of graph record types 
     *  @return the graph form 
     *  @throws org.osid.NullArgumentException <code> graphRecordTypes </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.GraphForm getGraphFormForCreate(org.osid.type.Type[] graphRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Graph. </code> 
     *
     *  @param  graphForm the form for this <code> Graph </code> 
     *  @return the new <code> Graph </code> 
     *  @throws org.osid.IllegalStateException <code> graphForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> graphForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> graphForm </code> did not 
     *          originate from <code> getGraphFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.Graph createGraph(org.osid.topology.GraphForm graphForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Graphs. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> Graph </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may not wish to offer update operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Graph </code> modification is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateGraphs();


    /**
     *  Gets the graph form for updating an existing graph. A new graph form 
     *  should be requested for each update transaction. 
     *
     *  @param  graphId the <code> Id </code> of the <code> Graph </code> 
     *  @return the graph form 
     *  @throws org.osid.NotFoundException <code> graphId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> graphId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.GraphForm getGraphFormForUpdate(org.osid.id.Id graphId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing graph 
     *
     *  @param  graphForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> graphForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> graphForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> graphForm </code> did not 
     *          originate from <code> getGraphFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateGraph(org.osid.topology.GraphForm graphForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Graphs. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> Graph </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may not wish to offer delete operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if <code> Graph </code> deletion is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteGraphs();


    /**
     *  Deletes a <code> Graph. </code> 
     *
     *  @param  graphId the <code> Id </code> of the <code> Graph </code> to 
     *          remove 
     *  @throws org.osid.NotFoundException <code> graphId </code> not found 
     *  @throws org.osid.NullArgumentException <code> graphId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteGraph(org.osid.id.Id graphId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for graphs. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known changing an alias will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer alias operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Graph </code> aliasing is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageGraphAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Graph </code> for the purpose of 
     *  creating compatibility. The primary <code> Id </code> of the <code> 
     *  Graph </code> is determined by the provider. The new <code> Id </code> 
     *  performs as an alias to the primary <code> Id. </code> If the alias is 
     *  a pointer to another graph, it is reassigned to the given graph <code> 
     *  Id. </code> 
     *
     *  @param  graphId the <code> Id </code> of a <code> Graph </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> graphId </code> not found 
     *  @throws org.osid.NullArgumentException <code> graphId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasGraph(org.osid.id.Id graphId, org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
