//
// org.osid.topology.NodeSearchSession
//
//     The OSID Java specification for org.osid.topology.NodeSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.topology;


/**
 *  <p>This session provides methods for searching among <code> Node </code> 
 *  objects. The search query is constructed using the <code> NodeQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getNodesByQuery() </code> is the basic search method and 
 *  returns a list of <code> Nodes. </code> A more advanced search may be 
 *  performed with <code> getNodesBySearch(). </code> It accepts a <code> 
 *  NodeSearch </code> in addition to the query for the purpose of specifying 
 *  additional options affecting the entire search, such as ordering. <code> 
 *  getNodesBySearch() </code> returns a <code> NodeSearchResults </code> that 
 *  can be used to access the resulting <code> NodeList </code> or be used to 
 *  perform a search within the result set through <code> NodeSearch. </code> 
 *  </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated graph view: searches include nodes in graphs of which 
 *      this graph is an ancestor in the graph hierarchy </li> 
 *      <li> isolated graph view: searches are restricted to nodes in this 
 *      graph </li> 
 *  </ul>
 *  
 *  
 *  <p> Nodes may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> NodeQuery. </code> </p>
 */

public interface NodeSearchSession
    extends org.osid.topology.NodeQuerySession {


    /**
     *  Gets a node search. 
     *
     *  @return the node search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.NodeSearch getNodeSearch();


    /**
     *  Gets a node search order. The <code> NodeSearchOrder </code> is 
     *  supplied to a <code> NodeSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the node search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.NodeSearchOrder getNodeSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  nodeQuery the node query 
     *  @param  nodeSearch the node search 
     *  @return the node search results 
     *  @throws org.osid.NullArgumentException <code> nodeQuery </code> or 
     *          <code> nodeSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> nodeQuery </code> or 
     *          <code> nodeSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.NodeSearchResults getNodesBySearch(org.osid.topology.NodeQuery nodeQuery, 
                                                                org.osid.topology.NodeSearch nodeSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a node query from an inspector. The inspector is available from a 
     *  <code> NodeSearchResults. </code> 
     *
     *  @param  nodeQueryInspector a node query inspector 
     *  @return the node query 
     *  @throws org.osid.NullArgumentException <code> nodeQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> nodeQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.NodeQuery getNodeQueryFromInspector(org.osid.topology.NodeQueryInspector nodeQueryInspector);
}
