//
// org.osid.topology.TopologyManager
//
//     The OSID Java specification for org.osid.topology.TopologyManager.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.topology;


/**
 *  <p>The topology manager provides access to topology sessions and provides 
 *  interoperability tests for various aspects of this service. The sessions 
 *  included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> TopologyTraversalSession: </code> a session to traverse 
 *      topologies </li> 
 *      <li> <code> TopologyRoutingSession: </code> a session get routes 
 *      through topologies </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> NodeLookupSession: </code> a session to retrieve nodes 
 *      </li> 
 *      <li> <code> NodeQuerySession: </code> a session to query nodes </li> 
 *      <li> <code> NodeSearchSession: </code> a session to search for nodes 
 *      </li> 
 *      <li> <code> NodeAdminSession: </code> a session to create and delete 
 *      nodes </li> 
 *      <li> <code> NodeNotificationSession: </code> a session to receive 
 *      notifications pertaining to node changes </li> 
 *      <li> <code> NodeGraphSession: </code> a session to look up node to 
 *      graph mappings </li> 
 *      <li> <code> NodeGraphAssignmentSession: </code> a session to manage 
 *      node to graph mappings </li> 
 *      <li> <code> NodeSmartGraphSession: </code> a session to manage smart 
 *      graphs of nodes </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> EdgeLookupSession: </code> a session to retrieve edges 
 *      </li> 
 *      <li> EdgeQuerySession: a session to query edges </li> 
 *      <li> <code> EdgeSearchSession: </code> a session to search for edges 
 *      </li> 
 *      <li> <code> EdgeAdminSession: </code> a session to create and delete 
 *      edges </li> 
 *      <li> <code> EdgeNotificationSession: </code> a session to receive 
 *      notifications pertaining to edge changes </li> 
 *      <li> <code> EdgeGraphSession: </code> a session to looking mappings of 
 *      edges to graphs </li> 
 *      <li> <code> EdgeGraphAssignmentSession: </code> a session to manage 
 *      edge to graph mappings </li> 
 *      <li> <code> EdgeSmartGraphSession: </code> a session to manage smart 
 *      graphs of edges </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> GraphLookupSession: </code> a session to retrieve graphs 
 *      </li> 
 *      <li> <code> GraphQuerySession: </code> a session to query for graphs 
 *      </li> 
 *      <li> <code> GraphSearchSession: </code> a session to search for graphs 
 *      </li> 
 *      <li> <code> GraphAdminSession: </code> a session to create and delete 
 *      graphs </li> 
 *      <li> <code> GraphNotificationSession: </code> a session to receive 
 *      notifications pertaining to graph changes </li> 
 *      <li> <code> GraphHierarchySession: </code> a session to traverse a 
 *      hierarchy of graph </li> 
 *      <li> <code> GraphHierarchyDesignSession: </code> a session to manage a 
 *      graph hierarchy </li> 
 *  </ul>
 *  
 */

public interface TopologyManager
    extends org.osid.OsidManager,
            org.osid.topology.TopologyProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the topology 
     *  traversal service. 
     *
     *  @return a <code> TopologyTraversalSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTopologyTraversal() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTopologyTraversal() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.topology.TopologyTraversalSession getTopologyTraversalSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the topology 
     *  traversal service for the given graph. 
     *
     *  @param  graphId the <code> Id </code> of the graph 
     *  @return a <code> TopologyTraversalSession </code> 
     *  @throws org.osid.NotFoundException no <code> Graph </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> graphId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTopologyTraversal() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTopologyTraversal() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.topology.TopologyTraversalSession getTopologyTraversalForGraph(org.osid.id.Id graphId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the topology 
     *  routing service. 
     *
     *  @return a <code> TopologyRoutingSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTopologyRouting() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTopologyRouting() </code> is <code> true. </code> 
     */

    public org.osid.topology.TopologyRoutingSession getTopologyRoutingSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the topology 
     *  routing service for the given graph. 
     *
     *  @param  graphId the <code> Id </code> of the graph 
     *  @return a <code> TopologyRoutingSession </code> 
     *  @throws org.osid.NotFoundException no <code> Graph </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> graphId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsTopologyRouting() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTopologyRouting() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.topology.TopologyRoutingSession getTopologyRoutingForGraph(org.osid.id.Id graphId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the node lookup 
     *  service. 
     *
     *  @return a <code> NodeLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsNodeLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsNodeLookup() </code> is <code> true. </code> 
     */

    public org.osid.topology.NodeLookupSession getNodeLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the node lookup 
     *  service for the given graph. 
     *
     *  @param  graphId the <code> Id </code> of the graph 
     *  @return a <code> NodeLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Graph </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> graphId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsNodeLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsNodeLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.topology.NodeLookupSession getNodeLookupSessionForGraph(org.osid.id.Id graphId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the node query 
     *  service. 
     *
     *  @return a <code> NodeQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsNodeQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsNodeQuery() </code> is <code> true. </code> 
     */

    public org.osid.topology.NodeQuerySession getNodeQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the node query 
     *  service for the given graph. 
     *
     *  @param  graphId the <code> Id </code> of the graph 
     *  @return a <code> NodeQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Graph </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> graphId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsNodeQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsNodeQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.topology.NodeQuerySession getNodeQuerySessionForGraph(org.osid.id.Id graphId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the node search 
     *  service. 
     *
     *  @return a <code> NodeSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsNodeSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsNodeSearch() </code> is <code> true. </code> 
     */

    public org.osid.topology.NodeSearchSession getNodeSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the node search 
     *  service for the given graph. 
     *
     *  @param  graphId the <code> Id </code> of the <code> Graph </code> 
     *  @return a <code> NodeSearchSession </code> 
     *  @throws org.osid.NotFoundException no graph found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> graphId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsNodeSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsNodeSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.topology.NodeSearchSession getNodeSearchSessionForGraph(org.osid.id.Id graphId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the node 
     *  administration service. 
     *
     *  @return a <code> NodeAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsNodeAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsNodeAdmin() </code> is <code> true. </code> 
     */

    public org.osid.topology.NodeAdminSession getNodeAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the node 
     *  administration service for the given graph. 
     *
     *  @param  graphId the <code> Id </code> of the <code> Graph </code> 
     *  @return a <code> NodeAdminSession </code> 
     *  @throws org.osid.NotFoundException no graph found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> graphId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsNodeAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsNodeAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.topology.NodeAdminSession getNodeAdminSessionForGraph(org.osid.id.Id graphId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the node 
     *  notification service. 
     *
     *  @param  nodeReceiver the notification callback 
     *  @return a <code> NodeNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> nodeReceiver </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsNodeNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsNodeNotification() </code> is <code> true. </code> 
     */

    public org.osid.topology.NodeNotificationSession getNodeNotificationSession(org.osid.topology.NodeReceiver nodeReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the node 
     *  notification service for the given graph. 
     *
     *  @param  nodeReceiver the notification callback 
     *  @param  graphId the <code> Id </code> of the <code> Graph </code> 
     *  @return a <code> NodeNotificationSession </code> 
     *  @throws org.osid.NotFoundException no graph found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> nodeReceiver </code> or 
     *          <code> graphId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsNodeNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsNodeNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.topology.NodeNotificationSession getNodeNotificationSessionForGraph(org.osid.topology.NodeReceiver nodeReceiver, 
                                                                                        org.osid.id.Id graphId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup node/graph mappings. 
     *
     *  @return a <code> NodeGraphSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsNodeGraph() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsNodeGraph() </code> is <code> true. </code> 
     */

    public org.osid.topology.NodeGraphSession getNodeGraphSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning nodes to 
     *  graphs. 
     *
     *  @return a <code> NodeGraphAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsNodeGraphAssignment() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsNodeGraphAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.topology.NodeGraphAssignmentSession getNodeGraphAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage dynamic graphs of 
     *  retlationships. 
     *
     *  @param  graphId the <code> Id </code> of the <code> Graph </code> 
     *  @return a <code> NodeSmartGraphSession </code> 
     *  @throws org.osid.NotFoundException no graph found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> graphId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsNodeSmartGraph() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsNodeSmartGraph() </code> is <code> true. </code> 
     */

    public org.osid.topology.NodeSmartGraphSession getNodeSmartGraphSession(org.osid.id.Id graphId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the edge lookup 
     *  service. 
     *
     *  @return an <code> EdgeLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEdgeLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEdgeLookup() </code> is <code> true. </code> 
     */

    public org.osid.topology.EdgeLookupSession getEdgeLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the edge lookup 
     *  service for the given graph. 
     *
     *  @param  graphId the <code> Id </code> of the <code> Graph </code> 
     *  @return an <code> EdgeLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Graph </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> graphId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEdgeLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEdgeLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.topology.EdgeLookupSession getEdgeLookupSessionForGraph(org.osid.id.Id graphId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the edge query 
     *  service. 
     *
     *  @return an <code> EdgeQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEdgeQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEdgeQuery() </code> is <code> true. </code> 
     */

    public org.osid.topology.EdgeQuerySession getEdgeQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the edge query 
     *  service for the given graph. 
     *
     *  @param  graphId the <code> Id </code> of the graph 
     *  @return an <code> EdgeQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Graph </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> graphId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEdgeQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEdgeQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.topology.EdgeQuerySession getEdgeQuerySessionForGraph(org.osid.id.Id graphId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the edge search 
     *  service. 
     *
     *  @return an <code> EdgeSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEdgeSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEdgeSearch() </code> is <code> true. </code> 
     */

    public org.osid.topology.EdgeSearchSession getEdgeSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the edge search 
     *  service for the given graph. 
     *
     *  @param  graphId the <code> Id </code> of the <code> Graph </code> 
     *  @return an <code> EdgeSearchSession </code> 
     *  @throws org.osid.NotFoundException no graph found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> graphId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEdgeSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEdgeSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.topology.EdgeSearchSession getEdgeSearchSessionForGraph(org.osid.id.Id graphId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the edge 
     *  administration service. 
     *
     *  @return an <code> EdgeAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEdgeAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEdgeAdmin() </code> is <code> true. </code> 
     */

    public org.osid.topology.EdgeAdminSession getEdgeAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the edge 
     *  administration service for the given graph. 
     *
     *  @param  graphId the <code> Id </code> of the <code> Graph </code> 
     *  @return an <code> EdgeAdminSession </code> 
     *  @throws org.osid.NotFoundException no graph found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> graphId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEdgeAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEdgeAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.topology.EdgeAdminSession getEdgeAdminSessionForGraph(org.osid.id.Id graphId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the edge 
     *  notification service. 
     *
     *  @param  edgeReceiver the notification callback 
     *  @return an <code> EdgeNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> edgeReceiver </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEdgeNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEdgeNotification() </code> is <code> true. </code> 
     */

    public org.osid.topology.EdgeNotificationSession getEdgeNotificationSession(org.osid.topology.EdgeReceiver edgeReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the edge 
     *  notification service for the given graph. 
     *
     *  @param  edgeReceiver the notification callback 
     *  @param  graphId the <code> Id </code> of the <code> Graph </code> 
     *  @return an <code> EdgeNotificationSession </code> 
     *  @throws org.osid.NotFoundException no graph found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> edgeReceiver </code> or 
     *          <code> graphId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEdgeNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEdgeNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.topology.EdgeNotificationSession getEdgeNotificationSessionForGraph(org.osid.topology.EdgeReceiver edgeReceiver, 
                                                                                        org.osid.id.Id graphId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup edge/graph mappings. 
     *
     *  @return an <code> EdgeGraphSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsEdgeGraph() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEdgeGraph() </code> is <code> true. </code> 
     */

    public org.osid.topology.EdgeGraphSession getEdgeGraphSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning edges to 
     *  graphs. 
     *
     *  @return an <code> EdgeGraphAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEdgeGraphAssignment() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEdgeGraphAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.topology.EdgeGraphAssignmentSession getEdgeGraphAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage dynamic graphs of 
     *  retlationships. 
     *
     *  @param  graphId the <code> Id </code> of the <code> Graph </code> 
     *  @return an <code> EdgeSmartGraphSession </code> 
     *  @throws org.osid.NotFoundException no graph found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> graphId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEdgeSmartGraph() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEdgeSmartGraph() </code> is <code> true. </code> 
     */

    public org.osid.topology.EdgeSmartGraphSession getEdgeSmartGraphSession(org.osid.id.Id graphId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the graph lookup 
     *  service. 
     *
     *  @return a <code> GraphLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsGraphLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGraphLookup() </code> is <code> true. </code> 
     */

    public org.osid.topology.GraphLookupSession getGraphLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the graph query 
     *  service. 
     *
     *  @return a <code> GraphQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsGraphQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGraphQuery() </code> is <code> true. </code> 
     */

    public org.osid.topology.GraphQuerySession getGraphQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the graph search 
     *  service. 
     *
     *  @return a <code> GraphSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsGraphSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGraphSearch() </code> is <code> true. </code> 
     */

    public org.osid.topology.GraphSearchSession getGraphSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the graph 
     *  administrative service. 
     *
     *  @return a <code> GraphAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsGraphAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGraphAdmin() </code> is <code> true. </code> 
     */

    public org.osid.topology.GraphAdminSession getGraphAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the graph 
     *  notification service. 
     *
     *  @param  graphReceiver the notification callback 
     *  @return a <code> GraphNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> graphReceiver </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGraphNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGraphNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.topology.GraphNotificationSession getGraphNotificationSession(org.osid.topology.GraphReceiver graphReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the graph 
     *  hierarchy service. 
     *
     *  @return a <code> GraphHierarchySession </code> for graphs 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGraphHierarchy() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGraphHierarchy() </code> is <code> true. </code> 
     */

    public org.osid.topology.GraphHierarchySession getGraphHierarchySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the graph 
     *  hierarchy design service. 
     *
     *  @return a <code> HierarchyDesignSession </code> for graphs 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsGraphHierarchyDesign() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsGraphHierarchyDesign() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.topology.GraphHierarchyDesignSession getGraphHierarchyDesignSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a <code> TopologyBatchManager. </code> 
     *
     *  @return a <code> TopologyBatchManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsTopologyBatch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTopologyBatch() </code> is <code> true. </code> 
     */

    public org.osid.topology.batch.TopologyBatchManager getTopologyBatchManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a <code> TopologyPathManager. </code> 
     *
     *  @return a <code> TopologyPathManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsTopologyPath() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTopologyPath() </code> is <code> true. </code> 
     */

    public org.osid.topology.path.TopologyPathManager getTopologyPathManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a <code> TopologyRulesManager. </code> 
     *
     *  @return a <code> TopologyRulesManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsTopologyRules() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsTopologyRules() </code> is <code> true. </code> 
     */

    public org.osid.topology.rules.TopologyRulesManager getTopologyRulesManager()
        throws org.osid.OperationFailedException;
}
