//
// org.osid.topology.TopologyProfile
//
//     The OSID Java specification for org.osid.topology.TopologyProfile.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.topology;


/**
 *  <p>The topology profile describes the interoperability among topology 
 *  services. </p>
 */

public interface TopologyProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any graph federation is exposed. Federation is exposed when a 
     *  specific graph may be identified, selected and used to create a lookup 
     *  or admin session. Federation is not exposed when a set of graphs 
     *  appears as a single graph. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if traversing topologies is supported. 
     *
     *  @return <code> true </code> if topology traversal is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTopologyTraversal();


    /**
     *  Tests if topology routing is supported. 
     *
     *  @return <code> true </code> if topology routing is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTopologyRouting();


    /**
     *  Tests if looking up nodes is supported. 
     *
     *  @return <code> true </code> if node lookup is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsNodeLookup();


    /**
     *  Tests if querying nodes is supported. 
     *
     *  @return <code> true </code> if node query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsNodeQuery();


    /**
     *  Tests if searching nodes is supported. 
     *
     *  @return <code> true </code> if node search is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsNodeSearch();


    /**
     *  Tests if node <code> </code> administrative service is supported. 
     *
     *  @return <code> true </code> if node administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsNodeAdmin();


    /**
     *  Tests if a node <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if node notification is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsNodeNotification();


    /**
     *  Tests if a node graph mapping lookup service is supported. 
     *
     *  @return <code> true </code> if a node graph lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsNodeGraph();


    /**
     *  Tests if a node graph mapping service is supported. 
     *
     *  @return <code> true </code> if node to graph mapping service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsNodeGraphAssignment();


    /**
     *  Tests if a node smart graph cataloging service is supported. 
     *
     *  @return <code> true </code> if node smart graphs are supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsNodeSmartGraph();


    /**
     *  Tests if looking up edges is supported. 
     *
     *  @return <code> true </code> if edge lookup is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEdgeLookup();


    /**
     *  Tests if searching edges is supported. 
     *
     *  @return <code> true </code> if edge search is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEdgeSearch();


    /**
     *  Tests if edge <code> </code> administrative service is supported. 
     *
     *  @return <code> true </code> if edge administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEdgeAdmin();


    /**
     *  Tests if an edge <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if edge notification is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEdgeNotification();


    /**
     *  Tests if an edge graph mapping lookup service is supported. 
     *
     *  @return <code> true </code> if an edge graph lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEdgeGraph();


    /**
     *  Tests if an edge graph mapping service is supported. 
     *
     *  @return <code> true </code> if edge to graph mapping service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEdgeGraphAssignment();


    /**
     *  Tests if an edgesmart graph cataloging service is supported. 
     *
     *  @return <code> true </code> if edge smart graphs are supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEdgeSmartGraph();


    /**
     *  Tests if looking up graphs is supported. 
     *
     *  @return <code> true </code> if graph lookup is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGraphLookup();


    /**
     *  Tests if querying graphs is supported. 
     *
     *  @return <code> true </code> if graph query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGraphQuery();


    /**
     *  Tests if searching graphs is supported. 
     *
     *  @return <code> true </code> if graph search is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGraphSearch();


    /**
     *  Tests if graph administrative service is supported. 
     *
     *  @return <code> true </code> if graph administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGraphAdmin();


    /**
     *  Tests if a graph <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if graph notification is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGraphNotification();


    /**
     *  Tests for the availability of a graph hierarchy traversal service. 
     *
     *  @return <code> true </code> if graph hierarchy traversal is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsGraphHierarchy();


    /**
     *  Tests for the availability of a graph hierarchy design service. 
     *
     *  @return <code> true </code> if graph hierarchy design is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGraphHierarchyDesign();


    /**
     *  Tests for the availability of a topology pbatchath service. 
     *
     *  @return <code> true </code> if a topology batch service is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTopologyBatch();


    /**
     *  Tests for the availability of a topology path service. 
     *
     *  @return <code> true </code> if a topology path service is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTopologyPath();


    /**
     *  Tests for the availability of a topology rules service. 
     *
     *  @return <code> true </code> if a topology rules service is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsTopologyRules();


    /**
     *  Gets the supported <code> Node </code> record types. 
     *
     *  @return a list containing the supported <code> Node </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getNodeRecordTypes();


    /**
     *  Tests if the given <code> Node </code> record type is supported. 
     *
     *  @param  nodeRecordType a <code> Type </code> indicating a <code> Node 
     *          </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> nodeRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsNodeRecordType(org.osid.type.Type nodeRecordType);


    /**
     *  Gets the supported <code> Node </code> search types. 
     *
     *  @return a list containing the supported <code> Node </code> search 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getNodeSearchRecordTypes();


    /**
     *  Tests if the given <code> Node </code> search type is supported. 
     *
     *  @param  nodeSearchRecordType a <code> Type </code> indicating a <code> 
     *          Node </code> search type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> nodeSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsNodeSearchRecordType(org.osid.type.Type nodeSearchRecordType);


    /**
     *  Gets the supported <code> Edge </code> record types. 
     *
     *  @return a list containing the supported <code> Edge </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getEdgeRecordTypes();


    /**
     *  Tests if the given <code> Edge </code> record type is supported. 
     *
     *  @param  edgeRecordType a <code> Type </code> indicating an <code> Edge 
     *          </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> edgeRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEdgeRecordType(org.osid.type.Type edgeRecordType);


    /**
     *  Gets the supported <code> Edge </code> search record types. 
     *
     *  @return a list containing the supported <code> Edge </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getEdgeSearchRecordTypes();


    /**
     *  Tests if the given <code> Edge </code> search record type is 
     *  supported. 
     *
     *  @param  edgeSearchRecordType a <code> Type </code> indicating an 
     *          <code> Edge </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> edgeSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEdgeSearchRecordType(org.osid.type.Type edgeSearchRecordType);


    /**
     *  Gets the supported <code> Graph </code> record types. 
     *
     *  @return a list containing the supported <code> Graph </code> types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getGraphRecordTypes();


    /**
     *  Tests if the given <code> Graph </code> record type is supported. 
     *
     *  @param  graphRecordType a <code> Type </code> indicating a <code> 
     *          Graph </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> graphRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGraphRecordType(org.osid.type.Type graphRecordType);


    /**
     *  Gets the supported <code> Graph </code> search record types. 
     *
     *  @return a list containing the supported <code> Graph </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getGraphSearchRecordTypes();


    /**
     *  Tests if the given <code> Graph </code> search record type is 
     *  supported. 
     *
     *  @param  graphSearchRecordType a <code> Type </code> indicating a 
     *          <code> Graph </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> graphSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsGraphSearchRecordType(org.osid.type.Type graphSearchRecordType);
}
