//
// org.osid.topology.path.Path
//
//     The OSID Java specification for org.osid.topology.path.Path.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.topology.path;


/**
 *  <p>A <code> Path </code> represents a means between two nodes. </p>
 */

public interface Path
    extends org.osid.OsidRelationship,
            org.osid.Aggregateable {


    /**
     *  Gets the <code> Id </code> of the starting node of this path. 
     *
     *  @return the starting node <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getStartingNodeId();


    /**
     *  Gets the starting node of this path. 
     *
     *  @return the starting node 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.Node getStartingNode()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the ending node of this path. 
     *
     *  @return the ending node <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getEndingNodeId();


    /**
     *  Gets the ending node of this path. 
     *
     *  @return the ending node 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.Node getEndingNode()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if all edges exist between the start and end nodes. A path may 
     *  be complete and inactive. 
     *
     *  @return <code> true </code> if the path is complete, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isComplete();


    /**
     *  Test if the starting node and ending node are equal. 
     *
     *  @return <code> true </code> if the path is closed, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isClosed();


    /**
     *  Gets the total number of nodes of this path. 
     *
     *  @return the total path hops 
     *  @compliance mandatory This method must be implemented. 
     */

    public long getHops();


    /**
     *  Gets the total distance of this path. 
     *
     *  @return the total path distance 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getDistance();


    /**
     *  Gets the total cost of this path. 
     *
     *  @return the total path cost 
     *  @compliance mandatory This method must be implemented. 
     */

    public java.math.BigDecimal getCost();


    /**
     *  Gets the edge <code> Ids </code> of this path. 
     *
     *  @return the edge <code> Ids </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getEdgeIds();


    /**
     *  Gets the edges of this path. 
     *
     *  @return the edges 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.EdgeList getEdges()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the path record corresponding to the given <code> Path </code> 
     *  record <code> Type. </code> This method is used to retrieve an object 
     *  implementing the requested record. The <code> pathRecordType </code> 
     *  may be the <code> Type </code> returned in <code> getRecordTypes() 
     *  </code> or any of its parents in a <code> Type </code> hierarchy where 
     *  <code> hasRecordType(pathRecordType) </code> is <code> true </code> . 
     *
     *  @param  pathRecordType the type of path record to retrieve 
     *  @return the path record 
     *  @throws org.osid.NullArgumentException <code> pathRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(pathRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.path.records.PathRecord getPathRecord(org.osid.type.Type pathRecordType)
        throws org.osid.OperationFailedException;
}
