//
// org.osid.topology.path.PathLookupSession
//
//     The OSID Java specification for org.osid.topology.path.PathLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.topology.path;


/**
 *  <p>This session provides methods for retrieving <code> Path </code> 
 *  objects. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated graph view: All path methods in this session operate, 
 *      retrieve and pertain to paths defined explicitly in the current graph. 
 *      Using an isolated view is useful for managing <code> Paths </code> 
 *      with the <code> PathAdminSession. </code> </li> 
 *      <li> federated graph view: All path methods in this session operate, 
 *      retrieve and pertain to all paths defined in this graph and any other 
 *      paths implicitly available in this graph through graph inheritence. 
 *      </li> 
 *      <li> effective path view: All path lookup methods return paths where 
 *      the current dates falls in between the effective dates inclusive. 
 *      </li> 
 *      <li> any effective path view: Paths of any effective date are 
 *      returned. </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedGraphView() </code> and <code> 
 *  useIsolatedGraphView() </code> behave as a radio group and one should be 
 *  selected before invoking any lookup methods. </p>
 */

public interface PathLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Graph </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Graph Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getGraphId();


    /**
     *  Gets the <code> Graph </code> associated with this session. 
     *
     *  @return the graph 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.Graph getGraph()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Path </code> lookups. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupPaths();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativePathView();


    /**
     *  A complete view of the <code> Path </code> returns is desired. Methods 
     *  will return what is requested or result in an error. This view is used 
     *  when greater precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryPathView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include paths in graphs which are children of this graph in the graph 
     *  hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedGraphView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this graph only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedGraphView();


    /**
     *  Only paths whose effective dates are current are returned by methods 
     *  in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectivePathView();


    /**
     *  All paths of any effective dates are returned by all methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectivePathView();


    /**
     *  Gets the <code> Path </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Path </code> may have a different <code> Id </code> than requested, 
     *  such as the case where a duplicate <code> Id </code> was assigned to a 
     *  <code> Path </code> and retained for compatibility. 
     *  
     *  In effective mode, paths are returned that are currently effective. In 
     *  any effective mode, effective paths and those currently expired are 
     *  returned. 
     *
     *  @param  pathId <code> Id </code> of the <code> Path </code> 
     *  @return the path 
     *  @throws org.osid.NotFoundException <code> pathId </code> not found 
     *  @throws org.osid.NullArgumentException <code> pathId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.topology.path.Path getPath(org.osid.id.Id pathId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PathList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  paths specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Paths </code> may be omitted from the list and may 
     *  present the elements in any order including returning a unique set. 
     *  
     *  In effective mode, paths are returned that are currently effective. In 
     *  any effective mode, effective paths and those currently expired are 
     *  returned. 
     *
     *  @param  pathIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Path </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> pathIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.path.PathList getPathsByIds(org.osid.id.IdList pathIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PathList </code> corresponding to the given path genus 
     *  <code> Type </code> which does not include paths of genus types 
     *  derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  paths or an error results. Otherwise, the returned list may contain 
     *  only those paths that are accessible through this session. 
     *  
     *  In effective mode, paths are returned that are currently effective. In 
     *  any effective mode, effective paths and those currently expired are 
     *  returned. 
     *
     *  @param  pathGenusType a path genus type 
     *  @return the returned <code> Path </code> list 
     *  @throws org.osid.NullArgumentException <code> pathGenusType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.path.PathList getPathsByGenusType(org.osid.type.Type pathGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PathList </code> corresponding to the given path genus 
     *  <code> Type </code> and include any additional paths with genus types 
     *  derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  paths or an error results. Otherwise, the returned list may contain 
     *  only those paths that are accessible through this session. 
     *  
     *  In effective mode, paths are returned that are currently effective. In 
     *  any effective mode, effective paths and those currently expired are 
     *  returned. 
     *
     *  @param  pathGenusType a path genus type 
     *  @return the returned <code> Path </code> list 
     *  @throws org.osid.NullArgumentException <code> pathGenusType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.path.PathList getPathsByParentGenusType(org.osid.type.Type pathGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PathList </code> containing the given path record <code> 
     *  Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  paths or an error results. Otherwise, the returned list may contain 
     *  only those paths that are accessible through this session. 
     *  
     *  In effective mode, paths are returned that are currently effective. In 
     *  any effective mode, effective paths and those currently expired are 
     *  returned. 
     *
     *  @param  pathRecordType a path record type 
     *  @return the returned <code> Path </code> list 
     *  @throws org.osid.NullArgumentException <code> pathRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.path.PathList getPathsByRecordType(org.osid.type.Type pathRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PathList </code> effective during the entire given date 
     *  range inclusive but not confined to the date range. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  paths or an error results. Otherwise, the returned list may contain 
     *  only those paths that are accessible through this session. 
     *  
     *  In effective mode, paths are returned that are currently effective. In 
     *  any effective mode, effective paths and those currently expired are 
     *  returned. 
     *
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Path </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> Is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.path.PathList getPathsOnDate(org.osid.calendaring.DateTime from, 
                                                          org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PathList </code> of a genus type and effective during 
     *  the entire given date range inclusive but not confined to the date 
     *  range. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  paths or an error results. Otherwise, the returned list may contain 
     *  only those paths that are accessible through this session. 
     *  
     *  In effective mode, paths are returned that are currently effective. In 
     *  any effective mode, effective paths and those currently expired are 
     *  returned. 
     *
     *  @param  pathGenusType a path genus type 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Path </code> list 
     *  @throws org.osid.InvalidArgumentException <code> edgeGenusType, from 
     *          </code> Is greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.path.PathList getPathsByGenusTypeOnDate(org.osid.type.Type pathGenusType, 
                                                                     org.osid.calendaring.DateTime from, 
                                                                     org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PathList </code> starting from the given <code> Node. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  paths, or an error results if a path connected to the node is not 
     *  found or inaccessible. Otherwise, inaccessible <code> Paths </code> 
     *  may be omitted from the list. 
     *  
     *  In effective mode, paths are returned that are currently effective. In 
     *  any effective mode, effective paths and those currently expired are 
     *  returned. 
     *
     *  @param  nodeId a node <code> Id </code> 
     *  @return the returned <code> Path </code> list 
     *  @throws org.osid.NullArgumentException <code> nodeId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.path.PathList getPathsForStartingNode(org.osid.id.Id nodeId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PathList </code> effective during the entire given date 
     *  range inclusive but not confined to the date range. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  paths or an error results. Otherwise, the returned list may contain 
     *  only those paths that are accessible through this session. 
     *  
     *  In effective mode, paths are returned that are currently effective. In 
     *  any effective mode, effective paths and those currently expired are 
     *  returned. 
     *
     *  @param  nodeId a node <code> Id </code> 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Path </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> Is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> nodeId, from </code> or 
     *          <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.path.PathList getPathsForStartingNodeOnDate(org.osid.id.Id nodeId, 
                                                                         org.osid.calendaring.DateTime from, 
                                                                         org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PathList </code> starting from the given <code> Node 
     *  </code> and path genus <code> Type including </code> any genus <code> 
     *  Types </code> derived from the given genus <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  paths, or an error results if a path connected to the node is not 
     *  found or inaccessible. Otherwise, inaccessible <code> Paths </code> 
     *  may be omitted from the list. 
     *  
     *  In effective mode, paths are returned that are currently effective. In 
     *  any effective mode, effective paths and those currently expired are 
     *  returned. 
     *
     *  @param  nodeId a node <code> Id </code> 
     *  @param  pathGenusType a path genus type 
     *  @return the returned <code> Path </code> list 
     *  @throws org.osid.NullArgumentException <code> nodeId </code> is or 
     *          <code> pathGenusType </code> <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.path.PathList getPathsByGenusTypeForStartingNode(org.osid.id.Id nodeId, 
                                                                              org.osid.type.Type pathGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PathList </code> of the given genus type and effective 
     *  during the entire given date range inclusive but not confined to the 
     *  date range. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  paths or an error results. Otherwise, the returned list may contain 
     *  only those paths that are accessible through this session. 
     *  
     *  In effective mode, paths are returned that are currently effective. In 
     *  any effective mode, effective paths and those currently expired are 
     *  returned. 
     *
     *  @param  nodeId a node <code> Id </code> 
     *  @param  pathGenusType a path genus type 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Path </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> Is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> nodeId, pathGenusType, 
     *          from </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.path.PathList getPathsByGenusTypeForStartingNodeOnDate(org.osid.id.Id nodeId, 
                                                                                    org.osid.type.Type pathGenusType, 
                                                                                    org.osid.calendaring.DateTime from, 
                                                                                    org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PathList </code> ending at the given <code> Node. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  paths, or an error results if a path connected to the node is not 
     *  found or inaccessible. Otherwise, inaccessible <code> Paths </code> 
     *  may be omitted from the list. 
     *  
     *  In effective mode, paths are returned that are currently effective. In 
     *  any effective mode, effective paths and those currently expired are 
     *  returned. 
     *
     *  @param  nodeId a node <code> Id </code> 
     *  @return the returned <code> Path </code> list 
     *  @throws org.osid.NullArgumentException <code> nodeId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.path.PathList getPathsForEndingNode(org.osid.id.Id nodeId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PathList </code> effective during the entire given date 
     *  range inclusive but not confined to the date range. 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  paths or an error results. Otherwise, the returned list may contain 
     *  only those paths that are accessible through this session. 
     *  
     *  In effective mode, paths are returned that are currently effective. In 
     *  any effective mode, effective paths and those currently expired are 
     *  returned. 
     *
     *  @param  nodeId a node <code> Id </code> 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Path </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> Is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> nodeId, from </code> or 
     *          <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.path.PathList getPathsForEndingNodeOnDate(org.osid.id.Id nodeId, 
                                                                       org.osid.calendaring.DateTime from, 
                                                                       org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PathList </code> ending at the given <code> Node </code> 
     *  and path genus <code> Type including </code> any genus <code> Types 
     *  </code> derived from the given genus <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  paths, or an error results if a path connected to the node is not 
     *  found or inaccessible. Otherwise, inaccessible <code> Paths </code> 
     *  may be omitted from the list. 
     *  
     *  In effective mode, paths are returned that are currently effective. In 
     *  any effective mode, effective paths and those currently expired are 
     *  returned. 
     *
     *  @param  nodeId a node <code> Id </code> 
     *  @param  pathGenusType a path genus type 
     *  @return the returned <code> Path </code> list 
     *  @throws org.osid.NullArgumentException <code> nodeId </code> or <code> 
     *          pathGenusType </code> <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.path.PathList getPathsByGenusTypeForEndingNode(org.osid.id.Id nodeId, 
                                                                            org.osid.type.Type pathGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PathList </code> of the given genus type and effective 
     *  during the entire given date range inclusive but not confined to the 
     *  date range. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  paths or an error results. Otherwise, the returned list may contain 
     *  only those paths that are accessible through this session. 
     *  
     *  In effective mode, paths are returned that are currently effective. In 
     *  any effective mode, effective paths and those currently expired are 
     *  returned. 
     *
     *  @param  nodeId a node <code> Id </code> 
     *  @param  pathGenusType a path genus type 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Path </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> Is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> nodeId, pathGenusType, 
     *          from </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.path.PathList getPathsByGenusTypeForEndingNodeOnDate(org.osid.id.Id nodeId, 
                                                                                  org.osid.type.Type pathGenusType, 
                                                                                  org.osid.calendaring.DateTime from, 
                                                                                  org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PathList </code> between to the two given <code> Nodes. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  paths, or an error results if a path connected to the node is not 
     *  found or inaccessible. Otherwise, inaccessible <code> Paths </code> 
     *  may be omitted from the list. 
     *  
     *  In effective mode, paths are returned that are currently effective. In 
     *  any effective mode, effective paths and those currently expired are 
     *  returned. 
     *
     *  @param  startingNodeId starting node <code> Id </code> 
     *  @param  endingNodeId ending node <code> Id </code> 
     *  @return the returned <code> Path </code> list 
     *  @throws org.osid.NullArgumentException <code> startingNodeId </code> 
     *          or <code> endingNodeId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.path.PathList getPathsForNodes(org.osid.id.Id startingNodeId, 
                                                            org.osid.id.Id endingNodeId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PathList </code> effective during the entire given date 
     *  range inclusive but not confined to the date range. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  paths or an error results. Otherwise, the returned list may contain 
     *  only those paths that are accessible through this session. 
     *  
     *  In effective mode, paths are returned that are currently effective. In 
     *  any effective mode, effective paths and those currently expired are 
     *  returned. 
     *
     *  @param  startingNodeId starting node <code> Id </code> 
     *  @param  endingNodeId ending node <code> Id </code> 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Path </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> Is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> startingNodeId, 
     *          endingNodeId, from </code> or <code> to </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.path.PathList getPathsForNodesOnDate(org.osid.id.Id startingNodeId, 
                                                                  org.osid.id.Id endingNodeId, 
                                                                  org.osid.calendaring.DateTime from, 
                                                                  org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PathList </code> of the given genus type between the 
     *  given <code> Nodes. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  paths, or an error results if a path connected to the node is not 
     *  found or inaccessible. Otherwise, inaccessible <code> Paths </code> 
     *  may be omitted from the list. 
     *  
     *  In effective mode, paths are returned that are currently effective. In 
     *  any effective mode, effective paths and those currently expired are 
     *  returned. 
     *
     *  @param  startingNodeId starting node <code> Id </code> 
     *  @param  endingNodeId ending node <code> Id </code> 
     *  @param  pathGenusType a path genus type 
     *  @return the returned <code> Path </code> list 
     *  @throws org.osid.NullArgumentException <code> startingNodeId, 
     *          endingNodeId </code> or <code> pathGenusType </code> <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.path.PathList getPathsByGenusTypeForNodes(org.osid.id.Id startingNodeId, 
                                                                       org.osid.id.Id endingNodeId, 
                                                                       org.osid.type.Type pathGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PathList </code> of the given genus type and effective 
     *  during the entire given date range inclusive but not confined to the 
     *  date range. 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  paths or an error results. Otherwise, the returned list may contain 
     *  only those paths that are accessible through this session. 
     *  
     *  In effective mode, paths are returned that are currently effective. In 
     *  any effective mode, effective paths and those currently expired are 
     *  returned. 
     *
     *  @param  startingNodeId starting node <code> Id </code> 
     *  @param  endingNodeId ending node <code> Id </code> 
     *  @param  pathGenusType a path genus type 
     *  @param  from starting date 
     *  @param  to ending date 
     *  @return the returned <code> Path </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> Is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> startingNodeId, 
     *          endingNodeId, pathGenusType, from </code> or <code> to </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.path.PathList getPathsByGenusTypeForNodesOnDate(org.osid.id.Id startingNodeId, 
                                                                             org.osid.id.Id endingNodeId, 
                                                                             org.osid.type.Type pathGenusType, 
                                                                             org.osid.calendaring.DateTime from, 
                                                                             org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PathList </code> connected to all the given <code> 
     *  Nodes. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  paths through the nodes, or an error results if a path connected to 
     *  the node is not found or inaccessible. Otherwise, inaccessible <code> 
     *  Paths </code> may be omitted from the list. 
     *  
     *  In effective mode, paths are returned that are currently effective. In 
     *  any effective mode, effective paths and those currently expired are 
     *  returned. 
     *
     *  @param  nodeIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Path </code> list 
     *  @throws org.osid.NullArgumentException <code> nodeIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.path.PathList getPathsAlongNodes(org.osid.id.IdList nodeIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PathList </code> connected to all the given <code> Nodes 
     *  </code> and and effective during the entire given date range inclusive 
     *  but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all of the paths through 
     *  the nodes, or an error results if a path connected to the node is not 
     *  found or inaccessible. Otherwise, inaccessible <code> Paths </code> 
     *  may be omitted from the list. 
     *  
     *  In effective mode, paths are returned that are currently effective. In 
     *  any effective mode, effective paths and those currently expired are 
     *  returned. 
     *
     *  @param  nodeIds the list of <code> Ids </code> to retrieve 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Path </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> nodeIds, from </code> , 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.path.PathList getPathsAlongNodesOnDate(org.osid.id.IdList nodeIds, 
                                                                    org.osid.calendaring.DateTime from, 
                                                                    org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Paths. </code> 
     *  
     *  In plenary mode, the returned list contains all known paths or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  paths that are accessible through this session. 
     *  
     *  In effective mode, paths are returned that are currently effective. In 
     *  any effective mode, effective paths and those currently expired are 
     *  returned. 
     *
     *  @return a list of <code> Paths </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.path.PathList getPaths()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
