//
// org.osid.topology.path.PathQuerySession
//
//     The OSID Java specification for org.osid.topology.path.PathQuerySession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.topology.path;


/**
 *  <p>This session provides methods for searching among <code> Path </code> 
 *  objects. The search query is constructed using the <code> PathQuery. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated graph view: searches include paths in graphs of which 
 *      this graph is an ancestor in the graph hierarchy </li> 
 *      <li> isolated graph view: searches are restricted to paths in this 
 *      graph </li> 
 *  </ul>
 *  
 *  
 *  <p> Paths may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> PathQuery. </code> </p>
 */

public interface PathQuerySession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Graph </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Graph Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getGraphId();


    /**
     *  Gets the <code> Graph </code> associated with this session. 
     *
     *  @return the graph 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.Graph getGraph()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Path </code> lookups. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may not offer lookup operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if search methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSearchPaths();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include paths in graphs which are children of this graph in the graph 
     *  hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedGraphView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts searches to this graph only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedGraphView();


    /**
     *  Gets a path query. 
     *
     *  @return the path query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.path.PathQuery getPathQuery();


    /**
     *  Gets a list of <code> Paths </code> matching the given path query. 
     *
     *  @param  pathQuery the path query 
     *  @return the returned <code> PathList </code> 
     *  @throws org.osid.NullArgumentException <code> pathQuery </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> pathQuery </code> is not 
     *          of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.path.PathList getPathsByQuery(org.osid.topology.path.PathQuery pathQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
