//
// org.osid.topology.path.PathSearchOrder
//
//     The OSID Java specification for org.osid.topology.path.PathSearchOrder.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.topology.path;


/**
 *  <p>An interface for specifying the ordering of search results. </p>
 */

public interface PathSearchOrder
    extends org.osid.OsidRelationshipSearchOrder,
            org.osid.OsidAggregateableSearchOrder {


    /**
     *  Specifies a preference for ordering the result set by the starting 
     *  node. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByStartingNode(org.osid.SearchOrderStyle style);


    /**
     *  Tests if a starting node search order is available. 
     *
     *  @return <code> true </code> if a node search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStartingNodeSearchOrder();


    /**
     *  Gets a starting node search order. 
     *
     *  @return a node search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStartingNodeSearchOrder() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStartingNodeSearchOrder() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.topology.NodeSearchOrder getStartingNodeSearchOrder();


    /**
     *  Specifies a preference for ordering the result set by the starting 
     *  node. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByEndingNode(org.osid.SearchOrderStyle style);


    /**
     *  Tests if an ending node search order is available. 
     *
     *  @return <code> true </code> if a node search order is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEndingNodeSearchOrder();


    /**
     *  Gets an ending node search order. 
     *
     *  @return a node search order 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsEndingNodeSearchOrder() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsEndingNodeSearchOrder() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.topology.NodeSearchOrder getEndingNodeSearchOrder();


    /**
     *  Specifies a preference for ordering the result set by the complete 
     *  state. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByComplete(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the open and 
     *  closed paths. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByClosed(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the number of 
     *  hops in the path. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByHops(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the path 
     *  distance. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByDistance(org.osid.SearchOrderStyle style);


    /**
     *  Specifies a preference for ordering the result set by the path cost. 
     *
     *  @param  style search order style 
     *  @throws org.osid.NullArgumentException <code> style </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderByCost(org.osid.SearchOrderStyle style);


    /**
     *  Gets the path search order record corresponding to the given path 
     *  record <code> Type. </code> Multiple retrievals return the same 
     *  underlying object. 
     *
     *  @param  pathRecordType a path record type 
     *  @return the path search order record 
     *  @throws org.osid.NullArgumentException <code> pathRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(pathRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.path.records.PathSearchOrderRecord getPathSearchOrderRecord(org.osid.type.Type pathRecordType)
        throws org.osid.OperationFailedException;
}
