//
// org.osid.topology.rules.EdgeEnablerAdminSession
//
//     The OSID Java specification for org.osid.topology.rules.EdgeEnablerAdminSession.
//
// Copyright (C) 2011 Ingenescus All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.topology.rules;


/**
 *  <p>This session creates and removes edge enablers. The data for create and 
 *  update is provided via the <code> EdgeEnablerForm. </code> </p>
 */

public interface EdgeEnablerAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Graph </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Graph Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getGraphId();


    /**
     *  Gets the <code> Graph </code> associated with this session. 
     *
     *  @return the graph 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.Graph getGraph()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create edge enablers. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known creating an <code> EdgeEnabler </code> will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> EdgeEnabler </code> creation is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateEdgeEnabler();


    /**
     *  Tests if this user can create a single <code> EdgeEnabler </code> 
     *  using the desired record types. While <code> 
     *  TopologyRulesManager.getEdgeEnablerRecordTypes() </code> can be used 
     *  to examine which records are supported, this method tests which 
     *  record(s) are required for creating a specific <code> EdgeEnabler. 
     *  </code> Providing an empty array tests if an <code> EdgeEnabler 
     *  </code> can be created with no records. 
     *
     *  @param  edgeEnablerRecordTypes array of edge enabler types 
     *  @return <code> true </code> if <code> EdgeEnabler </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> edgeEnablerRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateEdgeEnablerWithRecordTypes(org.osid.type.Type[] edgeEnablerRecordTypes);


    /**
     *  Gets the edge enabler form for creating new edge enablers. A new form 
     *  should be requested for each create transaction. 
     *
     *  @param  edgeEnablerRecordTypes array of edge enabler types 
     *  @return the edge enabler form 
     *  @throws org.osid.NullArgumentException <code> edgeEnablerRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.rules.EdgeEnablerForm getEdgeEnablerFormForCreate(org.osid.type.Type[] edgeEnablerRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> EdgeEnabler. </code> 
     *
     *  @param  edgeEnablerForm the form for this <code> EdgeEnabler </code> 
     *  @return the new <code> EdgeEnabler </code> 
     *  @throws org.osid.IllegalStateException <code> edgeEnablerForm </code> 
     *          already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> edgeEnablerForm </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> edgeEnablerForm </code> 
     *          did not originate from <code> getEdgeEnablerFormForCreate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.rules.EdgeEnabler createEdgeEnabler(org.osid.topology.rules.EdgeEnablerForm edgeEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update edge enablers. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known updating an <code> EdgeEnabler </code> will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer update operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> EdgeEnabler </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateEdgeEnablers();


    /**
     *  Gets the edge enabler form for updating an existing edge enabler. A 
     *  new edge enabler form should be requested for each update transaction. 
     *
     *  @param  edgeEnablerId the <code> Id </code> of the <code> EdgeEnabler 
     *          </code> 
     *  @return the edge enabler form 
     *  @throws org.osid.NotFoundException <code> edgeEnablerId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> edgeEnablerId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.rules.EdgeEnablerForm getEdgeEnablerFormForUpdate(org.osid.id.Id edgeEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing edge enabler. 
     *
     *  @param  edgeEnablerForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> edgeEnablerForm </code> 
     *          already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> edgeEnablerId </code> or 
     *          <code> edgeEnablerForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> edgeEnablerForm </code> 
     *          did not originate from <code> getEdgeEnablerFormForUpdate() 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateEdgeEnabler(org.osid.topology.rules.EdgeEnablerForm edgeEnablerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete edge enablers. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known deleting an <code> EdgeEnabler </code> will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer delete operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> EdgeEnabler </code> deletion is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteEdgeEnablers();


    /**
     *  Deletes an <code> EdgeEnabler. </code> 
     *
     *  @param  edgeEnablerId the <code> Id </code> of the <code> EdgeEnabler 
     *          </code> to remove 
     *  @throws org.osid.NotFoundException <code> edgeEnablerId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> edgeEnablerId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteEdgeEnabler(org.osid.id.Id edgeEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for edge 
     *  enablers. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> EdgeEnabler </code> aliasing is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageEdgeEnablerAliases();


    /**
     *  Adds an <code> Id </code> to an <code> EdgeEnabler </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> EdgeEnabler </code> is determined by the provider. The new 
     *  <code> Id </code> performs as an alias to the primary <code> Id 
     *  </code> . If the alias is a pointer to another edge enabler. it is 
     *  reassigned to the given edge enabler <code> Id. </code> 
     *
     *  @param  edgeEnablerId the <code> Id </code> of an <code> EdgeEnabler 
     *          </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> edgeEnablerId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> edgeEnablerId </code> or 
     *          <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasEdgeEnabler(org.osid.id.Id edgeEnablerId, 
                                 org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
