//
// org.osid.topology.rules.EdgeEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.topology.rules.EdgeEnablerRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.topology.rules;


/**
 *  <p>This session provides methods to apply <code> EdgeEnablers </code> to 
 *  <code> Edges. </code> An <code> Edge </code> with multiple <code> 
 *  EdgeEnablers </code> means any positive rule evaluation across the 
 *  enablers result in an effective <code> Edge. </code> </p>
 */

public interface EdgeEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Graph </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Graph Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getGraphId();


    /**
     *  Gets the <code> Graph </code> associated with this session. 
     *
     *  @return the graph 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.Graph getGraph()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter edge enabler/edge mappings. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignEdgeEnablers();


    /**
     *  Adds an existing <code> EdgeEnabler </code> to an <code> Edge. </code> 
     *
     *  @param  edgeEnablerId the <code> Id </code> of the <code> EdgeEnabler 
     *          </code> 
     *  @param  edgeId the <code> Id </code> of the <code> Edge </code> 
     *  @throws org.osid.AlreadyExistsException <code> edgeEnablerId </code> 
     *          is already applied to <code> edgeId </code> 
     *  @throws org.osid.NotFoundException <code> edgeEnablerId </code> or 
     *          <code> edgeId </code> not found 
     *  @throws org.osid.NullArgumentException <code> edgeEnablerId </code> or 
     *          <code> edgeId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignEdgeEnablerToEdge(org.osid.id.Id edgeEnablerId, 
                                        org.osid.id.Id edgeId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an <code> EdgeEnabler </code> from an <code> Edge. </code> 
     *
     *  @param  edgeEnablerId the <code> Id </code> of the <code> EdgeEnabler 
     *          </code> 
     *  @param  edgeId the <code> Id </code> of the <code> Edge </code> 
     *  @throws org.osid.NotFoundException <code> edgeEnablerId </code> or 
     *          <code> edgeId </code> not found or <code> edgeEnablerId 
     *          </code> is not applied to <code> edgeId </code> 
     *  @throws org.osid.NullArgumentException <code> edgeEnablerId </code> or 
     *          <code> edgeId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignEdgeEnablerFromEdge(org.osid.id.Id edgeEnablerId, 
                                            org.osid.id.Id edgeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> EdgeEnablers. </code> A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known sequencing operations will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> EdgeEnabler </code> ordering is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceEdgeEnablers();


    /**
     *  Reorders edge enablers for an edge by moving the specified edge 
     *  enabler in front of a reference edge enabler. 
     *
     *  @param  edgeEnablerId the <code> Id </code> of an <code> EdgeEnabler 
     *          </code> 
     *  @param  edgeId the <code> Id </code> of an <code> Edge </code> 
     *  @param  referenceId the reference edge enabler <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> edgeEnablerId, edgeId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          edgeEnablerId </code> or <code> referenceId </code> not 
     *          related to <code> edgeId </code> 
     *  @throws org.osid.NullArgumentException <code> edgeEnablerId, edgeId, 
     *          </code> or <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveEdgeEnablerAhead(org.osid.id.Id edgeEnablerId, 
                                     org.osid.id.Id edgeId, 
                                     org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders edge enablers for an edge by moving the specified edge 
     *  enabler behind a reference edge enabler. 
     *
     *  @param  edgeEnablerId the <code> Id </code> of an <code> EdgeEnabler 
     *          </code> 
     *  @param  edgeId the <code> Id </code> of an <code> Edge </code> 
     *  @param  referenceId the reference edge enabler <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> edgeEnablerId, edgeId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          edgeEnablerId </code> or <code> referenceId </code> not 
     *          related to <code> edgeId </code> 
     *  @throws org.osid.NullArgumentException <code> edgeEnablerId, edgeId, 
     *          </code> or <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveEdgeEnablerBehind(org.osid.id.Id edgeEnablerId, 
                                      org.osid.id.Id edgeId, 
                                      org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of edge enablers for an edge. 
     *
     *  @param  edgeEnablerIds the <code> Ids </code> for a set of <code> 
     *          EdgeEnablers </code> 
     *  @param  edgeId the <code> Id </code> of an <code> Edge </code> 
     *  @throws org.osid.NotFoundException <code> edgeId </code> not found or, 
     *          an <code> edgeEnablerId </code> not related to <code> edgeId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> edgeEnablerIds </code> 
     *          or <code> edgeId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderEdgeEnablers(org.osid.id.Id[] edgeEnablerIds, 
                                  org.osid.id.Id edgeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
