//
// org.osid.topology.rules.EdgeEnablerRuleLookupSession
//
//     The OSID Java specification for org.osid.topology.rules.EdgeEnablerRuleLookupSession.
//
// Copyright (C) 2011 Ingenescus All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.topology.rules;


/**
 *  <p>This session provides methods to retrieve <code> EdgeEnabler </code> to 
 *  <code> Edge </code> mappings. An <code> Edge </code> with multiple <code> 
 *  EdgeEnablers </code> means any positive rule evaluation across the 
 *  enablers result in an effective <code> Edge. </code> </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated graph view: All methods in this session operate, 
 *      retrieve and pertain edge enablers defined explicitly in the current 
 *      graph </li> 
 *      <li> federated graph view: All methods in this session operate, 
 *      retrieve and pertain to all edge enablers defined in this graph and 
 *      any other edge enablers implicitly available in this graph through 
 *      graph inheritence. </li> 
 *  </ul>
 *  
 */

public interface EdgeEnablerRuleLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Graph </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Graph Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getGraphId();


    /**
     *  Gets the <code> Graph </code> associated with this session. 
     *
     *  @return the graph 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.Graph getGraph()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform lookups of edge enabler/edge mappings. 
     *  A return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known lookup methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if looking up mappings is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupEdgeEnablerRules();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeEdgeEnablerRuleView();


    /**
     *  A complete view of the <code> EdgeEnabler </code> and <code> Edge 
     *  </code> returns is desired. Methods will return what is requested or 
     *  result in an error. This view is used when greater precision is 
     *  desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryEdgeEnablerRuleView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include edge enablers in ontologies which are children of this graph 
     *  in the graph hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedGraphView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this graph only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedGraphView();


    /**
     *  Gets the <code> EdgeEnabler Id </code> associated with an <code> Edge. 
     *  </code> 
     *
     *  @param   edgeId <code> Id </code> of the <code> Edge </code> 
     *  @return the edge enabler <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> edgeId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> edgeId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getEdgeEnablerIdsForEdge(org.osid.id.Id  edgeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> EdgeEnabler </code> associated with an <code> Edge. 
     *  </code> 
     *
     *  @param  edgeId <code> Id </code> of the <code> Edge </code> 
     *  @return the edge enablers 
     *  @throws org.osid.NotFoundException <code> edgeId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> edgeId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.rules.EdgeEnablerList getEdgeEnablersForEdge(org.osid.id.Id edgeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Edge </code> <code> Ids </code> mapped to an <code> 
     *  EdgeEnabler. </code> 
     *
     *  @param  edgeEnablerId <code> Id </code> of an <code> EdgeEnabler 
     *          </code> 
     *  @return list of edge <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> edgeEnablerId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> edgeEnablerId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getEdgeIdsByEdgeEnabler(org.osid.id.Id edgeEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Edges </code> mapped to an <code> EdgeEnabler. </code> 
     *
     *  @param  edgeEnablerId <code> Id </code> of an <code> EdgeEnabler 
     *          </code> 
     *  @return list of edges 
     *  @throws org.osid.NotFoundException <code> edgeEnablerId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> edgeEnablerId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.topology.EdgeList getEdgesByEdgeEnabler(org.osid.id.Id edgeEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
