//
// org.osid.tracking.DuplicateIssueAdminSession
//
//     The OSID Java specification for org.osid.tracking.DuplicateIssueAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.tracking;


/**
 *  <p>This session creates and manages linked issues. </p>
 */

public interface DuplicateIssueAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> FrontOffice </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> FrontOffice Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFrontOfficeId();


    /**
     *  Gets the <code> FrontOffice </code> associated with this session. 
     *
     *  @return the front office 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.FrontOffice getFrontOffice()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can link duplicate <code> Issues. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known linking an issue will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if linking <code> Issues </code> is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLinkIssues();


    /**
     *  Tests if this user can link an <code> Issue. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known linking the issue will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer update operations to an 
     *  unauthorized user. 
     *
     *  @param  issueId the <code> Id </code> of the <code> Issue </code> 
     *  @return <code> false </code> if issue linking is not authorized, 
     *          <code> true </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> issueId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If the <code> issueId </code> is not found, then it is 
     *          acceptable to return false to indicate the lack of linking 
     *          available. 
     */

    public boolean canLinkIssue(org.osid.id.Id issueId);


    /**
     *  Links two issues as duplicates. An issue may link to more than issue. 
     *
     *  @param  issueId the <code> Id </code> of the <code> Issue </code> 
     *  @param  anotherIssueId the <code> Id </code> of another <code> Issue 
     *          </code> 
     *  @throws org.osid.AlreadyExistsException <code> issueId </code> and 
     *          <code> anotherIssueId </code> already linked 
     *  @throws org.osid.NotFoundException <code> issueId </code> or <code> 
     *          anotherIssueId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> issueId </code> or 
     *          <code> anotherIssueId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void linkIssue(org.osid.id.Id issueId, 
                          org.osid.id.Id anotherIssueId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes the link between two issues as duplicates. 
     *
     *  @param  issueId the <code> Id </code> of the <code> Issue </code> 
     *  @param  anotherIssueId the <code> Id </code> of another <code> Issue 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> issueId </code> and <code> 
     *          anotherIssueId </code> not linked 
     *  @throws org.osid.NullArgumentException <code> issueId </code> or 
     *          <code> anotherIssueId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unlinkIssue(org.osid.id.Id issueId, 
                            org.osid.id.Id anotherIssueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
