//
// org.osid.tracking.FrontOfficeQuery
//
//     The OSID Java specification for org.osid.tracking.FrontOfficeQuery.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.tracking;


/**
 *  <p>This is the query for searching front offices. Each method match 
 *  specifies an <code> AND </code> term while multiple invocations of the 
 *  same method produce a nested <code> OR. </code> </p>
 */

public interface FrontOfficeQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the issue <code> Id </code> for this query to match front offices 
     *  that have a related issue. 
     *
     *  @param  issueId a issue <code> Id </code> 
     *  @param  match <code> true </code> if a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> issueId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchIssueId(org.osid.id.Id issueId, boolean match);


    /**
     *  Clears the issue <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearIssueIdTerms();


    /**
     *  Tests if a <code> IssueQuery </code> is available. 
     *
     *  @return <code> true </code> if a issue query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsIssueQuery();


    /**
     *  Gets the query for a issue. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the issue query 
     *  @throws org.osid.UnimplementedException <code> supportsIssueQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsIssueQuery() </code> is <code> true. </code> 
     */

    public org.osid.tracking.IssueQuery getIssueQuery();


    /**
     *  Matches front offices that have any issue. 
     *
     *  @param  match <code> true </code> to match front offices with any 
     *          issue, <code> false </code> to match front offices with no 
     *          issue 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyIssue(boolean match);


    /**
     *  Clears the issue query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearIssueTerms();


    /**
     *  Sets the effort <code> Id </code> for this query to match front 
     *  offices containing queues. 
     *
     *  @param  queueId the queue <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> queueId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchQueueId(org.osid.id.Id queueId, boolean match);


    /**
     *  Clears the queue query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearQueueIdTerms();


    /**
     *  Tests if a <code> QueueQuery </code> is available. 
     *
     *  @return <code> true </code> if a queue query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueQuery();


    /**
     *  Gets the query for a queue. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the queue query 
     *  @throws org.osid.UnimplementedException <code> supportsQueueQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsQueueQuery() </code> is <code> true. </code> 
     */

    public org.osid.tracking.QueueQuery getQueueQuery();


    /**
     *  Matches front offices that have any queue. 
     *
     *  @param  match <code> true </code> to match front offices with any 
     *          queue, <code> false </code> to match front offices with no 
     *          queue 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyQueue(boolean match);


    /**
     *  Clears the queue query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearQueueTerms();


    /**
     *  Sets the front office <code> Id </code> for this query to match front 
     *  offices that have the specified front office as an ancestor. 
     *
     *  @param  frontOfficeId a front office <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> frontOfficeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorFrontOfficeId(org.osid.id.Id frontOfficeId, 
                                           boolean match);


    /**
     *  Clears the ancestor front office <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorFrontOfficeIdTerms();


    /**
     *  Tests if a <code> FrontOfficeQuery </code> is available. 
     *
     *  @return <code> true </code> if a front office query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorFrontOfficeQuery();


    /**
     *  Gets the query for a frontOffice/ Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the front office query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorFrontOfficeQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorFrontOfficeQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.tracking.FrontOfficeQuery getAncestorFrontOfficeQuery();


    /**
     *  Matches front offices with any ancestor. 
     *
     *  @param  match <code> true </code> to match front offices with any 
     *          ancestor, <code> false </code> to match root frontOffices 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorFrontOffice(boolean match);


    /**
     *  Clears the ancestor front office query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorFrontOfficeTerms();


    /**
     *  Sets the front office <code> Id </code> for this query to match front 
     *  offices that have the specified front office as a descendant. 
     *
     *  @param  frontOfficeId a front office <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> frontOfficeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantFrontOfficeId(org.osid.id.Id frontOfficeId, 
                                             boolean match);


    /**
     *  Clears the descendant front office <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantFrontOfficeIdTerms();


    /**
     *  Tests if a <code> FrontOfficeQuery </code> is available. 
     *
     *  @return <code> true </code> if a front office query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantFrontOfficeQuery();


    /**
     *  Gets the query for a frontOffice/ Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the front office query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantFrontOfficeQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantFrontOfficeQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.tracking.FrontOfficeQuery getDescendantFrontOfficeQuery();


    /**
     *  Matches front offices with any descendant. 
     *
     *  @param  match <code> true </code> to match front offices with any 
     *          descendant, <code> false </code> to match leaf frontOffices 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantFrontOffice(boolean match);


    /**
     *  Clears the descendant front office query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantFrontOfficeTerms();


    /**
     *  Gets the front office query record corresponding to the given <code> 
     *  FrontOffice </code> record <code> Type. </code> Multiple record 
     *  retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  frontOfficeRecordType a front office record type 
     *  @return the front office query record 
     *  @throws org.osid.NullArgumentException <code> frontOfficeRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(frontOfficeRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.records.FrontOfficeQueryRecord getFrontOfficeQueryRecord(org.osid.type.Type frontOfficeRecordType)
        throws org.osid.OperationFailedException;
}
