//
// org.osid.tracking.FrontOfficeReceiver
//
//     The OSID Java specification for org.osid.tracking.FrontOfficeReceiver.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.tracking;


/**
 *  <p>The front office receiver is the consumer supplied interface for 
 *  receiving notifications pertaining to new, updated or deleted <code> 
 *  FrontOffice </code> objects. </p>
 */

public interface FrontOfficeReceiver
    extends org.osid.OsidReceiver {


    /**
     *  The callback for notifications of new frontOffices. 
     *
     *  @param  frontOfficeIds the <code> Ids </code> of the new <code> 
     *          FrontOffices </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newFrontOffices(org.osid.id.IdList frontOfficeIds);


    /**
     *  The callback for notifications of new front office ancestors. 
     *
     *  @param  frontOfficeId the <code> Id </code> of the <code> FrontOffice 
     *          </code> 
     *  @param  ancestorId the <code> Id </code> of the new <code> FrontOffice 
     *          </code> ancestor 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newAncestorFrontOffice(org.osid.id.Id frontOfficeId, 
                                       org.osid.id.Id ancestorId);


    /**
     *  The callback for notifications of new front office descendants. 
     *
     *  @param  frontOfficeId the <code> Id </code> of the <code> FrontOffice 
     *          </code> 
     *  @param  descendantId the <code> Id </code> of the new <code> 
     *          FrontOffice </code> descendant 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newDescendantFrontOffice(org.osid.id.Id frontOfficeId, 
                                         org.osid.id.Id descendantId);


    /**
     *  The callback for notification of updated front office. 
     *
     *  @param  frontOfficeIds the <code> Ids </code> of the updated <code> 
     *          FrontOffices </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void changedFrontOffices(org.osid.id.IdList frontOfficeIds);


    /**
     *  The callback for notification of deleted frontOffices. 
     *
     *  @param  frontOfficeIds the <code> Ids </code> of the deleted <code> 
     *          FrontOffices </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedFrontOffices(org.osid.id.IdList frontOfficeIds);


    /**
     *  The callback for notifications of deleted front office ancestors. 
     *
     *  @param  frontOfficeId the <code> Id </code> of the <code> FrontOffice 
     *          </code> 
     *  @param  ancestorId the <code> Id </code> of the removed <code> 
     *          FrontOffice </code> ancestor 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedAncestorFrontOffice(org.osid.id.Id frontOfficeId, 
                                           org.osid.id.Id ancestorId);


    /**
     *  The callback for notifications of deleted front office descendants. 
     *
     *  @param  frontOfficeId the <code> Id </code> of the <code> FrontOffice 
     *          </code> 
     *  @param  descendantId the <code> Id </code> of the removed <code> 
     *          FrontOffice </code> descendant 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedDescendantFrontOffice(org.osid.id.Id frontOfficeId, 
                                             org.osid.id.Id descendantId);


    /**
     *  The callback for notifications of changes to a front office hierarchy 
     *  where the hierarchy needs to refreshed. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void restructuredFrontOfficeHierarchy();
}
