//
// org.osid.tracking.Issue
//
//     The OSID Java specification for org.osid.tracking.Issue.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.tracking;


/**
 *  <p>A <code> Issue </code> represents a issue in a <code> Queue. </code> An 
 *  <code> Issue </code> is an <code> OsidRelationship </code> between a 
 *  customer and a <code> Queue </code> where the effective dates represent 
 *  the dates this <code> Issue </code> was opened. </p>
 */

public interface Issue
    extends org.osid.OsidRelationship {


    /**
     *  Gets the queue <code> Id. </code> 
     *
     *  @return the queue <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getQueueId();


    /**
     *  Gets the queue. 
     *
     *  @return the queue 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.Queue getQueue()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the customer <code> Id. </code> 
     *
     *  @return the customer <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCustomerId();


    /**
     *  Gets the customer. 
     *
     *  @return the customer 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getCustomer()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the topic <code> Id. </code> 
     *
     *  @return the topic <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getTopicId();


    /**
     *  Gets the topic. 
     *
     *  @return the topic 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.ontology.Subject getTopic()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this issue is a subtask of another issue. 
     *
     *  @return <code> true </code> if this issue is a subtask, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isSubTask();


    /**
     *  Gets the master issue <code> Id </code> . If <code> isSubtask() 
     *  </code> is <code> false </code> then the <code> Id </code> of this 
     *  <code> Issue </code> is returned. 
     *
     *  @return the master issue <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getMasterIssueId();


    /**
     *  Gets the master issue. If <code> isSubtask() </code> is <code> false 
     *  </code> then this <code> Issue </code> is returned. 
     *
     *  @return the master issue 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.Issue getMasterIssue()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this issue is a duplicate of another issue. 
     *
     *  @return <code> true </code> if this issue is a duplicate, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isDuplicate();


    /**
     *  Gets the duplicate issue <code> Ids. </code> 
     *
     *  @return the duplicate issue <code> Ids </code> 
     *  @throws org.osid.IllegalStateException <code> isDuplicate() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getDuplicateIssueIds();


    /**
     *  Gets the duplicate issues. 
     *
     *  @return the duplicate issues 
     *  @throws org.osid.IllegalStateException <code> isDuplicate() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.IssueList getDuplicateIssues()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this issue is a branch of another issue. 
     *
     *  @return <code> true </code> if this issue is a branch, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isBranched();


    /**
     *  Gets the branched issue <code> Id. </code> 
     *
     *  @return the branched issue 
     *  @throws org.osid.IllegalStateException <code> isBranched() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getBranchedIssueId();


    /**
     *  Gets the branched issue. 
     *
     *  @return the branched issue 
     *  @throws org.osid.IllegalStateException <code> isBranched() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.Issue getBranchedIssue()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the root issue <code> Id </code> . If <code> isBranched() </code> 
     *  is <code> false </code> then the <code> Id </code> of this <code> 
     *  Issue </code> is returned. 
     *
     *  @return the root issue <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getRootIssueId();


    /**
     *  Gets the root issue. If <code> isBranched() </code> is <code> false 
     *  </code> then this <code> Issue </code> is returned. 
     *
     *  @return the root issue 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.Issue getRootIssue()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the priority type of this issue. 
     *
     *  @return the priority type 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getPriorityType();


    /**
     *  Gets the creator <code> Id. </code> 
     *
     *  @return the creator <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCreatorId();


    /**
     *  Gets the creator of this issue. 
     *
     *  @return the creator 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getCreator()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the creating agent <code> Id. </code> 
     *
     *  @return the creatoing agent <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCreatingAgentId();


    /**
     *  Gets the creating agent of this issue. 
     *
     *  @return the creating agent 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.Agent getCreatingAgent()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the created date. 
     *
     *  @return the created date 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getCreatedDate();


    /**
     *  Tests if this issue has been resurrected after a close. A reopened 
     *  <code> Issue </code> extends the effective dates through to when it is 
     *  closed again. 
     *
     *  @return <code> true </code> if this issue is reopened, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isReopened();


    /**
     *  Gets the reopener <code> Id. </code> If reoepned more than once, this 
     *  method returns the last reopened event. 
     *
     *  @return the reopener <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isReopened() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getReopenerId();


    /**
     *  Gets the reopener of this issue. If reoepned more than once, this 
     *  method returns the last reopened event. 
     *
     *  @return the reopener 
     *  @throws org.osid.IllegalStateException <code> isReopened() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getReopener()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the reopening agent <code> Id. </code> If reoepned more than 
     *  once, this method returns the last reopened event. 
     *
     *  @return the reopening agent <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isReopened() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getReopeningAgentId();


    /**
     *  Gets the reopening agent of this issue. If reoepned more than once, 
     *  this method returns the last reopened event. 
     *
     *  @return the reopening agent 
     *  @throws org.osid.IllegalStateException <code> isReopened() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.Agent getReopeningAgent()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the last reopened date. If reoepned more than once, this method 
     *  returns the last reopened event. 
     *
     *  @return the last reopened date 
     *  @throws org.osid.IllegalStateException <code> hasReopened() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getReopenedDate();


    /**
     *  Tests if this issue has a due date. 
     *
     *  @return <code> true </code> if this issue has a due date, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasDueDate();


    /**
     *  Gets the due date. 
     *
     *  @return the due date 
     *  @throws org.osid.IllegalStateException <code> hasDueDate() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getDueDate();


    /**
     *  Tests if this issue is pending a response from the customer. 
     *
     *  @return <code> true </code> if this issue is pending, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isPending();


    /**
     *  Tests if this issue is blocked on another issue. 
     *
     *  @return <code> true </code> if this issue is blocked, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isBlocked();


    /**
     *  Gets the blocker issue <code> Ids. </code> 
     *
     *  @return the blocking issue <code> Ids </code> 
     *  @throws org.osid.IllegalStateException <code> isBlocked() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getBlockerIds();


    /**
     *  Gets the blocking issues. 
     *
     *  @return the blocking issues 
     *  @throws org.osid.IllegalStateException <code> isBlocked() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.IssueList getBlockers()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this issue is resolved. If the issue was reopened, it is no 
     *  longer resolved. 
     *
     *  @return <code> true </code> if this issue is resolved, <code> false 
     *          </code> if unresolved 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isResolved();


    /**
     *  Gets the resolver <code> Id. </code> 
     *
     *  @return the reopener <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isResolved() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getResolverId();


    /**
     *  Gets the resolver of this issue. 
     *
     *  @return the resolver 
     *  @throws org.osid.IllegalStateException <code> isResolved() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getResolver()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the resolving agent <code> Id. </code> 
     *
     *  @return the resolving agent <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isResolved() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getResolvingAgentId();


    /**
     *  Gets the resolving agent of this issue. 
     *
     *  @return the resolving agent 
     *  @throws org.osid.IllegalStateException <code> isResolved() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.Agent getResolvingAgent()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the resolved date. A resolved issue is still open until it is 
     *  closed. 
     *
     *  @return the resolved date 
     *  @throws org.osid.IllegalStateException <code> isResolved() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getResolvedDate();


    /**
     *  Gets a type indicating the resolution; "fixed," "canceled", "cannot 
     *  reproduce." 
     *
     *  @return the resolution type 
     *  @throws org.osid.IllegalStateException <code> isResolved() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.Type getResolutionType();


    /**
     *  Tests if this issue is closed. An issue may be left opened after being 
     *  resolved for acknowledgement or review. 
     *
     *  @return <code> true </code> if this issue is closed, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isClosed();


    /**
     *  Gets the resource <code> Id </code> of the closer. 
     *
     *  @return the closing resource <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isClosed() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCloserId();


    /**
     *  Gets the resource of the closer. 
     *
     *  @return the closing resource 
     *  @throws org.osid.IllegalStateException <code> isClosed() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getCloser()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the agent <code> Id </code> of the closer. 
     *
     *  @return the closing agent <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isClosed() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getClosingAgentId();


    /**
     *  Gets the agent of the closer. 
     *
     *  @return the closing agent 
     *  @throws org.osid.IllegalStateException <code> isClosed() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.Agent getClosingAgent()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the closed date. 
     *
     *  @return the closed date 
     *  @throws org.osid.IllegalStateException <code> isClosed() </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getClosedDate();


    /**
     *  Tests if this issue is assigned. 
     *
     *  @return <code> true </code> if this issue is assigned, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isAssigned();


    /**
     *  Gets the assigned resource <code> Id. </code> 
     *
     *  @return the assigned resource <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isAssigned() </code> is 
     *          <code> false </code> or <code> isClosed() </code> is <code> 
     *          true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getAssignedResourceId();


    /**
     *  Gets the assigned resource. 
     *
     *  @return the assigned resource 
     *  @throws org.osid.IllegalStateException <code> isAssigned() </code> is 
     *          <code> false </code> or <code> isClosed() </code> is <code> 
     *          true </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getAssignedResource()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the issue record corresponding to the given <code> Issue </code> 
     *  record <code> Type. </code> This method is used to retrieve an object 
     *  implementing the requested record. The <code> issueRecordType </code> 
     *  may be the <code> Type </code> returned in <code> getRecordTypes() 
     *  </code> or any of its parents in a <code> Type </code> hierarchy where 
     *  <code> hasRecordType(issueRecordType) </code> is <code> true </code> . 
     *
     *  @param  issueRecordType the type of issue record to retrieve 
     *  @return the issue record 
     *  @throws org.osid.NullArgumentException <code> issueRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(issueRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.records.IssueRecord getIssueRecord(org.osid.type.Type issueRecordType)
        throws org.osid.OperationFailedException;
}
