//
// org.osid.tracking.IssueAction
//
//     Specifies the OSID definition for org.osid.tracking.IssueAction.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.tracking;


/**
 *  This enumeration contains the possible issue action types. 
 */

public enum IssueAction {

    /** the issue was opened */
    OPENED("Opened", "the issue was opened"),

    /** the issue was reopened */
    REOPENED("Reopened", "the issue was reopened"),

    /** the issue was assigned */
    ASSIGNED("Assigned", "the issue was assigned"),

    /** the issue was unassigned by the assignee */
    FORWARDED("Forwarded", "the issue was unassigned by the assignee"),

    /** a message was sent to or from the customer */
    MESSAGE_SENT("Message_sent", "a message was sent to or from the customer"),

    /** a comment was added to the log */
    COMMENTED("Commented", "a comment was added to the log"),

    /** the issue was updated */
    UPDATED("Updated", "the issue was updated"),

    /** the issue is blocked on other issues */
    BLOCKED("Blocked", "the issue is blocked on other issues"),

    /** the blocking issues were closed */
    UNBLOCKED("Unblocked", "the blocking issues were closed"),

    /** the issue was resolved */
    RESOLVED("Resolved", "the issue was resolved"),

    /** the issue was closed */
    CLOSED("Closed", "the issue was closed");


    private final String displayName;
    private final String description;

    IssueAction(String displayName, String description) {
        this.displayName = displayName;
        this.description = description;
    }

    public String getDisplayName() {
        return (this.displayName);
    }

    public String getDescription() {
        return (this.description);
    }
}
