//
// org.osid.tracking.IssueFrontOfficeAssignmentSession
//
//     The OSID Java specification for org.osid.tracking.IssueFrontOfficeAssignmentSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.tracking;


/**
 *  <p>This session provides methods to re-assign <code> Issues </code> to 
 *  <code> FrontOffice </code> objects. An <code> Issue </code> may appear in 
 *  multiple <code> FrontOffice </code> objects and removing the last 
 *  reference to an <code> Issue </code> is the equivalent of deleting it. 
 *  Each <code> FrontOffice </code> may have its own authorizations governing 
 *  who is allowed to operate on it. </p> 
 *  
 *  <p> Adding a reference of an <code> Issue </code> to another <code> 
 *  FrontOffice </code> is not a copy operation (eg: does not change its 
 *  <code> Id </code> ). </p>
 */

public interface IssueFrontOfficeAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter issue/front office mappings. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignIssues();


    /**
     *  Tests if this user can alter issue/front office mappings. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @param  frontOfficeId the <code> Id </code> of the <code> FrontOffice 
     *          </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> frontOfficeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignIssuesToFrontOffice(org.osid.id.Id frontOfficeId);


    /**
     *  Gets a list of front offices including and under the given front 
     *  office node in which any issue can be assigned. 
     *
     *  @param  frontOfficeId the <code> Id </code> of the <code> FrontOffice 
     *          </code> 
     *  @return list of assignable front office <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> frontOfficeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableFrontOfficeIds(org.osid.id.Id frontOfficeId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of front offices including and under the given front 
     *  office node in which a specific issue can be assigned. 
     *
     *  @param  frontOfficeId the <code> Id </code> of the <code> FrontOffice 
     *          </code> 
     *  @param  issueId the <code> Id </code> of the <code> Issue </code> 
     *  @return list of assignable front office <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> frontOfficeId </code> or 
     *          <code> issueId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableFrontOfficeIdsForIssue(org.osid.id.Id frontOfficeId, 
                                                                  org.osid.id.Id issueId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> Issue </code> to a <code> FrontOffice. </code> 
     *
     *  @param  issueId the <code> Id </code> of the <code> Issue </code> 
     *  @param  frontOfficeId the <code> Id </code> of the <code> FrontOffice 
     *          </code> 
     *  @throws org.osid.AlreadyExistsException <code> issueId </code> is 
     *          already assigned to <code> frontOfficeId </code> 
     *  @throws org.osid.NotFoundException <code> issueId </code> or <code> 
     *          frontOfficeId </code> not found 
     *  @throws org.osid.NullArgumentException <code> issueId </code> or 
     *          <code> frontOfficeId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignIssueToFrontOffice(org.osid.id.Id issueId, 
                                         org.osid.id.Id frontOfficeId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes an <code> Issue </code> from a <code> FrontOffice. </code> 
     *
     *  @param  issueId the <code> Id </code> of the <code> Issue </code> 
     *  @param  frontOfficeId the <code> Id </code> of the <code> FrontOffice 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> issueId </code> or <code> 
     *          frontOfficeId </code> not found or <code> issueId </code> not 
     *          assigned to <code> frontOfficeId </code> 
     *  @throws org.osid.NullArgumentException <code> issueId </code> or 
     *          <code> frontOfficeId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignIssueFromFrontOffice(org.osid.id.Id issueId, 
                                             org.osid.id.Id frontOfficeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
