//
// org.osid.tracking.IssueMessagingSession
//
//     The OSID Java specification for org.osid.tracking.IssueMessagingSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.tracking;


/**
 *  <p>This session creates comments on issues and sends messages to 
 *  customers. A comment is a direct log entry that may not be visible to the 
 *  customer. A message is sent by some means to the customer and recorded in 
 *  the log. In both cases, <code> LogEntryForms </code> are used to specify 
 *  the content of the message or comment with an IssueAction of <code> 
 *  COMMENTED </code> or <code> MESSAGE_SENT </code> . </p>
 */

public interface IssueMessagingSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> FrontOffice </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> FrontOffice Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFrontOfficeId();


    /**
     *  Gets the <code> FrontOffice </code> associated with this session. 
     *
     *  @return the front office 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.FrontOffice getFrontOffice()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can comment on Issues. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known creating a <code> LogEntry </code> will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer comment operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if commenting is not authorized, <code> 
     *          true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canComment();


    /**
     *  Tests if this user can create a single <code> LogEntry </code> using 
     *  the desired record types. While <code> 
     *  TrackingManager.getLogEntryRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> LogEntry. </code> 
     *  Providing an empty array tests if a <code> LogEntry </code> can be 
     *  created with no records. 
     *
     *  @param  logEntryRecordTypes array of log entry record types 
     *  @return <code> true </code> if <code> LogEntry </code> creation using 
     *          the specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> logEntryRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateLogEntryCommentWithRecordTypes(org.osid.type.Type[] logEntryRecordTypes);


    /**
     *  Gets the log entry form for creating commenting on issues. A new form 
     *  should be requested for each create transaction. 
     *
     *  @param  logEntryRecordTypes array of log entry record types 
     *  @return the log entry form 
     *  @throws org.osid.NullArgumentException <code> logEntryRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.LogEntryForm getLogEntryFormForCommenting(org.osid.type.Type[] logEntryRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Comments on an issue. 
     *
     *  @param  issueId the <code> Id </code> of the issue 
     *  @param  logEntryForm the form for this <code> LogEntry </code> 
     *  @return the new <code> LogEntry </code> 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NotFoundException <code> issueId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> issueId </code> or 
     *          <code> logEntryForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> logEntryForm </code> is 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.LogEntry comment(org.osid.id.Id issueId, 
                                              org.osid.tracking.LogEntryForm logEntryForm)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update comments. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known updating a comment will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer update operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if comment modification is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateComments();


    /**
     *  Tests if this user can update a specified <code> LogEntry. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known updating the <code> LogEntry 
     *  </code> will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer an 
     *  update operation to an unauthorized user for this log entry. 
     *
     *  @param  logEntryId the <code> Id </code> of the comment entry 
     *  @return <code> false </code> if log entry modification is not 
     *          authorized, <code> true </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> logEntryId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If the <code> logEntryId </code> is not found, then it is 
     *          acceptable to return false to indicate the lack of an update 
     *          available. 
     */

    public boolean canUpdateComment(org.osid.id.Id logEntryId);


    /**
     *  Gets the log entry form for updating an existing comment. A new log 
     *  entry form should be requested for each update transaction. 
     *
     *  @param  Id the <code> Id </code> of the <code> LogEntry </code> 
     *  @return the log entry form 
     *  @throws org.osid.NotFoundException <code> logEntryId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> logEntryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.LogEntryForm getLogEntryFormForCommentUpdate(org.osid.id.Id Id)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Updates an existing log entry. 
     *
     *  @param  logEntryId the <code> Id </code> of the <code> LogEntry 
     *          </code> 
     *  @param  logEntryForm the form containing the elements to be updated 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NotFoundException <code> logEntryId </code> is not 
     *          found or not a comment 
     *  @throws org.osid.NullArgumentException <code> logEntryId </code> or 
     *          <code> logEntryForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> logEntryForm </code> is 
     *          not supported 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateComment(org.osid.id.Id logEntryId, 
                              org.osid.tracking.LogEntryForm logEntryForm)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete comments. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known deleting a comment will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer delete operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if comment deletion is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteComments();


    /**
     *  Tests if this user can delete a specified comment. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting the comment will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer an delete operation to an 
     *  unauthorized user for this log entry. 
     *
     *  @param  logEntryId the <code> Id </code> of the comment 
     *  @return <code> false </code> if deletion of this <code> LogEntry 
     *          </code> is not authorized, <code> true </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> logEntryId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     *  @notes  If the <code> logEntryId </code> is not found, then it is 
     *          acceptable to return false to indicate the lack of an delete 
     *          available. 
     */

    public boolean canDeleteComment(org.osid.id.Id logEntryId);


    /**
     *  Deletes a comment. 
     *
     *  @param  logEntryId the <code> Id </code> of the comment to remove 
     *  @throws org.osid.NotFoundException <code> logEntryId </code> not found 
     *  @throws org.osid.NullArgumentException <code> logEntryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteComment(org.osid.id.Id logEntryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all comments in this <code> FrontOffice. </code> 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteComments()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all comments within the given date range inclusive in this 
     *  <code> FrontOffice. </code> 
     *
     *  @param  from start date 
     *  @param  to end date 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteCommentsByDate(org.osid.calendaring.DateTime from, 
                                     org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all comments in a <code> Queue. </code> 
     *
     *  @param  queueId the <code> Id </code> of a <code> Queue </code> 
     *  @throws org.osid.NotFoundException <code> queueId </code> not found 
     *  @throws org.osid.NullArgumentException <code> queueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteCommentsForQueue(org.osid.id.Id queueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all comments within the given date range inclusive in this 
     *  <code> Queue. </code> 
     *
     *  @param  queueId the <code> Id </code> of a <code> Queue </code> 
     *  @param  from start date 
     *  @param  to end date 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NotFoundException <code> queueId </code> not found 
     *  @throws org.osid.NullArgumentException <code> queueId, from </code> or 
     *          <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteCommentsByDateForQueue(org.osid.id.Id queueId, 
                                             org.osid.calendaring.DateTime from, 
                                             org.osid.calendaring.DateTime to)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all comments in an <code> Issue. </code> 
     *
     *  @param  issueId the <code> Id </code> of an <code> Issue </code> 
     *  @throws org.osid.NotFoundException <code> issueId </code> not found 
     *  @throws org.osid.NullArgumentException <code> issueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteCommentsForIssue(org.osid.id.Id issueId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all comments within the given date range inclusive in this 
     *  <code> Issue. </code> 
     *
     *  @param  issueId the <code> Id </code> of an <code> Issue </code> 
     *  @param  from start date 
     *  @param  to end date 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NotFoundException <code> issueId </code> not found 
     *  @throws org.osid.NullArgumentException <code> issueId, from </code> or 
     *          <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteCommentsByDateForIssue(org.osid.id.Id issueId, 
                                             org.osid.calendaring.DateTime from, 
                                             org.osid.calendaring.DateTime to)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can send customer messages. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known creating a <code> LogEntry </code> will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer comment operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if messaging is not authorized, <code> 
     *          true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSendMessages();


    /**
     *  Tests if this user can create a single <code> LogEntry </code> using 
     *  the desired record types. While <code> 
     *  TrackingManager.getLogEntryRecordTypes() </code> can be used to 
     *  examine which records are supported, this method tests which record(s) 
     *  are required for creating a specific <code> LogEntry. </code> 
     *  Providing an empty array tests if a <code> LogEntry </code> can be 
     *  created with no records. 
     *
     *  @param  logEntryRecordTypes array of log entry record types 
     *  @return <code> true </code> if <code> LogEntry </code> creation using 
     *          the specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> logEntryRecordTypes 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateLogEntryMessageWithRecordTypes(org.osid.type.Type[] logEntryRecordTypes);


    /**
     *  Gets the log entry form for creating messages to customers. A new form 
     *  should be requested for each create transaction. 
     *
     *  @param  logEntryRecordTypes array of log entry record types 
     *  @return the log entry form 
     *  @throws org.osid.NullArgumentException <code> logEntryRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.LogEntryForm getLogEntryFormForMessaging(org.osid.type.Type[] logEntryRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Send a customer a message and records it in the issue log. 
     *
     *  @param  issueId the <code> Id </code> of the issue 
     *  @param  logEntryForm the form for this <code> LogEntry </code> 
     *  @return the new <code> LogEntry </code> 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NotFoundException <code> issueId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> issueId </code> or 
     *          <code> logEntryForm </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> logEntryForm </code> is 
     *          not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.LogEntry sendMessage(org.osid.id.Id issueId, 
                                                  org.osid.tracking.LogEntryForm logEntryForm)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
