//
// org.osid.tracking.IssueNotificationSession
//
//     The OSID Java specification for org.osid.tracking.IssueNotificationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.tracking;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> Issue </code> objects in this <code> FrontOffice. </code> This 
 *  session is intended for consumers needing to synchronize their state with 
 *  this service without the use of polling. Notifications are cancelled when 
 *  this session is closed. </p> 
 *  
 *  <p> The two views defined in this session correspond to the views in the 
 *  <code> IssueLookupSession. </code> </p>
 */

public interface IssueNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> FrontOffice </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> FrontOffice Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFrontOfficeId();


    /**
     *  Gets the <code> FrontOffice </code> associated with this session. 
     *
     *  @return the front office 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.FrontOffice getFrontOffice()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> Issue </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForIssueNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include issues in front offices which are children of this front 
     *  office in the front office hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedFrontOfficeView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts notifications to this front office only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedFrontOfficeView();


    /**
     *  Register for notifications of new issues. <code> 
     *  IssueReceiver.newIssues() </code> is invoked when a new <code> Issue 
     *  </code> appears in this front office. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewIssues()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new issues in the given queue. <code> 
     *  IssueReceiver.newIssues() </code> is invoked when a new <code> Issue 
     *  </code> appears in this front office. 
     *
     *  @param  queueId the <code> Id </code> of the queue to monitor 
     *  @throws org.osid.NullArgumentException <code> queueId is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewIssuesForQueue(org.osid.id.Id queueId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new issues for the given customer. 
     *  <code> IssueReceiver.newIssues() </code> is invoked when a new <code> 
     *  Issue </code> appears in this front office. 
     *
     *  @param  resourceId the <code> Id </code> of the customer to monitor 
     *  @throws org.osid.NullArgumentException <code> resourceId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewIssuesForCustomer(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new issues for the given topic. <code> 
     *  IssueReceiver.newIssues() </code> is invoked when a new <code> Issue 
     *  </code> appears in this front office. 
     *
     *  @param  subjectId the <code> Id </code> of the subject to monitor 
     *  @throws org.osid.NullArgumentException <code> subjectId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewIssuesByTopic(org.osid.id.Id subjectId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated issues. <code> 
     *  IssueReceiver.changedIssues() </code> is invoked when an issue in this 
     *  front office is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedIssues()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated issues in the given queue. 
     *  <code> IssueReceiver.changedIssues() </code> is invoked when an issue 
     *  in this front office is changed. 
     *
     *  @param  queueId the <code> Id </code> of the queue to monitor 
     *  @throws org.osid.NullArgumentException <code> queueId is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedIssuesForQueue(org.osid.id.Id queueId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated issues for the given customer. 
     *  <code> IssueReceiver.changedIssue() </code> is invoked when an issue 
     *  in this front office is changed. 
     *
     *  @param  resourceId the <code> Id </code> of the customer to monitor 
     *  @throws org.osid.NullArgumentException <code> resourceId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedIssuesForCustomer(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated issues for the given topic. 
     *  <code> IssueReceiver.changedIssues() </code> is invoked when an issue 
     *  in this front office is changed. 
     *
     *  @param  subjectId the <code> Id </code> of the subject to monitor 
     *  @throws org.osid.NullArgumentException <code> subjectId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedIssuesByTopic(org.osid.id.Id subjectId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an updated issue. <code> 
     *  IssueReceiver.changedIssues() </code> is invoked when the specified 
     *  issue in this front office is changed. 
     *
     *  @param  issueId the <code> Id </code> of the <code> Issue </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> issueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedIssue(org.osid.id.Id issueId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted issues. <code> 
     *  IssueReceiver.deletedIssues() </code> is invoked when an issue is 
     *  deleted or removed from this front office. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedIssues()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted issues in the given queue. 
     *  <code> IssueReceiver.deletedIssues() </code> is invoked when an issue 
     *  is deleted or removed from this front office. 
     *
     *  @param  queueId the <code> Id </code> of the queue to monitor 
     *  @throws org.osid.NullArgumentException <code> queueId is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedIssuesForQueue(org.osid.id.Id queueId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted issues for the given customer. 
     *  <code> IssueReceiver.deletedIssues() </code> is invoked when an issue 
     *  is deleted or removed from this front office. 
     *
     *  @param  resourceId the <code> Id </code> of the customer to monitor 
     *  @throws org.osid.NullArgumentException <code> resourceId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedIssuesForCustomer(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted issues for the given topic. 
     *  <code> IssueReceiver.deletedIssues() </code> is invoked when an issue 
     *  is deleted or removed from this front office. 
     *
     *  @param  subjectId the <code> Id </code> of the subject to monitor 
     *  @throws org.osid.NullArgumentException <code> subjectId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedIssuesByTopic(org.osid.id.Id subjectId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted issue. <code> 
     *  IssueReceiver.deletedIssues() </code> is invoked when the specified 
     *  issue is deleted or removed from this front office. 
     *
     *  @param  issueId the <code> Id </code> of the <code> Issue </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> issueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedIssue(org.osid.id.Id issueId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a subtask for the given issue. <code> 
     *  IssueReceiver.subtaskIssues() </code> is invoked when the specified 
     *  issue is gets a new subtask. 
     *
     *  @param  issueId the <code> Id </code> of the <code> Issue </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> issueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForSubtasks(org.osid.id.Id issueId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a linked issue to the given issue. 
     *  <code> IssueReceiver.linkedIssue() </code> is invoked when the 
     *  specified issue gets a new duplicate. 
     *
     *  @param  issueId the <code> Id </code> of the <code> Issue </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> issueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForLinkedIssues(org.osid.id.Id issueId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of an unlinked issue from the given issue. 
     *  <code> IssueReceiver.unlinkedIssue() </code> is invoked when the 
     *  specified issue loses a duplicate. 
     *
     *  @param  issueId the <code> Id </code> of the <code> Issue </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> issueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForUnlinkedIssues(org.osid.id.Id issueId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a blocking issue to the given issue. 
     *  <code> IssueReceiver.blockedIssue() </code> is invoked when the 
     *  specified issue is blocked by another issue. 
     *
     *  @param  issueId the <code> Id </code> of the <code> Issue </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> issueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForBlockingIssues(org.osid.id.Id issueId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of the removal of a blocking issue to the 
     *  given issue. <code> IssueReceiver.unblockedIssue() </code> is invoked 
     *  when the specified issue is no longer blocked by another issue. 
     *
     *  @param  issueId the <code> Id </code> of the <code> Issue </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> issueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForUnblockingIssues(org.osid.id.Id issueId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a blocked issue to the given issue. 
     *  <code> IssueReceiver.blockedIssue() </code> is invoked when the 
     *  specified issue is blocking another issue. 
     *
     *  @param  issueId the <code> Id </code> of the <code> Issue </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> issueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForBlockedIssues(org.osid.id.Id issueId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of the removal of a blocked issue to the 
     *  given issue. <code> IssueReceiver.unblockedIssue() </code> is invoked 
     *  when the specified issue is no longer blocking another issue. 
     *
     *  @param  issueId the <code> Id </code> of the <code> Issue </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> issueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForUnblockedIssues(org.osid.id.Id issueId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
