//
// org.osid.tracking.IssueReceiver
//
//     The OSID Java specification for org.osid.tracking.IssueReceiver.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.tracking;


/**
 *  <p>The issue receiver is the consumer supplied interface for receiving 
 *  notifications pertaining to new, updated or deleted issues. </p>
 */

public interface IssueReceiver
    extends org.osid.OsidReceiver {


    /**
     *  The callback for notifications of new issues. 
     *
     *  @param  issueIds the <code> Ids </code> of the new <code> Issues 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void newIssues(org.osid.id.IdList issueIds);


    /**
     *  The callback for notification of updated issues. 
     *
     *  @param  issueIds the <code> Ids </code> of the updated <code> Issues 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void changedIssues(org.osid.id.IdList issueIds);


    /**
     *  The callback for notification of deleted issues. 
     *
     *  @param  issueIds the <code> Ids </code> of the deleted <code> Issues 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deletedIssues(org.osid.id.IdList issueIds);


    /**
     *  The callback for notification of subtask issues. 
     *
     *  @param  subtaskIssueIds the <code> Ids </code> of the subtasks 
     *  @compliance mandatory This method must be implemented. 
     */

    public void subtaskIssues(org.osid.id.IdList subtaskIssueIds);


    /**
     *  The callback for notification of linked issues. 
     *
     *  @param  issueId the <code> Id </code> of the <code> Issue </code> 
     *  @param  linkedIssueId the <code> Id </code> of the linked <code> Issue 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void linkedIssue(org.osid.id.Id issueId, 
                            org.osid.id.Id linkedIssueId);


    /**
     *  The callback for notification of linked issues. 
     *
     *  @param  issueId the <code> Id </code> of the <code> Issue </code> 
     *  @param  linkedIssueId the <code> Id </code> of the linked <code> Issue 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unlinkedIssue(org.osid.id.Id issueId, 
                              org.osid.id.Id linkedIssueId);


    /**
     *  The callback for notification of blocked issues. 
     *
     *  @param  blockingIssueId the <code> Id </code> of the blocking <code> 
     *          Issue </code> 
     *  @param  blockedIssue the <code> Id </code> of the blocked <code> Issue 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void blockedIssue(org.osid.id.Id blockingIssueId, 
                             org.osid.id.Id blockedIssue);


    /**
     *  The callback for notification of unblocked issues. 
     *
     *  @param  blockingIssueId the <code> Id </code> of the blocking <code> 
     *          Issue </code> 
     *  @param  blockedIssue the <code> Id </code> of the blocked <code> Issue 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unblockedIssue(org.osid.id.Id blockingIssueId, 
                               org.osid.id.Id blockedIssue);
}
