//
// org.osid.tracking.LogEntryLookupSession
//
//     The OSID Java specification for org.osid.tracking.LogEntryLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.tracking;


/**
 *  <p>This session provides methods for retrieving premade <code> LogEntries. 
 *  </code> The <code> LogEntry </code> represents a set of efforts <code> . 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated front office view: All log entry methods in this session 
 *      operate, retrieve and pertain to log entries defined explicitly in the 
 *      current front office. Using an isolated view is useful for managing 
 *      <code> LogEntries </code> with the <code> LogEntryAdminSession. 
 *      </code> </li> 
 *      <li> federated front office view: All log entry methods in this 
 *      session operate, retrieve and pertain to all log entries defined in 
 *      this front office and any other log entries implicitly available in 
 *      this front office through front office inheritence. </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedFrontOfficeView() </code> and <code> 
 *  useIsolatedFrontOfficeView() </code> behave as a radio group and one 
 *  should be selected before invoking the methods in this session. </p>
 */

public interface LogEntryLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> FrontOffice </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> FrontOffice Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFrontOfficeId();


    /**
     *  Gets the <code> FrontOffice </code> associated with this session. 
     *
     *  @return the front office 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.FrontOffice getFrontOffice()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> LogEntry </code> lookups. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupLogEntries();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeLogEntryView();


    /**
     *  A complete view of the <code> LogEntry </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryLogEntryView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include log entries in front offices which are children of this front 
     *  office in the front office hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedFrontOfficeView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this front office only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedFrontOfficeView();


    /**
     *  Gets the <code> LogEntry </code> specified by its <code> Id. </code> 
     *  In plenary mode, the exact <code> Id </code> is found or a <code> 
     *  NOT_FOUND </code> results. Otherwise, the returned <code> LogEntry 
     *  </code> may have a different <code> Id </code> than requested, such as 
     *  the case where a duplicate <code> Id </code> was assigned to a <code> 
     *  LogEntry </code> and retained for compatibility. 
     *
     *  @param  logEntryId <code> Id </code> of the <code> LogEntry </code> 
     *  @return the log entry 
     *  @throws org.osid.NotFoundException <code> logEntryId </code> not found 
     *  @throws org.osid.NullArgumentException <code> logEntryId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.tracking.LogEntry getLogEntry(org.osid.id.Id logEntryId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> LogEntryList </code> corresponding to the given <code> 
     *  IdList. </code> In plenary mode, the returned list contains all of the 
     *  log entries specified in the <code> Id </code> list, in the order of 
     *  the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> LogEntries </code> may be omitted from the list. 
     *
     *  @param  logEntryIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> LogEntry </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> logEntryIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.LogEntryList getLogEntriesByIds(org.osid.id.IdList logEntryIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> LogEntryList </code> corresponding to the given log 
     *  entry genus <code> Type </code> which does not include log entries of 
     *  genus types derived from the specified <code> Type. </code> In plenary 
     *  mode, the returned list contains all known log entries or an error 
     *  results. Otherwise, the returned list may contain only those log 
     *  entries that are accessible through this session. 
     *
     *  @param  logEntryGenusType a log entry genus type 
     *  @return the returned <code> LogEntry </code> list 
     *  @throws org.osid.NullArgumentException <code> logEntryGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.LogEntryList getLogEntriesByGenusType(org.osid.type.Type logEntryGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> LogEntryList </code> corresponding to the given log 
     *  entry genus <code> Type </code> and include any additional log entries 
     *  with genus types derived from the specified <code> Type. </code> In 
     *  plenary mode, the returned list contains all known log entries or an 
     *  error results. Otherwise, the returned list may contain only those log 
     *  entries that are accessible through this session. 
     *
     *  @param  logEntryGenusType a log entry genus type 
     *  @return the returned <code> LogEntry </code> list 
     *  @throws org.osid.NullArgumentException <code> logEntryGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.LogEntryList getLogEntriesByParentGenusType(org.osid.type.Type logEntryGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> LogEntryList </code> containing the given log entry 
     *  record <code> Type. </code> In plenary mode, the returned list 
     *  contains all known log entries or an error results. Otherwise, the 
     *  returned list may contain only those log entries that are accessible 
     *  through this session. 
     *
     *  @param  logEntryRecordType a log entry record type 
     *  @return the returned <code> LogEntry </code> list 
     *  @throws org.osid.NullArgumentException <code> logEntryRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.LogEntryList getLogEntriesByRecordType(org.osid.type.Type logEntryRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of log entries logged in the date range. In plenary mode, 
     *  the returned list contains all known availabilities or an error 
     *  results. Otherwise, the returned list may contain only those log 
     *  entries that are accessible through this session. 
     *
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> LogEntry </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.LogEntryList getLogEntriesByDate(org.osid.calendaring.DateTime from, 
                                                              org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> LogEntryList </code> in the given <code> Queue. </code> 
     *  In plenary mode, the returned list contains all of the log entries, or 
     *  an error results if a log entry connected to the issue is not found or 
     *  inaccessible. Otherwise, inaccessible <code> LogEntries </code> may be 
     *  omitted from the list. 
     *
     *  @param  queueId a queue <code> Id </code> 
     *  @return the returned <code> LogEntry </code> list 
     *  @throws org.osid.NullArgumentException <code> issueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.LogEntryList getLogEntriesForQueue(org.osid.id.Id queueId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of log entries logged in the date range in the given 
     *  queue. In plenary mode, the returned list contains all known 
     *  availabilities or an error results. Otherwise, the returned list may 
     *  contain only those log entries that are accessible through this 
     *  session. 
     *
     *  @param  queueId a queue <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> LogEntry </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> queueId, from </code> or 
     *          <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.LogEntryList getLogEntriesByDateForQueue(org.osid.id.Id queueId, 
                                                                      org.osid.calendaring.DateTime from, 
                                                                      org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> LogEntryList </code> connected to the given <code> 
     *  Issue. </code> In plenary mode, the returned list contains all of the 
     *  log entries, or an error results if a log entry connected to the issue 
     *  is not found or inaccessible. Otherwise, inaccessible <code> 
     *  LogEntries </code> may be omitted from the list. 
     *
     *  @param  issueId an issue <code> Id </code> 
     *  @return the returned <code> LogEntry </code> list 
     *  @throws org.osid.NullArgumentException <code> issueId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.LogEntryList getLogEntriesForIssue(org.osid.id.Id issueId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of log entries logged in the date range in the given 
     *  issue. In plenary mode, the returned list contains all known 
     *  availabilities or an error results. Otherwise, the returned list may 
     *  contain only those log entries that are accessible through this 
     *  session. 
     *
     *  @param  issueId an issue <code> Id </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> LogEntry </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> issueId, from </code> or 
     *          <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.LogEntryList getLogEntriesByDateForIssue(org.osid.id.Id issueId, 
                                                                      org.osid.calendaring.DateTime from, 
                                                                      org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> LogEntries. </code> In plenary mode, the returned list 
     *  contains all known log entries or an error results. Otherwise, the 
     *  returned list may contain only those log entries that are accessible 
     *  through this session. 
     *
     *  @return a list of <code> LogEntries </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.LogEntryList getLogEntries()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
