/**
 * <p>The Open Service Interface Definitions for the org.osid.tracking
 * service.</p>
 * 
 * <p>The Tracking OSID provides a means for tracking <code> Issues. </code> 
 * The Tracking OSID is part of a service cluster that includes the Resourcing 
 * OSID, Ontology OSID, Workflow OSID, and Process OSID. Each of these 
 * services defines a set of service operations to construct an overall work 
 * management system. </p> 
 * <h4> Issues </h4> 
 * 
 * <p> <code> Issues </code> are <code> OsidRelationships </code> between a 
 * customer and a <code> Queue. </code> The effective dates of the <code> 
 * Issue </code> represent the opening and closing of the <code> Issue. 
 * </code> An <code> Issue </code> defines some built-in states indicating if 
 * the <code> Issue </code> is resolved, waiting for a response, or blocked on 
 * another <code> Issue. </code> Additional states can be modeled 
 * orchestrating the Process OSID or through the Workflow OSID. </p> 
 * 
 * <p> <code> Issues </code> can be related to each other in various ways. 
 * </p> 
 * <h4> Subtask Issues </h4> 
 * 
 * <p> <code> Issues </code> can be created off of other <code> Issues </code> 
 * in the <code> SubtaskIssueAdminSession. </code> The subtask is an Issue in 
 * itself which can have its own relationships including additional subtasks. 
 * A Tracking OSID Provider may prevent the resolution of a master issue 
 * unless all the subtask <code> Issues </code> have been resolved. </p> 
 * <h4> Duplicate Issues </h4> 
 * 
 * <p> <code> Issues </code> can be linekd to each other to indicate that two 
 * Issues are duplicates of each other. A Tracking OSID Provider may implement 
 * a behavior to replicate operations across duplicate issues. </p> 
 * <h4> Branched Issues </h4> 
 * 
 * <p> A branched <code> Issue </code> is created from a root <code> Issue 
 * </code> where new tasks need to be assigned and tracked separately but it 
 * is desirable to link these new tasks to the data in the root <code> Issue. 
 * </code> The difference between a subtask and a branched <code> Issue 
 * </code> is that a branched <code> Issue </code> is independent of the root 
 * <code> Issue. </code> </p> 
 * <h4> Blocking Issues </h4> 
 * 
 * <p> Blocking <code> Issues </code> indicate an <code> Issue </code> is 
 * blocked in the resolution of another <code> Issue </code> . </p> 
 * <h4> Log Entries </h4> 
 * 
 * <p> <code> Issues </code> have logs to provide a record of actions and 
 * comments. </p> 
 * <h4> Queues </h4> 
 * 
 * <p> A <code> Queue </code> is an <code> OsidGovernator </code> that governs 
 * the constraints and processing of a set of <code> Issues. </code> All 
 * Issues belong to one <code> Queue. </code> </p> 
 * <h4> Topics </h4> 
 * 
 * <p> The Ontology OSID can be orchestrated with the Tracking OSID to assign 
 * a topic ( <code> Subject </code> ) to an <code> Issue. </code> The 
 * orchestration requires relating a <code> Queue </code> to an <code> 
 * Ontology </code> and can be explicitly managed using the <code> 
 * OntologyAssignmentSession. </code> An <code> Ontology </code> serves to 
 * restrict the set of topics an <code> Issue </code> can be assigned. </p> 
 * 
 * <p> An <code> Issue </code> is defined as having a single topic that is 
 * directly accessible from an <code> Issue </code> that may be assigned 
 * directly in the Tracking OSID. However, a view of the hierarchy of 
 * assignable topics can be created using the Ontology OSID where the <code> 
 * Ontology </code> <code> Id </code> is orchestrated with the <code> Queue 
 * </code> <code> Id </code> . For convenience, a simple non-hierarchical list 
 * of topics can be accessed directly in the Tracking OSID. </p> 
 * 
 * <p> To summarize, assignment of pre-determined flat lists of topics can be 
 * performed directly in the Tracking OSID while managing the set of 
 * assignable topics or viewing the topics in a hierarchy is performed using 
 * the Ontology OSID. </p> 
 * <h4> Issue States </h4> 
 * 
 * <p> Issues define a set of basic states to indicate if they are new, 
 * reopened, closed, or resolved. To create other states requires the Process 
 * OSID where a <code> Queue </code> <code> Id </code> is orchestrated with a 
 * <code> Process </code> Id. To view the flow of an Issue through its steps 
 * to resolution, the Workflow OSID can be used for a more sophisticated view 
 * and tighter management controls through a custom state model. </p> 
 * <h4> Assigning Resources </h4> 
 * 
 * <p> Issues can be assigned a Resource which generally represents the person 
 * assigned to the case. Simple Resource management is provided by the 
 * IssueResourcingSession. More sophisticated Resource management and 
 * automated resource matching and assignment may be orchestrated using the 
 * Resourcing OSID. </p> 
 * 
 * <p> When using the Resourcing OSID for automated assignment it may be 
 * useful to manage competencies based on experience with the topic of an 
 * <code> Issue </code> to determine the best match with a <code> Resource. 
 * </code> In this scenario, orchestrationof the Resourcing OSID with the 
 * Learning OSID should be considered which involves linking a <code> Subject 
 * </code> in the Ontology OSID with an <code> Objective </code> in the 
 * Learning OSID. </p> 
 * 
 * <p> A tracking service has many aspects that can be independently 
 * integrated and consequently the Tracking OSID is at the intersection of 
 * several other OSIDs. </p> 
 * <h4> Front Office Cataloging </h4> 
 * 
 * <p> <code> Queues </code> and <code> Issues </code> may be organized into 
 * federatable <code> OsidCatalogs. </code> </p>
 * 
 * <br/><hr/><br/>
 * 
 * <p>Copyright &copy; 2011 Ingenescus. All Rights Reserved. </p>
 * 
 * <p>This Work is being provided by the copyright holder(s) subject to the 
 * following license. By obtaining, using and/or copying this Work, you agree 
 * that you have read, understand, and will comply with the following terms 
 * and conditions. </p> 
 * 
 * <p> Permission to use, copy and distribute unmodified versions of this 
 * Work, for any purpose, without fee or royalty is hereby granted, provided 
 * that you include the above copyright notices and the terms of this license 
 * on ALL copies of the Work or portions thereof. </p> 
 * 
 * <p> You may modify or create Derivatives of this Work only for your 
 * internal purposes. You shall not distribute or transfer any such Derivative 
 * of this Work to any location or to any third party. For the purposes of 
 * this license, "Derivative" shall mean any derivative of the Work as defined 
 * in the United States Copyright Act of 1976, such as a translation or 
 * modification. </p> 
 * 
 * <p> This Work and the information contained herein is provided on an "AS 
 * IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT 
 * NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR 
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT 
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN 
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN 
 * CONNECTION WITH THE WORK OR THE USE OR OTHER DEALINGS IN THE WORK. </p> 
 * 
 * <p> The export of software employing encryption technology may require a 
 * specific license from the United States Government. It is the 
 * responsibility of any person or organization contemplating export to obtain 
 * such a license before exporting this Work. </p>
 */

package org.osid.tracking;
