//
// org.osid.tracking.rules.QueueConstrainerEnablerQuerySession
//
//     The OSID Java specification for org.osid.tracking.rules.QueueConstrainerEnablerQuerySession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.tracking.rules;


/**
 *  <p>This session provides methods for searching among <code> 
 *  QueueConstrainerEnabler </code> objects. The search query is constructed 
 *  using the <code> QueueConstrainerEnablerQuery. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated front office view: searches include queue constrainer 
 *      enablers in front office of which this front office is an ancestor in 
 *      the front office hierarchy </li> 
 *      <li> isolated front office view: searches are restricted to queue 
 *      constrainer enablers in this office </li> 
 *  </ul>
 *  
 *  
 *  <p> Queue constrainer enablers may have a query record indicated by their 
 *  respective record types. The query record is accessed via the <code> 
 *  QueueConstrainerEnablerQuery. </code> </p>
 */

public interface QueueConstrainerEnablerQuerySession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> FrontOffice </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> FrontOffice Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFrontOfficeId();


    /**
     *  Gets the <code> FrontOffice </code> associated with this session. 
     *
     *  @return the office 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.FrontOffice getFrontOffice()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> QueueConstrainerEnabler </code> 
     *  lookups. A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known all methods in this 
     *  session will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may not offer lookup 
     *  operations to unauthorized users. 
     *
     *  @return <code> false </code> if search methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSearchQueueConstrainerEnablers();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include queue constrainer enablers in front offices which are children 
     *  of this queue in the front office hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedFrontOfficeView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this front office only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedFrontOfficeView();


    /**
     *  Gets a queue constrainer enabler query. 
     *
     *  @return the queue constrainer enabler query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.rules.QueueConstrainerEnablerQuery getQueueConstrainerEnablerQuery();


    /**
     *  Gets a list of <code> QueueConstrainerEnablers </code> matching the 
     *  given queue constrainer enabler query. 
     *
     *  @param  queueConstrainerEnablerQuery the sequeue constrainer enabler 
     *          query 
     *  @return the returned <code> QueueConstrainerEnablerList </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueConstrainerEnablerQuery </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          queueConstrainerEnablerQuery </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.rules.QueueConstrainerEnablerList getQueueConstrainerEnablersByQuery(org.osid.tracking.rules.QueueConstrainerEnablerQuery queueConstrainerEnablerQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
