//
// org.osid.tracking.rules.QueueConstrainerEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.tracking.rules.QueueConstrainerEnablerRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.tracking.rules;


/**
 *  <p>This session provides methods to apply <code> QueueConstrainerEnablers 
 *  </code> to <code> QueueConstrainers. </code> a <code> QueueConstrainer 
 *  </code> with multiple <code> QueueConstrainerEnablers </code> means any 
 *  positive rule evaluation across the enablers result in an effective <code> 
 *  QueueConstrainer. </code> </p>
 */

public interface QueueConstrainerEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> FrontOffice </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> FrontOffice Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFrontOfficeId();


    /**
     *  Gets the <code> FrontOffice </code> associated with this session. 
     *
     *  @return the office 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.FrontOffice getFrontOffice()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter queue constrainer enabler/queue 
     *  constrainer mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known mapping 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignQueueConstrainerEnablers();


    /**
     *  Adds an existing <code> QueueConstrainerEnabler </code> to a <code> 
     *  QueueConstrainer. </code> 
     *
     *  @param  queueConstrainerEnablerId the <code> Id </code> of the <code> 
     *          QueueConstrainerEnabler </code> 
     *  @param  queueConstrainerId the <code> Id </code> of the <code> 
     *          QueueConstrainer </code> 
     *  @throws org.osid.AlreadyExistsException <code> 
     *          queueConstrainerEnablerId </code> is already applied to <code> 
     *          queueConstrainerId </code> 
     *  @throws org.osid.NotFoundException <code> queueConstrainerEnablerId 
     *          </code> or <code> queueConstrainerId </code> not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueConstrainerEnablerId </code> or <code> queueConstrainerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignQueueConstrainerEnablerToQueueConstrainer(org.osid.id.Id queueConstrainerEnablerId, 
                                                                org.osid.id.Id queueConstrainerId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> QueueConstrainerEnabler </code> from a <code> 
     *  QueueConstrainer. </code> 
     *
     *  @param  queueConstrainerEnablerId the <code> Id </code> of the <code> 
     *          QueueConstrainerEnabler </code> 
     *  @param  queueConstrainerId the <code> Id </code> of the <code> 
     *          QueueConstrainer </code> 
     *  @throws org.osid.NotFoundException <code> queueConstrainerEnablerId 
     *          </code> or <code> queueConstrainerId </code> not found or 
     *          <code> queueConstrainerEnablerId </code> not applied to <code> 
     *          queueConstrainerId </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueConstrainerEnablerId </code> or <code> queueConstrainerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignQueueConstrainerEnablerFromQueueConstrainer(org.osid.id.Id queueConstrainerEnablerId, 
                                                                    org.osid.id.Id queueConstrainerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> QueueConstrainerEnablers. </code> 
     *  A return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known sequencing operations will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> QueueConstrainerEnabler </code> 
     *          ordering is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceQueueConstrainerEnablers();


    /**
     *  Reorders queue constrainer enablers for a queue constrainer by moving 
     *  the specified queue constrainer enabler in front of a reference queue 
     *  constrainer enabler. 
     *
     *  @param  queueConstrainerEnablerId the <code> Id </code> of a <code> 
     *          QueueConstrainerEnabler </code> 
     *  @param  queueConstrainerId the <code> Id </code> of a <code> 
     *          QueueConstrainer </code> 
     *  @param  referenceId the reference queue constrainer enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> queueConstrainerEnablerId, 
     *          queueConstrainerId, </code> or <code> referenceId </code> not 
     *          found or, <code> queueConstrainerEnablerId </code> or <code> 
     *          referenceId </code> not related to <code> queueConstrainerId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueConstrainerEnablerId, queueConstrainerId, </code> or 
     *          <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveQueueConstrainerEnablerAhead(org.osid.id.Id queueConstrainerEnablerId, 
                                                 org.osid.id.Id queueConstrainerId, 
                                                 org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders queue constrainer enablers for a queue constrainer by moving 
     *  the specified queue constrainer enabler behind a reference queue 
     *  constrainer enabler. 
     *
     *  @param  queueConstrainerEnablerId the <code> Id </code> of a <code> 
     *          QueueConstrainerEnabler </code> 
     *  @param  queueConstrainerId the <code> Id </code> of a <code> 
     *          QueueConstrainer </code> 
     *  @param  referenceId the reference queue constrainer enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> queueConstrainerEnablerId, 
     *          queueConstrainerId, </code> or <code> referenceId </code> not 
     *          found or, <code> queueConstrainerEnablerId </code> or <code> 
     *          referenceId </code> not related to <code> queueConstrainerId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueConstrainerEnablerId, queueConstrainerId, </code> or 
     *          <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveQueueConstrainerEnablerBehind(org.osid.id.Id queueConstrainerEnablerId, 
                                                  org.osid.id.Id queueConstrainerId, 
                                                  org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of queue constrainer enablers for a queue constrainer. 
     *
     *  @param  queueConstrainerEnablerIds the <code> Ids </code> for a set of 
     *          <code> QueueConstrainerEnablers </code> 
     *  @param  queueConstrainerId the <code> Id </code> of a <code> 
     *          QueueConstrainer </code> 
     *  @throws org.osid.NotFoundException <code> queueConstrainerId </code> 
     *          not found or, an <code> queueConstrainerEnablerId </code> not 
     *          related to <code> queueConstrainerId </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueConstrainerEnablerIds </code> or <code> 
     *          queueConstrainerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderQueueConstrainerEnablers(org.osid.id.Id[] queueConstrainerEnablerIds, 
                                              org.osid.id.Id queueConstrainerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
