//
// org.osid.tracking.rules.QueueProcessorEnablerLookupSession
//
//     The OSID Java specification for org.osid.tracking.rules.QueueProcessorEnablerLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.tracking.rules;


/**
 *  <p>This session provides methods for retrieving <code> 
 *  QueueProcessorEnablers. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated front office view: All queue processor enabler methods 
 *      in this session operate, retrieve and pertain to queue processor 
 *      enablers defined explicitly in the current front office. Using an 
 *      isolated view is useful for managing <code> QueueProcessorEnablers 
 *      </code> with the <code> QueueProcessorEnablerAdminSession. </code> 
 *      </li> 
 *      <li> federated front office view: All queue processor enabler methods 
 *      in this session operate, retrieve and pertain to all queue processor 
 *      enablers defined in this front office and any other queue processor 
 *      enablers implicitly available in this front office through front 
 *      office inheritence. </li> 
 *      <li> actuve queue processor enabler view: All queue processor enabler 
 *      lookup methods return active queue processor enablers. </li> 
 *      <li> any stayus queue processor enabler view: Queue processor enablers 
 *      of any active or inactive status are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedFrontOfficeView() </code> and <code> 
 *  useIsolatedFrontOfficeView() </code> behave as a radio group and one 
 *  should be selected before invoking the methods in this session. </p>
 */

public interface QueueProcessorEnablerLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> FrontOffice </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> FrontOffice Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFrontOfficeId();


    /**
     *  Gets the <code> FrontOffice </code> associated with this session. 
     *
     *  @return the office 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.FrontOffice getFrontOffice()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> QueueProcessorEnablers </code> 
     *  lookups. A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known all methods in this 
     *  session will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer lookup 
     *  operations to unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupQueueProcessorEnablers();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeQueueProcessorEnablerView();


    /**
     *  A complete view of the <code> QueueProcessorEnabler </code> returns is 
     *  desired. Methods will return what is requested or result in an error. 
     *  This view is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryQueueProcessorEnablerView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include queue processor enablers in front offices which are children 
     *  of this front office in the front office hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedFrontOfficeView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this front office only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedFrontOfficeView();


    /**
     *  Only active queue processor enablers are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveQueueProcessorEnablerView();


    /**
     *  All active and inactive queue processor enablers are returned by 
     *  methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusQueueProcessorEnablerView();


    /**
     *  Gets the <code> QueueProcessorEnabler </code> specified by its <code> 
     *  Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  QueueProcessorEnabler </code> may have a different <code> Id </code> 
     *  than requested, such as the case where a duplicate <code> Id </code> 
     *  was assigned to a <code> QueueProcessorEnabler </code> and retained 
     *  for compatibility. 
     *  
     *  In active mode, queue processor enablers are returned that are 
     *  currently active. In any status mode, active and inactive queue 
     *  processors enablers are returned. 
     *
     *  @param  queueProcessorEnablerId <code> Id </code> of the <code> 
     *          QueueProcessorEnabler </code> 
     *  @return the queue processor enabler 
     *  @throws org.osid.NotFoundException <code> queueProcessorEnablerId 
     *          </code> not found 
     *  @throws org.osid.NullArgumentException <code> queueProcessorEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.tracking.rules.QueueProcessorEnabler getQueueProcessorEnabler(org.osid.id.Id queueProcessorEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> QueueProcessorEnablerList </code> corresponding to the 
     *  given <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  queue processor enablers specified in the <code> Id </code> list, in 
     *  the order of the list, including duplicates, or an error results if a 
     *  <code> Id </code> in the supplied list is not found or inaccessible. 
     *  Otherwise, inaccessible <code> QueueProcessorEnablers </code> may be 
     *  omitted from the list and may present the elements in any order 
     *  including returning a unique set. 
     *  
     *  In active mode, queue processor enablers are returned that are 
     *  currently active. In any status mode, active and inactive queue 
     *  processors enablers are returned. 
     *
     *  @param  queueProcessorEnablerIds the list of <code> Ids </code> to 
     *          retrieve 
     *  @return the returned <code> QueueProcessorEnabler </code> list 
     *  @throws org.osid.NotFoundException a <code> Id </code> was not found 
     *  @throws org.osid.NullArgumentException <code> queueProcessorEnablerIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.rules.QueueProcessorEnablerList getQueueProcessorEnablersByIds(org.osid.id.IdList queueProcessorEnablerIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> QueueProcessorEnablerList </code> corresponding to the 
     *  given queue processor enabler genus <code> Type </code> which does not 
     *  include queue processor enablers of genus types derived from the 
     *  specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  queue processor enablers or an error results. Otherwise, the returned 
     *  list may contain only those queue processor enablers that are 
     *  accessible through this session. 
     *  
     *  In active mode, queue processor enablers are returned that are 
     *  currently active. In any status mode, active and inactive queue 
     *  processors enablers are returned. 
     *
     *  @param  queueProcessorEnablerGenusType a queue processor enabler genus 
     *          type 
     *  @return the returned <code> QueueProcessorEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueProcessorEnablerGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.rules.QueueProcessorEnablerList getQueueProcessorEnablersByGenusType(org.osid.type.Type queueProcessorEnablerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> QueueProcessorEnablerList </code> corresponding to the 
     *  given queue processor enabler genus <code> Type </code> and include 
     *  any additional queue processor enablers with genus types derived from 
     *  the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  queue processor enablers or an error results. Otherwise, the returned 
     *  list may contain only those queue processor enablers that are 
     *  accessible through this session. 
     *  
     *  In active mode, queue processor enablers are returned that are 
     *  currently active. In any status mode, active and inactive queue 
     *  processors enablers are returned. 
     *
     *  @param  queueProcessorEnablerGenusType a queue processor enabler genus 
     *          type 
     *  @return the returned <code> QueueProcessorEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueProcessorEnablerGenusType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.rules.QueueProcessorEnablerList getQueueProcessorEnablersByParentGenusType(org.osid.type.Type queueProcessorEnablerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> QueueProcessorEnablerList </code> containing the given 
     *  queue processor enabler record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  queue processor enablers or an error results. Otherwise, the returned 
     *  list may contain only those queue processor enablers that are 
     *  accessible through this session. 
     *  
     *  In active mode, queue processor enablers are returned that are 
     *  currently active. In any status mode, active and inactive queue 
     *  processors enablers are returned. 
     *
     *  @param  queueProcessorEnablerRecordType a queue processor enabler 
     *          record type 
     *  @return the returned <code> QueueProcessorEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueProcessorEnablerRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.rules.QueueProcessorEnablerList getQueueProcessorEnablersByRecordType(org.osid.type.Type queueProcessorEnablerRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> QueueProcessorEnablerList </code> that are effective for 
     *  the entire given date range inclusive but not confined to the date 
     *  range for any agent. 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  queue processor enablers or an error results. Otherwise, the returned 
     *  list may contain only those queue processor enablers that are 
     *  accessible through this session. 
     *  
     *  In active mode, queue processor enablers are returned that are 
     *  currently active. In any status mode, active and inactive queue 
     *  processors enablers are returned. 
     *
     *  @param  from a start date 
     *  @param  to an end date 
     *  @return the returned <code> QueueProcessorEnabler </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater tha <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.rules.QueueProcessorEnablerList getQueueProcessorEnablersOnDate(org.osid.calendaring.DateTime from, 
                                                                                             org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> QueueProcessorEnablerList </code> that are effective for 
     *  the entire given date range inclusive but not confined to the date 
     *  range and evaluated against the given agent. 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  queue processor enablers or an error results. Otherwise, the returned 
     *  list may contain only those queue processor enablers that are 
     *  accessible through this session. 
     *  
     *  In active mode, queue processor enablers are returned that are 
     *  currently active. In any status mode, active and inactive queue 
     *  processors enablers are returned. 
     *
     *  @param  agentId an agent <code> Id </code> 
     *  @param  from a start date 
     *  @param  to an end date 
     *  @return the returned <code> QueueProcessorEnabler </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater tha <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> agentId, from, </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.rules.QueueProcessorEnablerList getQueueProcessorEnablersOnDateWithAgent(org.osid.id.Id agentId, 
                                                                                                      org.osid.calendaring.DateTime from, 
                                                                                                      org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> QueueProcessorEnablers. </code> 
     *  
     *  In plenary mode, the returned list contains all known queue processor 
     *  enablers or an error results. Otherwise, the returned list may contain 
     *  only those queue processor enablers that are accessible through this 
     *  session. 
     *  
     *  In active mode, queue processor enablers are returned that are 
     *  currently active. In any status mode, active and inactive queue 
     *  processors enablers are returned. 
     *
     *  @return the returned <code> QueueProcessorEnabler </code> list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.rules.QueueProcessorEnablerList getQueueProcessorEnablers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
