//
// org.osid.tracking.rules.QueueProcessorEnablerSmartFrontOfficeSession
//
//     The OSID Java specification for org.osid.tracking.rules.QueueProcessorEnablerSmartFrontOfficeSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.tracking.rules;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  front office. a <code> QueueProcessorEnablerQuery </code> can be retrieved 
 *  from this session and mapped to this <code> FrontOffice </code> to create 
 *  a virtual collection of queue processor enablers. The queue processor 
 *  enablers may be sequenced using the <code> 
 *  QueueProcessorEnablerSearchOrder </code> from this session. </p> 
 *  
 *  <p> This <code> FrontOffice </code> has a default query that matches any 
 *  queue processor enabler and a default search order that specifies no 
 *  sequencing. The queries may be examined using a <code> 
 *  QueueProcessorEnablerQueryInspector. </code> The query may be modified by 
 *  converting the inspector back to a <code> QueueProcessorEnablerQuery. 
 *  </code> </p>
 */

public interface QueueProcessorEnablerSmartFrontOfficeSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> FrontOffice </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> FrontOffice Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFrontOfficeId();


    /**
     *  Gets the <code> FrontOffice </code> associated with this session. 
     *
     *  @return the office 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.FrontOffice getFrontOffice()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart front office. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known methods in this session will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart front office management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartFrontOffices();


    /**
     *  Gets a queue processor enabler query. 
     *
     *  @return the queue processor enabler query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.rules.QueueProcessorEnablerQuery getQueueProcessorEnablerQuery();


    /**
     *  Gets a queue processor enabler search order. 
     *
     *  @return the queue processor enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.rules.QueueProcessorEnablerSearchOrder getQueueProcessorEnablerSearchOrder();


    /**
     *  Applies a queue processor enabler query to this front office. 
     *
     *  @param  queueProcessorEnablerQuery the queue processor enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueProcessorEnablerQuery </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          queueProcessorEnablerQuery </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyQueueProcessorEnablerQuery(org.osid.tracking.rules.QueueProcessorEnablerQuery queueProcessorEnablerQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a queue processor enabler query inspector for this front office. 
     *
     *  @return the queue processor enabler query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.rules.QueueProcessorEnablerQueryInspector inspectQueueProcessorEnablerQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a queue processor enabler search order to this front office. 
     *
     *  @param  queueProcessorEnablerSearchOrder the queue processor enabler 
     *          search order 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueProcessorEnablerSearchOrder </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          queueProcessorEnablerSearchOrder </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyQueueProcessorEnablerSequencing(org.osid.tracking.rules.QueueProcessorEnablerSearchOrder queueProcessorEnablerSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a queue processor enabler query from an inspector. 
     *
     *  @param  queueProcessorEnablerQueryInspector a queue processor enabler 
     *          query inspector 
     *  @return the queue processor enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueProcessorEnablerQueryInspector </code> is <code> null 
     *          </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          queueProcessorEnablerQueryInspector </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.tracking.rules.QueueProcessorEnablerQuery getQueueProcessorEnablerQueryFromInspector(org.osid.tracking.rules.QueueProcessorEnablerQueryInspector queueProcessorEnablerQueryInspector);
}
