//
// org.osid.tracking.rules.TrackingRulesProfile
//
//     The OSID Java specification for org.osid.tracking.rules.TrackingRulesProfile.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.tracking.rules;


/**
 *  <p>The tracking rules profile describes the interoperability among 
 *  tracking rules services. </p>
 */

public interface TrackingRulesProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any broker federation is exposed. Federation is exposed when 
     *  a specific broker may be identified, selected and used to create a 
     *  lookup or admin session. Federation is not exposed when a set of 
     *  brokers appears as a single broker. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if looking up queue constrainer is supported. 
     *
     *  @return <code> true </code> if queue constrainer lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerLookup();


    /**
     *  Tests if querying queue constrainer is supported. 
     *
     *  @return <code> true </code> if queue constrainer query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerQuery();


    /**
     *  Tests if searching queue constrainer is supported. 
     *
     *  @return <code> true </code> if queue constrainer search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerSearch();


    /**
     *  Tests if a queue constrainer administrative service is supported. 
     *
     *  @return <code> true </code> if queue constrainer administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerAdmin();


    /**
     *  Tests if a queue constrainer notification service is supported. 
     *
     *  @return <code> true </code> if queue constrainer notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerNotification();


    /**
     *  Tests if a queue constrainer front office lookup service is supported. 
     *
     *  @return <code> true </code> if a queue constrainer front office lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerFrontOffice();


    /**
     *  Tests if a queue constrainer front office service is supported. 
     *
     *  @return <code> true </code> if queue constrainer front office 
     *          assignment service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerFrontOfficeAssignment();


    /**
     *  Tests if a queue constrainer front office lookup service is supported. 
     *
     *  @return <code> true </code> if a queue constrainer front office 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerSmartFrontOffice();


    /**
     *  Tests if a queue constrainer rule lookup service is supported. 
     *
     *  @return <code> true </code> if a queue constrainer rule lookup service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerRuleLookup();


    /**
     *  Tests if a queue constrainer rule application service is supported. 
     *
     *  @return <code> true </code> if a queue constrainer rule application 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerRuleApplication();


    /**
     *  Tests if looking up queue constrainer enablers is supported. 
     *
     *  @return <code> true </code> if queue constrainer enabler lookup is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerEnablerLookup();


    /**
     *  Tests if querying queue constrainer enablers is supported. 
     *
     *  @return <code> true </code> if queue constrainer enabler query is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerEnablerQuery();


    /**
     *  Tests if searching queue constrainer enablers is supported. 
     *
     *  @return <code> true </code> if queue constrainer enabler search is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerEnablerSearch();


    /**
     *  Tests if a queue constrainer enabler administrative service is 
     *  supported. 
     *
     *  @return <code> true </code> if queue constrainer enabler 
     *          administration is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerEnablerAdmin();


    /**
     *  Tests if a queue constrainer enabler notification service is 
     *  supported. 
     *
     *  @return <code> true </code> if queue constrainer enabler notification 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerEnablerNotification();


    /**
     *  Tests if a queue constrainer enabler front office lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if a queue constrainer enabler front 
     *          office lookup service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerEnablerFrontOffice();


    /**
     *  Tests if a queue constrainer enabler front office service is 
     *  supported. 
     *
     *  @return <code> true </code> if queue constrainer enabler front office 
     *          assignment service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerEnablerFrontOfficeAssignment();


    /**
     *  Tests if a queue constrainer enabler front office lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if a queue constrainer enabler front 
     *          office service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerEnablerSmartFrontOffice();


    /**
     *  Tests if a queue constrainer enabler rule lookup service is supported. 
     *
     *  @return <code> true </code> if a queue constrainer enabler rule lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerEnablerRuleLookup();


    /**
     *  Tests if a queue constrainer enabler rule application service is 
     *  supported. 
     *
     *  @return <code> true </code> if queue constrainer enabler rule 
     *          application service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerEnablerRuleApplication();


    /**
     *  Tests if looking up queue processor is supported. 
     *
     *  @return <code> true </code> if queue processor lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorLookup();


    /**
     *  Tests if querying queue processor is supported. 
     *
     *  @return <code> true </code> if queue processor query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorQuery();


    /**
     *  Tests if searching queue processor is supported. 
     *
     *  @return <code> true </code> if queue processor search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorSearch();


    /**
     *  Tests if a queue processor administrative service is supported. 
     *
     *  @return <code> true </code> if queue processor administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorAdmin();


    /**
     *  Tests if a queue processor notification service is supported. 
     *
     *  @return <code> true </code> if queue processor notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorNotification();


    /**
     *  Tests if a queue processor front office lookup service is supported. 
     *
     *  @return <code> true </code> if a queue processor front office lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorFrontOffice();


    /**
     *  Tests if a queue processor front office service is supported. 
     *
     *  @return <code> true </code> if queue processor front office assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorFrontOfficeAssignment();


    /**
     *  Tests if a queue processor front office lookup service is supported. 
     *
     *  @return <code> true </code> if a queue processor front office service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorSmartFrontOffice();


    /**
     *  Tests if a queue processor rule lookup service is supported. 
     *
     *  @return <code> true </code> if a queue processor rule lookup service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorRuleLookup();


    /**
     *  Tests if a queue processor rule application service is supported. 
     *
     *  @return <code> true </code> if queue processor rule application 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorRuleApplication();


    /**
     *  Tests if looking up queue processor enablers is supported. 
     *
     *  @return <code> true </code> if queue processor enabler lookup is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorEnablerLookup();


    /**
     *  Tests if querying queue processor enablers is supported. 
     *
     *  @return <code> true </code> if queue processor enabler query is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorEnablerQuery();


    /**
     *  Tests if searching queue processor enablers is supported. 
     *
     *  @return <code> true </code> if queue processor enabler search is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorEnablerSearch();


    /**
     *  Tests if a queue processor enabler administrative service is 
     *  supported. 
     *
     *  @return <code> true </code> if queue processor enabler administration 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorEnablerAdmin();


    /**
     *  Tests if a queue processor enabler notification service is supported. 
     *
     *  @return <code> true </code> if queue processor enabler notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorEnablerNotification();


    /**
     *  Tests if a queue processor enabler front office lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if a queue processor enabler front office 
     *          lookup service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorEnablerFrontOffice();


    /**
     *  Tests if a queue processor enabler front office service is supported. 
     *
     *  @return <code> true </code> if queue processor enabler front office 
     *          assignment service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorEnablerFrontOfficeAssignment();


    /**
     *  Tests if a queue processor enabler front office lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if a queue processor enabler front office 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorEnablerSmartFrontOffice();


    /**
     *  Tests if a queue processor enabler rule lookup service is supported. 
     *
     *  @return <code> true </code> if an processor enabler rule lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorEnablerRuleLookup();


    /**
     *  Tests if a queue processor enabler rule application service is 
     *  supported. 
     *
     *  @return <code> true </code> if queue processor enabler rule 
     *          application service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorEnablerRuleApplication();


    /**
     *  Gets the supported <code> QueueConstrainer </code> record types. 
     *
     *  @return a list containing the supported <code> QueueConstrainer 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getQueueConstrainerRecordTypes();


    /**
     *  Tests if the given <code> QueueConstrainer </code> record type is 
     *  supported. 
     *
     *  @param  queueConstrainerRecordType a <code> Type </code> indicating a 
     *          <code> QueueConstrainer </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueConstrainerRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerRecordType(org.osid.type.Type queueConstrainerRecordType);


    /**
     *  Gets the supported <code> QueueConstrainer </code> search record 
     *  types. 
     *
     *  @return a list containing the supported <code> QueueConstrainer 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getQueueConstrainerSearchRecordTypes();


    /**
     *  Tests if the given <code> QueueConstrainer </code> search record type 
     *  is supported. 
     *
     *  @param  queueConstrainerSearchRecordType a <code> Type </code> 
     *          indicating a <code> QueueConstrainer </code> search record 
     *          type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueConstrainerSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerSearchRecordType(org.osid.type.Type queueConstrainerSearchRecordType);


    /**
     *  Gets the supported <code> QueueConstrainerEnabler </code> record 
     *  types. 
     *
     *  @return a list containing the supported <code> QueueConstrainerEnabler 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getQueueConstrainerEnablerRecordTypes();


    /**
     *  Tests if the given <code> QueueConstrainerEnabler </code> record type 
     *  is supported. 
     *
     *  @param  queueConstrainerEnablerRecordType a <code> Type </code> 
     *          indicating a <code> QueueConstrainerEnabler </code> record 
     *          type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueConstrainerEnablerRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerEnablerRecordType(org.osid.type.Type queueConstrainerEnablerRecordType);


    /**
     *  Gets the supported <code> QueueConstrainerEnabler </code> search 
     *  record types. 
     *
     *  @return a list containing the supported <code> QueueConstrainerEnabler 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getQueueConstrainerEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> QueueConstrainerEnabler </code> search 
     *  record type is supported. 
     *
     *  @param  queueConstrainerEnablerSearchRecordType a <code> Type </code> 
     *          indicating a <code> QueueConstrainerEnabler </code> search 
     *          record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueConstrainerEnablerSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueConstrainerEnablerSearchRecordType(org.osid.type.Type queueConstrainerEnablerSearchRecordType);


    /**
     *  Gets the supported <code> QueueProcessor </code> record types. 
     *
     *  @return a list containing the supported <code> QueueProcessor </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getQueueProcessorRecordTypes();


    /**
     *  Tests if the given <code> QueueProcessor </code> record type is 
     *  supported. 
     *
     *  @param  queueProcessorRecordType a <code> Type </code> indicating a 
     *          <code> QueueProcessor </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> queueProcessorRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorRecordType(org.osid.type.Type queueProcessorRecordType);


    /**
     *  Gets the supported <code> QueueProcessor </code> search record types. 
     *
     *  @return a list containing the supported <code> QueueProcessor </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getQueueProcessorSearchRecordTypes();


    /**
     *  Tests if the given <code> QueueProcessor </code> search record type is 
     *  supported. 
     *
     *  @param  queueProcessorSearchRecordType a <code> Type </code> 
     *          indicating a <code> QueueProcessor </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueProcessorSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorSearchRecordType(org.osid.type.Type queueProcessorSearchRecordType);


    /**
     *  Gets the supported <code> QueueProcessorEnabler </code> record types. 
     *
     *  @return a list containing the supported <code> QueueProcessorEnabler 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getQueueProcessorEnablerRecordTypes();


    /**
     *  Tests if the given <code> QueueProcessorEnabler </code> record type is 
     *  supported. 
     *
     *  @param  queueProcessorEnablerRecordType a <code> Type </code> 
     *          indicating a <code> QueueProcessorEnabler </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueProcessorEnablerRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorEnablerRecordType(org.osid.type.Type queueProcessorEnablerRecordType);


    /**
     *  Gets the supported <code> QueueProcessorEnabler </code> search record 
     *  types. 
     *
     *  @return a list containing the supported <code> QueueProcessorEnabler 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getQueueProcessorEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> QueueProcessorEnabler </code> search record 
     *  type is supported. 
     *
     *  @param  queueProcessorEnablerSearchRecordType a <code> Type </code> 
     *          indicating a <code> QueueProcessorEnabler </code> search 
     *          record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          queueProcessorEnablerSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsQueueProcessorEnablerSearchRecordType(org.osid.type.Type queueProcessorEnablerSearchRecordType);
}
