//
// org.osid.transaction.batch.CreateResponse
//
//     The OSID Java specification for org.osid.transaction.batch.CreateResponse.
//
// Copyright (C) 2002, 2006 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.transaction.batch;


/**
 *  <p><code> CreateResponses </code> are returned from bulk create 
 *  operations. Batch-oriented methods are executed on a best effort basis 
 *  unless wrapped in <code> Transaction </code> that supports an atomic 
 *  <code> commit(). </code> Batch methods may be invoked outside of a <code> 
 *  Transaction </code> where some of the items supplied may fail. </p> 
 *  
 *  <p> Bulk create operations accept a list of <code> OsidForms </code> and 
 *  to be created. There is one <code> CreateResponse </code> returned for 
 *  every <code> OsidForm </code> supplied but not necessarily in the same 
 *  order. The created <code> Id </code> in the response is the newly created 
 *  <code> Id </code> is the create item was successful. </p>
 */

public interface CreateResponse
    extends org.osid.OsidCapsule {


    /**
     *  Gets the form <code> Id </code> corresponding to this response. 
     *
     *  @return the form <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getFormId();


    /**
     *  Tests if this item within the create operation was successful. 
     *
     *  @return <code> true </code> if the create operation was successful, 
     *          <code> false </code> if it was not successful 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isSuccessful();


    /**
     *  Gets the <code> Id </code> of the newly created object. 
     *
     *  @return the reference object <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> isSuccessful() </code> 
     *          is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getCreatedId();


    /**
     *  Gets the error message for an unsuccessful item within the create 
     *  operation. 
     *
     *  @return the message 
     *  @throws org.osid.IllegalStateException <code> isSuccessful() </code> 
     *          is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getErrorMessage();
}
