//
// org.osid.transaction.batch.DeleteResponse
//
//     The OSID Java specification for org.osid.transaction.batch.DeleteResponse.
//
// Copyright (C) 2002, 2006 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.transaction.batch;


/**
 *  <p><code> DeleteResponses </code> are returned from bulk delete 
 *  operations. Batch-oriented methods are executed on a best effort basis 
 *  unless wrapped in <code> Transaction </code> that supports an atomic 
 *  <code> commit(). </code> Batch methods may be invoked outside of a <code> 
 *  Transaction </code> where some of the items supplied may fail. </p> 
 *  
 *  <p> While bulk delete operations may accept a list of <code> Ids </code> 
 *  to be deleted. In this case, there is one <code> DeleteResponse </code> 
 *  returned for every <code> Id </code> supplied but not necessarily in the 
 *  same order. The reference <code> Id </code> in the response may be the 
 *  primary <code> Id </code> of a given <code> Id, </code> and may differ. 
 *  </p> 
 *  
 *  <p> Some bulk delete operations may operate on a set of criteria where a 
 *  list of <code> Ids </code> are not supplied. In this case, there is one 
 *  <code> DeleteResponse </code> generated for every <code> Id </code> that 
 *  matches the criteria. </p>
 */

public interface DeleteResponse
    extends org.osid.OsidCapsule {


    /**
     *  Gets the reference <code> Id </code> of the object on which this item 
     *  within the delete operation operated. 
     *
     *  @return the reference object <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getDeletedId();


    /**
     *  Tests if this item within the delete operation was successful. 
     *
     *  @return <code> true </code> if the delete operation was successful, 
     *          <code> false </code> if it was not successful 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isSuccessful();


    /**
     *  Gets the error message for an unsuccessful item within the delete 
     *  operation. 
     *
     *  @return the message 
     *  @throws org.osid.IllegalStateException <code> isSuccessful() </code> 
     *          is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.locale.DisplayText getErrorMessage();
}
