//
// org.osid.transport.OutboundMessageSession
//
//     The OSID Java specification for org.osid.transport.OutboundMessageSession.
//
// Copyright (C) 2006 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.transport;


/**
 *  <p>This session provides access to a request/response protocol provider. 
 *  The data and format of the requests and responses are identified through 
 *  their respective <code> Types. </code> While this session is used for 
 *  structured conversations, it doesn't preclude the use of byte streams as 
 *  part of a <code> Request </code> or <code> Response. </code> </p> 
 *  
 *  <p> <code> </code> A <code> Request </code> is retrieved via <code> 
 *  getRequest() </code> and data is supplied to its corresponding record. The 
 *  <code> Request </code> is then sent using <code> sendRequest() </code> 
 *  along with an interface to be called when the <code> Response </code> 
 *  arrives. The FSM of the protocol is indicated through the available <code> 
 *  Request </code> <code> Types </code> that may change from one transaction 
 *  to another. </p> 
 *  
 *  <p> While multiple requests may be submitted before receiving a response, 
 *  the requests may or may not be queued. </p>
 */

public interface OutboundMessageSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Endpoint </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Endpoint </code> <code> Id </code> associated with 
     *          this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getEndpointId();


    /**
     *  Gets the <code> Endpoint </code> associated with this session. 
     *
     *  @return the <code> Endpoint </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transport.Endpoint getEndpoint()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> Request </code> for use with <code> sendRequest(). 
     *  </code> This is not a receive call. 
     *
     *  @return a request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transport.Request getRequest();


    /**
     *  Sends a request to the remote transport endpoint and waits for a 
     *  response. 
     *
     *  @param  request the request 
     *  @param  response callback for the response 
     *  @throws org.osid.NullArgumentException <code> request </code> or 
     *          <code> receiver </code> is null 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> request </code> is not 
     *          supported 
     *  @compliance mandatory This method must be implemented. 
     */

    public void makeRequest(org.osid.transport.Request request, 
                            org.osid.transport.Response response)
        throws org.osid.OperationFailedException;


    /**
     *  Sends data to the remote transport endpoint and sends the response to 
     *  the callback. 
     *
     *  @param  request the request 
     *  @param  callback callback for the response 
     *  @throws org.osid.NullArgumentException <code> request </code> or 
     *          <code> callback </code> is null 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> request </code> is not 
     *          supported 
     *  @compliance mandatory This method must be implemented. 
     */

    public void sendRequest(org.osid.transport.Request request, 
                            org.osid.transport.MessageReceiver callback)
        throws org.osid.OperationFailedException;
}
