//
// org.osid.transport.OutboundStreamSession
//
//     The OSID Java specification for org.osid.transport.OutboundStreamSession.
//
// Copyright (C) 2006 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.transport;


/**
 *  <p>The outbound stream session is used to send and receive arbitrary data 
 *  to and from a remote end point. The methods accept and return a data 
 *  stream. Some protocols may send or receive all data within a single stream 
 *  while others may use the streams as channels or frames of data. </p> 
 *  
 *  <p> A stream may be available for reading before all the data as arrived 
 *  and as such multiple streams may be processed simultaneously. </p>
 */

public interface OutboundStreamSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Endpoint </code> <code> Id </code> associated with 
     *  this session. 
     *
     *  @return the <code> Endpoint </code> <code> Id </code> associated with 
     *          this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getEndpointId();


    /**
     *  Gets the <code> Endpoint </code> associated with this session. 
     *
     *  @return the <code> Endpoint </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transport.Endpoint getEndpoint()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Sends data to the remote transport endpoint. 
     *
     *  @return the output stream in which to send data 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transport.DataOutputStream sendData()
        throws org.osid.OperationFailedException;


    /**
     *  Tests to see if an input stream is available for retrieval. 
     *
     *  @return <code> true </code> if a stream is available for reading, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean hasDataAvailable();


    /**
     *  Receives data from the remote transport endpoint. 
     *
     *  @return the input stream containing the received data 
     *  @throws org.osid.IllegalStateException <code> hasDataAvailable() 
     *          </code> is <code> false </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transport.DataInputStream receiveData()
        throws org.osid.OperationFailedException;
}
