//
// org.osid.transport.TransportManager
//
//     The OSID Java specification for org.osid.transport.TransportManager.
//
// Copyright (C) 2006 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.transport;


/**
 *  <p>This manager provides access to the sessions defined in this service. 
 *  The outbound sessions are used to connect to a remote endpoint and the 
 *  inbound sessions are used to receive incoming connections. </p> 
 *  
 *  <p> The two flavors of transport are stream and message oriented. Messages 
 *  offer more structured requests and responses although their structure may 
 *  include embedded streams. </p>
 */

public interface TransportManager
    extends org.osid.OsidManager,
            org.osid.transport.TransportProfile {


    /**
     *  Gets a service for outbound stream transport. 
     *
     *  @return an <code> OutboundStreamSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOutboundStream() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOutboundStream() </code> is <code> true. </code> 
     */

    public org.osid.transport.OutboundStreamSession getOutboundStreamSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a service for outbound stream transport using a specified <code> 
     *  Endpoint. </code> 
     *
     *  @param  endpointId a transport endpoint 
     *  @return an <code> OutboundStreamSession </code> 
     *  @throws org.osid.NotFoundException <code> endpointId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> endpointId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOutboundStream() </code> or <code> 
     *          supportsVisibleFederationI() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOutboundStream() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.transport.OutboundStreamSession getOutboundStreamSessionForEndpoint(org.osid.id.Id endpointId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a service for inbound stream transport. 
     *
     *  @param  streamReceiver a stream receiver 
     *  @return an <code> InboundStreamSession </code> 
     *  @throws org.osid.NullArgumentException <code> streamReceiver </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsInboundStream() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInboundStream() </code> is <code> true. </code> 
     */

    public org.osid.transport.InboundStreamSession getInboundStreamSession(org.osid.transport.StreamReceiver streamReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a service for inbound stream transport using a specified <code> 
     *  Endpoint. </code> 
     *
     *  @param  streamReceiver a stream receiver 
     *  @param  endpointId a transport endpoint 
     *  @return an <code> InboundStreamSession </code> 
     *  @throws org.osid.NotFoundException <code> endpointId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> streamReceiver </code> 
     *          or <code> endpointId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> supportsInboundStream() 
     *          </code> or <code> supportsVisibleFederationI() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInboundStream() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.transport.InboundStreamSession getInboundStreamSessionForEndpoint(org.osid.transport.StreamReceiver streamReceiver, 
                                                                                      org.osid.id.Id endpointId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a service for outbound message transport. 
     *
     *  @return an <code> OutboundMessageSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOutboundMessage() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOutboundMessage() </code> is <code> true. </code> 
     */

    public org.osid.transport.OutboundMessageSession getOutboundMessageSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a service for outbound message transport using a specified 
     *  Endpoint. 
     *
     *  @param  endpointId a transport endpoint 
     *  @return an <code> OutboundMessageSession </code> 
     *  @throws org.osid.NotFoundException <code> endpointId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> endpointId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOutboundMessage() or supportsVisibleFederationI() is 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOutboundMessage() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.transport.OutboundMessageSession getOutboundMessageSessionForEndpoint(org.osid.id.Id endpointId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a service for inbound message transport. 
     *
     *  @param  messageReceiver a message receiver 
     *  @return an <code> InboundMessageSession </code> 
     *  @throws org.osid.NullArgumentException <code> messageReceiver </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInboundMessage() is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInboundMessage() </code> is <code> true. </code> 
     */

    public org.osid.transport.InboundMessageSession getInboundMessageSession(org.osid.transport.MessageReceiver messageReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a service for inbound message transport using a specified 
     *  Endpoint. 
     *
     *  @param  messageReceiver a message receiver 
     *  @param  endpointId a transport endpoint 
     *  @return an <code> InboundMessageSession </code> 
     *  @throws org.osid.NotFoundException <code> endpointId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> messageReceiver </code> 
     *          or <code> endpointId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInboundMessage() or supportsVisibleFederationI() is 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInboundMessage() </code> and <code> 
     *              supportsVisibleFederation() </code> are true. 
     */

    public org.osid.transport.InboundMessageSession getInboundMessageSessionForEndpoint(org.osid.transport.MessageReceiver messageReceiver, 
                                                                                        org.osid.id.Id endpointId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the endpoint lookup service. 
     *
     *  @return an <code> EndpointLookupSesson </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsInbound() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInbound() </code> is <code> true. </code> 
     */

    public org.osid.transport.EndpointLookupSession getEndpointLookupSession()
        throws org.osid.OperationFailedException;
}
