//
// org.osid.transport.TransportProfile
//
//     The OSID Java specification for org.osid.transport.TransportProfile.
//
// Copyright (C) 2006 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.transport;


/**
 *  <p>The <code> TransportProfile </code> defines the interoperability of the 
 *  transport OSID. </p>
 */

public interface TransportProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any transport endpoint federation is exposed. Federation is 
     *  exposed when a specific endpoint may be used. Federation is not 
     *  exposed when a set of endpoints appears as a single endpoint. 
     *
     *  @return <code> true </code> if federation is visible <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if outbound stream transport is supported. 
     *
     *  @return <code> true </code> if outbound stream transport is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOutboundStream();


    /**
     *  Tests if inbound stream transport is supported. 
     *
     *  @return <code> true </code> if incoming stream transport is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInboundStream();


    /**
     *  Tests if outbound message transport is supported. 
     *
     *  @return <code> true </code> if outbound message transport is supported 
     *          <code> , </code> <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOutboundMessage();


    /**
     *  Tests if inbound message transport is supported. 
     *
     *  @return <code> true </code> if incoming message transport is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInboundMessage();


    /**
     *  Tests if endpoint lookup is supported. 
     *
     *  @return <code> true </code> if endpoint lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEndpointLookup();


    /**
     *  Gets a list of supported endpoint record types. 
     *
     *  @return a list of supported endpoint record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getEndpointRecordTypes();


    /**
     *  Tests if an endpoint record type is supported. 
     *
     *  @param  endpointRecordType an endpoint record type 
     *  @return <code> true </code> if the endpoint record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> endpointRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsEndpointRecordType(org.osid.type.Type endpointRecordType);


    /**
     *  Gets a list of supported request record types. 
     *
     *  @return a list of supported request record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRequestRecordTypes();


    /**
     *  Tests if a request record type is supported. 
     *
     *  @param  requestRecordType a request record type 
     *  @return <code> true </code> if the request record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> requestRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRequestRecordType(org.osid.type.Type requestRecordType);


    /**
     *  Gets a list of supported response record types. 
     *
     *  @return a list of supported response record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getResponseRecordTypes();


    /**
     *  Tests if a response record type is supported. 
     *
     *  @param  responseRecordType a response record type 
     *  @return <code> true </code> if the response record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> responseRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResponseRecordType(org.osid.type.Type responseRecordType);
}
