/**
 * <p>The Open Service Interface Definitions for the org.osid.type
 * service.</p>
 * 
 * <p>The Type OSID defines a set of interfaces for managing <code> Type 
 * </code> definitions. <code> Types </code> are used as an identifier 
 * primarily for identification of interface extensions throughout the OSIDs 
 * and occasionally used as an extensible enumeration. An agreement between an 
 * OSID Consumer and an OSID Provider means they support the same <code> Type. 
 * </code> </p> 
 * <h4> Types </h4> 
 * 
 * <p> A <code> Type </code> is similar to an Id but includes other data for 
 * display and organization. The identification portion of the Type is 
 * globally unique and contains: </p> 
 * 
 * <ul>
 *     <li> authority: the name of the entity or organization responsible for 
 *     the type. Using a domain name is a reasonable convention. </li> 
 *     <li> identifier: a string serving as an id. The identifier may be a 
 *     urn, guid, oid or some other means of identification. Since all of the 
 *     identification elements including the domain and authority create an 
 *     overall unique Type, the identifier may even be a sequence number 
 *     defined within a particular domain. </li> 
 *     <li> namespace: a string identifying the namespace of the identifier, 
 *     such as "urn" or "oid". </li> 
 * </ul>
 * 
 * <h4> Example </h4> 
 * 
 * <pre>
 *      
 *      
 *      Type type = lookupSession.getType("asset", "uri",         
 *                                        "http://harvestroad.com/osidTypes/image",
 *                                        "harvestroad.com");
 *      print type.getDisplayName();
 *      
 *              
 *      
 * </pre>
 * 
 * 
 * <p> The sessions in this OSID offer the capabilities of a <code> Type 
 * </code> registry to centrally manage definitions and localized display 
 * strings and descriptions. Applications may opt to construct their own 
 * <code> Types </code> directly and bypass this service. </p> 
 * <h4> Type Hierarchies </h4> 
 * 
 * <p> Types are part of an internal hierarchy. A <code> Type </code> in a 
 * hierarchy includes the <code> Types </code> of its children. For example, 
 * an <code> Asset </code> may have a "photograph" <code> Type </code> 
 * included as part of an "image" base <code> Type. </code> </p> 
 * 
 * <p> Unless an application will display a type, it can simply construct a 
 * type based on the identification components. OSID Providers may benefit by 
 * using this service to manage the type hierarchy, to provide a place to 
 * perform mappings across different type definitions, and to provide 
 * displayable metadata to its consumers. </p> 
 * <h4> Type Type Relations </h4> 
 * 
 * <p> <code> Types </code> may relate to other <code> Types </code> to 
 * describe constraints or compositions. The relationship is expressed as 
 * another Type. For example, a <code> Position </code> of type "researcher" 
 * may be appropriately associated with an <code> Organization </code> of type 
 * "laboratory" using a relation Type of "allowed." Or, a root <code> Event 
 * </code> type depends on a root <code> TimePeriod </code> type using a 
 * relationship type of "depends on." </p> 
 * <h4> Types for Constraints and Side Effects </h4> 
 * 
 * <p> An OSID Provider may link a <code> Type, </code> such as a genus, to a 
 * set of constraints that are made known to the application as <code> 
 * Metadata </code> through an <code> OsidForm. </code> Types of an <code> 
 * OsidObject </code> may also be used by an OSID Provider to constrain the 
 * possible relationship <code> Types </code> that may be possible to that 
 * <code> OsidObject. </code> In these uses of <code> Types, </code> there is 
 * a semantic accompanying the <code> Type </code> definition managed within 
 * an OSID Provider. The Type OSID manages the metadata of the <code> Type 
 * </code> itself. Logic implementing the meaning of the <code> Type </code> 
 * is managed completely within an OSID Provider. </p> 
 * 
 * <p> OSIDs emphasize relationships over data typing since type agreements 
 * are often an impediment to interoperability. Generally, the rule of thumb 
 * for record <code> Types </code> is to first explore other <code> 
 * OsidObjects, </code> even those in other OSIDs for a place for extra data. 
 * Often, what is hiding behind a list of data elements is a separate service 
 * that can be provided as a separate module and serves to keep the principal 
 * <code> OsidObject </code> lighter and more flexible. </p> 
 * 
 * <p> Genus <code> Types </code> primarily serve as a quick and dirty way to 
 * unclutter the record <code> Types </code> with "is kind of like" tags. 
 * <code> OsidCatalogs </code> can be used for a richer solution. For example, 
 * a genus <code> Type </code> may be used to identify all <code> Events 
 * </code> on a <code> Calendar </code> which are classes at a school and is 
 * accompanied by constraint logic such that the <code> Events </code> occur 
 * at a <code> Location </code> on campus. </p> 
 * 
 * <p> Another pathway to explore is to create a smart <code> Calendar </code> 
 * from an <code> EventQuery </code> that specifies constrraints on the <code> 
 * Event </code> sponsor, <code> Location, </code> or other data required for 
 * classes. Creates and updates for Events in that smart <code> Calendar 
 * </code> will be similarly constrained and surfaced to the OSID Consumer 
 * through the <code> Metadata </code> in the EventForms. While this path is 
 * certainly more difficult than simply nailing up some logic indexed by a 
 * genus Type, it can be considered if there is a need to expose the logic and 
 * authoring capabilities. </p> 
 * <h4> OsidPrimitives </h4> 
 * 
 * <p> Most OSID interfaces are used to encapsulate implementation-specific 
 * objects from provider to consumer. <code> Type </code> is an <code> 
 * OsidPrimitive </code> and as such cannot be used to encapsulate 
 * implementation-specific data other than what is defined explicitly in the 
 * <code> Type. </code> An OSID Provider must respect any <code> Type </code> 
 * constructed by an OSID Consumer. </p>
 * 
 * <br/><hr/><br/>
 * 
 * <p>Copyright &copy; 2006-2008 Massachusetts Institute of Technology. All 
 * Rights Reserved. </p>
 * 
 * <p>This Work is being provided by the copyright holder(s) subject to the 
 * following license. By obtaining, using and/or copying this Work, you agree 
 * that you have read, understand, and will comply with the following terms 
 * and conditions. </p> 
 * 
 * <p> Permission to use, copy and distribute unmodified versions of this 
 * Work, for any purpose, without fee or royalty is hereby granted, provided 
 * that you include the above copyright notices and the terms of this license 
 * on ALL copies of the Work or portions thereof. </p> 
 * 
 * <p> You may modify or create Derivatives of this Work only for your 
 * internal purposes. You shall not distribute or transfer any such Derivative 
 * of this Work to any location or to any third party. For the purposes of 
 * this license, "Derivative" shall mean any derivative of the Work as defined 
 * in the United States Copyright Act of 1976, such as a translation or 
 * modification. </p> 
 * 
 * <p> This Work and the information contained herein is provided on an "AS 
 * IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT 
 * NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR 
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT 
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN 
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN 
 * CONNECTION WITH THE WORK OR THE USE OR OTHER DEALINGS IN THE WORK. </p> 
 * 
 * <p> The export of software employing encryption technology may require a 
 * specific license from the United States Government. It is the 
 * responsibility of any person or organization contemplating export to obtain 
 * such a license before exporting this Work. </p>
 */

package org.osid.type;
