//
// org.osid.voting.BallotLookupSession
//
//     The OSID Java specification for org.osid.voting.BallotLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting;


/**
 *  <p>This session defines methods for retrieving ballots. A <code> Ballot 
 *  </code> is an arbitrary entity that may represent a person, place or thing 
 *  used to identify an object used in various services. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated polls view: All ballot methods in this session operate, 
 *      retrieve and pertain to ballots defined explicitly in the current 
 *      polls. Using an isolated view is useful for managing <code> Ballots 
 *      </code> with the <code> BallotAdminSession. </code> </li> 
 *      <li> federated polls view: All ballot methods in this session operate, 
 *      retrieve and pertain to all ballots defined in this polls and any 
 *      other ballots implicitly available in this polls through polls 
 *      inheritence. </li> 
 *      <li> active ballot view: active ballots are returned from methods in 
 *      this session </li> 
 *      <li> any status ballot view: active and inactive ballots are returned 
 *      from methods in this session </li> 
 *  </ul>
 *  
 *  
 *  <p> The methods <code> useFederatedPollsView() </code> and <code> 
 *  useIsolatedPollsView() </code> behave as a radio group and one should be 
 *  selected before invoking any lookup methods. </p> 
 *  
 *  <p> Ballots may have an additional records indicated by their respective 
 *  record types. The record may not be accessed through a cast of the <code> 
 *  Ballot. </code> </p>
 */

public interface BallotLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Polls </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Polls Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPollsId();


    /**
     *  Gets the <code> Polls </code> associated with this session. 
     *
     *  @return the <code> Polls </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.Polls getPolls()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> Ballot </code> lookups. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupBallots();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeBallotView();


    /**
     *  A complete view of the <code> Ballot </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryBallotView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include ballots in polls which are children of this polls in the polls 
     *  hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedPollsView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this polls only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedPollsView();


    /**
     *  Only active ballots are returned from methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveBallotView();


    /**
     *  Borth active and inactive ballots are returned from methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusBallotView();


    /**
     *  Gets the <code> Ballot </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Ballot </code> may have a different <code> Id </code> than requested, 
     *  such as the case where a duplicate <code> Id </code> was assigned to a 
     *  <code> Ballot </code> and retained for compatibility. 
     *  
     *  In active mode, ballots are returned that are currently active. In any 
     *  status mode, active and inactive ballots are returned. 
     *
     *  @param  ballotId the <code> Id </code> of the <code> Ballot </code> to 
     *          retrieve 
     *  @return the returned <code> Ballot </code> 
     *  @throws org.osid.NotFoundException no <code> Ballot </code> found with 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> ballotId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.Ballot getBallot(org.osid.id.Id ballotId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BallotList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  ballots specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Ballots </code> may be omitted from the list and 
     *  may present the elements in any order including returning a unique 
     *  set. 
     *  
     *  In active mode, ballots are returned that are currently active. In any 
     *  status mode, active and inactive ballots are returned. 
     *
     *  @param  ballotIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Ballot </code> list 
     *  @throws org.osid.NotFoundException an <code> Id </code> was not found 
     *  @throws org.osid.NullArgumentException <code> ballotIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.BallotList getBallotsByIds(org.osid.id.IdList ballotIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BallotList </code> corresponding to the given ballot 
     *  genus <code> Type </code> which does not include ballot of types 
     *  derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  ballots or an error results. Otherwise, the returned list may contain 
     *  only those ballots that are accessible through this session. 
     *  
     *  In active mode, ballots are returned that are currently active. In any 
     *  status mode, active and inactive ballots are returned. 
     *
     *  @param  ballotGenusType a ballot genus type 
     *  @return the returned <code> Ballot </code> list 
     *  @throws org.osid.NullArgumentException <code> ballotGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.BallotList getBallotsByGenusType(org.osid.type.Type ballotGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BallotList </code> corresponding to the given ballot 
     *  genus <code> Type </code> and include any additional ballots with 
     *  genus types derived from the specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  ballots or an error results. Otherwise, the returned list may contain 
     *  only those ballots that are accessible through this session. 
     *  
     *  In active mode, ballots are returned that are currently active. In any 
     *  status mode, active and inactive ballots are returned. 
     *
     *  @param  ballotGenusType a ballot genus type 
     *  @return the returned <code> Ballot </code> list 
     *  @throws org.osid.NullArgumentException <code> ballotGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.BallotList getBallotsByParentGenusType(org.osid.type.Type ballotGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BallotList </code> containing the given ballot record 
     *  <code> Type. </code> 
     *  
     *  In plenary mode, the returned list contains all known ballots or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  ballots that are accessible through this session. 
     *  
     *  In active mode, ballots are returned that are currently active. In any 
     *  status mode, active and inactive ballots are returned. 
     *
     *  @param  ballotRecordType a ballot record type 
     *  @return the returned <code> Ballot </code> list 
     *  @throws org.osid.NullArgumentException <code> ballotRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.BallotList getBallotsByRecordType(org.osid.type.Type ballotRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BallotList </code> from the given provider. 
     *  
     *  In plenary mode, the returned list contains all known ballots or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  ballots that are accessible through this session. 
     *  
     *  In active mode, ballots are returned that are currently active. In any 
     *  status mode, active and inactive ballots are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned <code> Ballot </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.BallotList getBallotsByProvider(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> BallotList </code> that are effective for the entire 
     *  given date range but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known ballots or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  ballots that are accessible through this session. 
     *  
     *  In active mode, ballots are returned that are currently active. In any 
     *  status mode, active and inactive ballots are returned. 
     *
     *  @param  from s atsrting date 
     *  @param  to an ending date 
     *  @return the returned <code> Ballot </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.BallotList getBallotsOnDate(org.osid.calendaring.DateTime from, 
                                                       org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Ballots. </code> 
     *  
     *  In plenary mode, the returned list contains all known ballots or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  ballots that are accessible through this session. 
     *  
     *  In active mode, ballots are returned that are currently active. In any 
     *  status mode, active and inactive ballots are returned. 
     *
     *  @return a list of <code> Ballots </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.BallotList getBallots()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
