//
// org.osid.voting.PollsLookupSession
//
//     The OSID Java specification for org.osid.voting.PollsLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting;


/**
 *  <p>This session provides methods for retrieving <code> Polls </code> 
 *  objects. The <code> Polls </code> represents a collection races, ballots, 
 *  candidates, and votes. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. For 
 *  example, a browsing application may only need to examine the <code> Polls 
 *  </code> it can access, without breaking execution. However, an 
 *  administrative application may require all <code> Polls </code> elements 
 *  to be available. </p> 
 *  
 *  <p> Polls may have an additional records indicated by their respective 
 *  record types. The record may not be accessed through a cast of the <code> 
 *  Polls. </code> </p>
 */

public interface PollsLookupSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can perform <code> Polls </code> lookups. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known all methods in this session will result in 
     *  a <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupPolls();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativePollsView();


    /**
     *  A complete view of the <code> Polls </code> returns is desired. 
     *  Methods will return what is requested or result in an error. This view 
     *  is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryPollsView();


    /**
     *  Gets the <code> Polls </code> specified by its <code> Id. </code> In 
     *  plenary mode, the exact <code> Id </code> is found or a <code> 
     *  NOT_FOUND </code> results. Otherwise, the returned <code> Polls 
     *  </code> may have a different <code> Id </code> than requested, such as 
     *  the case where a duplicate <code> Id </code> was assigned to a <code> 
     *  Polls </code> and retained for compatibility. 
     *
     *  @param  pollsId <code> Id </code> of the <code> Polls </code> 
     *  @return the polls 
     *  @throws org.osid.NotFoundException <code> pollsId </code> not found 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.voting.Polls getPolls(org.osid.id.Id pollsId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PollsList </code> corresponding to the given <code> 
     *  IdList. </code> In plenary mode, the returned list contains all of the 
     *  polls specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Polls </code> may be omitted from the list and may 
     *  present the elements in any order including returning a unique set. 
     *
     *  @param  pollsIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Polls list </code> 
     *  @throws org.osid.NotFoundException an <code> Id </code> was not found 
     *  @throws org.osid.NullArgumentException <code> pollsIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.PollsList getPollsByIds(org.osid.id.IdList pollsIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PollsList </code> corresponding to the given polls genus 
     *  <code> Type </code> which does not include polls of types derived from 
     *  the specified <code> Type. </code> In plenary mode, the returned list 
     *  contains all known polls or an error results. Otherwise, the returned 
     *  list may contain only those polls that are accessible through this 
     *  session. 
     *
     *  @param  pollsGenusType a polls genus type 
     *  @return the returned <code> Polls list </code> 
     *  @throws org.osid.NullArgumentException <code> pollsGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.PollsList getPollsByGenusType(org.osid.type.Type pollsGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PollsList </code> corresponding to the given polls genus 
     *  <code> Type </code> and include any additional polls with genus types 
     *  derived from the specified <code> Type. </code> In plenary mode, the 
     *  returned list contains all known polls or an error results. Otherwise, 
     *  the returned list may contain only those polls that are accessible 
     *  through this session. 
     *
     *  @param  pollsGenusType a polls genus type 
     *  @return the returned <code> Polls list </code> 
     *  @throws org.osid.NullArgumentException <code> pollsGenusType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.PollsList getPollsByParentGenusType(org.osid.type.Type pollsGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PollsList </code> containing the given polls record 
     *  <code> Type. </code> In plenary mode, the returned list contains all 
     *  known polls or an error results. Otherwise, the returned list may 
     *  contain only those polls that are accessible through this session. 
     *
     *  @param  pollsRecordType a polls interface type 
     *  @return the returned <code> Polls list </code> 
     *  @throws org.osid.NullArgumentException <code> pollsRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.PollsList getPollsByRecordType(org.osid.type.Type pollsRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> PollsList </code> for the given provider. <code> </code> 
     *  In plenary mode, the returned list contains all known polls or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  polls that are accessible through this session. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned <code> Polls list </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.PollsList getPollsByProvider(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Polls. </code> In plenary mode, the returned list 
     *  contains all known polls or an error results. Otherwise, the returned 
     *  list may contain only those polls that are accessible through this 
     *  session. 
     *
     *  @return a list of <code> Polls </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.PollsList getAllPolls()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
