//
// org.osid.voting.PollsQuery
//
//     The OSID Java specification for org.osid.voting.PollsQuery.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting;


/**
 *  <p>This is the query for searching polls. Each method specifies an <code> 
 *  AND </code> term while multiple invocations of the same method produce a 
 *  nested <code> OR. </code> </p>
 */

public interface PollsQuery
    extends org.osid.OsidCatalogQuery {


    /**
     *  Sets the candidate <code> Id </code> for this query. 
     *
     *  @param  candidateId a candidate <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> candidateId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchCandidateId(org.osid.id.Id candidateId, boolean match);


    /**
     *  Clears the candidate <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCandidateIdTerms();


    /**
     *  Tests if a <code> CandidateQuery </code> is available. 
     *
     *  @return <code> true </code> if a candidate query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsCandidateQuery();


    /**
     *  Gets the query for a candidate. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the candidate query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCandidateQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCandidateQuery() </code> is <code> true. </code> 
     */

    public org.osid.voting.CandidateQuery getCandidateQuery();


    /**
     *  Matches polls with any candidate. 
     *
     *  @param  match <code> true </code> to match polls with any candidate, 
     *          <code> false </code> to match polls with no candidates 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyCandidate(boolean match);


    /**
     *  Clears the candidate terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearCandidateTerms();


    /**
     *  Sets the polls <code> Id </code> for this query to match polls that 
     *  have the specified polls as an ancestor. 
     *
     *  @param  pollsid a polls <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAncestorPollsId(org.osid.id.Id pollsid, boolean match);


    /**
     *  Clears the ancestor polls <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorPollsIdTerms();


    /**
     *  Tests if a <code> PollsQuery </code> is available. 
     *
     *  @return <code> true </code> if a polls query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsAncestorPollsQuery();


    /**
     *  Gets the query for a polls. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the polls query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsAncestorPollsQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsAncestorPollsQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.voting.PollsQuery getAncestorPollsQuery();


    /**
     *  Matches polls with any ancestor. 
     *
     *  @param  match <code> true </code> to match polls with any ancestor, 
     *          <code> false </code> to match root polls 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyAncestorPolls(boolean match);


    /**
     *  Clears the ancestor polls terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearAncestorPollsTerms();


    /**
     *  Sets the polls <code> Id </code> for this query to match polls that 
     *  have the specified polls as a descendant. 
     *
     *  @param  pollsid a polls <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchDescendantPollsId(org.osid.id.Id pollsid, boolean match);


    /**
     *  Clears the descendant polls <code> Id </code> terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantPollsIdTerms();


    /**
     *  Tests if a <code> PollsQuery </code> is available. 
     *
     *  @return <code> true </code> if a polls query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsDescendantPollsQuery();


    /**
     *  Gets the query for a polls. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the polls query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsDescendantPollsQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsDescendantPollsQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.voting.PollsQuery getDescendantPollsQuery();


    /**
     *  Matches polls with any descendant. 
     *
     *  @param  match <code> true </code> to match polls with any descendant, 
     *          <code> false </code> to match leaf polls 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyDescendantPolls(boolean match);


    /**
     *  Clears the descendant polls terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearDescendantPollsTerms();


    /**
     *  Gets the polls query record corresponding to the given <code> Polls 
     *  </code> record <code> Type. </code> Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @param  pollsRecordType a polls record type 
     *  @return the polls query record 
     *  @throws org.osid.NullArgumentException <code> pollsRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(pollsRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.records.PollsQueryRecord getPollsQueryRecord(org.osid.type.Type pollsRecordType)
        throws org.osid.OperationFailedException;
}
