//
// org.osid.voting.RaceAdminSession
//
//     The OSID Java specification for org.osid.voting.RaceAdminSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting;


/**
 *  <p>This session creates, updates, and deletes <code> Races. </code> The 
 *  data for create and update is provided by the consumer via the form 
 *  object. <code> OsidForms </code> are requested for each create or update 
 *  and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Race, </code> a <code> RaceForm </code> is requested using <code> 
 *  getRaceFormForCreate() </code> specifying the <code> Ballot </code> and 
 *  desired record <code> Types </code> or none if no record <code> Types 
 *  </code> are needed. The returned <code> RaceForm </code> will indicate 
 *  that it is to be used with a create operation and can be used to examine 
 *  metdata or validate data prior to creation. Once the <code> RaceForm 
 *  </code> is submiited to a create operation, it cannot be reused with 
 *  another create operation unless the first operation was unsuccessful. Each 
 *  <code> RaceForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> For updates, <code> RaceForms </code> are requested to the <code> Race 
 *  </code> <code> Id </code> that is to be updated using <code> 
 *  getRaceFormForUpdate(). </code> Similarly, the <code> RaceForm </code> has 
 *  metadata about the data that can be updated and it can perform validation 
 *  before submitting the update. The <code> RaceForm </code> can only be used 
 *  once for a successful update and cannot be reused. </p> 
 *  
 *  <p> The delete operations delete <code> Races. </code> To unmap a <code> 
 *  Race </code> from the current <code> Polls, </code> the <code> 
 *  RacePollsAssignmentSession </code> should be used. These delete operations 
 *  attempt to remove the <code> Race </code> itself thus removing it from all 
 *  known <code> Polls </code> catalogs. </p> 
 *  
 *  <p> This session includes an <code> Id </code> aliasing mechanism to 
 *  assign an external <code> Id </code> to an internally assigned Id. </p>
 */

public interface RaceAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Polls </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Polls Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPollsId();


    /**
     *  Gets the <code> Polls </code> associated with this session. 
     *
     *  @return the <code> Polls </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.Polls getPolls()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create <code> Races </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> Race </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Race </code> creation is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateRaces();


    /**
     *  Tests if this user can create a single <code> Race </code> using the 
     *  desired record types. While <code> VotingManager.getRaceRecordTypes() 
     *  </code> can be used to examine which records are supported, this 
     *  method tests which record(s) are required for creating a specific 
     *  <code> Race. </code> Providing an empty array tests if a <code> Race 
     *  </code> can be created with no records. 
     *
     *  @param  raceRecordTypes array of race record types 
     *  @return <code> true </code> if <code> Race </code> creation using the 
     *          specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> raceRecordTypes </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateRaceWithRecordTypes(org.osid.type.Type[] raceRecordTypes);


    /**
     *  Gets the race form for creating new races. A new form should be 
     *  requested for each create transaction. 
     *
     *  @param  ballotId a ballot <code> Id </code> 
     *  @param  raceRecordTypes array of race record types 
     *  @return the race form 
     *  @throws org.osid.NotFoundException <code> raceId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> raceId </code> or <code> 
     *          raceRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form with 
     *          requested record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.RaceForm getRaceFormForCreate(org.osid.id.Id ballotId, 
                                                         org.osid.type.Type[] raceRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> Race. </code> 
     *
     *  @param  raceForm the form for this <code> Race </code> 
     *  @return the new <code> Race </code> 
     *  @throws org.osid.IllegalStateException <code> raceForm </code> already 
     *          used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> raceForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> raceForm </code> did not 
     *          originate from <code> getRaceFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.Race createRace(org.osid.voting.RaceForm raceForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update <code> Races. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> Race </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer update operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Race </code> modification is 
     *          not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateRaces();


    /**
     *  Gets the race form for updating an existing race. A new race form 
     *  should be requested for each update transaction. 
     *
     *  @param  raceId the <code> Id </code> of the <code> Race </code> 
     *  @return the race form 
     *  @throws org.osid.NotFoundException <code> raceId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> raceId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.RaceForm getRaceFormForUpdate(org.osid.id.Id raceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing race. 
     *
     *  @param  raceForm the form containing the elements to be updated 
     *  @throws org.osid.IllegalStateException <code> raceForm </code> already 
     *          used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> raceId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> raceForm </code> did not 
     *          originate from <code> getRaceFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateRace(org.osid.voting.RaceForm raceForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete <code> Races. </code> A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> Race </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer delete operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> Race </code> deletion is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteRaces();


    /**
     *  Deletes a <code> Race. </code> 
     *
     *  @param  raceId the <code> Id </code> of the <code> Race </code> to 
     *          remove 
     *  @throws org.osid.NotFoundException <code> raceId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> raceId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteRace(org.osid.id.Id raceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for <code> 
     *  Races. </code> A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> Race </code> aliasing is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageRaceAliases();


    /**
     *  Adds an <code> Id </code> to a <code> Race </code> for the purpose of 
     *  creating compatibility. The primary <code> Id </code> of the <code> 
     *  Race </code> is determined by the provider. The new <code> Id </code> 
     *  performs as an alias to the primary <code> Id. </code> If the alias is 
     *  a pointer to another race, it is reassigned to the given race <code> 
     *  Id. </code> 
     *
     *  @param  raceId the <code> Id </code> of a <code> Race </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> raceId </code> not found 
     *  @throws org.osid.NullArgumentException <code> raceId </code> or <code> 
     *          aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasRace(org.osid.id.Id raceId, org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
