//
// org.osid.voting.RaceLookupSession
//
//     The OSID Java specification for org.osid.voting.RaceLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting;


/**
 *  <p>This session defines methods for retrieving races. A <code> Race 
 *  </code> represents a statistic. </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> federated polls view: includes races in polls which are children 
 *      of this polls in the polls hierarchy </li> 
 *      <li> isolated polls view: restricts lookups to this polls only </li> 
 *      <li> active race view: active races are returned from methods in this 
 *      session </li> 
 *      <li> any status race view: active and inactive races are returned from 
 *      methods in this session </li> 
 *  </ul>
 *  
 */

public interface RaceLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Polls </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Polls Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPollsId();


    /**
     *  Gets the <code> Polls </code> associated with this session. 
     *
     *  @return the polls 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.Polls getPolls()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can lookup races. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer reading operations. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupRaces();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeRaceView();


    /**
     *  A complete view of the <code> Race </code> returns is desired. Methods 
     *  will return what is requested or result in an error. This view is used 
     *  when greater precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryRaceView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include races in polls which are children of this polls in the polls 
     *  hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedPollsView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts retrievals to this polls only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedPollsView();


    /**
     *  Only active races are returned from methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveRaceView();


    /**
     *  Borth active and inactive races are returned from methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusRaceView();


    /**
     *  Gets the <code> Race </code> specified by its <code> Id. </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  Race </code> may have a different <code> Id </code> than requested, 
     *  such as the case where a duplicate <code> Id </code> was assigned to a 
     *  <code> Race </code> and retained for compatibility. 
     *  
     *  In active mode, races are returned that are currently active. In any 
     *  status mode, active and inactive races are returned. 
     *
     *  @param  raceId the <code> Id </code> of the <code> Race </code> to 
     *          retrieve 
     *  @return the returned <code> Race </code> 
     *  @throws org.osid.NotFoundException no <code> Race </code> found with 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> raceId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.Race getRace(org.osid.id.Id raceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RaceList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  races specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible races may be omitted from the list and may present the 
     *  elements in any order including returning a unique set. 
     *  
     *  In active mode, races are returned that are currently active. In any 
     *  status mode, active and inactive races are returned. 
     *
     *  @param  raceIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Race list </code> 
     *  @throws org.osid.NotFoundException an <code> Id </code> was not found 
     *  @throws org.osid.NullArgumentException <code> raceIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.RaceList getRacesByIds(org.osid.id.IdList raceIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RaceList </code> corresponding to the given race genus 
     *  <code> Type </code> which does not include races of types derived from 
     *  the specified <code> Type. </code> In plenary mode, the returned list 
     *  contains all known races or an error results. Otherwise, the returned 
     *  list may contain only those races that are accessible through this 
     *  session. 
     *
     *  @param  raceGenusType a race genus type 
     *  @return the returned <code> Race </code> list 
     *  @throws org.osid.NullArgumentException <code> raceGenusType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.RaceList getRacesByGenusType(org.osid.type.Type raceGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RaceList </code> corresponding to the given race genus 
     *  <code> Type </code> and include races of types derived from the 
     *  specified <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  races or an error results. Otherwise, the returned list may contain 
     *  only those races that are accessible through this session. 
     *  
     *  In active mode, races are returned that are currently active. In any 
     *  status mode, active and inactive races are returned. 
     *
     *  @param  raceGenusType a race genus type 
     *  @return the returned <code> Race </code> list 
     *  @throws org.osid.NullArgumentException <code> raceGenusType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.RaceList getRacesByParentGenusType(org.osid.type.Type raceGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RaceList </code> containing the given race record <code> 
     *  Type. </code> 
     *  
     *  In plenary mode, the returned list contains all known races or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  races that are accessible through this session. 
     *  
     *  In active mode, races are returned that are currently active. In any 
     *  status mode, active and inactive races are returned. 
     *
     *  @param  raceRecordType a race record type 
     *  @return the returned <code> Race </code> list 
     *  @throws org.osid.NullArgumentException <code> raceRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.RaceList getRacesByRecordType(org.osid.type.Type raceRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RaceList </code> from the given provider. 
     *  
     *  In plenary mode, the returned list contains all known races or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  races that are accessible through this session. 
     *  
     *  In active mode, races are returned that are currently active. In any 
     *  status mode, active and inactive races are returned. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the returned <code> Race </code> list 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.RaceList getRacesByProvider(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> RaceList </code> for the given <code> Ballot. </code> 
     *  
     *  In plenary mode, the returned list contains all known races or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  races that are accessible through this session. 
     *  
     *  In active mode, races are returned that are currently active. In any 
     *  status mode, active and inactive races are returned. 
     *
     *  @param  ballotId a ballot <code> Id </code> 
     *  @return the returned <code> Race </code> list 
     *  @throws org.osid.NullArgumentException <code> ballotId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.RaceList getRacesForBallot(org.osid.id.Id ballotId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all races. 
     *  
     *  In plenary mode, the returned list contains all known races or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  races that are accessible through this session. 
     *  
     *  In active mode, races are returned that are currently active. In any 
     *  status mode, active and inactive races are returned. 
     *
     *  @return a list of races 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.RaceList getRaces()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
