//
// org.osid.voting.RaceSearchSession
//
//     The OSID Java specification for org.osid.voting.RaceSearchSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting;


/**
 *  <p>This session provides methods for searching among races. The search 
 *  query is constructed using the <code> RaceQuery. </code> </p> 
 *  
 *  <p> <code> getRacesByQuery() </code> is the basic search method and 
 *  returns a list of races. A more advanced search may be performed with 
 *  <code> getRacesBySearch(). </code> It accepts a <code> RaceSearch </code> 
 *  in addition to the query for the purpose of specifying additional options 
 *  affecting the entire search, such as ordering. <code> getRacesBySearch() 
 *  </code> returns a <code> RaceSearchResults </code> that can be used to 
 *  access the resulting <code> RaceList </code> or be used to perform a 
 *  search within the result set through <code> RaceSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated polls view: searches include races in polls of which 
 *      this polls is an ancestor in the polls hierarchy </li> 
 *      <li> isolated polls view: searches are restricted to races in this 
 *      polls only </li> 
 *  </ul>
 *  
 */

public interface RaceSearchSession
    extends org.osid.voting.RaceQuerySession {


    /**
     *  Gets a race search. 
     *
     *  @return the race search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.RaceSearch getRaceSearch();


    /**
     *  Gets a race search order. The <code> RaceSearchOrder </code> is 
     *  supplied to a <code> RaceSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the race search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.RaceSearchOrder getRaceSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  raceQuery the race query 
     *  @param  raceSearch the race search 
     *  @return the returned race search results 
     *  @throws org.osid.NullArgumentException <code> raceQuery </code> or 
     *          <code> raceSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> raceQuery </code> or 
     *          <code> raceSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.RaceSearchResults getRacesBySearch(org.osid.voting.RaceQuery raceQuery, 
                                                              org.osid.voting.RaceSearch raceSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a race query from an inspector. The inspector is available from a 
     *  <code> RaceSearchResults. </code> 
     *
     *  @param  raceQueryInspector a race query inspector 
     *  @return the race query 
     *  @throws org.osid.NullArgumentException <code> raceQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> raceQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.RaceQuery getRaceQueryFromInspector(org.osid.voting.RaceQueryInspector raceQueryInspector);
}
