//
// org.osid.voting.VoteLookupSession
//
//     The OSID Java specification for org.osid.voting.VoteLookupSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting;


/**
 *  <p>This session provides methods for looking up votes. </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error votes </li> 
 *      <li> isolated polls view: All vote methods in this session operate, 
 *      retrieve and pertain to votes defined explicitly in the current polls. 
 *      Using an isolated view is useful for managing votes with the <code> 
 *      VoteAdminSession. </code> </li> 
 *      <li> federated polls view: All vote methods in this session operate, 
 *      retrieve and pertain to all votes defined in these polls and any other 
 *      catalogs implicitly available in this polls through polls inheritence. 
 *      </li> 
 *      <li> effective vote view: All vote lookup methods return votes where 
 *      the current date falls in between the effective dates inclusive. </li> 
 *      <li> any effective vote view: Votes of any effective date are returned 
 *      from methods. </li> 
 *  </ul>
 *  
 */

public interface VoteLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Polls </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Polls Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPollsId();


    /**
     *  Gets the <code> Polls </code> associated with this session. 
     *
     *  @return the <code> Polls </code> associated with this session 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.Polls getPolls()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can access votes. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer vote operations. 
     *
     *  @return <code> false </code> if voting methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupVotes();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeVoteView();


    /**
     *  A complete view of the vote returns is desired. Methods will return 
     *  what is requested or result in an error. This view is used when 
     *  greater precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryVoteView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include votes in polls which are children of this polls in the polls 
     *  hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedPollsView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts votes to these polls only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedPollsView();


    /**
     *  Only votes whose effective dates are current are returned by methods 
     *  in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useEffectiveVoteView();


    /**
     *  All votes of any effective dates are returned by methods in this 
     *  session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyEffectiveVoteView();


    /**
     *  Gets a <code> Vote </code> specified by its <code> Id. </code> 
     *
     *  @param  voteId <code> Id </code> of the <code> Vote </code> 
     *  @return the vote 
     *  @throws org.osid.NotFoundException <code> voteId </code> not found 
     *  @throws org.osid.NullArgumentException <code> voteId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.voting.Vote getVote(org.osid.id.Id voteId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> VoteList </code> corresponding to the given <code> 
     *  IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  votes specified in the <code> Id </code> list, in the order of the 
     *  list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> Votes </code> may be omitted from the list and may 
     *  present the elements in any order including returning a unique set. 
     *  
     *  In effective mode, votes are returned that are currently effective. In 
     *  any effective mode, effective votes and those currently expired are 
     *  returned. 
     *
     *  @param  voteIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> Vote </code> list 
     *  @throws org.osid.NotFoundException an <code> Id </code> was not found 
     *  @throws org.osid.NullArgumentException <code> voteIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.VoteList getVotesByIds(org.osid.id.IdList voteIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the votes for the given vote genus type. 
     *  
     *  In plenary mode, the returned list contains all known votes or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  votes that are accessible through this session. 
     *  
     *  In effective mode, votes are returned that are currently effective. In 
     *  any effective mode, effective votes and those currently expired are 
     *  returned. 
     *
     *  @param  voteGenusType a vote genus type 
     *  @return the votes 
     *  @throws org.osid.NullArgumentException <code> voteGenusType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.VoteList getVotesByGenusType(org.osid.type.Type voteGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the votes for the given vote genus type and include any votes 
     *  with a genus type derived from the specified genus type. 
     *  
     *  In plenary mode, the returned list contains all known votes or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  votes that are accessible through this session. 
     *  
     *  In effective mode, votes are returned that are currently effective. In 
     *  any effective mode, effective votes and those currently expired are 
     *  returned. 
     *
     *  @param  voteGenusType a vote genus type 
     *  @return the votes 
     *  @throws org.osid.NullArgumentException <code> voteGenusType </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.VoteList getVotesByParentGenusType(org.osid.type.Type voteGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the votes for the given vote record type. 
     *  
     *  In plenary mode, the returned list contains all known votes or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  votes that are accessible through this session. 
     *  
     *  In effective mode, votes are returned that are currently effective. In 
     *  any effective mode, effective votes and those currently expired are 
     *  returned. 
     *
     *  @param  voteRecordType a vote record type 
     *  @return the votes 
     *  @throws org.osid.NullArgumentException <code> voteRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.VoteList getVotesByRecordType(org.osid.type.Type voteRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of votes effective during the entire given date range 
     *  inclusive but not confined to the date range. 
     *  
     *  In plenary mode, the returned list contains all known votes or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  votes that are accessible through this session. 
     *  
     *  In effective mode, votes are returned that are currently effective. In 
     *  any effective mode, effective votes and those currently expired are 
     *  returned. 
     *
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Vote </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.VoteList getVotesOnDate(org.osid.calendaring.DateTime from, 
                                                   org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the votes cast by the given voter. 
     *  
     *  In plenary mode, the returned list contains all of the votes mapped to 
     *  the candidate <code> Id </code> or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible votes may be omitted from the list and may present the 
     *  elements in any order including returning a unique set. 
     *  
     *  In effective mode, votes are returned that are currently effective. In 
     *  any effective mode, effective votes and those currently expired are 
     *  returned. 
     *
     *  @param  resourceId <code> Id </code> of a <code> Voter </code> 
     *  @return the votes 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.VoteList getVotesForVoter(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of votes for a voter effective during the entire given 
     *  date range inclusive but not confined to the date range. <code> 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  votes or an error results. Otherwise, the returned list may contain 
     *  only those votes that are accessible through this session. 
     *  
     *  In effective mode, votes are returned that are currently effective. In 
     *  any effective mode, effective votes and those currently expired are 
     *  returned. 
     *
     *  @param  resourceId <code> Id </code> of a <code> Voter </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Vote </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, from </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.VoteList getVotesForVoterOnDate(org.osid.id.Id resourceId, 
                                                           org.osid.calendaring.DateTime from, 
                                                           org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Votes </code> for a candidate. 
     *  
     *  In plenary mode, the returned list contains all known votes or an 
     *  error results. Otherwise, the returned list may contain only those 
     *  votes that are accessible through this session. 
     *  
     *  In effective mode, votes are returned that are currently effective. In 
     *  any effective mode, effective votes and those currently expired are 
     *  returned. 
     *
     *  @param  candidateId <code> Id </code> of a <code> Candidate </code> 
     *  @return the votes 
     *  @throws org.osid.NullArgumentException <code> candidateId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.VoteList getVotesForCandidate(org.osid.id.Id candidateId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of votes for a candidate effective during the entire given 
     *  date range inclusive but not confined to the date range. <code> 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  votes or an error results. Otherwise, the returned list may contain 
     *  only those votes that are accessible through this session. 
     *  
     *  In effective mode, votes are returned that are currently effective. In 
     *  any effective mode, effective votes and those currently expired are 
     *  returned. 
     *
     *  @param  candidateId <code> Id </code> of a <code> Candidate </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Vote </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> candidateId, from 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.VoteList getVotesForCandidateOnDate(org.osid.id.Id candidateId, 
                                                               org.osid.calendaring.DateTime from, 
                                                               org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the votes cast by the given voter and candidate. 
     *  
     *  In plenary mode, the returned list contains all of the votes mapped to 
     *  the candidate <code> Id </code> or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible votes may be omitted from the list and may present the 
     *  elements in any order including returning a unique set. 
     *  
     *  In effective mode, votes are returned that are currently effective. In 
     *  any effective mode, effective votes and those currently expired are 
     *  returned. 
     *
     *  @param  resourceId <code> Id </code> of a <code> Voter </code> 
     *  @param  candidateId <code> Id </code> of a <code> Candidate </code> 
     *  @return the votes 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> or 
     *          <code> candidateId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.VoteList getVotesForVoterAndCandidate(org.osid.id.Id resourceId, 
                                                                 org.osid.id.Id candidateId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of votes for a voter and candidate effective during the 
     *  entire given date range inclusive but not confined to the date range. 
     *  <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  votes or an error results. Otherwise, the returned list may contain 
     *  only those votes that are accessible through this session. 
     *  
     *  In effective mode, votes are returned that are currently effective. In 
     *  any effective mode, effective votes and those currently expired are 
     *  returned. 
     *
     *  @param  resourceId <code> Id </code> of a <code> Voter </code> 
     *  @param  candidateId <code> Id </code> of a <code> Candidate </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Vote </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, candidateId, 
     *          from </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.VoteList getVotesForVoterAndCandidateOnDate(org.osid.id.Id resourceId, 
                                                                       org.osid.id.Id candidateId, 
                                                                       org.osid.calendaring.DateTime from, 
                                                                       org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the votes cast in the given race. 
     *  
     *  In plenary mode, the returned list contains all of the votes mapped to 
     *  the candidate <code> Id </code> or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible votes may be omitted from the list and may present the 
     *  elements in any order including returning a unique set. 
     *  
     *  In effective mode, votes are returned that are currently effective. In 
     *  any effective mode, effective votes and those currently expired are 
     *  returned. 
     *
     *  @param  raceId <code> Id </code> of a <code> Race </code> 
     *  @return the votes 
     *  @throws org.osid.NullArgumentException <code> ballotId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.VoteList getVotesForRace(org.osid.id.Id raceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of votes in a race effective during the entire given date 
     *  range inclusive but not confined to the date range. <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  votes or an error results. Otherwise, the returned list may contain 
     *  only those votes that are accessible through this session. 
     *  
     *  In effective mode, votes are returned that are currently effective. In 
     *  any effective mode, effective votes and those currently expired are 
     *  returned. 
     *
     *  @param  raceId <code> Id </code> of a <code> Race </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Vote </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> raceId, from </code> or 
     *          <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.VoteList getVotesForRaceOnDate(org.osid.id.Id raceId, 
                                                          org.osid.calendaring.DateTime from, 
                                                          org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the votes cast by the given voter and race. 
     *  
     *  In plenary mode, the returned list contains all of the votes mapped to 
     *  the candidate <code> Id </code> or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible votes may be omitted from the list and may present the 
     *  elements in any order including returning a unique set. 
     *  
     *  In effective mode, votes are returned that are currently effective. In 
     *  any effective mode, effective votes and those currently expired are 
     *  returned. 
     *
     *  @param  resourceId <code> Id </code> of a <code> Voter </code> 
     *  @param  raceId <code> Id </code> of a <code> Race </code> 
     *  @return the votes 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> or 
     *          <code> raceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.VoteList getVotesForVoterAndRace(org.osid.id.Id resourceId, 
                                                            org.osid.id.Id raceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of votes for a voter and race effective during the entire 
     *  given date range inclusive but not confined to the date range. <code> 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  votes or an error results. Otherwise, the returned list may contain 
     *  only those votes that are accessible through this session. 
     *  
     *  In effective mode, votes are returned that are currently effective. In 
     *  any effective mode, effective votes and those currently expired are 
     *  returned. 
     *
     *  @param  resourceId <code> Id </code> of a <code> Voter </code> 
     *  @param  raceId <code> Id </code> of a <code> Race </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Vote </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, raceId, from 
     *          </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.VoteList getVotesForVoterAndRaceOnDate(org.osid.id.Id resourceId, 
                                                                  org.osid.id.Id raceId, 
                                                                  org.osid.calendaring.DateTime from, 
                                                                  org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the votes cast in the given ballot. 
     *  
     *  In plenary mode, the returned list contains all of the votes mapped to 
     *  the candidate <code> Id </code> or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible votes may be omitted from the list and may present the 
     *  elements in any order including returning a unique set. 
     *  
     *  In effective mode, votes are returned that are currently effective. In 
     *  any effective mode, effective votes and those currently expired are 
     *  returned. 
     *
     *  @param  ballotId <code> Id </code> of a <code> Ballot </code> 
     *  @return the votes 
     *  @throws org.osid.NullArgumentException <code> ballotId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.VoteList getVotesForBallot(org.osid.id.Id ballotId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of votes in a ballot effective during the entire given 
     *  date range inclusive but not confined to the date range. <code> 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  votes or an error results. Otherwise, the returned list may contain 
     *  only those votes that are accessible through this session. 
     *  
     *  In effective mode, votes are returned that are currently effective. In 
     *  any effective mode, effective votes and those currently expired are 
     *  returned. 
     *
     *  @param  ballotId <code> Id </code> of a <code> Ballot </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Vote </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> ballotId, from </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.VoteList getVotesForBallotOnDate(org.osid.id.Id ballotId, 
                                                            org.osid.calendaring.DateTime from, 
                                                            org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the votes cast by the given voter and ballot. 
     *  
     *  In plenary mode, the returned list contains all of the votes mapped to 
     *  the candidate <code> Id </code> or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible votes may be omitted from the list and may present the 
     *  elements in any order including returning a unique set. 
     *  
     *  In effective mode, votes are returned that are currently effective. In 
     *  any effective mode, effective votes and those currently expired are 
     *  returned. 
     *
     *  @param  resourceId <code> Id </code> of a <code> Voter </code> 
     *  @param  ballotId <code> Id </code> of a <code> Ballot </code> 
     *  @return the votes 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> or 
     *          <code> ballotId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.VoteList getVotesForVoterAndBallot(org.osid.id.Id resourceId, 
                                                              org.osid.id.Id ballotId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a list of votes for a voter and ballot effective during the 
     *  entire given date range inclusive but not confined to the date range. 
     *  <code> </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  votes or an error results. Otherwise, the returned list may contain 
     *  only those votes that are accessible through this session. 
     *  
     *  In effective mode, votes are returned that are currently effective. In 
     *  any effective mode, effective votes and those currently expired are 
     *  returned. 
     *
     *  @param  resourceId <code> Id </code> of a <code> Voter </code> 
     *  @param  ballotId <code> Id </code> of a <code> Ballot </code> 
     *  @param  from start of date range 
     *  @param  to end of date range 
     *  @return the returned <code> Vote </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, ballotId, 
     *          from </code> or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.VoteList getVotesForVoterAndBallotOnDate(org.osid.id.Id resourceId, 
                                                                    org.osid.id.Id ballotId, 
                                                                    org.osid.calendaring.DateTime from, 
                                                                    org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all votes. 
     *  
     *  In plenary mode, the returned list contains all of the votes mapped to 
     *  the candidate <code> Id </code> or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible votes may be omitted from the list and may present the 
     *  elements in any order including returning a unique set. 
     *  
     *  In effective mode, votes are returned that are currently effective. In 
     *  any effective mode, effective votes and those currently expired are 
     *  returned. 
     *
     *  @return the votes 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.VoteList getVotes()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
