//
// org.osid.voting.VoteNotificationSession
//
//     The OSID Java specification for org.osid.voting.VoteNotificationSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting;


/**
 *  <p>This session defines methods to receive asynchronous notifications on 
 *  adds/changes to votes. This session is intended for consumers needing to 
 *  synchronize their state with this service without the use of polling. 
 *  Notifications are cancelled when this session is closed. </p> 
 *  
 *  <p> The views defined in this session correspond to the views in the 
 *  <code> VoteLookupSession. </code> </p>
 */

public interface VoteNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Polls </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Polls Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPollsId();


    /**
     *  Gets the <code> Polls </code> associated with this session. 
     *
     *  @return the polls 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.Polls getPolls()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can register for <code> Vote </code> notifications. 
     *  A return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer notification 
     *  operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForVoteNotifications();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include notifications for votes in polls which are children of this 
     *  polls in the polls hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedPollsView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts notifications for votes in this polls only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedPollsView();


    /**
     *  Register for notifications of new votes. <code> 
     *  VoteReceiver.newVotes() </code> is invoked when a new vote is created. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewVotes()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new votes for the given ballot. <code> 
     *  VoteReceiver.newVotes() </code> is invoked when a new vote is created. 
     *
     *  @param  ballotId the <code> Id </code> of the <code> Ballot </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> ballotId is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewVotesForBallot(org.osid.id.Id ballotId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new votes for the given race. <code> 
     *  VoteReceiver.newVotes() </code> is invoked when a new vote is created. 
     *
     *  @param  raceId the <code> Id </code> of the <code> Race </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> raceId is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewVotesForRace(org.osid.id.Id raceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new votes for the given candidate. 
     *  <code> VoteReceiver.newVotes() </code> is invoked when a new vote is 
     *  created. 
     *
     *  @param  candidateId the <code> Id </code> of the <code> Candidate 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> candidateId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewVotesForCandidate(org.osid.id.Id candidateId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new votes for the given voter. <code> 
     *  VoteReceiver.newVotes() </code> is invoked when a new vote is created. 
     *
     *  @param  resourceId the <code> Id </code> of the voter to monitor 
     *  @throws org.osid.NullArgumentException <code> resourceId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewVotesForVoter(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of updated votes. <code> 
     *  VoteReceiver.ChangedVotes() </code> is invoked when a vote is changed. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedVotes()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of updated votes for the given ballot. 
     *  <code> VoteReceiver.changedVotes() </code> is invoked when a vote is 
     *  changed. 
     *
     *  @param  ballotId the <code> Id </code> of the <code> Ballot </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> ballotId is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedVotesForBallot(org.osid.id.Id ballotId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of updated votes for the given race. <code> 
     *  VoteReceiver.changedVotes() </code> is invoked when a vote is changed. 
     *
     *  @param  raceId the <code> Id </code> of the <code> Race </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> raceId is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedVotesForRace(org.osid.id.Id raceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of updated votes for the given candidate. 
     *  <code> VoteReceiver.changedVotes() </code> is invoked when a vote is 
     *  changed. 
     *
     *  @param  candidateId the <code> Id </code> of the <code> Candidate 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> candidateId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedVotesForCandidate(org.osid.id.Id candidateId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of updated votes for the given voter. 
     *  <code> VoteReceiver.changedVotes() </code> is invoked when a vote is 
     *  changed. 
     *
     *  @param  resourceId the <code> Id </code> of the voter to monitor 
     *  @throws org.osid.NullArgumentException <code> resourceId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedVotesForVoter(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of updated votes for the given vote. <code> 
     *  VoteReceiver.changedVotes() </code> is invoked when a vote is changed. 
     *
     *  @param  voteId the <code> Id </code> of the <code> Vote </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> voteId is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForChangedVote(org.osid.id.Id voteId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of deleted votes. <code> 
     *  VoteReceiver.deletedVotes() </code> is invoked when a vote is deleted. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedVotes()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of deleted votes for the given ballot. 
     *  <code> VoteReceiver.deletedVotes() </code> is invoked when a vote is 
     *  deleted. 
     *
     *  @param  ballotId the <code> Id </code> of the <code> Ballot </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> ballotId is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedVotesForBallot(org.osid.id.Id ballotId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of deleted votes for the given race. <code> 
     *  VoteReceiver.deletedVotes() </code> is invoked when a vote is deleted. 
     *
     *  @param  raceId the <code> Id </code> of the <code> Race </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> raceId is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedVotesForRace(org.osid.id.Id raceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of deleted votes for the given candidate. 
     *  <code> VoteReceiver.deletedVotes() </code> is invoked when a vote is 
     *  deleted. 
     *
     *  @param  candidateId the <code> Id </code> of the <code> Candidate 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> candidateId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedVotesForCandidate(org.osid.id.Id candidateId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of deleted votes for the given voter. 
     *  <code> VoteReceiver.deletedVotes() </code> is invoked when a vote is 
     *  deleted. 
     *
     *  @param  resourceId the <code> Id </code> of the voter to monitor 
     *  @throws org.osid.NullArgumentException <code> resourceId is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedVotesForVoter(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Registers for notification of a deleted vote. <code> 
     *  VoteReceiver.changedVotes() </code> is invoked when the specified vote 
     *  is deleted. 
     *
     *  @param  voteId the <code> Id </code> of the <code> Vote </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> voteId is null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForDeletedVote(org.osid.id.Id voteId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
