//
// org.osid.voting.VotingManager
//
//     The OSID Java specification for org.osid.voting.VotingManager.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting;


/**
 *  <p>The voring manager provides access to voting sessions and provides 
 *  interoperability tests for various aspects of this service. The sessions 
 *  included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> VotingSession: </code> a session to vote </li> 
 *      <li> <code> VotingResultsSession: </code> a session to examine voting 
 *      results </li> 
 *      <li> <code> VoterAllocationLookupSession: </code> a session to look up 
 *      voter allocations </li> 
 *      <li> <code> VoterAllocationAdminSession: </code> a session to manage 
 *      voter allocations </li> 
 *      <li> <code> VoteLookupSession: </code> a session to retrieve votes 
 *      </li> 
 *      <li> <code> VoteQuerySession: </code> a session to query for votes 
 *      </li> 
 *      <li> <code> VoteSearchSession: </code> a session to search for votes 
 *      </li> 
 *      <li> <code> VoteAdminSession: </code> a session to create and delete 
 *      votes </li> 
 *      <li> <code> VoteNotificationSession: </code> a session to receive 
 *      notifications pertaining to votechanges </li> 
 *      <li> <code> VotePollsSession: </code> a session to look up vote to 
 *      polls mappings </li> 
 *      <li> <code> VotePollsAssignmentSession: </code> a session to manage 
 *      vote to polls mappings </li> 
 *      <li> <code> VoteSmartPollsSession: </code> a session to manage smart 
 *      vote pollss </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> CandidateLookupSession: </code> a session to retrieve 
 *      candidates </li> 
 *      <li> <code> CandidateQuerySession: </code> a session to query 
 *      candidates </li> 
 *      <li> <code> CandidateSearchSession: </code> a session to search for 
 *      candidates </li> 
 *      <li> <code> CandidateAdminSession: </code> a session to create and 
 *      delete candidates </li> 
 *      <li> <code> CandidateNotificationSession: </code> a session to receive 
 *      notifications pertaining to candidate changes </li> 
 *      <li> <code> CandidatePollsSession: </code> a session to look up 
 *      candidate to polls mappings </li> 
 *      <li> <code> CandidatePollsAssignmentSession: </code> a session to 
 *      manage candidate to polls mappings </li> 
 *      <li> <code> CandidateSmartPollsSession: </code> a session to manage 
 *      smart candidate polls </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> RaceLookupSession: </code> a session to retrieve races 
 *      </li> 
 *      <li> <code> RaceQuerySession: </code> a session to query for races 
 *      </li> 
 *      <li> <code> RaceSearchSession: </code> a session to search for races 
 *      </li> 
 *      <li> <code> RaceAdminSession: </code> a session to create and delete 
 *      races </li> 
 *      <li> <code> RaceNotificationSession: </code> a session to receive 
 *      notifications pertaining to races changes </li> 
 *      <li> <code> RacePollsSession: </code> a session to look up races to 
 *      polls mappings </li> 
 *      <li> <code> RacePollsAssignmentSession: </code> a session to manage 
 *      race to polls mappings </li> 
 *      <li> <code> RaceSmartPollsSession: </code> a session to manage smart 
 *      race polls </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> BallotLookupSession: </code> a session to retrieve ballots 
 *      </li> 
 *      <li> <code> BallotQuerySession: </code> a session to query for ballots 
 *      </li> 
 *      <li> <code> BallotSearchSession: </code> a session to search for 
 *      ballots </li> 
 *      <li> <code> BallotAdminSession: </code> a session to create and delete 
 *      ballots </li> 
 *      <li> <code> BallotNotificationSession: </code> a session to receive 
 *      notifications pertaining to ballots changes </li> 
 *      <li> <code> BallotPollsSession: </code> a session to look up ballots 
 *      to polls mappings </li> 
 *      <li> <code> BallotPollsAssignmentSession: </code> a session to manage 
 *      ballot to polls mappings </li> 
 *      <li> <code> BallotSmartPollsSession: </code> a session to manage smart 
 *      ballot polls </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> PollsLookupSession: a </code> session to retrieve polls 
 *      </li> 
 *      <li> <code> PollsQuerySession: </code> a session to query polls </li> 
 *      <li> <code> PollsSearchSession: </code> a session to search for pollss 
 *      </li> 
 *      <li> <code> PollsAdminSession: </code> a session to create, update and 
 *      delete polls </li> 
 *      <li> <code> PollsNotificationSession: </code> a session to receive 
 *      notifications pertaining to changes in polls </li> 
 *      <li> <code> PollsHierarchySession: </code> a session to traverse polls 
 *      hierarchies </li> 
 *      <li> <code> PollsHierarchyDesignSession: </code> a session to manage 
 *      polls hierarchies </li> 
 *  </ul>
 *  
 */

public interface VotingManager
    extends org.osid.OsidManager,
            org.osid.voting.VotingProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the voting 
     *  service. 
     *
     *  @return a <code> VotingSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsVoting() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVoting() </code> is <code> true. </code> 
     */

    public org.osid.voting.VotingSession getVotingSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the voting service 
     *  for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Pools </code> 
     *  @return a <code> VotingSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsVoting() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVoting() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.voting.VotingSession getVotingSessionForPolls(org.osid.id.Id pollsId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race results 
     *  service. 
     *
     *  @return a <code> RaceResultsSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRaceResults() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceResults() </code> is <code> true. </code> 
     */

    public org.osid.voting.RaceResultsSession getRaceResultsSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race results 
     *  service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Pools </code> 
     *  @return a <code> RaceResultsSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRaceResults() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceResults() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.voting.RaceResultsSession getRaceResultsSessionForPolls(org.osid.id.Id pollsId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the voter 
     *  allocation lookup service. 
     *
     *  @return a <code> VoterAllocationLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsVoterAllocationLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVoterAllocationLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.voting.VoterAllocationLookupSession getVoterAllocationLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the voter 
     *  allocation lookup service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @return a <code> VoterAllocationLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given Id 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsVoterAllocationLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVoterAllocationLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.voting.VoterAllocationLookupSession getVoterAllocationLookupSessionForPolls(org.osid.id.Id pollsId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the voter 
     *  allocation administrative service. 
     *
     *  @return a <code> VoterAllocationAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsVoterAllocationAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVoterAllocationAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.voting.VoterAllocationAdminSession getVoterAllocationAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the voter 
     *  allocation administrative service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @return a <code> VoterAllocationAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given Id 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsVoterAllocationAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVoterAllocationAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.voting.VoterAllocationAdminSession getVoterAllocationAdminSessionForPolls(org.osid.id.Id pollsId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the vote lookup 
     *  service. 
     *
     *  @return a <code> VoteLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsVoteLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVoteLookup() </code> is <code> true. </code> 
     */

    public org.osid.voting.VoteLookupSession getVoteLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the vote lookup 
     *  service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @return a <code> VoteLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsVoteLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVoteLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.voting.VoteLookupSession getVoteLookupSessionForPolls(org.osid.id.Id pollsId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the vote query 
     *  service. 
     *
     *  @return a <code> VoteQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsVoteQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVoteQuery() </code> is <code> true. </code> 
     */

    public org.osid.voting.VoteQuerySession getVoteQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the vote query 
     *  service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @return a <code> VoteQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsVoteQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVoteQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.voting.VoteQuerySession getVoteQuerySessionForPolls(org.osid.id.Id pollsId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the vote search 
     *  service. 
     *
     *  @return a <code> VoteSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsVoteSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVoteSearch() </code> is <code> true. </code> 
     */

    public org.osid.voting.VoteSearchSession getVoteSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the vote search 
     *  service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @return a <code> VoteSearchSession </code> 
     *  @throws org.osid.NotFoundException no polls found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsVoteSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVoteSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.voting.VoteSearchSession getVoteSearchSessionForPolls(org.osid.id.Id pollsId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the vote 
     *  notification service. 
     *
     *  @param  voteReceiver the notification callback 
     *  @return a <code> VoteNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> voteReceiver </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsVoteNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVoteNotification() </code> is <code> true. </code> 
     */

    public org.osid.voting.VoteNotificationSession getVoteNotificationSession(org.osid.voting.VoteReceiver voteReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the vote 
     *  notification service for the given polls. 
     *
     *  @param  voteReceiver the notification callback 
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @return a <code> VoteNotificationSession </code> 
     *  @throws org.osid.NotFoundException no polls found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> voteReceiver </code> or 
     *          <code> pollsId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsVoteNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVoteNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.voting.VoteNotificationSession getVoteNotificationSessionForPolls(org.osid.voting.VoteReceiver voteReceiver, 
                                                                                      org.osid.id.Id pollsId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving vote to polls mappings. 
     *
     *  @return a <code> VotePollsSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsVotePolls() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVotePolls() </code> is <code> true. </code> 
     */

    public org.osid.voting.VotePollsSession getVotePollsSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning votes to polls mappings. 
     *
     *  @return a <code> VotePollsAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsVotePollsAssignment() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVotePollsAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.voting.VotePollsAssignmentSession getVotePollsAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for managing dynamic vote polls. 
     *
     *  @param  pollsId the <code> Id </code> of the polls 
     *  @return a <code> VoteSmartPollsSession </code> 
     *  @throws org.osid.NotFoundException <code> pollsId </code> not found 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsVoteSmartPolls() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVoteSmartPolls() </code> is <code> true. </code> 
     */

    public org.osid.voting.VoteSmartPollsSession getVoteSmartPollsSession(org.osid.id.Id pollsId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the candidate 
     *  lookup service. 
     *
     *  @return <code> a CandidateLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCandidateLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCandidateLookup() </code> is <code> true. </code> 
     */

    public org.osid.voting.CandidateLookupSession getCandidateLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the candidate 
     *  lookup service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the polls 
     *  @return <code> a CandidateLookupSession </code> 
     *  @throws org.osid.NotFoundException <code> pollsId </code> not found 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCandidateLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCandidateLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.voting.CandidateLookupSession getCandidateLookupSessionForPolls(org.osid.id.Id pollsId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a candidate query session. 
     *
     *  @return <code> a CandidateQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCandidateQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCandidateQuery() </code> is <code> true. </code> 
     */

    public org.osid.voting.CandidateQuerySession getCandidateQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a candidate query session for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the polls 
     *  @return <code> a CandidateQuerySession </code> 
     *  @throws org.osid.NotFoundException <code> pollsId </code> not found 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCandidateQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCandidateQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.voting.CandidateQuerySession getCandidateQuerySessionForPolls(org.osid.id.Id pollsId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a candidate search session. 
     *
     *  @return <code> a CandidateSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCandidateSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCandidateSearch() </code> is <code> true. </code> 
     */

    public org.osid.voting.CandidateSearchSession getCandidateSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a candidate search session for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the polls 
     *  @return <code> a CandidateSearchSession </code> 
     *  @throws org.osid.NotFoundException <code> pollsId </code> not found 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCandidateSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCandidateSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.voting.CandidateSearchSession getCandidateSearchSessionForPolls(org.osid.id.Id pollsId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets a candidate administration session for creating, updating and 
     *  deleting candidates. 
     *
     *  @return <code> a CandidateAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCandidateAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCandidateAdmin() </code> is <code> true. </code> 
     */

    public org.osid.voting.CandidateAdminSession getCandidateAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a candidate administration session for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the polls 
     *  @return <code> a CandidateAdminSession </code> 
     *  @throws org.osid.NotFoundException <code> pollsId </code> not found 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCandidateAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCandidateAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.voting.CandidateAdminSession getCandidateAdminSessionForPolls(org.osid.id.Id pollsId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the notification session for notifications pertaining to 
     *  candidate changes. 
     *
     *  @param  candidateReceiver the notification callback 
     *  @return <code> a CandidateNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> candidateReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCandidateNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCandidateNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.voting.CandidateNotificationSession getCandidateNotificationSession(org.osid.voting.CandidateReceiver candidateReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the candidate notification session for the given polls. 
     *
     *  @param  candidateReceiver the notification callback 
     *  @param  pollsId the <code> Id </code> of the polls 
     *  @return <code> a CandidateNotificationSession </code> 
     *  @throws org.osid.NotFoundException <code> pollsId </code> not found 
     *  @throws org.osid.NullArgumentException <code> candidateReceiver 
     *          </code> or <code> pollsId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException <code> unable to complete 
     *          request </code> 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCandidateNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCandidateNotfication() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.voting.CandidateNotificationSession getCandidateNotificationSessionForPolls(org.osid.voting.CandidateReceiver candidateReceiver, 
                                                                                                org.osid.id.Id pollsId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving candidate to polls mappings. 
     *
     *  @return a <code> CandidatePollsSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCandidatePolls() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCandidatePolls() </code> is <code> true. </code> 
     */

    public org.osid.voting.CandidatePollsSession getCandidatePollsSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning candidate to polls mappings. 
     *
     *  @return a <code> CandidatePollsAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCandidatePollsAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCandidatePollsAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.voting.CandidatePollsAssignmentSession getCandidatePollsAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for managing dynamic candidate polls. 
     *
     *  @param  pollsId the <code> Id </code> of the polls 
     *  @return a <code> CandidateSmartPollsSession </code> 
     *  @throws org.osid.NotFoundException <code> pollsId </code> not found 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsCandidateSmartPolls() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsCandidateSmartPolls() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.voting.CandidateSmartPollsSession getCandidateSmartPollsSession(org.osid.id.Id pollsId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race lookup 
     *  service. 
     *
     *  @return a <code> RaceLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRaceLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceLookup() </code> is <code> true. </code> 
     */

    public org.osid.voting.RaceLookupSession getRaceLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race lookup 
     *  service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @return a <code> RaceLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRaceLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.voting.RaceLookupSession getRaceLookupSessionForPolls(org.osid.id.Id pollsId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race query 
     *  service. 
     *
     *  @return a <code> RaceQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRaceQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceQuery() </code> is <code> true. </code> 
     */

    public org.osid.voting.RaceQuerySession getRaceQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race query 
     *  service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @return a <code> RaceQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRaceQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.voting.RaceQuerySession getRaceQuerySessionForPolls(org.osid.id.Id pollsId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race search 
     *  service. 
     *
     *  @return a <code> RaceSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRaceSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceSearch() </code> is <code> true. </code> 
     */

    public org.osid.voting.RaceSearchSession getRaceSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race search 
     *  service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @return a <code> RaceSearchSession </code> 
     *  @throws org.osid.NotFoundException no polls found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supporstRaceSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.voting.VoteSearchSession getRaceSearchSessionForPolls(org.osid.id.Id pollsId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race 
     *  administration service. 
     *
     *  @return a <code> RaceAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRaceAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceAdmin() </code> is <code> true. </code> 
     */

    public org.osid.voting.RaceAdminSession getRaceAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race 
     *  administration service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @return a <code> RaceAdminSession </code> 
     *  @throws org.osid.NotFoundException no polls found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRaceAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.voting.RaceAdminSession getRaceAdminSessionForPolls(org.osid.id.Id pollsId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race 
     *  notification service. 
     *
     *  @param  raceReceiver the notification callback 
     *  @return a <code> RaceNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> raceReceiver </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceNotification() </code> is <code> true. </code> 
     */

    public org.osid.voting.RaceNotificationSession getRaceNotificationSession(org.osid.voting.RaceReceiver raceReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race 
     *  notification service for the given polls. 
     *
     *  @param  raceReceiver the notification callback 
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @return a <code> RaceNotificationSession </code> 
     *  @throws org.osid.NotFoundException no polls found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> raceReceiver </code> or 
     *          <code> pollsId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.voting.RaceNotificationSession getRaceNotificationSessionForPolls(org.osid.voting.RaceReceiver raceReceiver, 
                                                                                      org.osid.id.Id pollsId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving race to polls mappings. 
     *
     *  @return a <code> RacePollsSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRacePolls() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRacePolls() </code> is <code> true. </code> 
     */

    public org.osid.voting.RacePollsSession getRacePollsSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning race to polls mappings. 
     *
     *  @return a <code> RacePollsAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRacePollsAssignment() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRacePollsAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.voting.RacePollsAssignmentSession getRacePollsAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for managing dynamic race polls. 
     *
     *  @param  pollsId the <code> Id </code> of the polls 
     *  @return a <code> RaceSmartPollsSession </code> 
     *  @throws org.osid.NotFoundException <code> pollsId </code> not found 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceSmartPolls() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceSmartPolls() </code> is <code> true. </code> 
     */

    public org.osid.voting.RaceSmartPollsSession getRaceSmartPollsSession(org.osid.id.Id pollsId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the ballot lookup 
     *  service. 
     *
     *  @return a <code> BallotLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBallotLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotLookup() </code> is <code> true. </code> 
     */

    public org.osid.voting.BallotLookupSession getBallotLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the ballot lookup 
     *  service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @return a <code> BallotLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBallotLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.voting.BallotLookupSession getBallotLookupSessionForPolls(org.osid.id.Id pollsId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the ballot query 
     *  service. 
     *
     *  @return a <code> BallotQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBallotQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotQuery() </code> is <code> true. </code> 
     */

    public org.osid.voting.BallotQuerySession getBallotQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the ballot query 
     *  service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @return a <code> BallotQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBallotQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.voting.BallotQuerySession getBallotQuerySessionForPolls(org.osid.id.Id pollsId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the ballot search 
     *  service. 
     *
     *  @return a <code> RaceSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsRaceSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotSearch() </code> is <code> true. </code> 
     */

    public org.osid.voting.BallotSearchSession getBallotSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the ballot search 
     *  service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @return a <code> BallotSearchSession </code> 
     *  @throws org.osid.NotFoundException no polls found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supporstBallotSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.voting.BallotSearchSession getBallotSearchSessionForPolls(org.osid.id.Id pollsId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the ballot 
     *  administration service. 
     *
     *  @return a <code> BallotAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBallotAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotAdmin() </code> is <code> true. </code> 
     */

    public org.osid.voting.BallotAdminSession getBallotAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the ballot 
     *  administration service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @return a <code> BallotAdminSession </code> 
     *  @throws org.osid.NotFoundException no polls found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBallotAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.voting.BallotAdminSession getBallotAdminSessionForPolls(org.osid.id.Id pollsId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the ballot 
     *  notification service. 
     *
     *  @param  ballotReceiver the notification callback 
     *  @return a <code> BallotNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> ballotReceiver </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBallotNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.voting.BallotNotificationSession getBallotNotificationSession(org.osid.voting.BallotReceiver ballotReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the ballot 
     *  notification service for the given polls. 
     *
     *  @param  ballotReceiver the notification callback 
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @return a <code> BallotNotificationSession </code> 
     *  @throws org.osid.NotFoundException no polls found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> ballotReceiver </code> 
     *          or <code> pollsId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBallotNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.voting.BallotNotificationSession getBallotNotificationSessionForPolls(org.osid.voting.BallotReceiver ballotReceiver, 
                                                                                          org.osid.id.Id pollsId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the session for retrieving ballot to polls mappings. 
     *
     *  @return a <code> BallotPollsSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsBallotPolls() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotPolls() </code> is <code> true. </code> 
     */

    public org.osid.voting.BallotPollsSession getBallotPollsSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for assigning ballot to polls mappings. 
     *
     *  @return a <code> BallotPollsAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBallotPollsAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotPollsAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.voting.BallotPollsAssignmentSession getBallotPollsAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the session for managing dynamic ballot polls. 
     *
     *  @param  pollsId the <code> Id </code> of the polls 
     *  @return a <code> BallotSmartPollsSession </code> 
     *  @throws org.osid.NotFoundException <code> pollsId </code> not found 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBallotSmartPolls() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotSmartPolls() </code> is <code> true. </code> 
     */

    public org.osid.voting.BallotSmartPollsSession getBallotSmartPollsSession(org.osid.id.Id pollsId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the polls lookup session. 
     *
     *  @return a <code> PollsLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPollsLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPollsLookup() </code> is <code> true. </code> 
     */

    public org.osid.voting.PollsLookupSession getPollsLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the polls query session. 
     *
     *  @return a <code> PollsQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPollsQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPollsQuery() </code> is <code> true. </code> 
     */

    public org.osid.voting.PollsQuerySession getPollsQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the polls search session. 
     *
     *  @return a <code> PollsSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPollsSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPollsSearch() </code> is <code> true. </code> 
     */

    public org.osid.voting.PollsSearchSession getPollsSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the polls administrative session for creating, updating and 
     *  deleteing polls. 
     *
     *  @return a <code> PollsAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsPollsAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPollsAdmin() </code> is <code> true. </code> 
     */

    public org.osid.voting.PollsAdminSession getPollsAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the notification session for subscripollsg to changes to a polls. 
     *
     *  @param  pollsReceiver the notification callback 
     *  @return a <code> PollsNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> pollsReceiver </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPollsNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPollsNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.voting.PollsNotificationSession getPollsNotificationSession(org.osid.voting.PollsReceiver pollsReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the polls hierarchy traversal session. 
     *
     *  @return <code> a PollsHierarchySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPollsHierarchy() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPollsHierarchy() </code> is <code> true. </code> 
     */

    public org.osid.voting.PollsHierarchySession getPollsHierarchySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the polls hierarchy design session. 
     *
     *  @return a <code> PollsHierarchyDesignSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsPollsHierarchyDesign() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPollsHierarchyDesign() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.voting.PollsHierarchyDesignSession getPollsHierarchyDesignSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a <code> VotingBatchManager. </code> 
     *
     *  @return a <code> VotingBatchManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsVotingBatch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVotingBatch() </code> is <code> true. </code> 
     */

    public org.osid.voting.batch.VotingBatchManager getVotingBatchManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a <code> VotingRulesManager. </code> 
     *
     *  @return a <code> VotingRulesManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsVotingRules() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsVotingRules() </code> is <code> true. </code> 
     */

    public org.osid.voting.rules.VotingRulesManager getVotingRulesManager()
        throws org.osid.OperationFailedException;
}
