//
// org.osid.voting.VotingSession
//
//     The OSID Java specification for org.osid.voting.VotingSession.
//
// Copyright (C) 2010 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting;


/**
 *  <p>This session provides methods for voting on a ballot. </p>
 */

public interface VotingSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Polls </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Polls Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPollsId();


    /**
     *  Gets the <code> Polls </code> associated with this session. 
     *
     *  @return the polls 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.Polls getPolls()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this ballot is open. 
     *
     *  @return <code> true </code> if the ballot is open, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean isOpen();


    /**
     *  Tests if this user can vote. A return of true does not guarantee 
     *  successful authorization. A return of false indicates that it is known 
     *  all methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer relationship operations. 
     *
     *  @return <code> false </code> if voting methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canVote();


    /**
     *  Gets a race. 
     *
     *  @param  raceId <code> Id </code> of the <code> Race </code> 
     *  @return the race 
     *  @throws org.osid.NotFoundException <code> raceId </code> not found 
     *  @throws org.osid.NullArgumentException <code> raceId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.voting.Race getRace(org.osid.id.Id raceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Races </code> on this ballot. 
     *
     *  @param  ballotId <code> Id </code> of the <code> Ballot </code> 
     *  @return the races 
     *  @throws org.osid.NotFoundException <code> ballotId </code> not found 
     *  @throws org.osid.NullArgumentException <code> ballotId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.RaceList getRacesForBallot(org.osid.id.Id ballotId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> Races </code> on this ballot for which a vote has not 
     *  been cast. 
     *
     *  @param  ballotId <code> Id </code> of the <code> Ballot </code> 
     *  @return the uncast races 
     *  @throws org.osid.NotFoundException <code> ballotId </code> not found 
     *  @throws org.osid.NullArgumentException <code> ballotId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.RaceList getMyUncastRacesForBallot(org.osid.id.Id ballotId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create a single <code> Vote </code> using the 
     *  desired record interface types. While <code> 
     *  VotingManager.getVoteRecordTypes() </code> can be used to examine 
     *  which records are supported, this method tests which record(s) are 
     *  required for creating a specific <code> Vote. </code> Providing an 
     *  empty array tests if an <code> Vote </code> can be created with no 
     *  records. 
     *
     *  @param  raceId a race <code> Id </code> 
     *  @param  voteRecordTypes array of vote record types 
     *  @return <code> true </code> if <code> Vote </code> creation using the 
     *          specified record <code> Types </code> is supported, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> ballotId </code> or 
     *          <code> voteRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canVoteWithRecordTypes(org.osid.id.Id raceId, 
                                          org.osid.type.Type[] voteRecordTypes);


    /**
     *  Gets the voter allocation for a race. 
     *
     *  @param  raceId <code> Id </code> of the <code> Race </code> 
     *  @return the allocation 
     *  @throws org.osid.NotFoundException <code> raceId </code> not found 
     *  @throws org.osid.NullArgumentException <code> raceId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.voting.VoterAllocation getVotingAllocation(org.osid.id.Id raceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a vote form for a race. 
     *
     *  @param  raceId <code> Id </code> of the <code> Race </code> 
     *  @param  candidateId a candidate 
     *  @param  voteRecordTypes array of vote record types 
     *  @return the race 
     *  @throws org.osid.NotFoundException <code> raceId </code> or <code> 
     *          candidateId </code> not found 
     *  @throws org.osid.NullArgumentException <code> raceId, candidateId, 
     *          </code> or <code> voteRecordTypes </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException cannot get form with requested 
     *          record types 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.voting.VoteForm getVoteForm(org.osid.id.Id raceId, 
                                                org.osid.id.Id candidateId, 
                                                org.osid.type.Type[] voteRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Votes for a candidate in a race. 
     *
     *  @param  voteForm the vote form 
     *  @return the vote 
     *  @throws org.osid.IllegalStateException <code> voteForm </code> already 
     *          used in a voting transaction 
     *  @throws org.osid.InvalidArgumentException form is invalid 
     *  @throws org.osid.NullArgumentException <code> voteForm </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> voteForm </code> did not 
     *          originate from <code> getVoteForm() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.Vote vote(org.osid.voting.VoteForm voteForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all my <code> Votes </code> cast on a ballot. 
     *
     *  @param  ballotId a ballot 
     *  @return the votes 
     *  @throws org.osid.NotFoundException <code> ballotId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> ballotId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.VoteList getMyVotesForBallot(org.osid.id.Id ballotId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all my <code> Votes </code> cast on this ballot for the given 
     *  race. 
     *
     *  @param  raceId a race 
     *  @return the votes 
     *  @throws org.osid.NotFoundException <code> raceId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> raceId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.VoteList getMyVotesForRace(org.osid.id.Id raceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can change a vote by deleting a vote and voting 
     *  again. 
     *
     *  @param  ballotId a ballot 
     *  @return <code> true </code> if changing a vote is permitted, <code> 
     *          false </code> otherwise 
     *  @throws org.osid.NotFoundException <code> ballotId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> ballotId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRevote(org.osid.id.Id ballotId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes a vote in a race. 
     *
     *  @param  voteId a vote 
     *  @throws org.osid.IllegalStateException <code> canRevote() </code> is 
     *          <code> false </code> 
     *  @throws org.osid.NotFoundException <code> voteId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> voteId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteMyVote(org.osid.id.Id voteId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
