//
// org.osid.voting.batch.BallotBatchAdminSession
//
//     The OSID Java specification for org.osid.voting.batch.BallotBatchAdminSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Ballots </code> in 
 *  bulk. The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Ballot, </code> a <code> BallotForm </code> is requested using <code> 
 *  getBallotFormsForCreate() </code> specifying the desired record <code> 
 *  Types </code> or none if no record <code> Types </code> are needed. Each 
 *  of the returned <code> BallotForms </code> will indicate that it is to be 
 *  used with a create operation and can be used to examine metdata or 
 *  validate data prior to creation. Once a <code> BallotForm </code> is 
 *  submiited to a create operation, it cannot be reused with another create 
 *  operation unless the first operation was unsuccessful. Each <code> 
 *  BallotForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> BallotForms </code> returned from <code> 
 *  getBallotFormsForCreate() </code> may be linked to the originating request 
 *  through the peer <code> Ids </code> of the <code> BallotForm. </code> In 
 *  the case where there may be duplicates, any <code> BallotForm </code> of 
 *  the same peer <code> Ids </code> may be used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> BallotForms </code> are submitted for create, a 
 *  <code> CreateResponse </code> is returned for each <code> BallotForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire create operation are returned from <code> createBallots(), 
 *  </code> errors specific to an individual <code> BallotForm </code> are 
 *  indicated in the corresponding <code> CreateResponse. </code> <code> 
 *  CreateResponses </code> may be linked to the originating <code> BallotForm 
 *  </code> through the <code> BallotForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> BallotForms </code> are requested to the <code> 
 *  Ballot </code> <code> Id </code> that is to be updated using <code> 
 *  getBallotFormsForUpdate() </code> where the reference <code> Id </code> in 
 *  the <code> BallotForm </code> may be used to link the request. Similarly, 
 *  the <code> BallotForm </code> has metadata about the data that can be 
 *  updated and it can perform validation before submitting the update. The 
 *  <code> BallotForm </code> can only be used once for a successful update 
 *  and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> BallotForms </code> are submitted for update, 
 *  an <code> UpdateResponse </code> is returned for each <code> BallotForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire update operation are returned from <code> updateBallots(), 
 *  </code> errors specific to an individual <code> BallotForm </code> are 
 *  indicated in the corresponding <code> UpdateResponse. </code> <code> 
 *  UpdateResponses </code> may be linked to the originating <code> BallotForm 
 *  </code> through the <code> BallotForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Ballots </code> in bulk. To unmap 
 *  a <code> Ballot </code> from the current <code> Polls, </code> the <code> 
 *  BallotPollsAssignmentSession </code> should be used. These delete 
 *  operations attempt to remove the <code> Ballot </code> itself thus 
 *  removing it from all known <code> Polls </code> catalogs. Bulk delete 
 *  operations return the results in <code> DeleteResponses. </code> </p>
 */

public interface BallotBatchAdminSession
    extends org.osid.voting.BallotAdminSession {


    /**
     *  Gets the ballot forms for creating a bunch of new ballots. 
     *
     *  @param  number the number of forms to retrieve 
     *  @param  ballotRecordTypes array of ballot record types to be included 
     *          in each create operation or an empty list if none 
     *  @return the ballot forms 
     *  @throws org.osid.NullArgumentException <code> ballotRecordTypes 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.batch.BallotBatchFormList getBallotFormsForCreate(long number, 
                                                                             org.osid.type.Type[] ballotRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Ballots. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  ballotForms the ballot forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> ballotForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createBallots(org.osid.voting.batch.BallotBatchFormList ballotForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the ballot forms for updating an existing set of ballots. A new 
     *  ballot form should be requested for each update transaction. 
     *
     *  @param  ballotIds the <code> Ids </code> of the <code> Ballot </code> 
     *  @return the ballot form 
     *  @throws org.osid.NotFoundException a <code> ballotId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> ballotIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.batch.BallotBatchFormList getBallotFormsForUpdate(org.osid.id.IdList ballotIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing ballots. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  ballotForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> ballotForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateBallots(org.osid.voting.batch.BallotBatchFormList ballotForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Ballots </code> in this <code> Polls </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllBallots()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes ballots for the given <code> Ids. </code> 
     *
     *  @param  ballotIds the <code> Ids </code> of the ballots to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> ballotIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteBallots(org.osid.id.IdList ballotIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Ballot </code> for the purpose 
     *  of creating compatibility. The primary <code> Id </code> of the <code> 
     *  Ballot </code> is determined by the provider. The new <code> Id 
     *  </code> is an alias to the primary <code> Id. </code> If the alias is 
     *  a pointer to another ballot, it is reassigned to the given ballot 
     *  <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasBallots(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
