//
// org.osid.voting.batch.CandidateBatchAdminSession
//
//     The OSID Java specification for org.osid.voting.batch.CandidateBatchAdminSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Candidates </code> in 
 *  bulk. The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Candidate, </code> a <code> CandidateForm </code> is requested using 
 *  <code> getCandidateFormsForCreate() </code> specifying the desired race, 
 *  resource, and record <code> Types </code> or none if no record <code> 
 *  Types </code> are needed. Each of the returned <code> CandidateForms 
 *  </code> will indicate that it is to be used with a create operation and 
 *  can be used to examine metdata or validate data prior to creation. Once a 
 *  <code> CandidateForm </code> is submiited to a create operation, it cannot 
 *  be reused with another create operation unless the first operation was 
 *  unsuccessful. Each <code> CandidateForm </code> corresponds to an 
 *  attempted transaction. </p> 
 *  
 *  <p> The <code> CandidateForms </code> returned from <code> 
 *  getCandidateFormsForCreate() </code> may be linked to the originating 
 *  request through the peer <code> Ids </code> of the <code> CandidateForm. 
 *  </code> In the case where there may be duplicates, any <code> 
 *  CandidateForm </code> of the same peer <code> Ids </code> may be used for 
 *  a create operation. </p> 
 *  
 *  <p> Once a batch of <code> CandidateForms </code> are submitted for 
 *  create, a <code> CreateResponse </code> is returned for each <code> 
 *  CandidateForm, </code> although the ordering is not defined. Only errors 
 *  that pertain to the entire create operation are returned from <code> 
 *  createCandidates(), </code> errors specific to an individual <code> 
 *  CandidateForm </code> are indicated in the corresponding <code> 
 *  CreateResponse. </code> <code> CreateResponses </code> may be linked to 
 *  the originating <code> CandidateForm </code> through the <code> 
 *  CandidateForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> CandidateForms </code> are requested to the <code> 
 *  Candidate </code> <code> Id </code> that is to be updated using <code> 
 *  getCandidateFormsForUpdate() </code> where the reference <code> Id </code> 
 *  in the <code> CandidateForm </code> may be used to link the request. 
 *  Similarly, the <code> CandidateForm </code> has metadata about the data 
 *  that can be updated and it can perform validation before submitting the 
 *  update. The <code> CandidateForm </code> can only be used once for a 
 *  successful update and cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> CandidateForms </code> are submitted for 
 *  update, an <code> UpdateResponse </code> is returned for each <code> 
 *  CandidateForm, </code> although the ordering is not defined. Only errors 
 *  that pertain to the entire update operation are returned from <code> 
 *  updateCandidates(), </code> errors specific to an individual <code> 
 *  CandidateForm </code> are indicated in the corresponding <code> 
 *  UpdateResponse. </code> <code> UpdateResponses </code> may be linked to 
 *  the originating <code> CandidateForm </code> through the <code> 
 *  CandidateForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Candidates </code> in bulk. To 
 *  unmap a <code> Candidate </code> from the current <code> Polls, </code> 
 *  the <code> CandidatePollsAssignmentSession </code> should be used. These 
 *  delete operations attempt to remove the <code> Candidate </code> itself 
 *  thus removing it from all known <code> Polls </code> catalogs. Bulk delete 
 *  operations return the results in <code> DeleteResponses. </code> </p>
 */

public interface CandidateBatchAdminSession
    extends org.osid.voting.CandidateAdminSession {


    /**
     *  Gets the candidate forms for creating a bunch of new candidates. A 
     *  candidate form is returned for each supplied race and resource pair. 
     *
     *  @param  peers the candidate peers 
     *  @param  candidateRecordTypes array of candidate record types to be 
     *          included in each create operation or an empty list if none 
     *  @return the candidate forms 
     *  @throws org.osid.NotFoundException a <code> resourceId </code> or 
     *          <code> raceId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> peers </code> or <code> 
     *          candidateRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.batch.CandidateBatchFormList getCandidateFormsForCreate(org.osid.voting.batch.CandidatePeerList peers, 
                                                                                   org.osid.type.Type[] candidateRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Candidates. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  candidateForms the candidate forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> candidateForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createCandidates(org.osid.voting.batch.CandidateBatchFormList candidateForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the candidate forms for updating an existing set of candidates. A 
     *  new candidate form should be requested for each update transaction. 
     *
     *  @param  candidateIds the <code> Ids </code> of the <code> Candidate 
     *          </code> 
     *  @return the candidate form 
     *  @throws org.osid.NotFoundException a <code> candidateId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> candidateIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.batch.CandidateBatchFormList getCandidateFormsForUpdate(org.osid.id.IdList candidateIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing candidates. This method returns an error if the 
     *  entire operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  candidateForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> candidateForms </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateCandidates(org.osid.voting.batch.CandidateBatchFormList candidateForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Candidates </code> in this <code> Polls </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllCandidates()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes candidates for the given <code> Ids. </code> 
     *
     *  @param  candidateIds the <code> Ids </code> of the candidates to 
     *          delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> candidateIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteCandidates(org.osid.id.IdList candidateIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes candidates for the given race. 
     *
     *  @param  raceId the <code> Ids </code> of a race 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> raceId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteCandidatesForRace(org.osid.id.Id raceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes candidates for the given resource. 
     *
     *  @param  resourceId the <code> Ids </code> of a resource 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteCandidatesForResource(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes candidates ineffective before the given date. 
     *
     *  @param  date a date 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> date </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteIneffectiveCandidatesByDate(org.osid.calendaring.DateTime date)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Candidate </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> Candidate </code> is determined by the provider. The new 
     *  <code> Id </code> is an alias to the primary <code> Id. </code> If the 
     *  alias is a pointer to another candidate, it is reassigned to the given 
     *  candidate <code> Id. </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasCandidates(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
