//
// org.osid.voting.rules.BallotConstrainerAdminSession
//
//     The OSID Java specification for org.osid.voting.rules.BallotConstrainerAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting.rules;


/**
 *  <p>This session creates and removes ballot constrainers. The data for 
 *  create and update is provided via the <code> BallotConstrainerForm. 
 *  </code> </p>
 */

public interface BallotConstrainerAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Polls </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Polls Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPollsId();


    /**
     *  Gets the <code> Polls </code> associated with this session. 
     *
     *  @return the polls 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.Polls getPolls()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create ballot constrainers. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known creating a <code> BallotConstrainer </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer create operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> BallotConstrainer </code> 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateBallotConstrainer();


    /**
     *  Tests if this user can create a single <code> BallotConstrainer 
     *  </code> using the desired record types. While <code> 
     *  VotingRulesManager.getBallotConstrainerRecordTypes() </code> can be 
     *  used to examine which records are supported, this method tests which 
     *  record(s) are required for creating a specific <code> 
     *  BallotConstrainer. </code> Providing an empty array tests if a <code> 
     *  BallotConstrainer </code> can be created with no records. 
     *
     *  @param  ballotConstrainerRecordTypes array of ballot constrainer 
     *          record types 
     *  @return <code> true </code> if <code> BallotConstrainer </code> 
     *          creation using the specified record <code> Types </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          ballotConstrainerRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateBallotConstrainerWithRecordTypes(org.osid.type.Type[] ballotConstrainerRecordTypes);


    /**
     *  Gets the ballot constrainer form for creating new ballot constrainers. 
     *  A new form should be requested for each create transaction. 
     *
     *  @param  ballotConstrainerRecordTypes array of ballot constrainer 
     *          record types 
     *  @return the ballot constrainer form 
     *  @throws org.osid.NullArgumentException <code> 
     *          ballotConstrainerRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.rules.BallotConstrainerForm getBallotConstrainerFormForCreate(org.osid.type.Type[] ballotConstrainerRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> BallotConstrainer. </code> 
     *
     *  @param  ballotConstrainerForm the form for this <code> 
     *          BallotConstrainer </code> 
     *  @return the new <code> BallotConstrainer </code> 
     *  @throws org.osid.IllegalStateException <code> ballotConstrainerForm 
     *          </code> already used for a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> ballotConstrainerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> ballotConstrainerForm 
     *          </code> did not originate from <code> 
     *          getBallotConstrainerFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.rules.BallotConstrainer createBallotConstrainer(org.osid.voting.rules.BallotConstrainerForm ballotConstrainerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update ballot constrainers. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known updating a <code> BallotConstrainer </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer update operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> BallotConstrainer </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateBallotConstrainers();


    /**
     *  Gets the ballot constrainer form for updating an existing ballot 
     *  constrainer. A new ballot constrainer form should be requested for 
     *  each update transaction. 
     *
     *  @param  ballotConstrainerId the <code> Id </code> of the <code> 
     *          BallotConstrainer </code> 
     *  @return the ballot constrainer form 
     *  @throws org.osid.NotFoundException <code> ballotConstrainerId </code> 
     *          is not found 
     *  @throws org.osid.NullArgumentException <code> ballotConstrainerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.rules.BallotConstrainerForm getBallotConstrainerFormForUpdate(org.osid.id.Id ballotConstrainerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing ballot constrainer. 
     *
     *  @param  ballotConstrainerForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> ballotConstrainerForm 
     *          </code> already used for an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> ballotConstrainerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> ballotConstrainerForm 
     *          </code> did not originate from <code> 
     *          getBallotConstrainerFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateBallotConstrainer(org.osid.voting.rules.BallotConstrainerForm ballotConstrainerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete ballot constrainers. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known deleting a <code> BallotConstrainer </code> 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer delete operations 
     *  to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> BallotConstrainer </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteBallotConstrainers();


    /**
     *  Deletes a <code> BallotConstrainer. </code> 
     *
     *  @param  ballotConstrainerId the <code> Id </code> of the <code> 
     *          BallotConstrainer </code> to remove 
     *  @throws org.osid.NotFoundException <code> ballotConstrainerId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> ballotConstrainerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteBallotConstrainer(org.osid.id.Id ballotConstrainerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for ballot 
     *  constrainers. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> BallotConstrainer </code> 
     *          aliasing is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageBallotConstrainerAliases();


    /**
     *  Adds an <code> Id </code> to a <code> BallotConstrainer </code> for 
     *  the purpose of creating compatibility. The primary <code> Id </code> 
     *  of the <code> BallotConstrainer </code> is determined by the provider. 
     *  The new <code> Id </code> performs as an alias to the primary <code> 
     *  Id </code> . If the alias is a pointer to another ballot constrainer. 
     *  it is reassigned to the given ballot constrainer <code> Id. </code> 
     *
     *  @param  ballotConstrainerId the <code> Id </code> of a <code> 
     *          BallotConstrainer </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> ballotConstrainerId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> ballotConstrainerId 
     *          </code> or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasBallotConstrainer(org.osid.id.Id ballotConstrainerId, 
                                       org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
