//
// org.osid.voting.rules.BallotConstrainerEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.voting.rules.BallotConstrainerEnablerRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting.rules;


/**
 *  <p>This session provides methods to apply <code> BallotConstrainerEnablers 
 *  </code> to <code> BallotConstrainers. </code> A <code> BallotConstrainer 
 *  </code> with multiple <code> BallotConstrainerEnablers </code> means any 
 *  positive rule evaluation across the enablers result in an effective <code> 
 *  BallotConstrainer. </code> </p>
 */

public interface BallotConstrainerEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Polls </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Polls Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPollsId();


    /**
     *  Gets the <code> Polls </code> associated with this session. 
     *
     *  @return the polls 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.Polls getPolls()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter ballot constrainer enabler/ballot 
     *  constrainer mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known mapping 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignBallotConstrainerEnablers();


    /**
     *  Adds an existing <code> BallotConstrainerEnabler </code> to a <code> 
     *  BallotConstrainer. </code> 
     *
     *  @param  ballotConstrainerEnablerId the <code> Id </code> of the <code> 
     *          BallotConstrainerEnabler </code> 
     *  @param  ballotConstrainerId the <code> Id </code> of the <code> 
     *          BallotConstrainer </code> 
     *  @throws org.osid.AlreadyExistsException <code> 
     *          ballotConstrainerEnablerId </code> is already applied to 
     *          <code> ballotConstrainerId </code> 
     *  @throws org.osid.NotFoundException <code> ballotConstrainerEnablerId 
     *          </code> or <code> ballotConstrainerId </code> not found 
     *  @throws org.osid.NullArgumentException <code> 
     *          ballotConstrainerEnablerId </code> or <code> 
     *          ballotConstrainerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignBallotConstrainerEnablerToBallotConstrainer(org.osid.id.Id ballotConstrainerEnablerId, 
                                                                  org.osid.id.Id ballotConstrainerId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> BallotConstrainerEnabler </code> from a <code> 
     *  BallotConstrainer. </code> 
     *
     *  @param  ballotConstrainerEnablerId the <code> Id </code> of the <code> 
     *          BallotConstrainerEnabler </code> 
     *  @param  ballotConstrainerId the <code> Id </code> of the <code> 
     *          BallotConstrainer </code> 
     *  @throws org.osid.NotFoundException <code> ballotConstrainerEnablerId 
     *          </code> or <code> ballotConstrainerId </code> not found or 
     *          <code> ballotConstrainerEnablerId </code> not applied to 
     *          <code> ballotConstrainerId </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          ballotConstrainerEnablerId </code> or <code> 
     *          ballotConstrainerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignBallotConstrainerEnablerFromBallotConstrainer(org.osid.id.Id ballotConstrainerEnablerId, 
                                                                      org.osid.id.Id ballotConstrainerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> BallotConstrainerEnablers. </code> 
     *  A return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known sequencing operations will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> BallotConstrainerEnabler 
     *          </code> ordering is not authorized, <code> true </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceBallotConstrainerEnablers();


    /**
     *  Reorders ballot constrainer enablers for a ballot constrainer by 
     *  moving the specified ballot constrainer enabler in front of a 
     *  reference ballot constrainer enabler. 
     *
     *  @param  ballotConstrainerEnablerId the <code> Id </code> of a <code> 
     *          BallotConstrainerEnabler </code> 
     *  @param  ballotConstrainerId the <code> Id </code> of a <code> 
     *          BallotConstrainer </code> 
     *  @param  referenceId the reference ballot constrainer enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> ballotConstrainerEnablerId, 
     *          ballotConstrainerId, </code> or <code> referenceId </code> not 
     *          found or, <code> ballotConstrainerId </code> or <code> 
     *          referenceId </code> not related to <code> ballotConstrainerId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          ballotConstrainerEnablerId, ballotConstrainerId, </code> or 
     *          <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveBallotConstrainerEnablerAhead(org.osid.id.Id ballotConstrainerEnablerId, 
                                                  org.osid.id.Id ballotConstrainerId, 
                                                  org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders ballot constrainer enablers for a ballot constrainer by 
     *  moving the specified ballot constrainer enabler behind a reference 
     *  ballot constrainer enabler. 
     *
     *  @param  ballotConstrainerEnablerId the <code> Id </code> of a <code> 
     *          BallotConstrainerEnabler </code> 
     *  @param  ballotConstrainerId the <code> Id </code> of a <code> 
     *          BallotConstrainer </code> 
     *  @param  referenceId the reference ballot constrainer enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> ballotConstrainerEnablerId, 
     *          ballotConstrainerId, </code> or <code> referenceId </code> not 
     *          found or, <code> ballotConstrainerId </code> or <code> 
     *          referenceId </code> not related to <code> ballotConstrainerId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          ballotConstrainerEnablerId, ballotConstrainerId, </code> or 
     *          <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveBallotConstrainerEnablerBehind(org.osid.id.Id ballotConstrainerEnablerId, 
                                                   org.osid.id.Id ballotConstrainerId, 
                                                   org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of ballot constrainer enablers for a ballot 
     *  constrainer. 
     *
     *  @param  ballotConstrainerEnablerIds the <code> Ids </code> for a set 
     *          of <code> BallotConstrainerEnablers </code> 
     *  @param  ballotConstrainerId the <code> Id </code> of a <code> 
     *          BallotConstrainer </code> 
     *  @throws org.osid.NotFoundException <code> ballotConstrainerId </code> 
     *          not found or, a <code> ballotConstrainerEnablerId </code> not 
     *          related to <code> ballotConstrainerId </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          ballotConstrainerEnablerIds </code> or <code> 
     *          ballotConstrainerId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderBallotConstrainerEnablers(org.osid.id.Id[] ballotConstrainerEnablerIds, 
                                               org.osid.id.Id ballotConstrainerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
