//
// org.osid.voting.rules.BallotConstrainerRuleApplicationSession
//
//     The OSID Java specification for org.osid.voting.rules.BallotConstrainerRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting.rules;


/**
 *  <p>This session provides methods to apply <code> BallotConstrainers 
 *  </code> to <code> Ballots. </code> A <code> Ballot </code> with multiple 
 *  <code> BallotConstrainers </code> means any positive rule evaluation 
 *  across the constrainers result in an accessible <code> Ballot. </code> 
 *  </p>
 */

public interface BallotConstrainerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Polls </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Polls Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPollsId();


    /**
     *  Gets the <code> Polls </code> associated with this session. 
     *
     *  @return the polls 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.Polls getPolls()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter ballot constrainer/ballot mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignBallotConstrainers();


    /**
     *  Adds an existing <code> BallotConstrainer </code> to a <code> Ballot. 
     *  </code> 
     *
     *  @param  ballotConstrainerId the <code> Id </code> of the <code> 
     *          BallotConstrainer </code> 
     *  @param  ballotId the <code> Id </code> of the <code> Ballot </code> 
     *  @throws org.osid.AlreadyExistsException <code> ballotConstrainerId 
     *          </code> is already applied to <code> ballotId </code> 
     *  @throws org.osid.NotFoundException <code> ballotConstrainerId </code> 
     *          or <code> ballotId </code> not found 
     *  @throws org.osid.NullArgumentException <code> ballotConstrainerId 
     *          </code> or <code> ballotId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignBallotConstrainerToBallot(org.osid.id.Id ballotConstrainerId, 
                                                org.osid.id.Id ballotId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> BallotConstrainer </code> from a <code> Ballot. 
     *  </code> 
     *
     *  @param  ballotConstrainerId the <code> Id </code> of the <code> 
     *          BallotConstrainer </code> 
     *  @param  ballotId the <code> Id </code> of the <code> Ballot </code> 
     *  @throws org.osid.NotFoundException <code> ballotConstrainerId </code> 
     *          or <code> ballotId </code> not found or <code> 
     *          ballotConstrainerId </code> not applied to <code> ballotId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> ballotConstrainerId 
     *          </code> or <code> ballotId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignBallotConstrainerFromBallot(org.osid.id.Id ballotConstrainerId, 
                                                    org.osid.id.Id ballotId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> BallotConstrainers. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known sequencing operations will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> BallotConstrainer </code> 
     *          ordering is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceBallotConstrainers();


    /**
     *  Reorders ballot constrainer for a ballot by moving the specified 
     *  ballot constrainer in front of a reference ballot constrainer. 
     *
     *  @param  ballotConstrainerId the <code> Id </code> of a <code> 
     *          BallotConstrainer </code> 
     *  @param  ballotId the <code> Id </code> of a <code> Ballot </code> 
     *  @param  referenceId the reference ballot constrainer <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> ballotConstrainerId, 
     *          ballotId, </code> or <code> referenceId </code> not found or, 
     *          <code> ballotConstrainerId </code> or <code> referenceId 
     *          </code> not related to <code> ballotId </code> 
     *  @throws org.osid.NullArgumentException <code> ballotConstrainerId, 
     *          ballotId, </code> or <code> referenceId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveBallotConstrainerAhead(org.osid.id.Id ballotConstrainerId, 
                                           org.osid.id.Id ballotId, 
                                           org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders ballot constrainer for a ballot by moving the specified 
     *  ballot constrainer behind a reference ballot constrainer. 
     *
     *  @param  ballotConstrainerId the <code> Id </code> of a <code> 
     *          BallotConstrainer </code> 
     *  @param  ballotId the <code> Id </code> of a <code> Ballot </code> 
     *  @param  referenceId the reference ballot constrainer <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> ballotConstrainerId, 
     *          ballotId, </code> or <code> referenceId </code> not found or, 
     *          <code> ballotConstrainerId </code> or <code> referenceId 
     *          </code> not related to <code> ballotId </code> 
     *  @throws org.osid.NullArgumentException <code> ballotConstrainerId, 
     *          ballotId, </code> or <code> referenceId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveBallotConstrainerBehind(org.osid.id.Id ballotConstrainerId, 
                                            org.osid.id.Id ballotId, 
                                            org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of ballot constrainers for a ballot 
     *
     *  @param  ballotConstrainerIds the <code> Ids </code> for a set of 
     *          <code> BallotConstrainer </code> 
     *  @param  ballotId the <code> Id </code> of a <code> Ballot </code> 
     *  @throws org.osid.NotFoundException <code> ballotId </code> not found 
     *          or, a <code> ballotConstrainerId </code> not related to <code> 
     *          ballotId </code> 
     *  @throws org.osid.NullArgumentException <code> ballotConstrainerIds 
     *          </code> or <code> ballotId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderBallotConstrainers(org.osid.id.Id[] ballotConstrainerIds, 
                                        org.osid.id.Id ballotId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
