//
// org.osid.voting.rules.BallotConstrainerSmartPollsSession
//
//     The OSID Java specification for org.osid.voting.rules.BallotConstrainerSmartPollsSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting.rules;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  polls. A <code> BallotConstrainerQuery </code> can be retrieved from this 
 *  session and mapped to this <code> Polls </code> to create a virtual 
 *  collection of ballot constrainers. The ballot constrainer may be sequenced 
 *  using the <code> BallotConstrainerSearchOrder </code> from this session. 
 *  </p> 
 *  
 *  <p> This <code> Polls </code> has a default query that matches any ballot 
 *  constrainer and a default search order that specifies no sequencing. The 
 *  queries may be examined using a <code> BallotConstrainerQueryInspector. 
 *  </code> The query may be modified by converting the inspector back to a 
 *  <code> BallotConstrainerQuery. </code> </p>
 */

public interface BallotConstrainerSmartPollsSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Polls </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Polls Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPollsId();


    /**
     *  Gets the <code> Polls </code> associated with this session. 
     *
     *  @return the polls 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.Polls getPolls()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart polls. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart polls management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartPolls();


    /**
     *  Gets a ballot constrainer query. 
     *
     *  @return the ballot constrainer query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.rules.BallotConstrainerQuery getBallotConstrainerQuery();


    /**
     *  Gets a ballot constrainer search order. 
     *
     *  @return the ballot constrainer search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.rules.BallotConstrainerSearchOrder getBallotConstrainerSearchOrder();


    /**
     *  Applies a ballot constrainer query to this polls. 
     *
     *  @param  ballotConstrainerQuery the ballot constrainer query 
     *  @throws org.osid.NullArgumentException <code> ballotConstrainerQuery 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> ballotConstrainerQuery 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyBallotConstrainerQuery(org.osid.voting.rules.BallotConstrainerQuery ballotConstrainerQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a ballot constrainer query inspector for this polls. 
     *
     *  @return the ballot constrainer query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.rules.BallotConstrainerQueryInspector inspectBallotConstrainerQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a ballot constrainer search order to this polls. 
     *
     *  @param  ballotConstrainerSearchOrder the ballot constrainer search 
     *          order 
     *  @throws org.osid.NullArgumentException <code> 
     *          ballotConstrainerSearchOrder </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          ballotConstrainerSearchOrder </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyBallotConstrainerSequencing(org.osid.voting.rules.BallotConstrainerSearchOrder ballotConstrainerSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a ballot constrainer query from an inspector. 
     *
     *  @param  ballotConstrainerQueryInspector a ballot constrainer query 
     *          inspector 
     *  @return the ballot constrainer query 
     *  @throws org.osid.NullArgumentException <code> 
     *          ballotConstrainerQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          ballotConstrainerQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.rules.BallotConstrainerQuery getBallotConstrainerQueryFromInspector(org.osid.voting.rules.BallotConstrainerQueryInspector ballotConstrainerQueryInspector);
}
