//
// org.osid.voting.rules.RaceConstrainerEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.voting.rules.RaceConstrainerEnablerRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting.rules;


/**
 *  <p>This session provides methods to apply <code> RaceConstrainerEnablers 
 *  </code> to <code> RaceConstrainers. </code> a <code> RaceConstrainer 
 *  </code> with multiple <code> RaceConstrainerEnablers </code> means any 
 *  positive rule evaluation across the enablers result in an effective <code> 
 *  RaceConstrainer. </code> </p>
 */

public interface RaceConstrainerEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Polls </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Polls Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPollsId();


    /**
     *  Gets the <code> Polls </code> associated with this session. 
     *
     *  @return the polls 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.Polls getPolls()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter race constrainer enabler/race constrainer 
     *  mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known mapping 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignRaceConstrainerEnablers();


    /**
     *  Adds an existing <code> RaceConstrainerEnabler </code> to a <code> 
     *  RaceConstrainer. </code> 
     *
     *  @param  raceConstrainerEnablerId the <code> Id </code> of the <code> 
     *          RaceConstrainerEnabler </code> 
     *  @param  raceConstrainerId the <code> Id </code> of the <code> 
     *          RaceConstrainer </code> 
     *  @throws org.osid.AlreadyExistsException <code> 
     *          raceConstrainerEnablerId </code> is already applied to <code> 
     *          raceConstrainerId </code> 
     *  @throws org.osid.NotFoundException <code> raceConstrainerEnablerId 
     *          </code> or <code> raceConstrainerId </code> not found 
     *  @throws org.osid.NullArgumentException <code> raceConstrainerEnablerId 
     *          </code> or <code> raceConstrainerId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignRaceConstrainerEnablerToRaceConstrainer(org.osid.id.Id raceConstrainerEnablerId, 
                                                              org.osid.id.Id raceConstrainerId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> RaceConstrainerEnabler </code> from a <code> 
     *  RaceConstrainer. </code> 
     *
     *  @param  raceConstrainerEnablerId the <code> Id </code> of the <code> 
     *          RaceConstrainerEnabler </code> 
     *  @param  raceConstrainerId the <code> Id </code> of the <code> 
     *          RaceConstrainer </code> 
     *  @throws org.osid.NotFoundException <code> raceConstrainerEnablerId 
     *          </code> or <code> raceConstrainerId </code> not found or 
     *          <code> raceConstrainerEnablerId </code> not applied to <code> 
     *          raceConstrainerId </code> 
     *  @throws org.osid.NullArgumentException <code> raceConstrainerEnablerId 
     *          </code> or <code> raceConstrainerId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignRaceConstrainerEnablerFromRaceConstrainer(org.osid.id.Id raceConstrainerEnablerId, 
                                                                  org.osid.id.Id raceConstrainerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> RaceConstrainerEnablers. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known sequencing operations will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> RaceConstrainerEnabler </code> 
     *          ordering is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceRaceConstrainerEnablers();


    /**
     *  Reorders race constrainer enablers for a race constrainer by moving 
     *  the specified race constrainer enabler in front of a reference race 
     *  constrainer enabler. 
     *
     *  @param  raceConstrainerEnablerId the <code> Id </code> of a <code> 
     *          RaceConstrainerEnabler </code> 
     *  @param  raceConstrainerId the <code> Id </code> of a <code> 
     *          RaceConstrainer </code> 
     *  @param  referenceId the reference race constrainer enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> raceConstrainerEnablerId, 
     *          raceConstrainerId, </code> or <code> referenceId </code> not 
     *          found or, <code> raceConstrainerEnablerId </code> or <code> 
     *          referenceId </code> not related to <code> raceConstrainerId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          raceConstrainerEnablerId, raceConstrainerId, </code> or <code> 
     *          referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveRaceConstrainerEnablerAhead(org.osid.id.Id raceConstrainerEnablerId, 
                                                org.osid.id.Id raceConstrainerId, 
                                                org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders race constrainer enablers for a race constrainer by moving 
     *  the specified race constrainer enabler behind a reference race 
     *  constrainer enabler. 
     *
     *  @param  raceConstrainerEnablerId the <code> Id </code> of a <code> 
     *          RaceConstrainerEnabler </code> 
     *  @param  raceConstrainerId the <code> Id </code> of a <code> 
     *          RaceConstrainer </code> 
     *  @param  referenceId the reference race constrainer enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> raceConstrainerEnablerId, 
     *          raceConstrainerId, </code> or <code> referenceId </code> not 
     *          found or, <code> raceConstrainerEnablerId </code> or <code> 
     *          referenceId </code> not related to <code> raceConstrainerId 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          raceConstrainerEnablerId, raceConstrainerId, </code> or <code> 
     *          referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveRaceConstrainerEnablerBehind(org.osid.id.Id raceConstrainerEnablerId, 
                                                 org.osid.id.Id raceConstrainerId, 
                                                 org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of race constrainer enablers for a race constrainer. 
     *
     *  @param  raceConstrainerEnablerIds the <code> Ids </code> for a set of 
     *          <code> RaceConstrainerEnablers </code> 
     *  @param  raceConstrainerId the <code> Id </code> of a <code> 
     *          RaceConstrainer </code> 
     *  @throws org.osid.NotFoundException <code> raceConstrainerId </code> 
     *          not found or, a <code> raceConstrainerEnablerId </code> not 
     *          related to <code> raceConstrainerId </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          raceConstrainerEnablerIds </code> or <code> raceConstrainerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderRaceConstrainerEnablers(org.osid.id.Id[] raceConstrainerEnablerIds, 
                                             org.osid.id.Id raceConstrainerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
