//
// org.osid.voting.rules.RaceConstrainerEnablerSearchSession
//
//     The OSID Java specification for org.osid.voting.rules.RaceConstrainerEnablerSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting.rules;


/**
 *  <p>This session provides methods for searching among <code> 
 *  RaceConstrainerEnabler </code> objects. The search query is constructed 
 *  using the <code> RaceConstrainerEnableryQuery. </code> </p> 
 *  
 *  <p> <code> getRaceConstrainerEnablersByQuery() </code> is the basic search 
 *  method and returns a list of <code> RaceConstrainerEnablers. </code> A 
 *  more advanced search may be performed with <code> 
 *  getRaceConstrainerEnablersBySearch(). </code> It accepts a <code> 
 *  RaceConstrainerEnablerSearch </code> in addition to the query for the 
 *  purpose of specifying additional options affecting the entire search, such 
 *  as voting. <code> getRaceConstrainerEnablersBySearch() </code> returns a 
 *  <code> RaceConstrainerEnablerSearchResults </code> that can be used to 
 *  access the resulting <code> RaceConstrainerEnablerList </code> or be used 
 *  to perform a search within the result set through <code> 
 *  RaceConstrainerEnablerSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated polls view: searches include race constrainer enablers 
 *      in polls of which this polls is an ancestor in the polls hierarchy 
 *      </li> 
 *      <li> isolated polls view: searches are restricted to race constrainer 
 *      enablers in this polls </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> RaceConstrainerEnablers </code> may have a query record 
 *  indicated by their respective record types. The query record is accessed 
 *  via the <code> RaceConstrainerEnablerQuery. </code> </p>
 */

public interface RaceConstrainerEnablerSearchSession
    extends org.osid.voting.rules.RaceConstrainerEnablerQuerySession {


    /**
     *  Gets a race constrainer enabler search. 
     *
     *  @return the race constrainer enabler search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.rules.RaceConstrainerEnablerSearch getRaceConstrainerEnablerSearch();


    /**
     *  Gets a race constrainer enabler search order. The <code> 
     *  RaceConstrainerEnablerSearchOrder </code> is supplied to a <code> 
     *  RaceConstrainerEnablerSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the race constrainer enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.rules.RaceConstrainerEnablerSearchOrder getRaceConstrainerEnablerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  raceConstrainerEnablerQuery the race constrainer enabler query 
     *  @param  raceConstrainerEnablerSearch the race constrainer enabler 
     *          search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> 
     *          raceConstrainerEnablerQuery </code> or <code> 
     *          raceConstrainerEnablerSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> 
     *          raceConstrainerEnablerQuery </code> or <code> 
     *          raceConstrainerEnablerSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.rules.RaceConstrainerEnablerSearchResults getRaceConstrainerEnablersBySearch(org.osid.voting.rules.RaceConstrainerEnablerQuery raceConstrainerEnablerQuery, 
                                                                                                        org.osid.voting.rules.RaceConstrainerEnablerSearch raceConstrainerEnablerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a race constrainer enabler query from an inspector. The inspector 
     *  is available from a <code> RaceConstrainerEnablerSearchResults. 
     *  </code> 
     *
     *  @param  raceConstrainerEnablerQueryInspector a race constrainer 
     *          enabler query inspector 
     *  @return the race constrainer enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          raceConstrainerEnablerQueryInspector </code> is <code> null 
     *          </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          raceConstrainerEnablerQueryInspector </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.rules.RaceConstrainerEnablerQuery getRaceConstrainerEnablerQueryFromInspector(org.osid.voting.rules.RaceConstrainerEnablerQueryInspector raceConstrainerEnablerQueryInspector);
}
