//
// org.osid.voting.rules.RaceConstrainerQuery
//
//     The OSID Java specification for org.osid.voting.rules.RaceConstrainerQuery.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting.rules;


/**
 *  <p>This is the query for searching race constrainers. Each method match 
 *  specifies a <code> AND </code> term while multiple invocations of the same 
 *  method produce a nested <code> OR. </code> </p>
 */

public interface RaceConstrainerQuery
    extends org.osid.OsidConstrainerQuery {


    /**
     *  Matches mapped to a race. 
     *
     *  @param  raceId the race <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> raceId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRuledRaceId(org.osid.id.Id raceId, boolean match);


    /**
     *  Clears the race <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledRaceIdTerms();


    /**
     *  Tests if a <code> RaceQuery </code> is available. 
     *
     *  @return <code> true </code> if a race query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRuledRaceQuery();


    /**
     *  Gets the query for a race. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the race query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRuledRaceQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRuledRaceQuery() </code> is <code> true. </code> 
     */

    public org.osid.voting.RaceQuery getRuledRaceQuery();


    /**
     *  Matches constrainers mapped to any race. 
     *
     *  @param  match <code> true </code> for constrainers mapped to any race, 
     *          <code> false </code> to match constrainers mapped to no races 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRuledRace(boolean match);


    /**
     *  Clears the race query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledRaceTerms();


    /**
     *  Matches constrainers mapped to the polls. 
     *
     *  @param  pollsId the polls <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchPollsId(org.osid.id.Id pollsId, boolean match);


    /**
     *  Clears the polls <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPollsIdTerms();


    /**
     *  Tests if a <code> PollsQuery </code> is available. 
     *
     *  @return <code> true </code> if a polls query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsPollsQuery();


    /**
     *  Gets the query for a polls. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the polls query 
     *  @throws org.osid.UnimplementedException <code> supportsPollsQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsPollsQuery() </code> is <code> true. </code> 
     */

    public org.osid.voting.PollsQuery getPollsQuery();


    /**
     *  Clears the polls query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearPollsTerms();


    /**
     *  Gets the race constrainer query record corresponding to the given 
     *  <code> RaceConstrainer </code> record <code> Type. </code> Multiple 
     *  record retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  raceConstrainerRecordType a race constrainer record type 
     *  @return the race constrainer query record 
     *  @throws org.osid.NullArgumentException <code> 
     *          raceConstrainerRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(raceConstrainerRecordType) </code> is <code> 
     *          false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.rules.records.RaceConstrainerQueryRecord getRaceConstrainerQueryRecord(org.osid.type.Type raceConstrainerRecordType)
        throws org.osid.OperationFailedException;
}
