//
// org.osid.voting.rules.RaceProcessorEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.voting.rules.RaceProcessorEnablerRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting.rules;


/**
 *  <p>This session provides methods to apply <code> RaceProcessorEnablers 
 *  </code> to <code> RaceProcessors. </code> a <code> RaceProcessor </code> 
 *  with multiple <code> RaceProcessorEnablers </code> means any positive rule 
 *  evaluation across the enablers result in an effective <code> 
 *  RaceProcessor. </code> </p>
 */

public interface RaceProcessorEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Polls </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Polls Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPollsId();


    /**
     *  Gets the <code> Polls </code> associated with this session. 
     *
     *  @return the polls 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.Polls getPolls()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter race processor enabler/race processor 
     *  mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known mapping 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignRaceProcessorEnablers();


    /**
     *  Adds an existing <code> RaceProcessorEnabler </code> to a <code> 
     *  RaceProcessor. </code> 
     *
     *  @param  raceProcessorEnablerId the <code> Id </code> of the <code> 
     *          RaceProcessorEnabler </code> 
     *  @param  raceProcessorId the <code> Id </code> of the <code> 
     *          RaceProcessor </code> 
     *  @throws org.osid.AlreadyExistsException <code> raceProcessorEnablerId 
     *          </code> is already applied to <code> raceProcessorId </code> 
     *  @throws org.osid.NotFoundException <code> raceProcessorEnablerId 
     *          </code> or <code> raceProcessorId </code> not found 
     *  @throws org.osid.NullArgumentException <code> raceProcessorEnablerId 
     *          </code> or <code> raceProcessorId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignRaceProcessorEnablerToRaceProcessor(org.osid.id.Id raceProcessorEnablerId, 
                                                          org.osid.id.Id raceProcessorId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> RaceProcessorEnabler </code> from a <code> 
     *  RaceProcessor. </code> 
     *
     *  @param  raceProcessorEnablerId the <code> Id </code> of the <code> 
     *          RaceProcessorEnabler </code> 
     *  @param  raceProcessorId the <code> Id </code> of the <code> 
     *          RaceProcessor </code> 
     *  @throws org.osid.NotFoundException <code> raceProcessorEnablerId 
     *          </code> or <code> raceProcessorId </code> not found or <code> 
     *          raceProcessorEnablerId </code> not applied to <code> 
     *          raceProcessorId </code> 
     *  @throws org.osid.NullArgumentException <code> raceProcessorEnablerId 
     *          </code> or <code> raceProcessorId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignRaceProcessorEnablerFromRaceProcessor(org.osid.id.Id raceProcessorEnablerId, 
                                                              org.osid.id.Id raceProcessorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> RaceProcessorEnablers. </code> A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known sequencing operations will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> RaceProcessorEnabler </code> 
     *          ordering is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceRaceProcessorEnablers();


    /**
     *  Reorders race processor enablers for a race processor by moving the 
     *  specified race processor enabler in front of a reference race 
     *  processor enabler. 
     *
     *  @param  raceProcessorEnablerId the <code> Id </code> of a <code> 
     *          RaceProcessorEnabler </code> 
     *  @param  raceProcessorId the <code> Id </code> of a <code> 
     *          RaceProcessor </code> 
     *  @param  referenceId the reference race processor enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> raceProcessorEnablerId, 
     *          raceProcessorId, </code> or <code> referenceId </code> not 
     *          found or, <code> raceProcessorEnablerId </code> or <code> 
     *          referenceId </code> not related to <code> processorId </code> 
     *  @throws org.osid.NullArgumentException <code> raceProcessorEnablerId, 
     *          raceProcessorId, </code> or <code> referenceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveRaceProcessorEnablerAhead(org.osid.id.Id raceProcessorEnablerId, 
                                              org.osid.id.Id raceProcessorId, 
                                              org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders race processor enablers for a race processor by moving the 
     *  specified race processor enabler behind a reference race processor 
     *  enabler. 
     *
     *  @param  raceProcessorEnablerId the <code> Id </code> of a <code> 
     *          RaceProcessorEnabler </code> 
     *  @param  raceProcessorId the <code> Id </code> of a <code> 
     *          RaceProcessor </code> 
     *  @param  referenceId the reference race processor enabler <code> Id 
     *          </code> 
     *  @throws org.osid.NotFoundException <code> praceProcessorEnablerId, 
     *          raceProcessorId, </code> or <code> referenceId </code> not 
     *          found or, <code> raceProcessorEnablerId </code> or <code> 
     *          referenceId </code> not related to <code> processorId </code> 
     *  @throws org.osid.NullArgumentException <code> raceProcessorEnablerId, 
     *          raceProcessorId, </code> or <code> referenceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveRaceProcessorEnablerBehind(org.osid.id.Id raceProcessorEnablerId, 
                                               org.osid.id.Id raceProcessorId, 
                                               org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of race processor enablers for a race processor. 
     *
     *  @param  raceProcessorEnablerIds the <code> Ids </code> for a set of 
     *          <code> RaceProcessorEnablers </code> 
     *  @param  raceProcessorId the <code> Id </code> of a <code> 
     *          RaceProcessor </code> 
     *  @throws org.osid.NotFoundException <code> raceProcessorId </code> not 
     *          found or, a <code> raceProcessorEnablerId </code> not related 
     *          to <code> raceProcessorId </code> 
     *  @throws org.osid.NullArgumentException <code> raceProcessorEnablerIds 
     *          </code> or <code> raceProcessorId </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderRaceProcessorEnablers(org.osid.id.Id[] raceProcessorEnablerIds, 
                                           org.osid.id.Id raceProcessorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
