//
// org.osid.voting.rules.RaceProcessorEnablerRuleLookupSession
//
//     The OSID Java specification for org.osid.voting.rules.RaceProcessorEnablerRuleLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting.rules;


/**
 *  <p>This session provides methods to retrieve <code> RaceProcessorEnabler 
 *  </code> to <code> RaceProcessor </code> mappings. a <code> RaceProcessor 
 *  </code> with multiple <code> RaceProcessorEnablers </code> means any 
 *  positive rule evaluation across the enablers result in an effective <code> 
 *  RaceProcessor. </code> </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated polls view: All methods in this session operate, 
 *      retrieve and pertain race processor enablers defined explicitly in the 
 *      current polls </li> 
 *      <li> federated polls view: All methods in this session operate, 
 *      retrieve and pertain to all race processor enablers defined in this 
 *      polls and any other race processor enablers implicitly available in 
 *      this polls through polls inheritence. </li> 
 *  </ul>
 *  
 */

public interface RaceProcessorEnablerRuleLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Polls </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Polls Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPollsId();


    /**
     *  Gets the <code> Polls </code> associated with this session. 
     *
     *  @return the polls 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.Polls getPolls()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform lookups of race processor enabler/race 
     *  processor mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known lookup 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if looking up mappings is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupRaceProcessorEnablerRules();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeRaceProcessorEnablerRuleView();


    /**
     *  A complete view of the <code> RaceProcessorEnabler </code> and <code> 
     *  RaceProcessor </code> returns is desired. Methods will return what is 
     *  requested or result in an error. This view is used when greater 
     *  precision is desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryRaceProcessorEnablerRuleView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include race processor enablers in polls which are children of this 
     *  polls in the polls hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedPollsView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this polls only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedPollsView();


    /**
     *  Gets the <code> RaceProcessorEnabler Id </code> associated with a 
     *  <code> RaceProcessor. </code> 
     *
     *  @param  raceProcessorId <code> Id </code> of the <code> RaceProcessor 
     *          </code> 
     *  @return the race processor enabler <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> raceProcessorId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> raceProcessorId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getRaceProcessorEnablerIdsForRaceProcessor(org.osid.id.Id raceProcessorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> RaceProcessorEnabler </code> associated with a <code> 
     *  RaceProcessor. </code> 
     *
     *  @param  raceProcessorId <code> Id </code> of the <code> RaceProcessor 
     *          </code> 
     *  @return the race processor enablers 
     *  @throws org.osid.NotFoundException <code> raceProcessorId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> raceProcessorId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.rules.RaceProcessorEnablerList getRaceProcessorEnablersForRaceProcessor(org.osid.id.Id raceProcessorId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> RaceProcessor </code> <code> Ids </code> mapped to a 
     *  <code> RaceProcessorEnabler. </code> 
     *
     *  @param  raceProcessorEnablerId <code> Id </code> of a <code> 
     *          RaceProcessorEnabler </code> 
     *  @return list of race processor <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> raceProcessorEnablerId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> raceProcessorEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getRaceProcessorIdsForRaceProcessorEnabler(org.osid.id.Id raceProcessorEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> RaceProcessors </code> mapped to a <code> 
     *  RaceProcessorEnabler. </code> 
     *
     *  @param  raceProcessorEnablerId <code> Id </code> of a <code> 
     *          RaceProcessorEnabler </code> 
     *  @return list of race processors 
     *  @throws org.osid.NotFoundException <code> raceProcessorEnablerId 
     *          </code> is not found 
     *  @throws org.osid.NullArgumentException <code> raceProcessorEnablerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.rules.RaceProcessorList getRaceProcessorsForRaceProcessorEnabler(org.osid.id.Id raceProcessorEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
