//
// org.osid.voting.rules.RaceProcessorForm
//
//     The OSID Java specification for org.osid.voting.rules.RaceProcessorForm.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting.rules;


/**
 *  <p>This is the form for creating and updating <code> RaceProcessors. 
 *  </code> Like all <code> OsidForm </code> objects, various data elements 
 *  may be set here for use in the create and update methods in the <code> 
 *  RaceProcessorAdminSession. </code> For each data element that may be set, 
 *  metadata may be examined to provide display hints or data constraints. 
 *  </p>
 */

public interface RaceProcessorForm
    extends org.osid.OsidProcessorForm {


    /**
     *  Gets the metadata for the maximum winners value. 
     *
     *  @return metadata for the maximum winners 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getMaximumWinnersMetadata();


    /**
     *  Sets the maximum winners. 
     *
     *  @param  winners the maximum winners 
     *  @throws org.osid.InvalidArgumentException <code> winners </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setMaximumWinners(long winners);


    /**
     *  Clears the maximum winners value. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMaximumWinners();


    /**
     *  Gets the metadata for the minimum percentage to win value. 
     *
     *  @return metadata for the minimum percentage to win 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getMinimumPercentageToWinMetadata();


    /**
     *  Sets the minimum percentage to win (0-100). 
     *
     *  @param  percentage the mnimum percentage to win 
     *  @throws org.osid.InvalidArgumentException <code> percentage </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setMinimumPercentageToWin(long percentage);


    /**
     *  Clears the minimum percentage to win value. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMinimumPercentageToWin();


    /**
     *  Gets the metadata for the minimum votes to win value. 
     *
     *  @return metadata for the minimum votes to win 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.Metadata getMinimumPVotesToWinMetadata();


    /**
     *  Sets the minimum votes to win (0-100). 
     *
     *  @param  votes the mnimum votes to win 
     *  @throws org.osid.InvalidArgumentException <code> votes </code> is 
     *          invalid 
     *  @throws org.osid.NoAccessException <code> Metadata.isReadOnly() 
     *          </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void setMinimumVotesToWin(long votes);


    /**
     *  Clears the minimum votes to win value. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearMinimumVotesToWin();


    /**
     *  Gets the <code> RaceProcessorFormRecord </code> corresponding to the 
     *  given race processor record <code> Type. </code> 
     *
     *  @param  raceProcessorRecordType a race processor record type 
     *  @return the race processor form record 
     *  @throws org.osid.NullArgumentException <code> raceProcessorRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(raceProcessorRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.rules.records.RaceProcessorFormRecord getRaceProcessorFormRecord(org.osid.type.Type raceProcessorRecordType)
        throws org.osid.OperationFailedException;
}
