//
// org.osid.voting.rules.RaceProcessorRuleApplicationSession
//
//     The OSID Java specification for org.osid.voting.rules.RaceProcessorRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting.rules;


/**
 *  <p>This session provides methods to apply <code> RaceProcessors </code> to 
 *  <code> Races. </code> </p>
 */

public interface RaceProcessorRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Polls </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Polls Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getPollsId();


    /**
     *  Gets the <code> Polls </code> associated with this session. 
     *
     *  @return the polls 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.Polls getPolls()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter race processor/race mappings. A return of 
     *  true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignRaceProcessors();


    /**
     *  Adds an existing <code> RaceProcessor </code> to a <code> Race. 
     *  </code> 
     *
     *  @param  raceProcessorId the <code> Id </code> of the <code> 
     *          RaceProcessor </code> 
     *  @param  raceId the <code> Id </code> of the <code> Race </code> 
     *  @throws org.osid.AlreadyExistsException <code> raceProcessorId </code> 
     *          is already applied to <code> raceId </code> 
     *  @throws org.osid.NotFoundException <code> raceProcessorId </code> or 
     *          <code> raceId </code> not found 
     *  @throws org.osid.NullArgumentException <code> raceProcessorId </code> 
     *          or <code> raceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignRaceProcessorToRace(org.osid.id.Id raceProcessorId, 
                                          org.osid.id.Id raceId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> RaceProcessor </code> from a <code> Race. </code> 
     *
     *  @param  raceProcessorId the <code> Id </code> of the <code> 
     *          RaceProcessor </code> 
     *  @param  raceId the <code> Id </code> of the <code> Race </code> 
     *  @throws org.osid.NotFoundException <code> raceProcessorId </code> or 
     *          <code> raceId </code> not found or <code> raceProcessorId 
     *          </code> not applied to <code> raceId </code> 
     *  @throws org.osid.NullArgumentException <code> raceProcessorId </code> 
     *          or <code> raceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignRaceProcessorFromRace(org.osid.id.Id raceProcessorId, 
                                              org.osid.id.Id raceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> RaceProcessors. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known sequencing operations will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> RaceProcessor </code> ordering 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceRaceProcessors();


    /**
     *  Reorders race processors for a race by moving the specified race 
     *  processor in front of a reference race processor. 
     *
     *  @param  raceProcessorId the <code> Id </code> of a <code> 
     *          RaceProcessor </code> 
     *  @param  raceId the <code> Id </code> of a <code> Race </code> 
     *  @param  referenceId the reference race processor <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> raceProcessorId, raceId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          raceProcessorId </code> or <code> referenceId </code> not 
     *          related to <code> raceId </code> 
     *  @throws org.osid.NullArgumentException <code> raceProcessorId, raceId, 
     *          </code> or <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveRaceProcessorAhead(org.osid.id.Id raceProcessorId, 
                                       org.osid.id.Id raceId, 
                                       org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders race processors for a race by moving the specified race 
     *  processor behind a reference race processor. 
     *
     *  @param  raceProcessorId the <code> Id </code> of a <code> 
     *          RaceProcessor </code> 
     *  @param  raceId the <code> Id </code> of a <code> Race </code> 
     *  @param  referenceId the reference race processor <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> raceProcessorId, raceId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          raceProcessorId </code> or <code> referenceId </code> not 
     *          related to <code> raceId </code> 
     *  @throws org.osid.NullArgumentException <code> raceProcessorId, raceId, 
     *          </code> or <code> referenceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveRaceProcessorBehind(org.osid.id.Id raceProcessorId, 
                                        org.osid.id.Id raceId, 
                                        org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of race processors for a race. 
     *
     *  @param  raceProcessorIds the <code> Ids </code> for a set of <code> 
     *          RaceProcessors </code> 
     *  @param  raceId the <code> Id </code> of a <code> Race </code> 
     *  @throws org.osid.NotFoundException <code> raceId </code> not found or, 
     *          a <code> raceProcessorId </code> not related to <code> 
     *          raceProcessorId </code> 
     *  @throws org.osid.NullArgumentException <code> raceProcessorIds </code> 
     *          or <code> raceId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderRaceProcessors(org.osid.id.Id[] raceProcessorIds, 
                                    org.osid.id.Id raceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
