//
// org.osid.voting.rules.RaceProcessorSearchSession
//
//     The OSID Java specification for org.osid.voting.rules.RaceProcessorSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting.rules;


/**
 *  <p>This session provides methods for searching among <code> RaceProcessor 
 *  </code> objects. The search query is constructed using the <code> 
 *  RaceProcessoryQuery. </code> </p> 
 *  
 *  <p> <code> getRaceProcessorsByQuery() </code> is the basic search method 
 *  and returns a list of <code> RaceProcessors. </code> A more advanced 
 *  search may be performed with <code> getRaceProcessorsBySearch(). </code> 
 *  It accepts a <code> RaceProcessorSearch </code> in addition to the query 
 *  for the purpose of specifying additional options affecting the entire 
 *  search, such as voting. <code> getRaceProcessorsBySearch() </code> returns 
 *  a <code> RaceProcessorSearchResults </code> that can be used to access the 
 *  resulting <code> RaceProcessorList </code> or be used to perform a search 
 *  within the result set through <code> RaceProcessorSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated polls view: searches include race processor in polls of 
 *      which this polls is an ancestor in the polls hierarchy </li> 
 *      <li> isolated polls view: searches are restricted to race processor in 
 *      this polls </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> RaceProcessors </code> may have a query record indicated by 
 *  their respective record types. Thequery record is accessed via the <code> 
 *  RaceProcessorQuery. </code> </p>
 */

public interface RaceProcessorSearchSession
    extends org.osid.voting.rules.RaceProcessorQuerySession {


    /**
     *  Gets a race processor search. 
     *
     *  @return the race processor search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.rules.RaceProcessorSearch getRaceProcessorSearch();


    /**
     *  Gets a race processor search order. The <code> 
     *  RaceProcessorSearchOrder </code> is supplied to a <code> 
     *  RaceProcessorSearch </code> to specify the ordering of results. 
     *
     *  @return the race processor search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.rules.RaceProcessorSearchOrder getRaceProcessorSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  raceProcessorQuery the race processor query 
     *  @param  raceProcessorSearch the race processor search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> raceProcessorQuery 
     *          </code> or <code> raceProcessorSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> raceProcessorQuery 
     *          </code> or <code> raceProcessorSearch </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.rules.RaceProcessorSearchResults getRaceProcessorsBySearch(org.osid.voting.rules.RaceProcessorQuery raceProcessorQuery, 
                                                                                      org.osid.voting.rules.RaceProcessorSearch raceProcessorSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a race processor query from an inspector. The inspector is 
     *  available from a <code> RaceProcessorSearchResults. </code> 
     *
     *  @param  raceProcessorQueryInspector a race processor query inspector 
     *  @return the race processor query 
     *  @throws org.osid.NullArgumentException <code> 
     *          raceProcessorQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          raceProcessorQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.voting.rules.RaceProcessorQuery getRaceProcessorQueryFromInspector(org.osid.voting.rules.RaceProcessorQueryInspector raceProcessorQueryInspector);
}
