//
// org.osid.voting.rules.VotingRulesProfile
//
//     The OSID Java specification for org.osid.voting.rules.VotingRulesProfile.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting.rules;


/**
 *  <p>The voting rules profile describes the interoperability among voting 
 *  rules services. </p>
 */

public interface VotingRulesProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any broker federation is exposed. Federation is exposed when 
     *  a specific broker may be identified, selected and used to create a 
     *  lookup or admin session. Federation is not exposed when a set of 
     *  brokers appears as a single broker. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if looking up race constrainer is supported. 
     *
     *  @return <code> true </code> if race constrainer lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceConstrainerLookup();


    /**
     *  Tests if querying race constrainer is supported. 
     *
     *  @return <code> true </code> if race constrainer query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceConstrainerQuery();


    /**
     *  Tests if searching race constrainer is supported. 
     *
     *  @return <code> true </code> if race constrainer search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceConstrainerSearch();


    /**
     *  Tests if a race constrainer administrative service is supported. 
     *
     *  @return <code> true </code> if race constrainer administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceConstrainerAdmin();


    /**
     *  Tests if a race constrainer notification service is supported. 
     *
     *  @return <code> true </code> if race constrainer notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceConstrainerNotification();


    /**
     *  Tests if a race constrainer polls lookup service is supported. 
     *
     *  @return <code> true </code> if a race constrainer polls lookup service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceConstrainerPolls();


    /**
     *  Tests if a race constrainer polls service is supported. 
     *
     *  @return <code> true </code> if race constrainer polls assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceConstrainerPollsAssignment();


    /**
     *  Tests if a race constrainer polls lookup service is supported. 
     *
     *  @return <code> true </code> if a race constrainer polls service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceConstrainerSmartPolls();


    /**
     *  Tests if a race constrainer rule lookup service is supported. 
     *
     *  @return <code> true </code> if a race constrainer rule lookup service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceConstrainerRuleLookup();


    /**
     *  Tests if a race constrainer rule application service is supported. 
     *
     *  @return <code> true </code> if a race constrainer rule application 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceConstrainerRuleApplication();


    /**
     *  Tests if looking up race constrainer enablers is supported. 
     *
     *  @return <code> true </code> if race constrainer enabler lookup is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceConstrainerEnablerLookup();


    /**
     *  Tests if querying race constrainer enablers is supported. 
     *
     *  @return <code> true </code> if race constrainer enabler query is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceConstrainerEnablerQuery();


    /**
     *  Tests if searching race constrainer enablers is supported. 
     *
     *  @return <code> true </code> if race constrainer enabler search is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceConstrainerEnablerSearch();


    /**
     *  Tests if a race constrainer enabler administrative service is 
     *  supported. 
     *
     *  @return <code> true </code> if race constrainer enabler administration 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceConstrainerEnablerAdmin();


    /**
     *  Tests if a race constrainer enabler notification service is supported. 
     *
     *  @return <code> true </code> if race constrainer enabler notification 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceConstrainerEnablerNotification();


    /**
     *  Tests if a race constrainer enabler polls lookup service is supported. 
     *
     *  @return <code> true </code> if a race constrainer enabler polls lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceConstrainerEnablerPolls();


    /**
     *  Tests if a race constrainer enabler polls service is supported. 
     *
     *  @return <code> true </code> if race constrainer enabler polls 
     *          assignment service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceConstrainerEnablerPollsAssignment();


    /**
     *  Tests if a race constrainer enabler polls lookup service is supported. 
     *
     *  @return <code> true </code> if a race constrainer enabler polls 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceConstrainerEnablerSmartPolls();


    /**
     *  Tests if a race constrainer enabler rule lookup service is supported. 
     *
     *  @return <code> true </code> if a race constrainer enabler rule lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceConstrainerEnablerRuleLookup();


    /**
     *  Tests if a race constrainer enabler rule application service is 
     *  supported. 
     *
     *  @return <code> true </code> if race constrainer enabler rule 
     *          application service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceConstrainerEnablerRuleApplication();


    /**
     *  Tests if looking up race processor is supported. 
     *
     *  @return <code> true </code> if race processor lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceProcessorLookup();


    /**
     *  Tests if querying race processor is supported. 
     *
     *  @return <code> true </code> if race processor query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceProcessorQuery();


    /**
     *  Tests if searching race processor is supported. 
     *
     *  @return <code> true </code> if race processor search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceProcessorSearch();


    /**
     *  Tests if a race processor administrative service is supported. 
     *
     *  @return <code> true </code> if race processor administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceProcessorAdmin();


    /**
     *  Tests if a race processor notification service is supported. 
     *
     *  @return <code> true </code> if race processor notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceProcessorNotification();


    /**
     *  Tests if a race processor polls lookup service is supported. 
     *
     *  @return <code> true </code> if a race processor polls lookup service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceProcessorPolls();


    /**
     *  Tests if a race processor polls service is supported. 
     *
     *  @return <code> true </code> if race processor polls assignment service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceProcessorPollsAssignment();


    /**
     *  Tests if a race processor polls lookup service is supported. 
     *
     *  @return <code> true </code> if a race processor polls service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceProcessorSmartPolls();


    /**
     *  Tests if a race processor rule lookup service is supported. 
     *
     *  @return <code> true </code> if a race processor rule lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceProcessorRuleLookup();


    /**
     *  Tests if a race processor rule application service is supported. 
     *
     *  @return <code> true </code> if race processor rule application service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceProcessorRuleApplication();


    /**
     *  Tests if looking up race processor enablers is supported. 
     *
     *  @return <code> true </code> if race processor enabler lookup is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceProcessorEnablerLookup();


    /**
     *  Tests if querying race processor enablers is supported. 
     *
     *  @return <code> true </code> if race processor enabler query is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceProcessorEnablerQuery();


    /**
     *  Tests if searching race processor enablers is supported. 
     *
     *  @return <code> true </code> if race processor enabler search is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceProcessorEnablerSearch();


    /**
     *  Tests if a race processor enabler administrative service is supported. 
     *
     *  @return <code> true </code> if race processor enabler administration 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceProcessorEnablerAdmin();


    /**
     *  Tests if a race processor enabler notification service is supported. 
     *
     *  @return <code> true </code> if race processor enabler notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceProcessorEnablerNotification();


    /**
     *  Tests if a race processor enabler polls lookup service is supported. 
     *
     *  @return <code> true </code> if a race processor enabler polls lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceProcessorEnablerPolls();


    /**
     *  Tests if a race processor enabler polls service is supported. 
     *
     *  @return <code> true </code> if race processor enabler polls assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceProcessorEnablerPollsAssignment();


    /**
     *  Tests if a race processor enabler polls lookup service is supported. 
     *
     *  @return <code> true </code> if a race processor enabler polls service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceProcessorEnablerSmartPolls();


    /**
     *  Tests if a race processor enabler rule lookup service is supported. 
     *
     *  @return <code> true </code> if an processor enabler rule lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceProcessorEnablerRuleLookup();


    /**
     *  Tests if a race processor enabler rule application service is 
     *  supported. 
     *
     *  @return <code> true </code> if race processor enabler rule application 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceProcessorEnablerRuleApplication();


    /**
     *  Tests if looking up ballot constrainer is supported. 
     *
     *  @return <code> true </code> if ballot constrainer lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBallotConstrainerLookup();


    /**
     *  Tests if querying ballot constrainer is supported. 
     *
     *  @return <code> true </code> if ballot constrainer query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBallotConstrainerQuery();


    /**
     *  Tests if searching ballot constrainer is supported. 
     *
     *  @return <code> true </code> if ballot constrainer search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBallotConstrainerSearch();


    /**
     *  Tests if a ballot constrainer administrative service is supported. 
     *
     *  @return <code> true </code> if ballot constrainer administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBallotConstrainerAdmin();


    /**
     *  Tests if a ballot constrainer notification service is supported. 
     *
     *  @return <code> true </code> if ballot constrainer notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBallotConstrainerNotification();


    /**
     *  Tests if a ballot constrainer polls lookup service is supported. 
     *
     *  @return <code> true </code> if a ballot constrainer polls lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBallotConstrainerPolls();


    /**
     *  Tests if a ballot constrainer polls service is supported. 
     *
     *  @return <code> true </code> if ballot constrainer polls assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBallotConstrainerPollsAssignment();


    /**
     *  Tests if a ballot constrainer polls lookup service is supported. 
     *
     *  @return <code> true </code> if a ballot constrainer polls service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBallotConstrainerSmartPolls();


    /**
     *  Tests if a ballot constrainer rule lookup service is supported. 
     *
     *  @return <code> true </code> if a ballot constrainer rule lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBallotConstrainerRuleLookup();


    /**
     *  Tests if a ballot constrainer rule application service is supported. 
     *
     *  @return <code> true </code> if a ballot constrainer rule application 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBallotConstrainerRuleApplication();


    /**
     *  Tests if looking up ballot constrainer enablers is supported. 
     *
     *  @return <code> true </code> if ballot constrainer enabler lookup is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBallotConstrainerEnablerLookup();


    /**
     *  Tests if querying ballot constrainer enablers is supported. 
     *
     *  @return <code> true </code> if ballot constrainer enabler query is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBallotConstrainerEnablerQuery();


    /**
     *  Tests if searching ballot constrainer enablers is supported. 
     *
     *  @return <code> true </code> if ballot constrainer enabler search is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBallotConstrainerEnablerSearch();


    /**
     *  Tests if a ballot constrainer enabler administrative service is 
     *  supported. 
     *
     *  @return <code> true </code> if ballot constrainer enabler 
     *          administration is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBallotConstrainerEnablerAdmin();


    /**
     *  Tests if a ballot constrainer enabler notification service is 
     *  supported. 
     *
     *  @return <code> true </code> if ballot constrainer enabler notification 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBallotConstrainerEnablerNotification();


    /**
     *  Tests if a ballot constrainer enabler polls lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if a ballot constrainer enabler polls 
     *          lookup service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBallotConstrainerEnablerPolls();


    /**
     *  Tests if a ballot constrainer enabler polls service is supported. 
     *
     *  @return <code> true </code> if ballot constrainer enabler polls 
     *          assignment service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBallotConstrainerEnablerPollsAssignment();


    /**
     *  Tests if a ballot constrainer enabler polls lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if a ballot constrainer enabler polls 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBallotConstrainerEnablerSmartPolls();


    /**
     *  Tests if a ballot constrainer enabler rule lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if a ballot constrainer enabler rule 
     *          lookup service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBallotConstrainerEnablerRuleLookup();


    /**
     *  Tests if a ballot constrainer enabler rule application service is 
     *  supported. 
     *
     *  @return <code> true </code> if ballot constrainer enabler rule 
     *          application service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBallotConstrainerEnablerRuleApplication();


    /**
     *  Gets the supported <code> RaceConstrainer </code> record types. 
     *
     *  @return a list containing the supported <code> RaceConstrainer </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRaceConstrainerRecordTypes();


    /**
     *  Tests if the given <code> RaceConstrainer </code> record type is 
     *  supported. 
     *
     *  @param  raceConstrainerRecordType a <code> Type </code> indicating a 
     *          <code> RaceConstrainer </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          raceConstrainerRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceConstrainerRecordType(org.osid.type.Type raceConstrainerRecordType);


    /**
     *  Gets the supported <code> RaceConstrainer </code> search record types. 
     *
     *  @return a list containing the supported <code> RaceConstrainer </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRaceConstrainerSearchRecordTypes();


    /**
     *  Tests if the given <code> RaceConstrainer </code> search record type 
     *  is supported. 
     *
     *  @param  raceConstrainerSearchRecordType a <code> Type </code> 
     *          indicating a <code> RaceConstrainer </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          raceConstrainerSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceConstrainerSearchRecordType(org.osid.type.Type raceConstrainerSearchRecordType);


    /**
     *  Gets the supported <code> RaceConstrainerEnabler </code> record types. 
     *
     *  @return a list containing the supported <code> RaceConstrainerEnabler 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRaceConstrainerEnablerRecordTypes();


    /**
     *  Tests if the given <code> RaceConstrainerEnabler </code> record type 
     *  is supported. 
     *
     *  @param  raceConstrainerEnablerRecordType a <code> Type </code> 
     *          indicating a <code> RaceConstrainerEnabler </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          raceConstrainerEnablerRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceConstrainerEnablerRecordType(org.osid.type.Type raceConstrainerEnablerRecordType);


    /**
     *  Gets the supported <code> RaceConstrainerEnabler </code> search record 
     *  types. 
     *
     *  @return a list containing the supported <code> RaceConstrainerEnabler 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRaceConstrainerEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> RaceConstrainerEnabler </code> search record 
     *  type is supported. 
     *
     *  @param  raceConstrainerEnablerSearchRecordType a <code> Type </code> 
     *          indicating a <code> RaceConstrainerEnabler </code> search 
     *          record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          raceConstrainerEnablerSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceConstrainerEnablerSearchRecordType(org.osid.type.Type raceConstrainerEnablerSearchRecordType);


    /**
     *  Gets the supported <code> RaceProcessor </code> record types. 
     *
     *  @return a list containing the supported <code> RaceProcessor </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRaceProcessorRecordTypes();


    /**
     *  Tests if the given <code> RaceProcessor </code> record type is 
     *  supported. 
     *
     *  @param  raceProcessorRecordType a <code> Type </code> indicating a 
     *          <code> RaceProcessor </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> raceProcessorRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceProcessorRecordType(org.osid.type.Type raceProcessorRecordType);


    /**
     *  Gets the supported <code> RaceProcessor </code> search record types. 
     *
     *  @return a list containing the supported <code> RaceProcessor </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRaceProcessorSearchRecordTypes();


    /**
     *  Tests if the given <code> RaceProcessor </code> search record type is 
     *  supported. 
     *
     *  @param  raceProcessorSearchRecordType a <code> Type </code> indicating 
     *          a <code> RaceProcessor </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          raceProcessorSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceProcessorSearchRecordType(org.osid.type.Type raceProcessorSearchRecordType);


    /**
     *  Gets the supported <code> RaceProcessorEnabler </code> record types. 
     *
     *  @return a list containing the supported <code> RaceProcessorEnabler 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRaceProcessorEnablerRecordTypes();


    /**
     *  Tests if the given <code> RaceProcessorEnabler </code> record type is 
     *  supported. 
     *
     *  @param  raceProcessorEnablerRecordType a <code> Type </code> 
     *          indicating a <code> RaceProcessorEnabler </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          raceProcessorEnablerRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceProcessorEnablerRecordType(org.osid.type.Type raceProcessorEnablerRecordType);


    /**
     *  Gets the supported <code> RaceProcessorEnabler </code> search record 
     *  types. 
     *
     *  @return a list containing the supported <code> RaceProcessorEnabler 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getRaceProcessorEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> RaceProcessorEnabler </code> search record 
     *  type is supported. 
     *
     *  @param  raceProcessorEnablerSearchRecordType a <code> Type </code> 
     *          indicating a <code> RaceProcessorEnabler </code> search record 
     *          type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          raceProcessorEnablerSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRaceProcessorEnablerSearchRecordType(org.osid.type.Type raceProcessorEnablerSearchRecordType);


    /**
     *  Gets the supported <code> BallotConstrainer </code> record types. 
     *
     *  @return a list containing the supported <code> BallotConstrainer 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBallotConstrainerRecordTypes();


    /**
     *  Tests if the given <code> BallotConstrainer </code> record type is 
     *  supported. 
     *
     *  @param  ballotConstrainerRecordType a <code> Type </code> indicating a 
     *          <code> BallotConstrainer </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          ballotConstrainerRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBallotConstrainerRecordType(org.osid.type.Type ballotConstrainerRecordType);


    /**
     *  Gets the supported <code> BallotConstrainer </code> search record 
     *  types. 
     *
     *  @return a list containing the supported <code> BallotConstrainer 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBallotConstrainerSearchRecordTypes();


    /**
     *  Tests if the given <code> BallotConstrainer </code> search record type 
     *  is supported. 
     *
     *  @param  ballotConstrainerSearchRecordType a <code> Type </code> 
     *          indicating a <code> BallotConstrainer </code> search record 
     *          type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          ballotConstrainerSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBallotConstrainerSearchRecordType(org.osid.type.Type ballotConstrainerSearchRecordType);


    /**
     *  Gets the supported <code> BallotConstrainerEnabler </code> record 
     *  types. 
     *
     *  @return a list containing the supported <code> 
     *          BallotConstrainerEnabler </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBallotConstrainerEnablerRecordTypes();


    /**
     *  Tests if the given <code> BallotConstrainerEnabler </code> record type 
     *  is supported. 
     *
     *  @param  ballotConstrainerEnablerRecordType a <code> Type </code> 
     *          indicating a <code> BallotConstrainerEnabler </code> record 
     *          type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          ballotConstrainerEnablerRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBallotConstrainerEnablerRecordType(org.osid.type.Type ballotConstrainerEnablerRecordType);


    /**
     *  Gets the supported <code> BallotConstrainerEnabler </code> search 
     *  record types. 
     *
     *  @return a list containing the supported <code> 
     *          BallotConstrainerEnabler </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getBallotConstrainerEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> BallotConstrainerEnabler </code> search 
     *  record type is supported. 
     *
     *  @param  ballotConstrainerEnablerSearchRecordType a <code> Type </code> 
     *          indicating a <code> BallotConstrainerEnabler </code> search 
     *          record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          ballotConstrainerEnablerSearchRecordType </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsBallotConstrainerEnablerSearchRecordType(org.osid.type.Type ballotConstrainerEnablerSearchRecordType);
}
