//
// org.osid.voting.rules.VotingRulesProxyManager
//
//     The OSID Java specification for org.osid.voting.rules.VotingRulesProxyManager.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.voting.rules;


/**
 *  <p>The voting rules proxy manager provides access to voting rules sessions 
 *  and provides interoperability tests for various aspects of this service. 
 *  Methods in this manager pass a <code> Proxy </code> for passing 
 *  information from server environments. The sessions included in this 
 *  manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> RaceConstrainerLookupSession: </code> a session to 
 *      retrieve race constrainer </li> 
 *      <li> <code> RaceConstrainerQuerySession: </code> a session to query 
 *      for race constrainer </li> 
 *      <li> <code> RaceConstrainerSearchSession: </code> a session to search 
 *      for race constrainer </li> 
 *      <li> <code> RaceConstrainerAdminSession: </code> a session to create 
 *      and delete race constrainer </li> 
 *      <li> <code> RaceConstrainerNotificationSession: </code> a session to 
 *      receive notifications pertaining to race constrainer changes </li> 
 *      <li> <code> RaceConstrainerPollsSession: </code> a session to look up 
 *      race constrainer polls mappings </li> 
 *      <li> <code> RaceConstrainerPollsAssignmentSession: </code> a session 
 *      to manage race constrainer to polls mappings </li> 
 *      <li> <code> RaceConstrainerSmartPollsSession: </code> a session to 
 *      manage dynamic polls of race constrainer </li> 
 *      <li> <code> RaceConstrainerRuleLookupSession: </code> a session to 
 *      look up race constrainer to race mappings </li> 
 *      <li> <code> RaceConstrainerRuleApplicationSession: </code> a session 
 *      to apply race constrainer to racess </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> RaceConstrainerEnablerLookupSession: </code> a session to 
 *      retrieve race constrainer enablers </li> 
 *      <li> <code> RaceConstrainerEnablerQuerySession: </code> a session to 
 *      query for race constrainer enablers </li> 
 *      <li> <code> RaceConstrainerEnablerSearchSession: </code> a session to 
 *      search for race constrainer enablers </li> 
 *      <li> <code> RaceConstrainerEnablerAdminSession: </code> a session to 
 *      create and delete race constrainer enablers </li> 
 *      <li> <code> RaceConstrainerEnablerNotificationSession: </code> a 
 *      session to receive notifications pertaining to race constrainer 
 *      enabler changes </li> 
 *      <li> <code> RaceConstrainerEnablerPollsSession: </code> a session to 
 *      look up race constrainer enabler polls mappings </li> 
 *      <li> <code> RaceConstrainerEnablerPollsAssignmentSession: </code> a 
 *      session to manage race constrainer enabler to polls mappings </li> 
 *      <li> <code> RaceConstrainerEnablerSmartPollsSession: </code> a session 
 *      to manage dynamic polls of race constrainer enablers </li> 
 *      <li> <code> RaceConstrainerEnableRuleLookupSession: </code> a session 
 *      to look up race constrainer enabler mappings </li> 
 *      <li> <code> RaceConstrainerEnablerRuleApplicationSession: </code> a 
 *      session to apply race constrainer enablers </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> RaceProcessorLookupSession: </code> a session to retrieve 
 *      race processor </li> 
 *      <li> <code> RaceProcessorQuerySession: </code> a session to query for 
 *      race processor </li> 
 *      <li> <code> RaceProcessorSearchSession: </code> a session to search 
 *      for race processor </li> 
 *      <li> <code> RaceProcessorAdminSession: </code> a session to create and 
 *      delete race processor </li> 
 *      <li> <code> RaceProcessorNotificationSession: </code> a session to 
 *      receive notifications pertaining to race processor changes </li> 
 *      <li> <code> RaceProcessorPollsSession: </code> a session to look up 
 *      race processor polls mappings </li> 
 *      <li> <code> RaceProcessorPollsAssignmentSession: </code> a session to 
 *      manage race processor to polls mappings </li> 
 *      <li> <code> RaceProcessorSmartPollsSession: </code> a session to 
 *      manage dynamic polls of race processor </li> 
 *      <li> <code> RaceProcessorRuleLookupSession: </code> a session to look 
 *      up race processor to race mappings </li> 
 *      <li> <code> RaceProcessorRuleApplicationSession: </code> a session to 
 *      apply race processor to racess </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> RaceProcessorEnablerLookupSession: </code> a session to 
 *      retrieve race processor enablers </li> 
 *      <li> <code> RaceProcessorEnablerQuerySession: </code> a session to 
 *      query for race processor enablers </li> 
 *      <li> <code> RaceProcessorEnablerSearchSession: </code> a session to 
 *      search for race processor enablers </li> 
 *      <li> <code> RaceProcessorEnablerAdminSession: </code> a session to 
 *      create and delete race processor enablers </li> 
 *      <li> <code> RaceProcessorEnablerNotificationSession: </code> a session 
 *      to receive notifications pertaining to race processor enabler changes 
 *      </li> 
 *      <li> <code> RaceProcessorEnablerPollsSession: </code> a session to 
 *      look up race processor enabler polls mappings </li> 
 *      <li> <code> RaceProcessorEnablerPollsAssignmentSession: </code> a 
 *      session to manage race processor enabler to polls mappings </li> 
 *      <li> <code> RaceProcessorEnablerSmartPollsSession: </code> a session 
 *      to manage dynamic polls of race processor enablers </li> 
 *      <li> <code> RaceProcessorEnablerRuleLookupSession: </code> a session 
 *      to look up race processor enabler mappings </li> 
 *      <li> <code> RaceProcessorEnablerRuleApplicationSession: </code> a 
 *      session to apply race processor enablers </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> BallotConstrainerLookupSession: </code> a session to 
 *      retrieve ballot constrainer </li> 
 *      <li> <code> BallotConstrainerQuerySession: </code> a session to query 
 *      for ballot constrainer </li> 
 *      <li> <code> BallotConstrainerSearchSession: </code> a session to 
 *      search for ballot constrainer </li> 
 *      <li> <code> BallotConstrainerAdminSession: </code> a session to create 
 *      and delete ballot constrainer </li> 
 *      <li> <code> BallotConstrainerNotificationSession: </code> a session to 
 *      receive notifications pertaining to ballot constrainer changes </li> 
 *      <li> <code> BallotConstrainerPollsSession: </code> a session to look 
 *      up ballot constrainer polls mappings </li> 
 *      <li> <code> BallotConstrainerPollsAssignmentSession: </code> a session 
 *      to manage ballot constrainer to polls mappings </li> 
 *      <li> <code> BallotConstrainerSmartPollsSession: </code> a session to 
 *      manage dynamic polls of ballot constrainer </li> 
 *      <li> <code> BallotConstrainerRuleLookupSession: </code> a session to 
 *      look up ballot constrainer to ballot mappings </li> 
 *      <li> <code> BallotConstrainerRuleApplicationSession: </code> a session 
 *      to apply ballot constrainer to ballotss </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> BallotConstrainerEnablerLookupSession: </code> a session 
 *      to retrieve ballot constrainer enablers </li> 
 *      <li> <code> BallotConstrainerEnablerQuerySession: </code> a session to 
 *      query for ballot constrainer enablers </li> 
 *      <li> <code> BallotConstrainerEnablerSearchSession: </code> a session 
 *      to search for ballot constrainer enablers </li> 
 *      <li> <code> BallotConstrainerEnablerAdminSession: </code> a session to 
 *      create and delete ballot constrainer enablers </li> 
 *      <li> <code> BallotConstrainerEnablerNotificationSession: </code> a 
 *      session to receive notifications pertaining to ballot constrainer 
 *      enabler changes </li> 
 *      <li> <code> BallotConstrainerEnablerPollsSession: </code> a session to 
 *      look up ballot constrainer enabler polls mappings </li> 
 *      <li> <code> BallotConstrainerEnablerPollsAssignmentSession: </code> a 
 *      session to manage ballot constrainer enabler to polls mappings </li> 
 *      <li> <code> BallotConstrainerEnablerSmartPollsSession: </code> a 
 *      session to manage dynamic polls of ballot constrainer enablers </li> 
 *      <li> <code> BallotConstrainerEnableRuleLookupSession: </code> a 
 *      session to look up ballot constrainer enabler mappings </li> 
 *      <li> <code> BallotConstrainerEnablerRuleApplicationSession: </code> a 
 *      session to apply ballot constrainer enablers </li> 
 *  </ul>
 *  
 */

public interface VotingRulesProxyManager
    extends org.osid.OsidProxyManager,
            org.osid.voting.rules.VotingRulesProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the race 
     *  constrainer lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RaceConstrainerLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceConstrainerLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceConstrainerLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.RaceConstrainerLookupSession getRaceConstrainerLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race 
     *  constrainer lookup service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RaceConstrainerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceConstrainerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceConstrainerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.RaceConstrainerLookupSession getRaceConstrainerLookupSessionForPolls(org.osid.id.Id pollsId, 
                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race 
     *  constrainer query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RaceConstrainerQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceConstrainerQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceConstrainerQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.RaceConstrainerQuerySession getRaceConstrainerQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race 
     *  constrainer query service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RaceConstrainerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceConstrainerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceConstrainerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.RaceConstrainerQuerySession getRaceConstrainerQuerySessionForPolls(org.osid.id.Id pollsId, 
                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race 
     *  constrainer search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RaceConstrainerSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceConstrainerSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceConstrainerSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.RaceConstrainerSearchSession getRaceConstrainerSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race 
     *  constrainer earch service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RaceConstrainerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceConstrainerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceConstrainerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.RaceConstrainerSearchSession getRaceConstrainerSearchSessionForPolls(org.osid.id.Id pollsId, 
                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race 
     *  constrainer administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RaceConstrainerAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceConstrainerAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceConstrainerAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.RaceConstrainerAdminSession getRaceConstrainerAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race 
     *  constrainer administration service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RaceConstrainerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceConstrainerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceConstrainerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.RaceConstrainerAdminSession getRaceConstrainerAdminSessionForPolls(org.osid.id.Id pollsId, 
                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race 
     *  constrainer notification service. 
     *
     *  @param  raceConstrainerReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> RaceConstrainerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> raceConstrainerReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceConstrainerNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceConstrainerNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.RaceConstrainerNotificationSession getRaceConstrainerNotificationSession(org.osid.voting.rules.RaceConstrainerReceiver raceConstrainerReceiver, 
                                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race 
     *  constrainer notification service for the given polls. 
     *
     *  @param  raceConstrainerReceiver the notification callback 
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RaceConstrainerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no polls found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> raceConstrainerReceiver, 
     *          pollsId </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceConstrainerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceConstrainerNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.RaceConstrainerNotificationSession getRaceConstrainerNotificationSessionForPolls(org.osid.voting.rules.RaceConstrainerReceiver raceConstrainerReceiver, 
                                                                                                                  org.osid.id.Id pollsId, 
                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup race constrainer/polls 
     *  mappings for race constrainers. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RaceConstrainerPollsSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceConstrainerPolls() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceConstrainerPolls() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.RaceConstrainerPollsSession getRaceConstrainerPollsSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning race 
     *  constrainer to polls. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RaceConstrainerPollsAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceConstrainerPollsAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceConstrainerPollsAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.RaceConstrainerPollsAssignmentSession getRaceConstrainerPollsAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage race constrainer smart 
     *  polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RaceConstrainerSmartPollsSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceConstrainerSmartPolls() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceConstrainerSmartPolls() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.RaceConstrainerSmartPollsSession getRaceConstrainerSmartPollsSession(org.osid.id.Id pollsId, 
                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race 
     *  constrainer mapping lookup service for looking up the rules applied to 
     *  ta race. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RaceConstrainerRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceConstrainerRuleLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceConstrainerRuleLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.RaceConstrainerRuleLookupSession getRaceConstrainerRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race 
     *  constrainer mapping lookup service for the given polls for looking up 
     *  rules applied to a qeue. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RaceConstrainerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceConstrainerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceConstrainerRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.RaceConstrainerRuleLookupSession getRaceConstrainerRuleLookupSessionForPolls(org.osid.id.Id pollsId, 
                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race 
     *  constrainer assignment service to apply to races. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RaceConstrainerRuleApplicationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceConstrainerRuleApplication() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceConstrainerRuleApplication() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.RaceConstrainerRuleApplicationSession getRaceConstrainerRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race 
     *  constrainer assignment service for the given polls to apply to races. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RaceConstrainerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceConstrainerRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceConstrainerRuleApplication() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.RaceConstrainerRuleApplicationSession getRaceConstrainerRuleApplicationSessionForPolls(org.osid.id.Id pollsId, 
                                                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race 
     *  constrainer enabler lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RaceConstrainerEnablerLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceConstrainerEnablerLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceConstrainerEnablerLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.RaceConstrainerEnablerLookupSession getRaceConstrainerEnablerLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race 
     *  constrainer enabler lookup service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RaceConstrainerEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceConstrainerEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceConstrainerEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.RaceConstrainerEnablerLookupSession getRaceConstrainerEnablerLookupSessionForPolls(org.osid.id.Id pollsId, 
                                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race 
     *  constrainer enabler query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RaceConstrainerEnablerQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceConstrainerEnablerQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceConstrainerEnablerQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.RaceConstrainerEnablerQuerySession getRaceConstrainerEnablerQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race 
     *  constrainer enabler query service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RaceConstrainerEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceConstrainerEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceConstrainerEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.RaceConstrainerEnablerQuerySession getRaceConstrainerEnablerQuerySessionForPolls(org.osid.id.Id pollsId, 
                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race 
     *  constrainer enabler search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RaceConstrainerEnablerSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceConstrainerEnablerSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceConstrainerEnablerSearch() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.RaceConstrainerEnablerSearchSession getRaceConstrainerEnablerSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race 
     *  constrainer enablers earch service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RaceConstrainerEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceConstrainerEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceConstrainerEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.RaceConstrainerEnablerSearchSession getRaceConstrainerEnablerSearchSessionForPolls(org.osid.id.Id pollsId, 
                                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race 
     *  constrainer enabler administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RaceConstrainerEnablerAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceConstrainerEnablerAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceConstrainerEnablerAdmin() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.RaceConstrainerEnablerAdminSession getRaceConstrainerEnablerAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race 
     *  constrainer enabler administration service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RaceConstrainerEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceConstrainerEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceConstrainerEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.RaceConstrainerEnablerAdminSession getRaceConstrainerEnablerAdminSessionForPolls(org.osid.id.Id pollsId, 
                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race 
     *  constrainer enabler notification service. 
     *
     *  @param  raceConstrainerEnablerReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> RaceConstrainerEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          raceConstrainerEnablerReceiver </code> or <code> proxy </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceConstrainerEnablerNotification() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceConstrainerEnablerNotification() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.voting.rules.RaceConstrainerEnablerNotificationSession getRaceConstrainerEnablerNotificationSession(org.osid.voting.rules.RaceConstrainerEnablerReceiver raceConstrainerEnablerReceiver, 
                                                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race 
     *  constrainer enabler notification service for the given polls. 
     *
     *  @param  raceConstrainerEnablerReceiver the notification callback 
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RaceConstrainerEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no polls found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          raceConstrainerEnablerReceiver, pollsId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceConstrainerEnablerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceConstrainerEnablerNotification() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.RaceConstrainerEnablerNotificationSession getRaceConstrainerEnablerNotificationSessionForPolls(org.osid.voting.rules.RaceConstrainerEnablerReceiver raceConstrainerEnablerReceiver, 
                                                                                                                                org.osid.id.Id pollsId, 
                                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup race constrainer 
     *  enabler/polls mappings for race constrainer enablers. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RaceConstrainerEnablerPollsSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceConstrainerEnablerPolls() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceConstrainerEnablerPolls() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.RaceConstrainerEnablerPollsSession getRaceConstrainerEnablerPollsSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning race 
     *  constrainer enablers to polls. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RaceConstrainerEnablerPollsAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceConstrainerEnablerPollsAssignment() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceConstrainerEnablerPollsAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.voting.rules.RaceConstrainerEnablerPollsAssignmentSession getRaceConstrainerEnablerPollsAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage race constrainer enabler 
     *  smart polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RaceConstrainerEnablerSmartPollsSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceConstrainerEnablerSmartPolls() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceConstrainerEnablerSmartPolls() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.voting.rules.RaceConstrainerEnablerSmartPollsSession getRaceConstrainerEnablerSmartPollsSession(org.osid.id.Id pollsId, 
                                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race 
     *  constrainer enabler mapping lookup service . 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RaceConstrainerEnablerRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceConstrainerEnablerRuleLookup() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceConstrainerEnablerRuleLookup() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.voting.rules.RaceConstrainerEnablerRuleLookupSession getRaceConstrainerEnablerRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race 
     *  constrainer enabler mapping lookup service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RaceConstrainerEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceConstrainerEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceConstrainerEnablerRuleLookup() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.RaceConstrainerEnablerRuleLookupSession getRaceConstrainerEnablerRuleLookupSessionForPolls(org.osid.id.Id pollsId, 
                                                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race 
     *  constrainer enabler assignment service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RaceConstrainerEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceConstrainerEnablerRuleApplication() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceConstrainerEnablerRuleApplication() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.voting.rules.RaceConstrainerEnablerRuleApplicationSession getRaceConstrainerEnablerRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race 
     *  constrainer enabler assignment service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RaceConstrainerEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceConstrainerEnablerRuleApplication() </code> or 
     *          <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceConstrainerEnablerRuleApplication() </code> 
     *              and <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.RaceConstrainerEnablerRuleApplicationSession getRaceConstrainerEnablerRuleApplicationSessionForPolls(org.osid.id.Id pollsId, 
                                                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race processor 
     *  lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RaceProcessorLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceProcessorLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceProcessorLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.RaceProcessorLookupSession getRaceProcessorLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race processor 
     *  lookup service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RaceProcessorLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceProcessorLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceProcessorLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.RaceProcessorLookupSession getRaceProcessorLookupSessionForPolls(org.osid.id.Id pollsId, 
                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race processor 
     *  query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RaceProcessorQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceProcessorQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceProcessorQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.RaceProcessorQuerySession getRaceProcessorQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race processor 
     *  query service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RaceProcessorQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceProcessorQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceProcessorQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.RaceProcessorQuerySession getRaceProcessorQuerySessionForPolls(org.osid.id.Id pollsId, 
                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race processor 
     *  search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RaceProcessorSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceProcessorSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceProcessorSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.RaceProcessorSearchSession getRaceProcessorSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race processor 
     *  earch service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RaceProcessorSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceProcessorSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceProcessorSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.RaceProcessorSearchSession getRaceProcessorSearchSessionForPolls(org.osid.id.Id pollsId, 
                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race processor 
     *  administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RaceProcessorAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceProcessorAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceProcessorAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.RaceProcessorAdminSession getRaceProcessorAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race processor 
     *  administration service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RaceProcessorAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceProcessorAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceProcessorAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.RaceProcessorAdminSession getRaceProcessorAdminSessionForPolls(org.osid.id.Id pollsId, 
                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race processor 
     *  notification service. 
     *
     *  @param  raceProcessorReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> RaceProcessorNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> raceProcessorReceiver 
     *          </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceProcessorNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceProcessorNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.RaceProcessorNotificationSession getRaceProcessorNotificationSession(org.osid.voting.rules.RaceProcessorReceiver raceProcessorReceiver, 
                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race processor 
     *  notification service for the given polls. 
     *
     *  @param  raceProcessorReceiver the notification callback 
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RaceProcessorNotificationSession </code> 
     *  @throws org.osid.NotFoundException no polls found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> raceProcessorReceiver, 
     *          pollsId </code> or <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceProcessorNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceProcessorNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.RaceProcessorNotificationSession getRaceProcessorNotificationSessionForPolls(org.osid.voting.rules.RaceProcessorReceiver raceProcessorReceiver, 
                                                                                                              org.osid.id.Id pollsId, 
                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup race processor/polls 
     *  mappings for race processors. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RaceProcessorPollsSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceProcessorPolls() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceProcessorPolls() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.RaceProcessorPollsSession getRaceProcessorPollsSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning race 
     *  processor to polls. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RaceProcessorPollsAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceProcessorPollsAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceProcessorPollsAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.RaceProcessorPollsAssignmentSession getRaceProcessorPollsAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage race processor smart 
     *  polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RaceProcessorSmartPollsSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceProcessorSmartPolls() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceProcessorSmartPolls() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.RaceProcessorSmartPollsSession getRaceProcessorSmartPollsSession(org.osid.id.Id pollsId, 
                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race processor 
     *  mapping lookup service for looking up the rules applied to a race 
     *  processor. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RaceProcessorRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceProcessorRuleLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceProcessorRuleLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.RaceProcessorRuleLookupSession getRaceProcessorRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race processor 
     *  mapping lookup service for the given polls for looking up rules 
     *  applied to a race. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RaceProcessorRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceProcessorRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceProcessorRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.RaceProcessorRuleLookupSession getRaceProcessorRuleLookupSessionForPolls(org.osid.id.Id pollsId, 
                                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race processor 
     *  assignment service to apply to races. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RaceProcessorRuleApplicationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceProcessorRuleApplication() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceProcessorRuleApplication() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.RaceProcessorRuleApplicationSession getRaceProcessorRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race processor 
     *  assignment service for the given polls to apply to races. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RaceProcessorRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceProcessorRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceProcessorRuleApplication() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.RaceProcessorRuleApplicationSession getRaceProcessorRuleApplicationSessionForPolls(org.osid.id.Id pollsId, 
                                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race processor 
     *  enabler lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RaceProcessorEnablerLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceProcessorEnablerLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceProcessorEnablerLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.RaceProcessorEnablerLookupSession getRaceProcessorEnablerLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race processor 
     *  enabler lookup service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RaceProcessorEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceProcessorEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceProcessorEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.RaceProcessorEnablerLookupSession getRaceProcessorEnablerLookupSessionForPolls(org.osid.id.Id pollsId, 
                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race processor 
     *  enabler query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RaceProcessorEnablerQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceProcessorEnablerQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceProcessorEnablerQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.RaceProcessorEnablerQuerySession getRaceProcessorEnablerQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race processor 
     *  enabler query service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RaceProcessorEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceProcessorEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceProcessorEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.RaceProcessorEnablerQuerySession getRaceProcessorEnablerQuerySessionForPolls(org.osid.id.Id pollsId, 
                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race processor 
     *  enabler search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RaceProcessorEnablerSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceProcessorEnablerSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceProcessorEnablerSearch() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.RaceProcessorEnablerSearchSession getRaceProcessorEnablerSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race processor 
     *  enablers earch service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RaceProcessorEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceProcessorEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceProcessorEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.RaceProcessorEnablerSearchSession getRaceProcessorEnablerSearchSessionForPolls(org.osid.id.Id pollsId, 
                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race processor 
     *  enabler administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RaceProcessorEnablerAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceProcessorEnablerAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceProcessorEnablerAdmin() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.RaceProcessorEnablerAdminSession getRaceProcessorEnablerAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race processor 
     *  enabler administration service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RaceProcessorEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceProcessorEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceProcessorEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.RaceProcessorEnablerAdminSession getRaceProcessorEnablerAdminSessionForPolls(org.osid.id.Id pollsId, 
                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race processor 
     *  enabler notification service. 
     *
     *  @param  raceProcessorEnablerReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> RaceProcessorEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          raceProcessorEnablerReceiver </code> or <code> proxy </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceProcessorEnablerNotification() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceProcessorEnablerNotification() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.voting.rules.RaceProcessorEnablerNotificationSession getRaceProcessorEnablerNotificationSession(org.osid.voting.rules.RaceProcessorEnablerReceiver raceProcessorEnablerReceiver, 
                                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race processor 
     *  enabler notification service for the given polls. 
     *
     *  @param  raceProcessorEnablerReceiver the notification callback 
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RaceProcessorEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no polls found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          raceProcessorEnablerReceiver, pollsId </code> or <code> proxy 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceProcessorEnablerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceProcessorEnablerNotification() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.RaceProcessorEnablerNotificationSession getRaceProcessorEnablerNotificationSessionForPolls(org.osid.voting.rules.RaceProcessorEnablerReceiver raceProcessorEnablerReceiver, 
                                                                                                                            org.osid.id.Id pollsId, 
                                                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup race processor 
     *  enabler/polls mappings for race processor enablers. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RaceProcessorEnablerPollsSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceProcessorEnablerPolls() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceProcessorEnablerPolls() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.RaceProcessorEnablerPollsSession getRaceProcessorEnablerPollsSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning race 
     *  processor enablers to race processors. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RaceProcessorEnablerPollsAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceProcessorEnablerPollsAssignment() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceProcessorEnablerPollsAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.voting.rules.RaceProcessorEnablerPollsAssignmentSession getRaceProcessorEnablerPollsAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage race processor enabler 
     *  smart polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RaceProcessorEnablerSmartPollsSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceProcessorEnablerSmartPolls() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceProcessorEnablerSmartPolls() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.RaceProcessorEnablerSmartPollsSession getRaceProcessorEnablerSmartPollsSession(org.osid.id.Id pollsId, 
                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race processor 
     *  enabler mapping lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RaceProcessorEnablerRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceProcessorEnablerRuleLookup() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceProcessorEnablerRuleLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.RaceProcessorEnablerRuleLookupSession getRaceProcessorEnablerRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race processor 
     *  enabler mapping lookup service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RaceProcessorEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceProcessorEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceProcessorEnablerRuleLookup() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.RaceProcessorEnablerRuleLookupSession getRaceProcessorEnablerRuleLookupSessionForPolls(org.osid.id.Id pollsId, 
                                                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race processor 
     *  enabler assignment service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> RaceProcessorEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceProcessorEnablerRuleApplication() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceProcessorEnablerRuleApplication() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.voting.rules.RaceProcessorEnablerRuleApplicationSession getRaceProcessorEnablerRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the race processor 
     *  enabler assignment service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> RaceProcessorEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRaceProcessorEnablerRuleApplication() </code> or 
     *          <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRaceProcessorEnablerRuleApplication() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.RaceProcessorEnablerRuleApplicationSession getRaceProcessorEnablerRuleApplicationSessionForPolls(org.osid.id.Id pollsId, 
                                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the ballot 
     *  constrainer lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BallotConstrainerLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBallotConstrainerLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotConstrainerLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.BallotConstrainerLookupSession getBallotConstrainerLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the ballot 
     *  constrainer lookup service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BallotConstrainerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBallotConstrainerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotConstrainerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.BallotConstrainerLookupSession getBallotConstrainerLookupSessionForPolls(org.osid.id.Id pollsId, 
                                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the ballot 
     *  constrainer query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BallotConstrainerQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBallotConstrainerQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotConstrainerQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.BallotConstrainerQuerySession getBallotConstrainerQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the ballot 
     *  constrainer query service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BallotConstrainerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBallotConstrainerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotConstrainerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.BallotConstrainerQuerySession getBallotConstrainerQuerySessionForPolls(org.osid.id.Id pollsId, 
                                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the ballot 
     *  constrainer search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BallotConstrainerSearchSession </code> 
     *  @throws org.osid.NullArgumentException a <code> 
     *          BallotConstrainerSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBallotConstrainerSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotConstrainerSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.BallotConstrainerSearchSession getBallotConstrainerSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the ballot 
     *  constrainer earch service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BallotConstrainerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBallotConstrainerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotConstrainerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.BallotConstrainerSearchSession getBallotConstrainerSearchSessionForPolls(org.osid.id.Id pollsId, 
                                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the ballot 
     *  constrainer administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BallotConstrainerAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBallotConstrainerAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotConstrainerAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.BallotConstrainerAdminSession getBallotConstrainerAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the ballot 
     *  constrainer administration service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BallotConstrainerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBallotConstrainerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotConstrainerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.BallotConstrainerAdminSession getBallotConstrainerAdminSessionForPolls(org.osid.id.Id pollsId, 
                                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the ballot 
     *  constrainer notification service. 
     *
     *  @param  ballotConstrainerReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> BallotConstrainerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          ballotConstrainerReceiver </code> or <code> proxy </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBallotConstrainerNotification() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotConstrainerNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.BallotConstrainerNotificationSession getBallotConstrainerNotificationSession(org.osid.voting.rules.BallotConstrainerReceiver ballotConstrainerReceiver, 
                                                                                                              org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the ballot 
     *  constrainer notification service for the given polls. 
     *
     *  @param  ballotConstrainerReceiver the notification callback 
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BallotConstrainerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no polls found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          ballotConstrainerReceiver, pollsId </code> or <code> proxy 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBallotConstrainerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotConstrainerNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.BallotConstrainerNotificationSession getBallotConstrainerNotificationSessionForPolls(org.osid.voting.rules.BallotConstrainerReceiver ballotConstrainerReceiver, 
                                                                                                                      org.osid.id.Id pollsId, 
                                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup ballot constrainer/polls 
     *  mappings for ballot constrainers. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BallotConstrainerPollsSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBallotConstrainerPolls() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotConstrainerPolls() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.BallotConstrainerPollsSession getBallotConstrainerPollsSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning ballot 
     *  constrainer to polls. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BallotConstrainerPollsAssignmentSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBallotConstrainerPollsAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotConstrainerPollsAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.voting.rules.BallotConstrainerPollsAssignmentSession getBallotConstrainerPollsAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage ballot constrainer smart 
     *  polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BallotConstrainerSmartPollsSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBallotConstrainerSmartPolls() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotConstrainerSmartPolls() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.BallotConstrainerSmartPollsSession getBallotConstrainerSmartPollsSession(org.osid.id.Id pollsId, 
                                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the ballot 
     *  constrainer mapping lookup service for looking up the rules applied to 
     *  a ballot. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BallotConstrainerRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBallotConstrainerRuleLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotConstrainerRuleLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.BallotConstrainerRuleLookupSession getBallotConstrainerRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the ballot 
     *  constrainer mapping lookup service for the given polls for looking up 
     *  rules applied to a ballot. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BallotConstrainerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBallotConstrainerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotConstrainerRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.BallotConstrainerRuleLookupSession getBallotConstrainerRuleLookupSessionForPolls(org.osid.id.Id pollsId, 
                                                                                                                  org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the ballot 
     *  constrainer assignment service to apply to ballots. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BallotConstrainerRuleApplicationSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBallotConstrainerRuleApplication() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotConstrainerRuleApplication() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.voting.rules.BallotConstrainerRuleApplicationSession getBallotConstrainerRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the ballot 
     *  constrainer assignment service for the given polls to apply to 
     *  ballots. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BallotConstrainerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBallotConstrainerRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotConstrainerRuleApplication() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.BallotConstrainerRuleApplicationSession getBallotConstrainerRuleApplicationSessionForPolls(org.osid.id.Id pollsId, 
                                                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the ballot 
     *  constrainer enabler lookup service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BallotConstrainerEnablerLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBallotConstrainerEnablerLookup() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotConstrainerEnablerLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.BallotConstrainerEnablerLookupSession getBallotConstrainerEnablerLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the ballot 
     *  constrainer enabler lookup service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BallotConstrainerEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBallotConstrainerEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotConstrainerEnablerLookup() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.BallotConstrainerEnablerLookupSession getBallotConstrainerEnablerLookupSessionForPolls(org.osid.id.Id pollsId, 
                                                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the ballot 
     *  constrainer enabler query service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BallotConstrainerEnablerQuerySession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBallotConstrainerEnablerQuery() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotConstrainerEnablerQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.BallotConstrainerEnablerQuerySession getBallotConstrainerEnablerQuerySession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the ballot 
     *  constrainer enabler query service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BallotConstrainerEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBallotConstrainerEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotConstrainerEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.BallotConstrainerEnablerQuerySession getBallotConstrainerEnablerQuerySessionForPolls(org.osid.id.Id pollsId, 
                                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the ballot 
     *  constrainer enabler search service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BallotConstrainerEnablerSearchSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBallotConstrainerEnablerSearch() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotConstrainerEnablerSearch() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.BallotConstrainerEnablerSearchSession getBallotConstrainerEnablerSearchSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the ballot 
     *  constrainer enablers earch service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BallotConstrainerEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBallotConstrainerEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotConstrainerEnablerSearch() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.BallotConstrainerEnablerSearchSession getBallotConstrainerEnablerSearchSessionForPolls(org.osid.id.Id pollsId, 
                                                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the ballot 
     *  constrainer enabler administration service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BallotConstrainerEnablerAdminSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBallotConstrainerEnablerAdmin() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotConstrainerEnablerAdmin() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.BallotConstrainerEnablerAdminSession getBallotConstrainerEnablerAdminSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the ballot 
     *  constrainer enabler administration service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BallotConstrainerEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId or proxy is null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBallotConstrainerEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotConstrainerEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.voting.rules.BallotConstrainerEnablerAdminSession getBallotConstrainerEnablerAdminSessionForPolls(org.osid.id.Id pollsId, 
                                                                                                                      org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the ballot 
     *  constrainer enabler notification service. 
     *
     *  @param  ballotConstrainerEnablerReceiver the notification callback 
     *  @param  proxy a proxy 
     *  @return a <code> BallotConstrainerEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          ballotConstrainerEnablerReceiver </code> or <code> proxy 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBallotConstrainerEnablerNotification() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotConstrainerEnablerNotification() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.voting.rules.BallotConstrainerEnablerNotificationSession getBallotConstrainerEnablerNotificationSession(org.osid.voting.rules.BallotConstrainerEnablerReceiver ballotConstrainerEnablerReceiver, 
                                                                                                                            org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the ballot 
     *  constrainer enabler notification service for the given polls. 
     *
     *  @param  ballotConstrainerEnablerReceiver the notification callback 
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BallotConstrainerEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no polls found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          ballotConstrainerEnablerReceiver, pollsId </code> or <code> 
     *          proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBallotConstrainerEnablerNotification() </code> or 
     *          <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotConstrainerEnablerNotification() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.BallotConstrainerEnablerNotificationSession getBallotConstrainerEnablerNotificationSessionForPolls(org.osid.voting.rules.BallotConstrainerEnablerReceiver ballotConstrainerEnablerReceiver, 
                                                                                                                                    org.osid.id.Id pollsId, 
                                                                                                                                    org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup ballot constrainer 
     *  enabler/polls mappings for ballot constrainer enablers. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BallotConstrainerEnablerPollsSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBallotConstrainerEnablerPolls() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotConstrainerEnablerPolls() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.BallotConstrainerEnablerPollsSession getBallotConstrainerEnablerPollsSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning ballot 
     *  constrainer enablers to polls. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BallotConstrainerEnablerPollsAssignmentSession 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBallotConstrainerEnablerPollsAssignment() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotConstrainerEnablerPollsAssignment() </code> 
     *              is <code> true. </code> 
     */

    public org.osid.voting.rules.BallotConstrainerEnablerPollsAssignmentSession getBallotConstrainerEnablerPollsAssignmentSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage ballot constrainer 
     *  enabler smart polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BallotConstrainerEnablerSmartPollsSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBallotConstrainerEnablerSmartPolls() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotConstrainerEnablerSmartPolls() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.voting.rules.BallotConstrainerEnablerSmartPollsSession getBallotConstrainerEnablerSmartPollsSession(org.osid.id.Id pollsId, 
                                                                                                                        org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the ballot 
     *  constrainer enabler mapping lookup service . 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BallotConstrainerEnablerRuleLookupSession </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBallotConstrainerEnablerRuleLookup() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotConstrainerEnablerRuleLookup() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.voting.rules.BallotConstrainerEnablerRuleLookupSession getBallotConstrainerEnablerRuleLookupSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the ballot 
     *  constrainer enabler mapping lookup service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BallotConstrainerEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBallotConstrainerEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotConstrainerEnablerRuleLookup() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.BallotConstrainerEnablerRuleLookupSession getBallotConstrainerEnablerRuleLookupSessionForPolls(org.osid.id.Id pollsId, 
                                                                                                                                org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the ballot 
     *  constrainer enabler assignment service. 
     *
     *  @param  proxy a proxy 
     *  @return a <code> BallotConstrainerEnablerRuleApplicationSession 
     *          </code> 
     *  @throws org.osid.NullArgumentException <code> proxy </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBallotConstrainerEnablerRuleApplication() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotConstrainerEnablerRuleApplication() </code> 
     *              is <code> true. </code> 
     */

    public org.osid.voting.rules.BallotConstrainerEnablerRuleApplicationSession getBallotConstrainerEnablerRuleApplicationSession(org.osid.proxy.Proxy proxy)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the ballot 
     *  constrainer enabler assignment service for the given polls. 
     *
     *  @param  pollsId the <code> Id </code> of the <code> Polls </code> 
     *  @param  proxy a proxy 
     *  @return a <code> BallotConstrainerEnablerRuleApplicationSession 
     *          </code> 
     *  @throws org.osid.NotFoundException no <code> Polls </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> pollsId </code> or 
     *          <code> proxy </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsBallotConstrainerEnablerRuleApplication() </code> or 
     *          <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsBallotConstrainerEnablerRuleApplication() </code> 
     *              and <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.voting.rules.BallotConstrainerEnablerRuleApplicationSession getBallotConstrainerEnablerRuleApplicationSessionForPolls(org.osid.id.Id pollsId, 
                                                                                                                                          org.osid.proxy.Proxy proxy)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;
}
