//
// org.osid.workflow.ManualWorkflowSession
//
//     The OSID Java specification for org.osid.workflow.ManualWorkflowSession.
//
// Copyright (C) 2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.workflow;


/**
 *  <p>This session provides methods for manually moving work through a 
 *  workflow. </p>
 */

public interface ManualWorkflowSession
    extends org.osid.workflow.WorkflowManagementSession {


    /**
     *  Tests if this user can operate a workflow. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer workflow operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if workflow operation methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canOperateWorkflow();


    /**
     *  Tests if this user can operate a workflow. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known all methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer workflow operations to 
     *  unauthorized users. 
     *
     *  @param  processId a process <code> Id </code> 
     *  @return <code> false </code> if workflow operation methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> processId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canOperateWorkflowForProcess(org.osid.id.Id processId);


    /**
     *  Advances work to a next step in the workflow based on the work and the 
     *  input conditions of the next steps. 
     *
     *  @param  processId a process <code> Id </code> 
     *  @param  workId a work <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> processId </code> is not 
     *          found or <code> workId </code> is in process 
     *  @throws org.osid.NullArgumentException <code> processId </code> or 
     *          <code> workId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void advanceWork(org.osid.id.Id processId, org.osid.id.Id workId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the valid next steps in this process in which the given work can 
     *  be manually advanced. 
     *
     *  @param  processId a process <code> Id </code> 
     *  @param  workId a work <code> Id </code> 
     *  @return the returned <code> Step </code> list 
     *  @throws org.osid.NotFoundException <code> processId </code> is not 
     *          found or <code> workId </code> is in process 
     *  @throws org.osid.NullArgumentException <code> processId </code> or 
     *          <code> workId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.StepList getValidNextStepsForWork(org.osid.id.Id processId, 
                                                               org.osid.id.Id workId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the all valid steps in this process the given work can be 
     *  manually assigned and includes the steps previous to the work's 
     *  current step. 
     *
     *  @param  processId a process <code> Id </code> 
     *  @param  workId a work <code> Id </code> 
     *  @return the returned <code> Step </code> list 
     *  @throws org.osid.NotFoundException <code> processId </code> is not 
     *          found or <code> workId </code> is in process 
     *  @throws org.osid.NullArgumentException <code> processId </code> or 
     *          <code> workId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.StepList getAllValidStepsForWork(org.osid.id.Id processId, 
                                                              org.osid.id.Id workId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Manually assigns a work to a step. 
     *
     *  @param  processId a process <code> Id </code> 
     *  @param  workId a work <code> Id </code> 
     *  @param  stepId a step <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> processId </code> is not 
     *          found or <code> workId </code> or <code> stepId </code> is not 
     *          found in this process 
     *  @throws org.osid.NullArgumentException <code> processId, workId, 
     *          </code> or <code> stepId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignWorkToStep(org.osid.id.Id processId, 
                                 org.osid.id.Id workId, org.osid.id.Id stepId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
