//
// org.osid.workflow.OfficeSearchSession
//
//     The OSID Java specification for org.osid.workflow.OfficeSearchSession.
//
// Copyright (C) 2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.workflow;


/**
 *  <p>This session provides methods for searching among <code> Office </code> 
 *  objects. The search query is constructed using the <code> OfficeQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getOfficesByQuery() </code> is the basic search method and 
 *  returns a list of <code> Offices. </code> A more advanced search may be 
 *  performed with <code> getOfficesBySearch(). </code> It accepts an <code> 
 *  OfficeSearch </code> in addition to the query for the purpose of 
 *  specifying additional options affecting the entire search, such as 
 *  ordering. <code> getOfficesBySearch() </code> returns an <code> 
 *  OfficeSearchResults </code> that can be used to access the resulting 
 *  <code> OfficeList </code> or be used to perform a search within the result 
 *  set through <code> OfficeSearch. </code> </p> 
 *  
 *  <p> Offices may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> OfficeQuery. </code> 
 *  </p>
 */

public interface OfficeSearchSession
    extends org.osid.workflow.OfficeQuerySession {


    /**
     *  Gets an office search. 
     *
     *  @return the office search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.OfficeSearch getOfficeSearch();


    /**
     *  Gets an office search order. The <code> OfficeSearchOrder </code> is 
     *  supplied to an <code> OfficeSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the office search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.OfficeSearchOrder getOfficeSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  officeQuery the office query 
     *  @param  officeSearch the office search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> officeQuery </code> or 
     *          <code> officeSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> officeQuery </code> or 
     *          <code> officeSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.OfficeSearchResults getOfficesBySearch(org.osid.workflow.OfficeQuery officeQuery, 
                                                                    org.osid.workflow.OfficeSearch officeSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets an office query from an inspector. The inspector is available 
     *  from an <code> OfficeSearchResults. </code> 
     *
     *  @param  officeQueryInspector an office query inspector 
     *  @return the office query 
     *  @throws org.osid.NullArgumentException <code> officeQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> officeQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.OfficeQuery getOfficeQueryFromInspector(org.osid.workflow.OfficeQueryInspector officeQueryInspector);
}
