//
// org.osid.workflow.StepOfficeAssignmentSession
//
//     The OSID Java specification for org.osid.workflow.StepOfficeAssignmentSession.
//
// Copyright (C) 2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.workflow;


/**
 *  <p>This session provides methods to re-assign <code> Step </code> to 
 *  <code> Office </code> mappings. A <code> Step </code> may appear in 
 *  multiple <code> Office </code> objects and removing the last reference to 
 *  a <code> Step </code> is the equivalent of deleting it. Each <code> Office 
 *  </code> may have its own authorizations governing who is allowed to 
 *  operate on it. </p> 
 *  
 *  <p> Adding a reference of a <code> Step </code> to another <code> Office 
 *  </code> is not a copy operation (eg: does not change its <code> Id </code> 
 *  ). </p>
 */

public interface StepOfficeAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter step/office mappings. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignStepes();


    /**
     *  Tests if this user can alter step/office mappings. A return of true 
     *  does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer assignment operations to 
     *  unauthorized users. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignStepesToOffice(org.osid.id.Id officeId);


    /**
     *  Gets a list of offices including and under the given office node in 
     *  which any step can be assigned. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return list of assignable office <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableOfficeIds(org.osid.id.Id officeId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of offices including and under the given office node in 
     *  which a specific step can be assigned. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @param  stepId the <code> Id </code> of the <code> Step </code> 
     *  @return list of assignable office <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> or 
     *          <code> stepId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableOfficeIdsForStep(org.osid.id.Id officeId, 
                                                            org.osid.id.Id stepId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> Step </code> to a <code> Office. </code> 
     *
     *  @param  stepId the <code> Id </code> of the <code> Step </code> 
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @throws org.osid.AlreadyExistsException <code> stepId </code> is 
     *          already assigned to <code> officeId </code> 
     *  @throws org.osid.NotFoundException <code> stepId </code> or <code> 
     *          officeId </code> not found 
     *  @throws org.osid.NullArgumentException <code> stepId </code> or <code> 
     *          officeId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignStepToOffice(org.osid.id.Id stepId, 
                                   org.osid.id.Id officeId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> Step </code> from a <code> Office. </code> 
     *
     *  @param  stepId the <code> Id </code> of the <code> Step </code> 
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @throws org.osid.NotFoundException <code> stepId </code> or <code> 
     *          officeId </code> not found or <code> stepId </code> is not 
     *          assigned to <code> officeId </code> 
     *  @throws org.osid.NullArgumentException <code> stepId </code> or <code> 
     *          officeId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignStepFromOffice(org.osid.id.Id stepId, 
                                       org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
