//
// org.osid.workflow.StepQuery
//
//     The OSID Java specification for org.osid.workflow.StepQuery.
//
// Copyright (C) 2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.workflow;


/**
 *  <p>This is the query for searching steps. Each method match specifies an 
 *  <code> AND </code> term while multiple invocations of the same method 
 *  produce a nested <code> OR. </code> </p>
 */

public interface StepQuery
    extends org.osid.OsidGovernatorQuery,
            org.osid.OsidSubjugateableQuery {


    /**
     *  Sets the process <code> Id </code> for this query. 
     *
     *  @param  processId the process <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> processId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchProcessId(org.osid.id.Id processId, boolean match);


    /**
     *  Clears the process <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProcessIdTerms();


    /**
     *  Tests if a <code> ProcessQuery </code> is available. 
     *
     *  @return <code> true </code> if a process query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcessQuery();


    /**
     *  Gets the query for a process. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the process query 
     *  @throws org.osid.UnimplementedException <code> supportsProcessQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessQuery() </code> is <code> true. </code> 
     */

    public org.osid.workflow.ProcessQuery getProcessQuery();


    /**
     *  Clears the process query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearProcessTerms();


    /**
     *  Sets the resource <code> Id </code> for this query. 
     *
     *  @param  resourceId the resource <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchResourceId(org.osid.id.Id resourceId, boolean match);


    /**
     *  Clears the resource <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearResourceIdTerms();


    /**
     *  Tests if a <code> ResourceQuery </code> is available. 
     *
     *  @return <code> true </code> if a resource query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsResourceQuery();


    /**
     *  Gets the query for a resource. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the resource query 
     *  @throws org.osid.UnimplementedException <code> supportsResourceQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsResourceQuery() </code> is <code> true. </code> 
     */

    public org.osid.resource.ResourceQuery getResourceQuery();


    /**
     *  Matches steps that have any resources. 
     *
     *  @param  match <code> true </code> to match steps with any resources, 
     *          <code> false </code> to match steps with no resources 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyResource(boolean match);


    /**
     *  Clears the resource query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearResourceTerms();


    /**
     *  Matches initial steps. 
     *
     *  @param  match <code> true </code> to match initial steps, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchInitial(boolean match);


    /**
     *  Clears the initial step terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearInitialTerms();


    /**
     *  Matches terminal steps. 
     *
     *  @param  match <code> true </code> to match terminal steps, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchTerminal(boolean match);


    /**
     *  Clears the terminal step terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearTerminalTerms();


    /**
     *  Sets the input state <code> Id </code> for this query. 
     *
     *  @param  stateId the state <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> stateId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchInputStateId(org.osid.id.Id stateId, boolean match);


    /**
     *  Clears the input state <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearInputStateIdTerms();


    /**
     *  Tests if a <code> StateQuery </code> is available. 
     *
     *  @return <code> true </code> if a state query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsInputStateQuery();


    /**
     *  Gets the query for an input state. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the state query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsInputStateQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsInputtStateQuery() </code> is <code> true. </code> 
     */

    public org.osid.process.StateQuery getInputStateQuery();


    /**
     *  Matches steps that have any input states. 
     *
     *  @param  match <code> true </code> to match steps with any input 
     *          states, <code> false </code> to match steps with no input 
     *          states 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyInputState(boolean match);


    /**
     *  Clears the input state terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearInputStateTerms();


    /**
     *  Sets the next state <code> Id </code> for this query. 
     *
     *  @param  stateId the state <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> stateId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchNextStateId(org.osid.id.Id stateId, boolean match);


    /**
     *  Clears the next state <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearNextStateIdTerms();


    /**
     *  Tests if a <code> StateQuery </code> is available. 
     *
     *  @return <code> true </code> if a state query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsNextStateQuery();


    /**
     *  Gets the query for a state. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the state query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsNextStateQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsNextStateQuery() </code> is <code> true. </code> 
     */

    public org.osid.process.StateQuery getNextStateQuery();


    /**
     *  Matches steps that have any next state, 
     *
     *  @param  match <code> true </code> to match steps with any next state, 
     *          <code> false </code> to match steps with no next state 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyNextState(boolean match);


    /**
     *  Clears the state terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearNextStateTerms();


    /**
     *  Sets the work <code> Id </code> for this query. 
     *
     *  @param  workId the work <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> workId </code> is <code> 
     *          null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchWorkId(org.osid.id.Id workId, boolean match);


    /**
     *  Clears the work <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearWorkIdTerms();


    /**
     *  Tests if a <code> WorkQuery </code> is available. 
     *
     *  @return <code> true </code> if a work query is available, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWorkQuery();


    /**
     *  Gets the query for a work. Multiple retrievals produce a nested <code> 
     *  OR </code> term. 
     *
     *  @return the work query 
     *  @throws org.osid.UnimplementedException <code> supportsWorkQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWorkQuery() </code> is <code> true. </code> 
     */

    public org.osid.workflow.WorkQuery getWorkQuery();


    /**
     *  Matches steps that have any work. 
     *
     *  @param  match <code> true </code> to match steps with any work, <code> 
     *          false </code> to match steps with no work 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyWork(boolean match);


    /**
     *  Clears the work query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearWorkTerms();


    /**
     *  Sets the office <code> Id </code> for this query to match steps 
     *  assigned to offices. 
     *
     *  @param  officeId the office <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchOfficeId(org.osid.id.Id officeId, boolean match);


    /**
     *  Clears the office <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOfficeIdTerms();


    /**
     *  Tests if a <code> OfficeQuery </code> is available. 
     *
     *  @return <code> true </code> if a office query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfficeQuery();


    /**
     *  Gets the query for a office. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the office query 
     *  @throws org.osid.UnimplementedException <code> supportsOfficeQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfficeQuery() </code> is <code> true. </code> 
     */

    public org.osid.workflow.OfficeQuery getOfficeQuery();


    /**
     *  Clears the office query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOfficeTerms();


    /**
     *  Gets the step query record corresponding to the given <code> Step 
     *  </code> record <code> Type. </code> Multiple record retrievals produce 
     *  a nested <code> OR </code> term. 
     *
     *  @param  stepRecordType a step record type 
     *  @return the step query record 
     *  @throws org.osid.NullArgumentException <code> stepRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(stepRecordType) </code> is <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.records.StepQueryRecord getStepQueryRecord(org.osid.type.Type stepRecordType)
        throws org.osid.OperationFailedException;
}
