//
// org.osid.workflow.StepSearchSession
//
//     The OSID Java specification for org.osid.workflow.StepSearchSession.
//
// Copyright (C) 2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.workflow;


/**
 *  <p>This session provides methods for searching among <code> Step </code> 
 *  objects. The search query is constructed using the <code> StepQuery. 
 *  </code> </p> 
 *  
 *  <p> <code> getStepsByQuery() </code> is the basic search method and 
 *  returns a list of <code> Steps. </code> A more advanced search may be 
 *  performed with <code> getStepsBySearch(). </code> It accepts a <code> 
 *  StepSearch </code> in addition to the query for the purpose of specifying 
 *  additional options affecting the entire search, such as ordering. <code> 
 *  getStepsBySearch() </code> returns a <code> StepSearchResults </code> that 
 *  can be used to access the resulting <code> StepList </code> or be used to 
 *  perform a search within the result set through <code> StepSearch. </code> 
 *  </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated office view: searches include steps in offices of which 
 *      this office is an ancestor in the office hierarchy </li> 
 *      <li> isolated office view: searches are restricted to steps in this 
 *      office </li> 
 *  </ul>
 *  
 *  
 *  <p> Steps may have a query record indicated by their respective record 
 *  types. The query record is accessed via the <code> StepQuery. </code> </p>
 */

public interface StepSearchSession
    extends org.osid.workflow.StepQuerySession {


    /**
     *  Gets a step search. 
     *
     *  @return the step search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.StepSearch getStepSearch();


    /**
     *  Gets a step search order. The <code> StepSearchOrder </code> is 
     *  supplied to a <code> StepSearch </code> to specify the ordering of 
     *  results. 
     *
     *  @return the step search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.StepSearchOrder getStepSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  stepQuery the step query 
     *  @param  stepSearch the step search 
     *  @return the step search results 
     *  @throws org.osid.NullArgumentException <code> stepQuery </code> or 
     *          <code> stepSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> stepQuery </code> or 
     *          <code> stepSearch </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.StepSearchResults getStepsBySearch(org.osid.workflow.StepQuery stepQuery, 
                                                                org.osid.workflow.StepSearch stepSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a step query from an inspector. The inspector is available from a 
     *  <code> StepSearchResults. </code> 
     *
     *  @param  stepQueryInspector a step query inspector 
     *  @return the step query 
     *  @throws org.osid.NullArgumentException <code> stepQueryInspector 
     *          </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> stepQueryInspector 
     *          </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.StepQuery getStepQueryFromInspector(org.osid.workflow.StepQueryInspector stepQueryInspector);
}
