//
// org.osid.workflow.WorkflowEvent
//
//     The OSID Java specification for org.osid.workflow.WorkflowEvent.
//
// Copyright (C) 2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.workflow;


/**
 *  <p>A <code> WorkflowEvent </code> is a change in a workflow. </p>
 */

public interface WorkflowEvent
    extends org.osid.OsidObject {


    /**
     *  Gets the timestamp of this event. 
     *
     *  @return the timestamp 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.calendaring.DateTime getTimestamp();


    /**
     *  Gets the <code> Id </code> of the process. 
     *
     *  @return the process <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getProcessId();


    /**
     *  Gets the process. 
     *
     *  @return the process 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.Process getProcess()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the resource that caused this event. 
     *
     *  @return the resource <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getWorkerId();


    /**
     *  Gets the resource that caused this event. 
     *
     *  @return the resource 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.resource.Resource getWorker()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the agent that caused this event. 
     *
     *  @return the agent <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getWorkingAgentId();


    /**
     *  Gets the agent that caused this event. 
     *
     *  @return the agent 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.authentication.Agent getWorkingAgent()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> Id </code> of the work. 
     *
     *  @return the work <code> Id </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getWorkId();


    /**
     *  Gets the work. 
     *
     *  @return the work 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.Work getWork()
        throws org.osid.OperationFailedException;


    /**
     *  Tests if this work event indicates the work has been canceled the 
     *  workflow and is not associated with a step at the time of this event. 
     *
     *  @return <code> true </code> if the work canceled, <code> false </code> 
     *          if the work is associated with a step in this event 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean didCancel();


    /**
     *  Gets the <code> Id </code> of the step at which the work is in at the 
     *  time of this event. 
     *
     *  @return the step <code> Id </code> 
     *  @throws org.osid.IllegalStateException <code> didComplete() </code> or 
     *          <code> didCancel() </code> is <code> true </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getStepId();


    /**
     *  Gets the step at which the work is in at the time of this event. 
     *
     *  @return the step 
     *  @throws org.osid.IllegalStateException <code> didComplete() </code> or 
     *          <code> didCancel() </code> is <code> true </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.Step getStep()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the workflow event record corresponding to the given <code> 
     *  WorkflowEvent </code> record <code> Type. </code> This method is used 
     *  to retrieve an object implementing the requested record. The <code> 
     *  workflowEventRecordType </code> may be the <code> Type </code> 
     *  returned in <code> getRecordTypes() </code> or any of its parents in a 
     *  <code> Type </code> hierarchy where <code> 
     *  hasRecordType(workflowEventRecordType) </code> is <code> true </code> 
     *  . 
     *
     *  @param  workFlowRecordType the type of workflow event record to 
     *          retrieve 
     *  @return the workflow event record 
     *  @throws org.osid.NullArgumentException <code> workRecordType </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(workflowEventRecordType) </code> is <code> false 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.records.WorkflowEventRecord getWorkflowEventRecord(org.osid.type.Type workFlowRecordType)
        throws org.osid.OperationFailedException;
}
