//
// org.osid.workflow.WorkflowEventLookupSession
//
//     The OSID Java specification for org.osid.workflow.WorkflowEventLookupSession.
//
// Copyright (C) 2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.workflow;


/**
 *  <p>This session provides methods for retrieving <code> WorkflowEvents. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated office view: All workflow event methods in this session 
 *      operate, retrieve and pertain to workflow events defined explicitly in 
 *      the current office. </li> 
 *      <li> federated office view: All workflow event methods in this session 
 *      operate, retrieve and pertain to all workflow events defined in this 
 *      office and any other wokflow events implicitly available in this 
 *      office through office inheritence. </li> 
 *  </ul>
 *  
 */

public interface WorkflowEventLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Office </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Office Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getOfficeId();


    /**
     *  Gets the <code> Office </code> associated with this session. 
     *
     *  @return the office 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.Office getOffice()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can look up workflow events. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known changing a step sequence in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer lookup operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if workflow event lookups is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupWorkflowEvents();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeWorkflowEventView();


    /**
     *  A complete view of the <code> WorkflowEvent </code> returns is 
     *  desired. Methods will return what is requested or result in an error. 
     *  This view is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryWorkflowEventView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include workflow events in offices which are children of this office 
     *  in the office hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedOfficeView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this office only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedOfficeView();


    /**
     *  Gets the <code> WorkflowEvent </code> specified by its <code> Id. 
     *  </code> In plenary mode, the exact <code> Id </code> is found or a 
     *  <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  WorkflowEvent </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> WorkflowEvent </code> and retained for 
     *  compatibility. 
     *
     *  @param  workflowEventId <code> Id </code> of the <code> WorkflowEvent 
     *          </code> 
     *  @return the workflow event 
     *  @throws org.osid.NotFoundException <code> workflowEventId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> workflowEventId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.workflow.WorkflowEvent getWorkflowEvent(org.osid.id.Id workflowEventId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> WorkflowEventList </code> corresponding to the given 
     *  <code> IdList. </code> In plenary mode, the returned list contains all 
     *  of the workflow events specified in the <code> Id </code> list, in the 
     *  order of the list, including duplicates, or an error results if an 
     *  <code> Id </code> in the supplied list is not found or inaccessible. 
     *  Otherwise, inaccessible <code> WorkflowEvents </code> may be omitted 
     *  from the list and may present the elements in any order including 
     *  returning a unique set. 
     *
     *  @param  workflowEventIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> WorkflowEvent </code> list 
     *  @throws org.osid.NotFoundException an <code> Id was </code> not found 
     *  @throws org.osid.NullArgumentException <code> workflowEventIds </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.WorkflowEventList getWorkflowEventsByIds(org.osid.id.IdList workflowEventIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> WorkflowEventList </code> corresponding to the given 
     *  workflow event genus <code> Type </code> which does not include 
     *  workflow events of genus types derived from the specified <code> Type. 
     *  </code> In plenary mode, the returned list contains all known workflow 
     *  events or an error results. Otherwise, the returned list may contain 
     *  only those workflow events that are accessible through this session. 
     *
     *  @param  workflowEventGenusType a workflow event genus type 
     *  @return the returned <code> WorkflowEvent </code> list 
     *  @throws org.osid.NullArgumentException <code> workflowEventGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.WorkflowEventList getWorkflowEventsByGenusType(org.osid.type.Type workflowEventGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> WorkflowEventList </code> corresponding to the given 
     *  workflow event genus <code> Type </code> and include any additional 
     *  workflow events with genus types derived from the specified <code> 
     *  Type. </code> In plenary mode, the returned list contains all known 
     *  workflow events or an error results. Otherwise, the returned list may 
     *  contain only those workflow events that are accessible through this 
     *  session. 
     *
     *  @param  workflowEventGenusType a workflow event genus type 
     *  @return the returned <code> WorkflowEvent </code> list 
     *  @throws org.osid.NullArgumentException <code> workflowEventGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.WorkflowEventList getWorkflowEventsByParentGenusType(org.osid.type.Type workflowEventGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> WorkflowEventList </code> containing the given workflow 
     *  event record <code> Type. </code> In plenary mode, the returned list 
     *  contains all known workflow events or an error results. Otherwise, the 
     *  returned list may contain only those workflow events that are 
     *  accessible through this session. 
     *
     *  @param  workflowEventRecordType a workflow event record type 
     *  @return the returned <code> WorkflowEvent </code> list 
     *  @throws org.osid.NullArgumentException <code> workflowEventRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.WorkflowEventList getWorkflowEventsByRecordType(org.osid.type.Type workflowEventRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the entire workflow log within the given date range inclusive. In 
     *  plenary mode, the returned list contains all known workflow events or 
     *  an error results. Otherwise, the returned list may contain only those 
     *  workflow events that are accessible through this session. 
     *
     *  @param  start start range 
     *  @param  end end range 
     *  @return the workflow events 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          greater than <code> end </code> 
     *  @throws org.osid.NullArgumentException <code> start </code> or <code> 
     *          end </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.WorkflowEventList getWorkflowEventsByDate(org.osid.calendaring.DateTime start, 
                                                                       org.osid.calendaring.DateTime end)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the entire workflow log for a process. In plenary mode, the 
     *  returned list contains all known workflow events or an error results. 
     *  Otherwise, the returned list may contain only those workflow events 
     *  that are accessible through this session. 
     *
     *  @param  processId a process <code> Id </code> 
     *  @return the workflow events 
     *  @throws org.osid.NullArgumentException <code> processId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.WorkflowEventList getWorkflowEventsForProcess(org.osid.id.Id processId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the entire workflow log for this process within the given date 
     *  range inclusive. In plenary mode, the returned list contains all known 
     *  workflow events or an error results. Otherwise, the returned list may 
     *  contain only those workflow events that are accessible through this 
     *  session. 
     *
     *  @param  processId a process <code> Id </code> 
     *  @param  start start range 
     *  @param  end end range 
     *  @return the workflow events 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          greater than <code> end </code> 
     *  @throws org.osid.NullArgumentException <code> processId, start, 
     *          </code> or <code> end </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.WorkflowEventList getWorkflowEventsByDateForProcess(org.osid.id.Id processId, 
                                                                                 org.osid.calendaring.DateTime start, 
                                                                                 org.osid.calendaring.DateTime end)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the workflow log for a step. In plenary mode, the returned list 
     *  contains all known workflow events or an error results. Otherwise, the 
     *  returned list may contain only those workflow events that are 
     *  accessible through this session. 
     *
     *  @param  stepId a step <code> Id </code> 
     *  @return the workflow events 
     *  @throws org.osid.NullArgumentException <code> stepId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.WorkflowEventList getWorkflowEventsForStep(org.osid.id.Id stepId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the workflow log for a step within the given date range 
     *  inclusive. In plenary mode, the returned list contains all known 
     *  workflow events or an error results. Otherwise, the returned list may 
     *  contain only those workflow events that are accessible through this 
     *  session. 
     *
     *  @param  stepId a step <code> Id </code> 
     *  @param  start start range 
     *  @param  end end range 
     *  @return the workflow events 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          greater than <code> end </code> 
     *  @throws org.osid.NullArgumentException <code> stepId, start </code> or 
     *          <code> end </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.WorkflowEventList getWorkflowEventsByDateForStep(org.osid.id.Id stepId, 
                                                                              org.osid.calendaring.DateTime start, 
                                                                              org.osid.calendaring.DateTime end)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the workflow log for a work. In plenary mode, the returned list 
     *  contains all known workflow events or an error results. Otherwise, the 
     *  returned list may contain only those workflow events that are 
     *  accessible through this session. 
     *
     *  @param  workId a work <code> Id </code> 
     *  @return the workflow events 
     *  @throws org.osid.NullArgumentException <code> workId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.WorkflowEventList getWorkflowEventsForWork(org.osid.id.Id workId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the workflow log for a work within the given date range 
     *  inclusive. In plenary mode, the returned list contains all known 
     *  workflow events or an error results. Otherwise, the returned list may 
     *  contain only those workflow events that are accessible through this 
     *  session. 
     *
     *  @param  workId a work <code> Id </code> 
     *  @param  start start range 
     *  @param  end end range 
     *  @return the workflow events 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          greater than <code> end </code> 
     *  @throws org.osid.NullArgumentException <code> workId, start </code> or 
     *          <code> end </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.WorkflowEventList getWorkflowEventsByDateForWork(org.osid.id.Id workId, 
                                                                              org.osid.calendaring.DateTime start, 
                                                                              org.osid.calendaring.DateTime end)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the workflow log for a work in a process. In plenary mode, the 
     *  returned list contains all known workflow events or an error results. 
     *  Otherwise, the returned list may contain only those workflow events 
     *  that are accessible through this session. 
     *
     *  @param  processId a process <code> Id </code> 
     *  @param  workId a work <code> Id </code> 
     *  @return the workflow events 
     *  @throws org.osid.NullArgumentException <code> workId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.WorkflowEventList getWorkflowEventsForWorkAndProcess(org.osid.id.Id processId, 
                                                                                  org.osid.id.Id workId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the workflow log for a work in a process within the given date 
     *  range inclusive. In plenary mode, the returned list contains all known 
     *  workflow events or an error results. Otherwise, the returned list may 
     *  contain only those workflow events that are accessible through this 
     *  session. 
     *
     *  @param  processId a process <code> Id </code> 
     *  @param  workId a work <code> Id </code> 
     *  @param  start start range 
     *  @param  end end range 
     *  @return the workflow events 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          greater than <code> end </code> 
     *  @throws org.osid.NullArgumentException <code> workId, start </code> or 
     *          <code> end </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.WorkflowEventList getWorkflowEventsByDateForWorkAndProcess(org.osid.id.Id processId, 
                                                                                        org.osid.id.Id workId, 
                                                                                        org.osid.calendaring.DateTime start, 
                                                                                        org.osid.calendaring.DateTime end)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the workflow log for a work in this process. In plenary mode, the 
     *  returned list contains all known workflow events or an error results. 
     *  Otherwise, the returned list may contain only those workflow events 
     *  that are accessible through this session. 
     *
     *  @param  stepId a step <code> Id </code> 
     *  @param  workId a work <code> Id </code> 
     *  @return the workflow events 
     *  @throws org.osid.NullArgumentException <code> stepId </code> or <code> 
     *          workId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.WorkflowEventList getWorkflowEventsForStepAndWork(org.osid.id.Id stepId, 
                                                                               org.osid.id.Id workId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the workflow log for a work in this process within the given date 
     *  range inclusive. In plenary mode, the returned list contains all known 
     *  workflow events or an error results. Otherwise, the returned list may 
     *  contain only those workflow events that are accessible through this 
     *  session. 
     *
     *  @param  stepId a step <code> Id </code> 
     *  @param  workId a work <code> Id </code> 
     *  @param  start start range 
     *  @param  end end range 
     *  @return the workflow events 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          greater than <code> end </code> 
     *  @throws org.osid.NullArgumentException <code> stepId, workId, start 
     *          </code> or <code> end </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.WorkflowEventList getWorkflowEventsByDateForStepAndWork(org.osid.id.Id stepId, 
                                                                                     org.osid.id.Id workId, 
                                                                                     org.osid.calendaring.DateTime start, 
                                                                                     org.osid.calendaring.DateTime end)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the workflow log by an agent in this process. In plenary mode, 
     *  the returned list contains all known workflow events or an error 
     *  results. Otherwise, the returned list may contain only those workflow 
     *  events that are accessible through this session. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @return the workflow events 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.WorkflowEventList getWorkflowEventsForWorker(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the workflow log by the resource in this process within the given 
     *  date range inclusive. In plenary mode, the returned list contains all 
     *  known workflow events or an error results. Otherwise, the returned 
     *  list may contain only those workflow events that are accessible 
     *  through this session. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  start start range 
     *  @param  end end range 
     *  @return the workflow events 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          greater than <code> end </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, start 
     *          </code> or <code> end </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.WorkflowEventList getWorkflowEventsByDateForWorker(org.osid.id.Id resourceId, 
                                                                                org.osid.calendaring.DateTime start, 
                                                                                org.osid.calendaring.DateTime end)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the workflow log by an agent in this process. In plenary mode, 
     *  the returned list contains all known workflow events or an error 
     *  results. Otherwise, the returned list may contain only those workflow 
     *  events that are accessible through this session. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  processId a process <code> Id </code> 
     *  @return the workflow events 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> or 
     *          <code> processId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.WorkflowEventList getWorkflowEventsForWorkerAndProcess(org.osid.id.Id resourceId, 
                                                                                    org.osid.id.Id processId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the workflow log by the resource in this process within the given 
     *  date range inclusive. In plenary mode, the returned list contains all 
     *  known workflow events or an error results. Otherwise, the returned 
     *  list may contain only those workflow events that are accessible 
     *  through this session. 
     *
     *  @param  resourceId a resource <code> Id </code> 
     *  @param  processId a process <code> Id </code> 
     *  @param  start start range 
     *  @param  end end range 
     *  @return the workflow events 
     *  @throws org.osid.InvalidArgumentException <code> start </code> is 
     *          greater than <code> end </code> 
     *  @throws org.osid.NullArgumentException <code> resourceId, processId, 
     *          start </code> or <code> end </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.WorkflowEventList getWorkflowEventsByDateForWorkerAndProcess(org.osid.id.Id resourceId, 
                                                                                          org.osid.id.Id processId, 
                                                                                          org.osid.calendaring.DateTime start, 
                                                                                          org.osid.calendaring.DateTime end)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the entire workflow log. In plenary mode, the returned list 
     *  contains all known workflow events or an error results. Otherwise, the 
     *  returned list may contain only those workflow events that are 
     *  accessible through this session. 
     *
     *  @return the workflow events 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.WorkflowEventList getWorkflowEvents()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
