//
// org.osid.workflow.WorkflowEventNotificationSession
//
//     The OSID Java specification for org.osid.workflow.WorkflowEventNotificationSession.
//
// Copyright (C) 2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.workflow;


/**
 *  <p>This session defines methods to receive notifications on adds/changes 
 *  to <code> WorkflowEvent </code> objects in this <code> Process. </code> 
 *  This session is intended for consumers needing to synchronize their state 
 *  with this service without the use of polling. Notifications are cancelled 
 *  when this session is closed. </p>
 */

public interface WorkflowEventNotificationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Office </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Office Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getOfficeId();


    /**
     *  Gets the <code> Office </code> associated with this session. 
     *
     *  @return the office 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.Office getOffice()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include events in offices which are children of this office in the 
     *  office hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedOfficeView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts notifications to this office only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedOfficeView();


    /**
     *  Tests if this user can register for <code> WorkflowEvent </code> 
     *  notifications. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known all 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer notification operations. 
     *
     *  @return <code> false </code> if notification methods are not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canRegisterForWorkflowEventNotifications();


    /**
     *  Register for notifications of new workflow events. <code> 
     *  WorkflowEventReceiver.newWorkflowEvents() </code> is invoked when a 
     *  new <code> WorkflowEvent </code> appears in this process. 
     *
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewWorkflowEvents()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new workflow events for the given 
     *  process. <code> WorkflowEventReceiver.newWorkflowEvents() </code> is 
     *  invoked when a new <code> WorkflowEvent </code> appears in this 
     *  process. 
     *
     *  @param  processId the <code> Id </code> of the <code> Process </code> 
     *          to monitor 
     *  @throws org.osid.NullArgumentException <code> processId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewWorkflowEventsForProcess(org.osid.id.Id processId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new workflow events for the given step. 
     *  <code> WorkflowEventReceiver.newWorkflowEvents() </code> is invoked 
     *  when a new <code> WorkflowEvent </code> appears in this process. 
     *
     *  @param  stepId the <code> Id </code> of the <code> Step </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> stepId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewWorkflowEventsForStep(org.osid.id.Id stepId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new workflow events for the given work. 
     *  <code> WorkflowEventReceiver.newWorkflowEvents() </code> is invoked 
     *  when a new <code> WorkflowEvent </code> appears in this process. 
     *
     *  @param  workId the <code> Id </code> of the <code> Work </code> to 
     *          monitor 
     *  @throws org.osid.NullArgumentException <code> workId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewWorkflowEventsForWork(org.osid.id.Id workId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Register for notifications of new workflow events for the given 
     *  resource. <code> WorkflowEventReceiver.newWorkflowEvents() </code> is 
     *  invoked when a new <code> WorkflowEvent </code> appears in this 
     *  process. 
     *
     *  @param  resourceId the <code> Id </code> of the <code> Resource 
     *          </code> to monitor 
     *  @throws org.osid.NullArgumentException <code> resourceId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void registerForNewWorkflowEventsForWorker(org.osid.id.Id resourceId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
