//
// org.osid.workflow.WorkflowManager
//
//     The OSID Java specification for org.osid.workflow.WorkflowManager.
//
// Copyright (C) 2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.workflow;


/**
 *  <p>The workflow manager provides access to rules sessions and provides 
 *  interoperability tests for various aspects of this service. The sessions 
 *  included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> ProcessLookupSession: </code> a session to retrieve 
 *      processs </li> 
 *      <li> <code> ProcessQuerySession: </code> a session to query for 
 *      processs </li> 
 *      <li> <code> ProcessSearchSession: </code> a session to search for 
 *      processs </li> 
 *      <li> <code> ProcessAdminSession: </code> a session to create and 
 *      delete processs </li> 
 *      <li> <code> ProcessNotificationSession: </code> a session to receive 
 *      notifications pertaining to process changes </li> 
 *      <li> <code> ProcessOfficeSession: </code> a session to looking 
 *      mappings of process to offices </li> 
 *      <li> <code> ProcessOfficeAssignmentSession: </code> a session to 
 *      manage process to office workflows </li> 
 *      <li> <code> ProcessSmartOfficeSession: </code> a session to manage 
 *      dynamic offices of processs </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> StepLookupSession: </code> a session to retrieve steps 
 *      </li> 
 *      <li> <code> StepQuerySession: </code> a session to query for steps 
 *      </li> 
 *      <li> <code> StepSearchSession: </code> a session to search for steps 
 *      </li> 
 *      <li> <code> StepAdminSession: </code> a session to create and delete 
 *      steps </li> 
 *      <li> <code> StepNotificationSession: </code> a session to receive 
 *      notifications pertaining to step changes </li> 
 *      <li> <code> StepOfficeSession: </code> a session to look up step 
 *      office mappings </li> 
 *      <li> <code> StepOfficeAssignmentSession: </code> a session to manage 
 *      steps to office mappings </li> 
 *      <li> <code> StepSmartOfficeSession: </code> a session to manage 
 *      dynamic offices of stepss </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> WorkLookupSession: </code> a session to retrieve work 
 *      </li> 
 *      <li> <code> WorkQuerySession: </code> a session to query for work 
 *      </li> 
 *      <li> <code> WorkSearchSession: </code> a session to search for work 
 *      </li> 
 *      <li> <code> WorkAdminSession: </code> a session to create and delete 
 *      work </li> 
 *      <li> <code> WorkNotificationSession: </code> a session to receive 
 *      notifications pertaining to work changes </li> 
 *      <li> <code> WorkOfficeSession: </code> a session to look up work 
 *      office mappings </li> 
 *      <li> <code> WorkOfficeAssignmentSession: </code> a session to manage 
 *      availability to office mappings </li> 
 *      <li> <code> WorkSmartOfficeSession: </code> a session to manage 
 *      dynamic offices of work </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> WorkflowSession: </code> a session to examine work in a 
 *      process </li> 
 *      <li> <code> WorkflowInitiationSession: </code> a session to start work 
 *      through a process </li> 
 *      <li> <code> WorkflowManagementSession: </code> a session to enable and 
 *      disable work in a process </li> 
 *      <li> <code> ManualWorkflowSession: </code> a session to manuall assign 
 *      work to steps in a process </li> 
 *      <li> <code> WorkflowLogSession: </code> a session to look up changes 
 *      in a workflow </li> 
 *      <li> <code> WorkflowEventNotificationSession: </code> a session to 
 *      receive notifications of workflow changes </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> OfficeLookupSession: </code> a session to retrieve offices 
 *      </li> 
 *      <li> <code> OfficeQuerySession: </code> a session to search for 
 *      offices </li> 
 *      <li> <code> OfficeSearchSession: </code> a session to search for 
 *      offices </li> 
 *      <li> <code> OfficeAdminSession: </code> a session to create and delete 
 *      offices </li> 
 *      <li> <code> OfficeNotificationSession: </code> a session to receive 
 *      notifications pertaining to office changes </li> 
 *      <li> <code> OfficeHierarchySession: </code> a session to traverse a 
 *      hierarchy of office </li> 
 *      <li> <code> OfficeHierarchyDesignSession: </code> a session to manage 
 *      a office hierarchy </li> 
 *  </ul>
 *  
 */

public interface WorkflowManager
    extends org.osid.OsidManager,
            org.osid.workflow.WorkflowProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the process lookup 
     *  service. 
     *
     *  @return a <code> ProcessLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProcessLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessLookup() </code> is <code> true. </code> 
     */

    public org.osid.workflow.ProcessLookupSession getProcessLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the process lookup 
     *  service for the given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> ProcessLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Office </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProcessLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.workflow.ProcessLookupSession getProcessLookupSessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the process query 
     *  service. 
     *
     *  @return a <code> ProcessQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProcessQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessQuery() </code> is <code> true. </code> 
     */

    public org.osid.workflow.ProcessQuerySession getProcessQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the process query 
     *  service for the given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> ProcessQuerySession </code> 
     *  @throws org.osid.NotFoundException no office found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProcessQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.workflow.ProcessQuerySession getProcessQuerySessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the process search 
     *  service. 
     *
     *  @return a <code> ProcessSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProcessSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessSearch() </code> is <code> true. </code> 
     */

    public org.osid.workflow.ProcessSearchSession getProcessSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the process search 
     *  service for the given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> ProcessSearchSession </code> 
     *  @throws org.osid.NotFoundException no office found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProcessSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.workflow.ProcessSearchSession getProcessSearchSessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the process 
     *  administration service. 
     *
     *  @return a <code> ProcessAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProcessAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessAdmin() </code> is <code> true. </code> 
     */

    public org.osid.workflow.ProcessAdminSession getProcessAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the process 
     *  administration service for the given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> ProcessAdminSession </code> 
     *  @throws org.osid.NotFoundException no office found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProcessAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.workflow.ProcessAdminSession getProcessAdminSessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the process 
     *  notification service. 
     *
     *  @param  processReceiver the notification callback 
     *  @return a <code> ProcessNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> processReceiver </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcessNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.workflow.ProcessNotificationSession getProcessNotificationSession(org.osid.workflow.ProcessReceiver processReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the process 
     *  notification service for the given office. 
     *
     *  @param  processReceiver the notification callback 
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> ProcessNotificationSession </code> 
     *  @throws org.osid.NotFoundException no office found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> processReceiver </code> 
     *          or <code> officeId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcessNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.workflow.ProcessNotificationSession getProcessNotificationSessionForOffice(org.osid.workflow.ProcessReceiver processReceiver, 
                                                                                               org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup process/office mappings. 
     *
     *  @return a <code> ProcessOfficeSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsProcessOffice() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessOffice() </code> is <code> true. </code> 
     */

    public org.osid.workflow.ProcessOfficeSession getProcessOfficeSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning process 
     *  to offices. 
     *
     *  @return a <code> ProcessOfficeAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcessOfficeAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessOfficeAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.workflow.ProcessOfficeAssignmentSession getProcessOfficeAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage process smart offices. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> ProcessSmartOfficeSession </code> 
     *  @throws org.osid.NotFoundException no <code> Office </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcessSmartOffice() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessSmartOffice() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.workflow.ProcessSmartOfficeSession getProcessSmartOfficeSession(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step lookup 
     *  service. 
     *
     *  @return a <code> StepLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsStepLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepLookup() </code> is <code> true. </code> 
     */

    public org.osid.workflow.StepLookupSession getStepLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step lookup 
     *  service for the given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> StepLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Office </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsStepLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.workflow.StepLookupSession getStepLookupSessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step query 
     *  service. 
     *
     *  @return a <code> StepQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsStepQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepQuery() </code> is <code> true. </code> 
     */

    public org.osid.workflow.StepQuerySession getStepQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step query 
     *  service for the given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> StepQuerySession </code> 
     *  @throws org.osid.NotFoundException no office found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsStepQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.workflow.StepQuerySession getStepQuerySessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step search 
     *  service. 
     *
     *  @return a <code> StepSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsStepSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepSearch() </code> is <code> true. </code> 
     */

    public org.osid.workflow.StepSearchSession getStepSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step search 
     *  service for the given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> StepSearchSession </code> 
     *  @throws org.osid.NotFoundException no office found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsStepSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.workflow.StepSearchSession getStepSearchSessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step 
     *  administration service. 
     *
     *  @return a <code> StepAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsStepAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepAdmin() </code> is <code> true. </code> 
     */

    public org.osid.workflow.StepAdminSession getStepAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step 
     *  administration service for the given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> StepAdminSession </code> 
     *  @throws org.osid.NotFoundException no office found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsStepAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.workflow.StepAdminSession getStepAdminSessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step 
     *  notification service. 
     *
     *  @param  stepReceiver the notification callback 
     *  @return a <code> StepNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> stepReceiver </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepNotification() </code> is <code> true. </code> 
     */

    public org.osid.workflow.StepNotificationSession getStepNotificationSession(org.osid.workflow.StepReceiver stepReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step 
     *  notification service for the given office. 
     *
     *  @param  stepReceiver the notification callback 
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> StepNotificationSession </code> 
     *  @throws org.osid.NotFoundException no office found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> stepReceiver </code> or 
     *          <code> officeId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.workflow.StepNotificationSession getStepNotificationSessionForOffice(org.osid.workflow.StepReceiver stepReceiver, 
                                                                                         org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup step/office mappings. 
     *
     *  @return a <code> StepOfficeSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsStepOffice() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepOffice() </code> is <code> true. </code> 
     */

    public org.osid.workflow.StepOfficeSession getStepOfficeSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning steps to 
     *  offices. 
     *
     *  @return a <code> StepOfficeAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepOfficeAssignment() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepOfficeAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.workflow.StepOfficeAssignmentSession getStepOfficeAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage step smart offices. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> StepSmartOfficeSession </code> 
     *  @throws org.osid.NotFoundException no office found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepSmartOffice() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepSmartOffice() </code> is <code> true. </code> 
     */

    public org.osid.workflow.StepOfficeSession getStepSmartOfficeSession(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the work lookup 
     *  service. 
     *
     *  @return a <code> WorkLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsWorkLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWorkLookup() </code> is <code> true. </code> 
     */

    public org.osid.workflow.WorkLookupSession getWorkLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the work lookup 
     *  service for the given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> WorkLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Office </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsWorkLookup() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWorkLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.workflow.WorkLookupSession getWorkLookupSessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the work query 
     *  service. 
     *
     *  @return a <code> WorkQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsWorkQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWorkQuery() </code> is <code> true. </code> 
     */

    public org.osid.workflow.WorkQuerySession getWorkQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the work query 
     *  service for the given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> WorkQuerySession </code> 
     *  @throws org.osid.NotFoundException no office found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsWorkQuery() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWorkQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.workflow.WorkQuerySession getWorkQuerySessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the work search 
     *  service. 
     *
     *  @return a <code> WorkSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsWorkSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWorkSearch() </code> is <code> true. </code> 
     */

    public org.osid.workflow.WorkSearchSession getWorkSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the work search 
     *  service for the given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> WorkSearchSession </code> 
     *  @throws org.osid.NotFoundException no office found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsWorkSearch() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWorkSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.workflow.WorkSearchSession getWorkSearchSessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the work 
     *  administration service. 
     *
     *  @return a <code> WorkAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsWorkAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWorkAdmin() </code> is <code> true. </code> 
     */

    public org.osid.workflow.WorkAdminSession getWorkAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the work 
     *  administration service for the given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> WorkAdminSession </code> 
     *  @throws org.osid.NotFoundException no office found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsWorkAdmin() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWorkAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.workflow.WorkAdminSession getWorkAdminSessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the work 
     *  notification service. 
     *
     *  @param  workReceiver the notification callback 
     *  @return a <code> WorkNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> workReceiver </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsWorkNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWorkNotification() </code> is <code> true. </code> 
     */

    public org.osid.workflow.WorkNotificationSession getWorkNotificationSession(org.osid.workflow.WorkReceiver workReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the work 
     *  notification service for the given office. 
     *
     *  @param  workReceiver the notification callback 
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> WorkNotificationSession </code> 
     *  @throws org.osid.NotFoundException no office found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> workReceiver </code> or 
     *          <code> officeId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsWorkNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWorkNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.workflow.WorkNotificationSession getWorkNotificationSessionForOffice(org.osid.workflow.WorkReceiver workReceiver, 
                                                                                         org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup work/office mappings. 
     *
     *  @return a <code> WorkOfficeSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsWorkOffice() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWorkOffice() </code> is <code> true. </code> 
     */

    public org.osid.workflow.WorkOfficeSession getWorkOfficeSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning work to 
     *  offices. 
     *
     *  @return a <code> WorkOfficeAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsWorkbOfficeAssignment() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWorkOfficeAssignment() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.workflow.WorkOfficeAssignmentSession getWorkOfficeAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage work smart offices. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> WorkSmartOfficeSession </code> 
     *  @throws org.osid.NotFoundException no office found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsWorkSmartOffice() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWorkSmartOffice() </code> is <code> true. </code> 
     */

    public org.osid.workflow.WorkSmartOfficeSession getWorkSmartOfficeSession(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> for a workflow service. 
     *
     *  @return a <code> WorkflowSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsWorkflow() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWorkflow() </code> is <code> true. </code> 
     */

    public org.osid.workflow.WorkflowSession getWorkflowSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> for a workflow service for the 
     *  given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> WorkflowSession </code> 
     *  @throws org.osid.NotFoundException no office found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsWorkflow() 
     *          </code> or <code> supportsVisibleFederation() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWorkflow() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.workflow.WorkflowSession getWorkflowSessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> for a workflow initiation service. 
     *
     *  @return a <code> WorkflowInitiationSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsWorkflowInitiation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWorkflowInitiation() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.workflow.WorkflowInitiationSession getWorkflowInitiationSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> for a workflow initiation service 
     *  for the given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> WorkflowInitiationSession </code> 
     *  @throws org.osid.NotFoundException no office found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> offiecId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsWorkflowInitiation() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWorkflowInitiation() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.workflow.WorkflowInitiationSession getWorkflowInitiationSessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> for a workflow management service. 
     *
     *  @return a <code> WorkflowManagementSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsWorkflowManagement() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWorkflowManagement() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.workflow.WorkflowManagementSession getWorkflowManagementSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> for a workflow management service 
     *  for the given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> WorkflowManagementSession </code> 
     *  @throws org.osid.NotFoundException no office found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsWorkflowManagement() or supportsVisibleFederation() is 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWorkflowManagement() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.workflow.WorkflowManagementSession getWorkflowManagementSessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> for a manual workflow service. 
     *
     *  @return a <code> ManualWorkflowSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsManualWorkflow() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsManualWorkflow() </code> is <code> true. </code> 
     */

    public org.osid.workflow.ManualWorkflowSession getManualWorkflowSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> for a manual workflow service for 
     *  the given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> office </code> 
     *  @return a <code> ManualWorkflowSession </code> 
     *  @throws org.osid.NotFoundException no office found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsManualWorkflow() or supportsVisibleFederation() is 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsManualWorkflow() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.workflow.ManualWorkflowSession getManualWorkflowSessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> for a workflow event lookup 
     *  service. 
     *
     *  @return a <code> WorkflowLogSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsWorkflowEventLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWorkflowEventLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.workflow.WorkflowEventLookupSession getWorkflowEventLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> for a workflow event lookup 
     *  service for the given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> office </code> 
     *  @return a <code> WorkflowEventLookupSession </code> 
     *  @throws org.osid.NotFoundException no office found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsWorkflowEventLookup() or supportsVisibleFederation() 
     *          is false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWorkflowEventLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.workflow.WorkflowEventLookupSession getWorkflowEventLookupSessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the workflow event 
     *  notification service. 
     *
     *  @param  workflowEventReceiver the notification callback 
     *  @return a <code> WorkflowEventNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> workflowEventReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsWorkflowEventNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWorkflowEventNotification() </code> is <code> true 
     *              </code> 
     */

    public org.osid.workflow.WorkflowEventNotificationSession getWorkflowEventNotificationSession(org.osid.workflow.WorkflowEventReceiver workflowEventReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the workflow event 
     *  notification service for the given office. 
     *
     *  @param  workflowEventReceiver the notification callback 
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> WorkflowEventNotificationSession </code> 
     *  @throws org.osid.NotFoundException no office found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> workflowEventReceiver 
     *          </code> or <code> officeId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsWorkflowEventNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWorkflowEventNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true 
     *              </code> 
     */

    public org.osid.workflow.WorkflowEventNotificationSession getWorkflowEventNotificationSessionForOffice(org.osid.workflow.WorkflowEventReceiver workflowEventReceiver, 
                                                                                                           org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the office lookup 
     *  service. 
     *
     *  @return a <code> OfficeLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsOfficeLookup() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfficeLookup() </code> is <code> true. </code> 
     */

    public org.osid.workflow.OfficeLookupSession getOfficeLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the office query 
     *  service. 
     *
     *  @return a <code> OfficeQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsOfficeQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfficeQuery() </code> is <code> true. </code> 
     */

    public org.osid.workflow.OfficeQuerySession getOfficeQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the office search 
     *  service. 
     *
     *  @return a <code> OfficeSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsOfficeSearch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfficeSearch() </code> is <code> true. </code> 
     */

    public org.osid.workflow.OfficeSearchSession getOfficeSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the office 
     *  administrative service. 
     *
     *  @return a <code> OfficeAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsOfficeAdmin() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfficeAdmin() </code> is <code> true. </code> 
     */

    public org.osid.workflow.OfficeAdminSession getOfficeAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the office 
     *  notification service. 
     *
     *  @param  officeReceiver the notification callback 
     *  @return a <code> OfficeNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> officeReceiver </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfficeNotification() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfficeNotification() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.workflow.OfficeNotificationSession getOfficeNotificationSession(org.osid.workflow.OfficeReceiver officeReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the office 
     *  hierarchy service. 
     *
     *  @return a <code> OfficeHierarchySession </code> for offices 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfficeHierarchy() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfficeHierarchy() </code> is <code> true. </code> 
     */

    public org.osid.workflow.OfficeHierarchySession getOfficeHierarchySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the office 
     *  hierarchy design service. 
     *
     *  @return a <code> HierarchyDesignSession </code> for offices 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsOfficeHierarchyDesign() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfficeHierarchyDesign() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.workflow.OfficeHierarchyDesignSession getOfficeHierarchyDesignSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a <code> WorkflowBatchManager. </code> 
     *
     *  @return a <code> WorkflowbatchManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsWorkflowBatch() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWorkflowBatch() </code> is <code> true. </code> 
     */

    public org.osid.workflow.batch.WorkflowBatchManager getWorkflowBatchManager()
        throws org.osid.OperationFailedException;


    /**
     *  Gets a <code> WorkflowRulesManager. </code> 
     *
     *  @return a <code> WorkflowRulesManager </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> supportsWorkflowRules() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsWorkflowRules() </code> is <code> true. </code> 
     */

    public org.osid.workflow.rules.WorkflowRulesManager getWorkflowRulesManager()
        throws org.osid.OperationFailedException;
}
