//
// org.osid.workflow.WorkflowProfile
//
//     The OSID Java specification for org.osid.workflow.WorkflowProfile.
//
// Copyright (C) 2004 Massachusetts Institute of Technology. 
// 
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.workflow;


/**
 *  <p>The workflow profile describes the interoperability among workflow 
 *  services. </p>
 */

public interface WorkflowProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any office federation is exposed. Federation is exposed when 
     *  a specific office may be identified, selected and used to create a 
     *  lookup or admin session. Federation is not exposed when a set of 
     *  offices appears as a single office. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if looking up process is supported. 
     *
     *  @return <code> true </code> if process lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcessLookup();


    /**
     *  Tests if querying process is supported. 
     *
     *  @return <code> true </code> if process query is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcessQuery();


    /**
     *  Tests if searching process is supported. 
     *
     *  @return <code> true </code> if process search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcessSearch();


    /**
     *  Tests if process administrative service is supported. 
     *
     *  @return <code> true </code> if process administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcessAdmin();


    /**
     *  Tests if a process notification service is supported. 
     *
     *  @return <code> true </code> if process notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcessNotification();


    /**
     *  Tests if a process office lookup service is supported. 
     *
     *  @return <code> true </code> if a process office lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcessOffice();


    /**
     *  Tests if a process office service is supported. 
     *
     *  @return <code> true </code> if process to office assignment service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcessOfficeAssignment();


    /**
     *  Tests if a process smart office lookup service is supported. 
     *
     *  @return <code> true </code> if a process smart office service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcessSmartOffice();


    /**
     *  Tests if looking up steps is supported. 
     *
     *  @return <code> true </code> if step lookup is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepLookup();


    /**
     *  Tests if querying steps is supported. 
     *
     *  @return <code> true </code> if step query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepQuery();


    /**
     *  Tests if searching steps is supported. 
     *
     *  @return <code> true </code> if step search is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepSearch();


    /**
     *  Tests if a step administrative service is supported. 
     *
     *  @return <code> true </code> if step administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepAdmin();


    /**
     *  Tests if a step <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if step notification is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepNotification();


    /**
     *  Tests if a step office lookup service is supported. 
     *
     *  @return <code> true </code> if a step office lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepOffice();


    /**
     *  Tests if a step office assignment service is supported. 
     *
     *  @return <code> true </code> if a step to office assignment service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepOfficeAssignment();


    /**
     *  Tests if a step smart office service is supported. 
     *
     *  @return <code> true </code> if a step smart office service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepSmartOffice();


    /**
     *  Tests if looking up work is supported. 
     *
     *  @return <code> true </code> if work lookup is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWorkLookup();


    /**
     *  Tests if querying work is supported. 
     *
     *  @return <code> true </code> if work query is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWorkQuery();


    /**
     *  Tests if searching work is supported. 
     *
     *  @return <code> true </code> if work search is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWorkSearch();


    /**
     *  Tests if work administrative service is supported. 
     *
     *  @return <code> true </code> if work administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWorkAdmin();


    /**
     *  Tests if a work notification service is supported. 
     *
     *  @return <code> true </code> if work notification is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWorkNotification();


    /**
     *  Tests if a work office lookup service is supported. 
     *
     *  @return <code> true </code> if a work office lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWorkOffice();


    /**
     *  Tests if a work office service is supported. 
     *
     *  @return <code> true </code> if work to office assignment service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWorkOfficeAssignment();


    /**
     *  Tests if a work smart office lookup service is supported. 
     *
     *  @return <code> true </code> if a work smart office service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWorkSmartOffice();


    /**
     *  Tests if a workflow service is supported. 
     *
     *  @return <code> true </code> if workflow is supported, <code> false 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWorkflow();


    /**
     *  Tests if a workflow initiation service is supported. 
     *
     *  @return <code> true </code> if workflow initiation is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWorkflowInitiation();


    /**
     *  Tests if a workflow management service is supported. 
     *
     *  @return <code> true </code> if workflow management is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWorkflowManagement();


    /**
     *  Tests if a manual workflow service is supported. 
     *
     *  @return <code> true </code> if manual workflow is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsManualWorkflow();


    /**
     *  Tests if a workflow <code> </code> event lookup service is supported. 
     *
     *  @return <code> true </code> if workflow event lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWorkflowEventLookup();


    /**
     *  Tests if a workflow event notification service is supported. 
     *
     *  @return <code> true </code> if a workflow event notification service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWorkflowEventNotification();


    /**
     *  Tests if looking up offices is supported. 
     *
     *  @return <code> true </code> if office lookup is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfficeLookup();


    /**
     *  Tests if querying offices is supported. 
     *
     *  @return <code> true </code> if a office query service is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfficeQuery();


    /**
     *  Tests if searching offices is supported. 
     *
     *  @return <code> true </code> if office search is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfficeSearch();


    /**
     *  Tests if office administrative service is supported. 
     *
     *  @return <code> true </code> if office administration is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfficeAdmin();


    /**
     *  Tests if a office <code> </code> notification service is supported. 
     *
     *  @return <code> true </code> if office notification is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfficeNotification();


    /**
     *  Tests for the availability of a office hierarchy traversal service. 
     *
     *  @return <code> true </code> if office hierarchy traversal is 
     *          available, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented in all 
     *              providers. 
     */

    public boolean supportsOfficeHierarchy();


    /**
     *  Tests for the availability of a office hierarchy design service. 
     *
     *  @return <code> true </code> if office hierarchy design is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfficeHierarchyDesign();


    /**
     *  Tests for the availability of a workflow batch service. 
     *
     *  @return <code> true </code> if a workflow batch service is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWorkflowBatch();


    /**
     *  Tests for the availability of a workflow rules service. 
     *
     *  @return <code> true </code> if a workflow rules service is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWorkflowRules();


    /**
     *  Gets the supported <code> Process </code> record types. 
     *
     *  @return a list containing the supported <code> Process </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getProcessRecordTypes();


    /**
     *  Tests if the given <code> Process </code> record type is supported. 
     *
     *  @param  processRecordType a <code> Type </code> indicating a <code> 
     *          Process </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> processRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcessRecordType(org.osid.type.Type processRecordType);


    /**
     *  Gets the supported <code> Process </code> search record types. 
     *
     *  @return a list containing the supported <code> Process </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getProcessSearchRecordTypes();


    /**
     *  Tests if the given <code> Process </code> search record type is 
     *  supported. 
     *
     *  @param  processSearchRecordType a <code> Type </code> indicating a 
     *          <code> Process </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> processSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcessSearchRecordType(org.osid.type.Type processSearchRecordType);


    /**
     *  Gets the supported <code> Step </code> record types. 
     *
     *  @return a list containing the supported <code> Step </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getStepRecordTypes();


    /**
     *  Tests if the given <code> Step </code> record type is supported. 
     *
     *  @param  stepRecordType a <code> Type </code> indicating a <code> Step 
     *          </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> stepRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepRecordType(org.osid.type.Type stepRecordType);


    /**
     *  Gets the supported <code> Step </code> search types. 
     *
     *  @return a list containing the supported <code> Step </code> search 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getStepSearchRecordTypes();


    /**
     *  Tests if the given <code> Step </code> search type is supported. 
     *
     *  @param  stepSearchRecordType a <code> Type </code> indicating a <code> 
     *          Step </code> search type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> effiortSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepSearchRecordType(org.osid.type.Type stepSearchRecordType);


    /**
     *  Gets the supported <code> Work </code> record types. 
     *
     *  @return a list containing the supported <code> Work </code> record 
     *          types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getWorkRecordTypes();


    /**
     *  Tests if the given <code> Work </code> record type is supported. 
     *
     *  @param  workRecordType a <code> Type </code> indicating a <code> Work 
     *          </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> workRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWorkRecordType(org.osid.type.Type workRecordType);


    /**
     *  Gets the supported <code> Work </code> search record types. 
     *
     *  @return a list containing the supported <code> Work </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getWorkSearchRecordTypes();


    /**
     *  Tests if the given <code> Work </code> search record type is 
     *  supported. 
     *
     *  @param  workSearchRecordType a <code> Type </code> indicating a <code> 
     *          Work </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> workSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWorkSearchRecordType(org.osid.type.Type workSearchRecordType);


    /**
     *  Gets the supported <code> WorkflowEvent </code> record types. 
     *
     *  @return a list containing the supported <code> WorkflowEvent </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getWorkflowEventRecordTypes();


    /**
     *  Tests if the given <code> WorkflowEvent </code> record type is 
     *  supported. 
     *
     *  @param  workflowEventRecordType a <code> Type </code> indicating a 
     *          <code> WorkflowEvent </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> workflowEventRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsWorkflowEventRecordType(org.osid.type.Type workflowEventRecordType);


    /**
     *  Gets the supported <code> Office </code> record types. 
     *
     *  @return a list containing the supported <code> Office </code> types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getOfficeRecordTypes();


    /**
     *  Tests if the given <code> Office </code> record type is supported. 
     *
     *  @param  officeRecordType a <code> Type </code> indicating a <code> 
     *          Office </code> record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> officeRecordType </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfficeRecordType(org.osid.type.Type officeRecordType);


    /**
     *  Gets the supported <code> Office </code> search record types. 
     *
     *  @return a list containing the supported <code> Office </code> search 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getOfficeSearchRecordTypes();


    /**
     *  Tests if the given <code> Office </code> search record type is 
     *  supported. 
     *
     *  @param  officeSearchRecordType a <code> Type </code> indicating a 
     *          <code> Office </code> search record type 
     *  @return <code> true </code> if the given <code> Type </code> is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> officeSearchRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfficeSearchRecordType(org.osid.type.Type officeSearchRecordType);
}
