//
// org.osid.workflow.batch.StepBatchAdminSession
//
//     The OSID Java specification for org.osid.workflow.batch.StepBatchAdminSession.
//
// Copyright (C) 2012 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may modify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.workflow.batch;


/**
 *  <p>This session creates, updates, and deletes <code> Steps </code> in 
 *  bulk. The data for create and update is provided by the consumer via the 
 *  form object. <code> OsidForms </code> are requested for each create or 
 *  update and may not be reused. </p> 
 *  
 *  <p> Create and update operations differ in their usage. To create a <code> 
 *  Step, </code> a <code> StepForm </code> is requested using <code> 
 *  getStepFormsForCreate() </code> specifying the process and desired record 
 *  <code> Types </code> or none if no record <code> Types </code> are needed. 
 *  Each of the returned <code> StepForms </code> will indicate that it is to 
 *  be used with a create operation and can be used to examine metdata or 
 *  validate data prior to creation. Once a <code> StepForm </code> is 
 *  submiited to a create operation, it cannot be reused with another create 
 *  operation unless the first operation was unsuccessful. Each <code> 
 *  StepForm </code> corresponds to an attempted transaction. </p> 
 *  
 *  <p> The <code> StepForms </code> returned from <code> 
 *  getStepFormsForCreate() </code> may be linked to the originating request 
 *  through the peer <code> Ids </code> of the <code> StepForm. </code> In the 
 *  case where there may be duplicates, any <code> StepForm </code> of the 
 *  same peer <code> Ids </code> may be used for a create operation. </p> 
 *  
 *  <p> Once a batch of <code> StepForms </code> are submitted for create, a 
 *  <code> CreateResponse </code> is returned for each <code> StepForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire create operation are returned from <code> createSteps(), 
 *  </code> errors specific to an individual <code> StepForm </code> are 
 *  indicated in the corresponding <code> CreateResponse. </code> <code> 
 *  CreateResponses </code> may be linked to the originating <code> StepForm 
 *  </code> through the <code> StepForm </code> <code> Id </code> . </p> 
 *  
 *  <p> For updates, <code> StepForms </code> are requested to the <code> Step 
 *  </code> <code> Id </code> that is to be updated using <code> 
 *  getStepFormsForUpdate() </code> where the reference <code> Id </code> in 
 *  the <code> StepForm </code> may be used to link the request. Similarly, 
 *  the <code> StepForm </code> has metadata about the data that can be 
 *  updated and it can perform validation before submitting the update. The 
 *  <code> StepForm </code> can only be used once for a successful update and 
 *  cannot be reused. </p> 
 *  
 *  <p> Once a batch of <code> StepForms </code> are submitted for update, an 
 *  <code> UpdateResponse </code> is returned for each <code> StepForm, 
 *  </code> although the ordering is not defined. Only errors that pertain to 
 *  the entire update operation are returned from <code> updateSteps(), 
 *  </code> errors specific to an individual <code> StepForm </code> are 
 *  indicated in the corresponding <code> UpdateResponse. </code> <code> 
 *  UpdateResponses </code> may be linked to the originating <code> StepForm 
 *  </code> through the <code> StepForm </code> <code> Id. </code> </p> 
 *  
 *  <p> The delete operations delete <code> Steps </code> in bulk. To unmap a 
 *  <code> Step </code> from the current <code> Office, </code> the <code> 
 *  StepOfficeAssignmentSession </code> should be used. These delete 
 *  operations attempt to remove the <code> Step </code> itself thus removing 
 *  it from all known <code> Office </code> catalogs. Bulk delete operations 
 *  return the results in <code> DeleteResponses. </code> </p>
 */

public interface StepBatchAdminSession
    extends org.osid.workflow.StepAdminSession {


    /**
     *  Gets the step forms for creating a bunch of new steps. A StepForm is 
     *  returned for each supplied process <code> Id. </code> 
     *
     *  @param  processIds an <code> Id </code> of a process 
     *  @param  stepRecordTypes array of step record types to be included in 
     *          each create operation or an empty list if none 
     *  @return the step forms 
     *  @throws org.osid.NotFoundException a <code> processId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> processId </code> or 
     *          <code> stepRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to request forms with 
     *          given record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.batch.StepBatchFormList getStepFormsForCreate(org.osid.id.IdList processIds, 
                                                                           org.osid.type.Type[] stepRecordTypes)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new set of <code> Steps. </code> This method returns an 
     *  error if the entire operation fails. Otherwise, the status of an 
     *  individual create operation is indicated in the <code> 
     *  BatchCreateResponse </code> . 
     *
     *  @param  stepForms the step forms 
     *  @return the create responses 
     *  @throws org.osid.NullArgumentException <code> stepForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.CreateResponseList createSteps(org.osid.workflow.batch.StepBatchFormList stepForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the step forms for updating an existing set of steps. A new step 
     *  form should be requested for each update transaction. 
     *
     *  @param  stepIds the <code> Ids </code> of the <code> Step </code> 
     *  @return the step form 
     *  @throws org.osid.NotFoundException a <code> stepId </code> is not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> stepIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.batch.StepBatchFormList getStepFormsForUpdate(org.osid.id.IdList stepIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates existing steps. This method returns an error if the entire 
     *  operation fails. Otherwise, the status of an individual update 
     *  operation is indicated in the <code> BatchCreateResponse </code> . 
     *
     *  @param  stepForms the form containing the elements to be updated 
     *  @return the update responses 
     *  @throws org.osid.NullArgumentException <code> stepForms </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.UpdateResponseList updateSteps(org.osid.workflow.batch.StepBatchFormList stepForms)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all <code> Steps </code> in this <code> Office </code> . 
     *
     *  @return the delete responses 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteAllSteps()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes steps for the given <code> Ids. </code> 
     *
     *  @param  stepIds the <code> Ids </code> of the steps to delete 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> stepIds </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteSteps(org.osid.id.IdList stepIds)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Deletes all steps for the given process. 
     *
     *  @param  processId an <code> Id </code> of a process 
     *  @return the delete responses 
     *  @throws org.osid.NullArgumentException <code> processId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.DeleteResponseList deleteStepsForProcess(org.osid.id.Id processId)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Adds an <code> Id </code> to a <code> Step </code> for the purpose of 
     *  creating compatibility. The primary <code> Id </code> of the <code> 
     *  Step </code> is determined by the provider. The new <code> Id </code> 
     *  is an alias to the primary <code> Id. </code> If the alias is a 
     *  pointer to another step, it is reassigned to the given step <code> Id. 
     *  </code> 
     *
     *  @param  aliasRequests the alias requests 
     *  @return the alias responses 
     *  @throws org.osid.NullArgumentException <code> aliasRequests </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.transaction.batch.AliasResponseList aliasSteps(org.osid.transaction.batch.AliasRequestList aliasRequests)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
