/**
 * <p>The Open Service Interface Definitions for the org.osid.workflow
 * service.</p>
 * 
 * <p>The Workflow OSID provides a means for managing the flow of work. The 
 * Workflow OSID is part of a service cluster that includes the Resourcing 
 * OSID, Tracking OSID and Process OSID. The Workflow OSID provides an overall 
 * view of the flow of work through a process. </p> 
 * <h4> Work </h4> 
 * 
 * <p> <code> Work </code> is an abstract concept that indicates something to 
 * be worked on by <code> Resources </code> (workers) in a workflow <code> 
 * Process </code> . </p> 
 * <h4> Steps </h4> 
 * 
 * <p> A <code> Step </code> is the primary component of a workflow process in 
 * which work is performed. A <code> Step </code> may have required input 
 * conditions (or states) that permit <code> Work </code> to enter a <code> 
 * Step. </code> When the <code> Work </code> is completed at a <code> Step, 
 * </code> the <code> Step </code> defines the <code> State </code> transition 
 * of the <code> Work. </code> The valid next <code> Steps </code> in a <code> 
 * Process </code> is determined by the accepted input <code> States </code> 
 * of the other <code> Steps. </code> </p> 
 * 
 * <p> A <code> Step </code> may have assigned <code> Resources </code> to 
 * perform the work. These <code> Resources </code> may be managed manually in 
 * the Workflow OSID or through orchestration of the Resourcing OSID where the 
 * <code> Process </code> maps to a <code> Job </code> and the <code> Work 
 * </code> is the <code> Work </code> . </p> 
 * <h4> Processes </h4> 
 * 
 * <p> A <code> Process </code> is a set of <code> Steps </code> in a 
 * workflow. <code> Work </code> entering a <code> Process </code> is assigned 
 * an initial <code> Step </code> and an initial <code> State </code> as 
 * defined by the <code> Process. </code> </p> 
 * 
 * <p> Both <code> Processes </code> and <code> Steps </code> are <code> 
 * OsidGovernators </code> that may be operated through a set of rules to 
 * dynamically manage the workflow. </p> 
 * <h4> WorkflowEvents </h4> 
 * 
 * <p> <code> Work </code> moving through a <code> Process </code> can be 
 * examined using <code> WorkflowEvents. </code> Monitoring at a finer grained 
 * level can be performed by orchestrating a Tracking OSID where a <code> Step 
 * </code> is a <code> Queue </code> and the <code> Work </code> is an <code> 
 * Issue. </code> </p> 
 * <h4> Office Cataloging </h4> 
 * 
 * <p> <code> Work, </code> <code> Steps, </code> and <code> Processes </code> 
 * may be organized into federateable <code> OsidCatalogs </code> . </p> 
 * <h4> Sub Packages </h4> 
 * 
 * <p> The Workflow OSID includes a Workflow Rules OSID to manage the 
 * operation of <code> Processes </code> and <code> Steps </code> and impose 
 * additional input constraints on <code> Steps. </code> </p>
 * 
 * <br/><hr/><br/>
 * 
 * <p>Copyright &copy; 2004 Massachusetts Institute of Technology. </p> 
 * 
 * <p> Copyright &copy; 2011 Ingenescus. All Rights Reserved. </p>
 * 
 * <p>This Work is being provided by the copyright holder(s) subject to the 
 * following license. By obtaining, using and/or copying this Work, you agree 
 * that you have read, understand, and will comply with the following terms 
 * and conditions. </p> 
 * 
 * <p> Permission to use, copy and distribute unmodified versions of this 
 * Work, for any purpose, without fee or royalty is hereby granted, provided 
 * that you include the above copyright notices and the terms of this license 
 * on ALL copies of the Work or portions thereof. </p> 
 * 
 * <p> You may modify or create Derivatives of this Work only for your 
 * internal purposes. You shall not distribute or transfer any such Derivative 
 * of this Work to any location or to any third party. For the purposes of 
 * this license, "Derivative" shall mean any derivative of the Work as defined 
 * in the United States Copyright Act of 1976, such as a translation or 
 * modification. </p> 
 * 
 * <p> This Work and the information contained herein is provided on an "AS 
 * IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT 
 * NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR 
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT 
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN 
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN 
 * CONNECTION WITH THE WORK OR THE USE OR OTHER DEALINGS IN THE WORK. </p> 
 * 
 * <p> The export of software employing encryption technology may require a 
 * specific license from the United States Government. It is the 
 * responsibility of any person or organization contemplating export to obtain 
 * such a license before exporting this Work. </p>
 */

package org.osid.workflow;
