//
// org.osid.workflow.rules.ProcessEnablerLookupSession
//
//     The OSID Java specification for org.osid.workflow.rules.ProcessEnablerLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.workflow.rules;


/**
 *  <p>This session provides methods for retrieving <code> ProcessEnablers. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated office view: All process enabler methods in this session 
 *      operate, retrieve and pertain to process enabler defined explicitly in 
 *      the current office. Using an isolated view is useful for managing 
 *      <code> ProcessEnablers </code> with the <code> 
 *      ProcessEnablerAdminSession. </code> </li> 
 *      <li> federated office view: All process enabler methods in this 
 *      session operate, retrieve and pertain to all process enabler defined 
 *      in this office and any other process enabler implicitly available in 
 *      this office through office inheritence. </li> 
 *      <li> active process enabler view: All process enabler lookup methods 
 *      return active process enablers. </li> 
 *      <li> any status process enabler view: Process enablers of any active 
 *      or inactive status are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedOfficeView() </code> and <code> 
 *  useIsolatedOfficeView() </code> behave as a radio group and one should be 
 *  selected before invoking the methods in this session. </p>
 */

public interface ProcessEnablerLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Office </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Office Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getOfficeId();


    /**
     *  Gets the <code> Office </code> associated with this session. 
     *
     *  @return the office 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.Office getOffice()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> ProcessEnablers </code> lookups. 
     *  A return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known all methods in this session will 
     *  result in a <code> PERMISSION_DENIED. </code> This is intended as a 
     *  hint to an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupProcessEnablers();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeProcessEnablerView();


    /**
     *  A complete view of the <code> ProcessEnabler </code> returns is 
     *  desired. Methods will return what is requested or result in an error. 
     *  This view is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryProcessEnablerView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include process enabler in office which are children of this office in 
     *  the office hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedOfficeView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this offices only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedOfficeView();


    /**
     *  Only active process enablers are returned by methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveProcessEnablerView();


    /**
     *  All active and inactive process enablers are returned by methods in 
     *  this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusProcessEnablerView();


    /**
     *  Gets the <code> ProcessEnabler </code> specified by its <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  ProcessEnabler </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> ProcessEnabler </code> and retained for 
     *  compatibility. 
     *  
     *  In active mode, process enablers are returned that are currently 
     *  active. In any status mode, active and inactive process enablers are 
     *  returned. 
     *
     *  @param  processEnablerId <code> Id </code> of the <code> 
     *          ProcessEnabler </code> 
     *  @return the process enabler 
     *  @throws org.osid.NotFoundException <code> processEnablerId </code> not 
     *          found 
     *  @throws org.osid.NullArgumentException <code> processEnablerId </code> 
     *          is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.workflow.rules.ProcessEnabler getProcessEnabler(org.osid.id.Id processEnablerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProcessEnablerList </code> corresponding to the given 
     *  <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  process enabler specified in the <code> Id </code> list, in the order 
     *  of the list, including duplicates, or an error results if an <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> ProcessEnablers </code> may be omitted from the 
     *  list and may present the elements in any order including returning a 
     *  unique set. 
     *  
     *  In active mode, process enablers are returned that are currently 
     *  active. In any status mode, active and inactive process enablers are 
     *  returned. 
     *
     *  @param  processEnablerIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> ProcessEnabler </code> list 
     *  @throws org.osid.NotFoundException an <code> Id </code> was not found 
     *  @throws org.osid.NullArgumentException <code> processEnablerIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.ProcessEnablerList getProcessEnablersByIds(org.osid.id.IdList processEnablerIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProcessEnablerList </code> corresponding to the given 
     *  process enabler genus <code> Type </code> which does not include 
     *  process enabler of genus types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  process enabler or an error results. Otherwise, the returned list may 
     *  contain only those process enabler that are accessible through this 
     *  session. 
     *  
     *  In active mode, process enablers are returned that are currently 
     *  active. In any status mode, active and inactive process enablers are 
     *  returned. 
     *
     *  @param  processEnablerGenusType a process enabler genus type 
     *  @return the returned <code> ProcessEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> processEnablerGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.ProcessEnablerList getProcessEnablersByGenusType(org.osid.type.Type processEnablerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProcessEnablerList </code> corresponding to the given 
     *  process enabler genus <code> Type </code> and include any additional 
     *  process enabler with genus types derived from the specified <code> 
     *  Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  process enabler or an error results. Otherwise, the returned list may 
     *  contain only those process enabler that are accessible through this 
     *  session. 
     *  
     *  In active mode, process enablers are returned that are currently 
     *  active. In any status mode, active and inactive process enablers are 
     *  returned. 
     *
     *  @param  processEnablerGenusType a process enabler genus type 
     *  @return the returned <code> ProcessEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> processEnablerGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.ProcessEnablerList getProcessEnablersByParentGenusType(org.osid.type.Type processEnablerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProcessEnablerList </code> containing the given process 
     *  enabler record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  process enabler or an error results. Otherwise, the returned list may 
     *  contain only those process enabler that are accessible through this 
     *  session. 
     *  
     *  In active mode, process enablers are returned that are currently 
     *  active. In any status mode, active and inactive process enablers are 
     *  returned. 
     *
     *  @param  processEnablerRecordType a process enabler record type 
     *  @return the returned <code> ProcessEnabler </code> list 
     *  @throws org.osid.NullArgumentException <code> processEnablerRecordType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.ProcessEnablerList getProcessEnablersByRecordType(org.osid.type.Type processEnablerRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProcessEnablerList </code> that are effective for the 
     *  entire given date range inclusive but not confined to the date range 
     *  for any agent. 
     *  
     *  In plenary mode, the returned list contains all known process enablers 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those process enablers that are accessible through this session. 
     *  
     *  In active mode, process enablers are returned that are currently 
     *  active in addition to being effective during the given date range. In 
     *  any status mode, active and inactive process enablers are returned. 
     *
     *  @param  from a start date 
     *  @param  to an end date 
     *  @return the returned <code> ProcessEnabler </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> from </code> or <code> 
     *          to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.ProcessEnablerList getProcessEnablersOnDate(org.osid.calendaring.DateTime from, 
                                                                               org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> ProcessEnablerList </code> that are effective for the 
     *  entire given date range inclusive but not confined to the date range 
     *  and evaluated against the given agent. 
     *  
     *  In plenary mode, the returned list contains all known process enablers 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those process enablers that are accessible through this session. 
     *  
     *  In active mode, process enablers are returned that are currently 
     *  active in addition to being effective during the given date range. In 
     *  any status mode, active and inactive process enablers are returned. 
     *
     *  @param  agentId an agent <code> Id </code> 
     *  @param  from a start date 
     *  @param  to an end date 
     *  @return the returned <code> ProcessEnabler </code> list 
     *  @throws org.osid.InvalidArgumentException <code> from </code> is 
     *          greater than <code> to </code> 
     *  @throws org.osid.NullArgumentException <code> agentId, from, </code> 
     *          or <code> to </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.ProcessEnablerList getProcessEnablersOnDateWithAgent(org.osid.id.Id agentId, 
                                                                                        org.osid.calendaring.DateTime from, 
                                                                                        org.osid.calendaring.DateTime to)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> ProcessEnablers. </code> 
     *  
     *  In plenary mode, the returned list contains all known process enabler 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those process enabler that are accessible through this session. 
     *  
     *  In active mode, process enablers are returned that are currently 
     *  active. In any status mode, active and inactive process enablers are 
     *  returned. 
     *
     *  @return the returned <code> ProcessEnabler </code> list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.ProcessEnablerList getProcessEnablers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
