//
// org.osid.workflow.rules.ProcessEnablerRuleApplicationSession
//
//     The OSID Java specification for org.osid.workflow.rules.ProcessEnablerRuleApplicationSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.workflow.rules;


/**
 *  <p>This session provides methods to apply <code> ProcessEnablers </code> 
 *  to <code> Processs. </code> A <code> Process </code> with multiple <code> 
 *  ProcessEnablers </code> means any positive rule evaluation across the 
 *  constrainers result in an accessible <code> Process. </code> </p>
 */

public interface ProcessEnablerRuleApplicationSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Office </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Office Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getOfficeId();


    /**
     *  Gets the <code> Office </code> associated with this session. 
     *
     *  @return the office 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.Office getOffice()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can alter process enabler/process mappings. A 
     *  return of true does not guarantee successful authorization. A return 
     *  of false indicates that it is known mapping methods in this session 
     *  will result in a <code> PERMISSION_DENIED. </code> This is intended as 
     *  a hint to an application that may opt not to offer lookup operations 
     *  to unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignProcessEnablers();


    /**
     *  Adds an existing <code> ProcessEnabler </code> to a <code> Process. 
     *  </code> 
     *
     *  @param  processEnablerId the <code> Id </code> of the <code> 
     *          ProcessEnabler </code> 
     *  @param  processId the <code> Id </code> of the <code> Process </code> 
     *  @throws org.osid.AlreadyExistsException <code> processEnablerId 
     *          </code> is already applied to <code> processId </code> 
     *  @throws org.osid.NotFoundException <code> processEnablerId </code> or 
     *          <code> processId </code> not found 
     *  @throws org.osid.NullArgumentException <code> processEnablerId </code> 
     *          or <code> processId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignProcessEnablerToProcess(org.osid.id.Id processEnablerId, 
                                              org.osid.id.Id processId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> ProcessEnabler </code> from a <code> Process. </code> 
     *
     *  @param  processEnablerId the <code> Id </code> of the <code> 
     *          ProcessEnabler </code> 
     *  @param  processId the <code> Id </code> of the <code> Process </code> 
     *  @throws org.osid.NotFoundException <code> processEnablerId </code> or 
     *          <code> processId </code> not found or <code> processEnablerId 
     *          </code> not applied to <code> processId </code> 
     *  @throws org.osid.NullArgumentException <code> processEnablerId </code> 
     *          or <code> processId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignProcessEnablerFromProcess(org.osid.id.Id processEnablerId, 
                                                  org.osid.id.Id processId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can order <code> ProcessEnablers. </code> A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known sequencing operations will result in a 
     *  <code> PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer sequencing operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> ProcessEnabler </code> ordering 
     *          is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canSequenceProcessEnablers();


    /**
     *  Reorders process enablers for a process by moving the specified 
     *  process enabler in front of a reference process enabler. 
     *
     *  @param  processEnablerId the <code> Id </code> of a <code> 
     *          ProcessEnabler </code> 
     *  @param  processId the <code> Id </code> of a <code> Process </code> 
     *  @param  referenceId the reference process enabler <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> processEnablerId, processId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          processEnablerId </code> or <code> referenceId </code> not 
     *          related to <code> processId </code> 
     *  @throws org.osid.NullArgumentException <code> processEnablerId, 
     *          processId, </code> or <code> referenceId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveProcessEnablerAhead(org.osid.id.Id processEnablerId, 
                                        org.osid.id.Id processId, 
                                        org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders process enablers for a process by moving the specified 
     *  process enabler behind a reference process enabler. 
     *
     *  @param  processEnablerId the <code> Id </code> of a <code> 
     *          ProcessEnabler </code> 
     *  @param  processId the <code> Id </code> of a <code> Process </code> 
     *  @param  referenceId the reference process enabler <code> Id </code> 
     *  @throws org.osid.NotFoundException <code> processEnablerId, processId, 
     *          </code> or <code> referenceId </code> not found or, <code> 
     *          processEnablerId </code> or <code> referenceId </code> not 
     *          related to <code> processId </code> 
     *  @throws org.osid.NullArgumentException <code> processEnablerId, 
     *          processId, </code> or <code> referenceId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void moveProcessEnablerBehind(org.osid.id.Id processEnablerId, 
                                         org.osid.id.Id processId, 
                                         org.osid.id.Id referenceId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Reorders a set of process enablers for a process. 
     *
     *  @param  processEnablerIds the <code> Ids </code> for a set of <code> 
     *          ProcessEnablers </code> 
     *  @param  processId the <code> Id </code> of a <code> Process </code> 
     *  @throws org.osid.NotFoundException <code> processId </code> not found 
     *          or, an <code> processEnablerId </code> not related to <code> 
     *          processId </code> 
     *  @throws org.osid.NullArgumentException <code> processEnabelrIds 
     *          </code> or <code> processId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void orderProcessEnablers(org.osid.id.Id[] processEnablerIds, 
                                     org.osid.id.Id processId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
