//
// org.osid.workflow.rules.ProcessEnablerSearchSession
//
//     The OSID Java specification for org.osid.workflow.rules.ProcessEnablerSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.workflow.rules;


/**
 *  <p>This session provides methods for searching among <code> ProcessEnabler 
 *  </code> objects. The search query is constructed using the <code> 
 *  ProcessEnableryQuery. </code> </p> 
 *  
 *  <p> <code> getProcessEnablersByQuery() </code> is the basic search method 
 *  and returns a list of <code> ProcessEnablers. </code> A more advanced 
 *  search may be performed with <code> getProcessEnablersBySearch(). </code> 
 *  It accepts a <code> ProcessEnablerSearch </code> in addition to the query 
 *  for the purpose of specifying additional options affecting the entire 
 *  search, such as workflow. <code> getProcessEnablersBySearch() </code> 
 *  returns a <code> ProcessEnablerSearchResults </code> that can be used to 
 *  access the resulting <code> ProcessEnablerList </code> or be used to 
 *  perform a search within the result set through <code> 
 *  ProcessEnablerSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated office view: searches include process enabler in office 
 *      of which this office is an ancestor in the office hierarchy </li> 
 *      <li> isolated office view: searches are restricted to process enabler 
 *      in this office </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> ProcessEnablers </code> may have a query record indicated by 
 *  their respective record types. The query record is accessed via the <code> 
 *  ProcessEnablerQuery. </code> </p>
 */

public interface ProcessEnablerSearchSession
    extends org.osid.workflow.rules.ProcessEnablerQuerySession {


    /**
     *  Gets a process enabler search. 
     *
     *  @return the process enabler search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.ProcessEnablerSearch getProcessEnablerSearch();


    /**
     *  Gets a process enabler search order. The <code> 
     *  ProcessEnablerSearchOrder </code> is supplied to a <code> 
     *  ProcessEnablerSearch </code> to specify the ordering of results. 
     *
     *  @return the process enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.ProcessEnablerSearchOrder getProcessEnablerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  processEnablerQuery the process enabler query 
     *  @param  processEnablerSearch the process enabler search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> processEnablerQuery 
     *          </code> or <code> processEnablerSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> processEnablerQuery 
     *          </code> or <code> processEnablerSearch </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.ProcessEnablerSearchResults getProcessEnablersBySearch(org.osid.workflow.rules.ProcessEnablerQuery processEnablerQuery, 
                                                                                          org.osid.workflow.rules.ProcessEnablerSearch processEnablerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a process enabler query from an inspector. The inspector is 
     *  available from a <code> ProcessEnablerSearchResults. </code> 
     *
     *  @param  processEnablerQueryInspector a process enabler query inspector 
     *  @return the process enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          processEnablerQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          processEnablerQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.ProcessEnablerQuery getProcessEnablerQueryFromInspector(org.osid.workflow.rules.ProcessEnablerQueryInspector processEnablerQueryInspector);
}
