//
// org.osid.workflow.rules.StepConstrainerAdminSession
//
//     The OSID Java specification for org.osid.workflow.rules.StepConstrainerAdminSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.workflow.rules;


/**
 *  <p>This session creates and removes step constrainers. The data for create 
 *  and update is provided via the <code> StepConstrainerForm. </code> </p>
 */

public interface StepConstrainerAdminSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Office </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Office Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getOfficeId();


    /**
     *  Gets the <code> Office </code> associated with this session. 
     *
     *  @return the office 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.Office getOffice()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can create step constrainers. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known creating a <code> StepConstrainer </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer create operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> StepConstrainer </code> 
     *          creation is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateStepConstrainer();


    /**
     *  Tests if this user can create a single <code> StepConstrainer </code> 
     *  using the desired record types. While <code> 
     *  WorkflowRulesManager.getStepConstrainerRecordTypes() </code> can be 
     *  used to examine which records are supported, this method tests which 
     *  record(s) are required for creating a specific <code> StepConstrainer. 
     *  </code> Providing an empty array tests if a <code> StepConstrainer 
     *  </code> can be created with no records. 
     *
     *  @param  stepConstrainerRecordTypes array of step constrainer record 
     *          types 
     *  @return <code> true </code> if <code> StepConstrainer </code> creation 
     *          using the specified record <code> Types </code> is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          stepConstrainerRecordTypes </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canCreateStepConstrainerWithRecordTypes(org.osid.type.Type[] stepConstrainerRecordTypes);


    /**
     *  Gets the step constrainer form for creating new step constrainers. A 
     *  new form should be requested for each create transaction. 
     *
     *  @param  stepConstrainerRecordTypes array of step constrainer record 
     *          types 
     *  @return the step constrainer form 
     *  @throws org.osid.NullArgumentException <code> 
     *          stepConstrainerRecordTypes </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException unable to get form for requested 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.StepConstrainerForm getStepConstrainerFormForCreate(org.osid.type.Type[] stepConstrainerRecordTypes)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Creates a new <code> StepConstrainer. </code> 
     *
     *  @param  stepConstrainerForm the form for this <code> StepConstrainer 
     *          </code> 
     *  @return the new <code> StepConstrainer </code> 
     *  @throws org.osid.IllegalStateException <code> stepConstrainerForm 
     *          </code> already used in a create transaction 
     *  @throws org.osid.InvalidArgumentException one or more of the form 
     *          elements is invalid 
     *  @throws org.osid.NullArgumentException <code> stepConstrainerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> stepConstrainerForm 
     *          </code> did not originate from <code> 
     *          getStepConstrainerFormForCreate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.StepConstrainer createStepConstrainer(org.osid.workflow.rules.StepConstrainerForm stepConstrainerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can update step constrainers. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known updating a <code> StepConstrainer </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer update operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> StepConstrainer </code> 
     *          modification is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canUpdateStepConstrainers();


    /**
     *  Gets the step constrainer form for updating an existing step 
     *  constrainer. A new step constrainer form should be requested for each 
     *  update transaction. 
     *
     *  @param  stepConstrainerId the <code> Id </code> of the <code> 
     *          StepConstrainer </code> 
     *  @return the step constrainer form 
     *  @throws org.osid.NotFoundException <code> stepConstrainerId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> stepConstrainerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.StepConstrainerForm getStepConstrainerFormForUpdate(org.osid.id.Id stepConstrainerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Updates an existing step constrainer. 
     *
     *  @param  stepConstrainerForm the form containing the elements to be 
     *          updated 
     *  @throws org.osid.IllegalStateException <code> stepConstrainerForm 
     *          </code> already used in an update transaction 
     *  @throws org.osid.InvalidArgumentException the form contains an invalid 
     *          value 
     *  @throws org.osid.NullArgumentException <code> stepConstrainerForm 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> stepConstrainerForm 
     *          </code> did not originate from <code> 
     *          getStepConstrainerFormForUpdate() </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void updateStepConstrainer(org.osid.workflow.rules.StepConstrainerForm stepConstrainerForm)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can delete step constrainers. A return of true does 
     *  not guarantee successful authorization. A return of false indicates 
     *  that it is known deleting a <code> StepConstrainer </code> will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer delete operations to an 
     *  unauthorized user. 
     *
     *  @return <code> false </code> if <code> StepConstrainer </code> 
     *          deletion is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canDeleteStepConstrainers();


    /**
     *  Deletes a <code> StepConstrainer. </code> 
     *
     *  @param  stepConstrainerId the <code> Id </code> of the <code> 
     *          StepConstrainer </code> to remove 
     *  @throws org.osid.NotFoundException <code> stepConstrainerId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> stepConstrainerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void deleteStepConstrainer(org.osid.id.Id stepConstrainerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage <code> Id </code> aliases for step 
     *  constrainers. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known changing 
     *  an alias will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer alias 
     *  operations to an unauthorized user. 
     *
     *  @return <code> false </code> if <code> StepConstrainer </code> 
     *          aliasing is not authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageStepConstrainerAliases();


    /**
     *  Adds a <code> Id </code> to a <code> StepConstrainer </code> for the 
     *  purpose of creating compatibility. The primary <code> Id </code> of 
     *  the <code> StepConstrainer </code> is determined by the provider. The 
     *  new <code> Id </code> performs as an alias to the primary <code> Id 
     *  </code> . If the alias is a pointer to another step constrainer. it is 
     *  reassigned to the given step constrainer <code> Id. </code> 
     *
     *  @param  stepConstrainerId the <code> Id </code> of a <code> 
     *          StepConstrainer </code> 
     *  @param  aliasId the alias <code> Id </code> 
     *  @throws org.osid.AlreadyExistsException <code> aliasId </code> is 
     *          already assigned 
     *  @throws org.osid.NotFoundException <code> stepConstrainerId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> stepConstrainerId 
     *          </code> or <code> aliasId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void aliasStepConstrainer(org.osid.id.Id stepConstrainerId, 
                                     org.osid.id.Id aliasId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
