//
// org.osid.workflow.rules.StepConstrainerLookupSession
//
//     The OSID Java specification for org.osid.workflow.rules.StepConstrainerLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.workflow.rules;


/**
 *  <p>This session provides methods for retrieving <code> StepConstrainers. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors when 
 *  retrieving multiple objects. </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete set or is an error condition 
 *      </li> 
 *      <li> isolated office view: All step constrainer methods in this 
 *      session operate, retrieve and pertain to step constrainer defined 
 *      explicitly in the current office. Using an isolated view is useful for 
 *      managing <code> StepConstrainers </code> with the <code> 
 *      StepConstrainerAdminSession. </code> </li> 
 *      <li> federated office view: All step constrainer methods in this 
 *      session operate, retrieve and pertain to all step constrainer defined 
 *      in this office and any other step constrainer implicitly available in 
 *      this office through office inheritence. </li> 
 *      <li> active step constrainer view: All step constrainer lookup methods 
 *      return active step constrainers. </li> 
 *      <li> any status step constrainer view: Step constrainers of any active 
 *      or inactive status are returned from methods. </li> 
 *  </ul>
 *  
 *  
 *  <p> Generally, the comparative view should be used for most applications 
 *  as it permits operation even if there is data that cannot be accessed. The 
 *  methods <code> useFederatedOfficeView() </code> and <code> 
 *  useIsolatedOfficeView() </code> behave as a radio group and one should be 
 *  selected before invoking the methods in this session. </p>
 */

public interface StepConstrainerLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Office </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Office Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getOfficeId();


    /**
     *  Gets the <code> Office </code> associated with this session. 
     *
     *  @return the office 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.Office getOffice()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform <code> StepConstrainers </code> 
     *  lookups. A return of true does not guarantee successful authorization. 
     *  A return of false indicates that it is known all methods in this 
     *  session will result in a <code> PERMISSION_DENIED. </code> This is 
     *  intended as a hint to an application that may opt not to offer lookup 
     *  operations to unauthorized users. 
     *
     *  @return <code> false </code> if lookup methods are not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupStepConstrainers();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeStepConstrainerView();


    /**
     *  A complete view of the <code> StepConstrainer </code> returns is 
     *  desired. Methods will return what is requested or result in an error. 
     *  This view is used when greater precision is desired at the expense of 
     *  interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryStepConstrainerView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include step constrainer in offices which are children of this office 
     *  in the office hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedOfficeView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this office only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedOfficeView();


    /**
     *  Only active step constrainers are returned by methods in this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useActiveStepConstrainerView();


    /**
     *  All active and inactive step constrainers are returned by methods in 
     *  this session. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useAnyStatusStepConstrainerView();


    /**
     *  Gets the <code> StepConstrainer </code> specified by its <code> Id. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the exact <code> Id </code> is found 
     *  or a <code> NOT_FOUND </code> results. Otherwise, the returned <code> 
     *  StepConstrainer </code> may have a different <code> Id </code> than 
     *  requested, such as the case where a duplicate <code> Id </code> was 
     *  assigned to a <code> StepConstrainer </code> and retained for 
     *  compatibility. 
     *  
     *  In active mode, step constrainers are returned that are currently 
     *  active. In any status mode, active and inactive step constrainers are 
     *  returned. 
     *
     *  @param  stepConstrainerId <code> Id </code> of the <code> 
     *          StepConstrainer </code> 
     *  @return the step constrainer 
     *  @throws org.osid.NotFoundException <code> stepConstrainerId </code> 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> stepConstrainerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method is must be implemented. 
     */

    public org.osid.workflow.rules.StepConstrainer getStepConstrainer(org.osid.id.Id stepConstrainerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> StepConstrainerList </code> corresponding to the given 
     *  <code> IdList. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all of the 
     *  step constrainer specified in the <code> Id </code> list, in the order 
     *  of the list, including duplicates, or an error results if a <code> Id 
     *  </code> in the supplied list is not found or inaccessible. Otherwise, 
     *  inaccessible <code> StepConstrainers </code> may be omitted from the 
     *  list and may present the elements in any order including returning a 
     *  unique set. 
     *  
     *  In active mode, step constrainers are returned that are currently 
     *  active. In any status mode, active and inactive step constrainers are 
     *  returned. 
     *
     *  @param  stepConstrainerIds the list of <code> Ids </code> to retrieve 
     *  @return the returned <code> StepConstrainer </code> list 
     *  @throws org.osid.NotFoundException a <code> Id </code> was not found 
     *  @throws org.osid.NullArgumentException <code> stepConstrainerIds 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.StepConstrainerList getStepConstrainersByIds(org.osid.id.IdList stepConstrainerIds)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> StepConstrainerList </code> corresponding to the given 
     *  step constrainer genus <code> Type </code> which does not include step 
     *  constrainer of genus types derived from the specified <code> Type. 
     *  </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  step constrainer or an error results. Otherwise, the returned list may 
     *  contain only those step constrainer that are accessible through this 
     *  session. 
     *  
     *  In active mode, step constrainers are returned that are currently 
     *  active. In any status mode, active and inactive step constrainers are 
     *  returned. 
     *
     *  @param  stepConstrainerGenusType a step constrainer genus type 
     *  @return the returned <code> StepConstrainer </code> list 
     *  @throws org.osid.NullArgumentException <code> stepConstrainerGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.StepConstrainerList getStepConstrainersByGenusType(org.osid.type.Type stepConstrainerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> StepConstrainerList </code> corresponding to the given 
     *  step constrainer genus <code> Type </code> and include any additional 
     *  step constrainer with genus types derived from the specified <code> 
     *  Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  step constrainer or an error results. Otherwise, the returned list may 
     *  contain only those step constrainer that are accessible through this 
     *  session. 
     *  
     *  In active mode, step constrainers are returned that are currently 
     *  active. In any status mode, active and inactive step constrainers are 
     *  returned. 
     *
     *  @param  stepConstrainerGenusType a step constrainer genus type 
     *  @return the returned <code> StepConstrainer </code> list 
     *  @throws org.osid.NullArgumentException <code> stepConstrainerGenusType 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.StepConstrainerList getStepConstrainersByParentGenusType(org.osid.type.Type stepConstrainerGenusType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a <code> StepConstrainerList </code> containing the given step 
     *  constrainer record <code> Type. </code> 
     *  
     *  <code> </code> In plenary mode, the returned list contains all known 
     *  step constrainer or an error results. Otherwise, the returned list may 
     *  contain only those step constrainer that are accessible through this 
     *  session. 
     *  
     *  In active mode, step constrainers are returned that are currently 
     *  active. In any status mode, active and inactive step constrainers are 
     *  returned. 
     *
     *  @param  stepConstrainerRecordType a step constrainer record type 
     *  @return the returned <code> StepConstrainer </code> list 
     *  @throws org.osid.NullArgumentException <code> 
     *          stepConstrainerRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.StepConstrainerList getStepConstrainersByRecordType(org.osid.type.Type stepConstrainerRecordType)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets all <code> StepConstrainers. </code> 
     *  
     *  In plenary mode, the returned list contains all known step constrainer 
     *  or an error results. Otherwise, the returned list may contain only 
     *  those step constrainer that are accessible through this session. 
     *  
     *  In active mode, step constrainers are returned that are currently 
     *  active. In any status mode, active and inactive step constrainers are 
     *  returned. 
     *
     *  @return the returned <code> StepConstrainer </code> list 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.StepConstrainerList getStepConstrainers()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
