//
// org.osid.workflow.rules.StepConstrainerRuleLookupSession
//
//     The OSID Java specification for org.osid.workflow.rules.StepConstrainerRuleLookupSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.workflow.rules;


/**
 *  <p>This session provides methods to retrieve <code> StepConstrainer 
 *  </code> to <code> Step </code> mappings. A <code> Step </code> with 
 *  multiple <code> StepConstrainers </code> means any positive rule 
 *  evaluation across the constrainers result in an accessible <code> Step. 
 *  </code> </p> 
 *  
 *  <p> This lookup session defines several views: </p> 
 *  
 *  <ul>
 *      <li> comparative view: elements may be silently omitted or re-ordered 
 *      </li> 
 *      <li> plenary view: provides a complete result set or is an error 
 *      condition </li> 
 *      <li> isolated office view: All methods in this session operate, 
 *      retrieve and pertain step constrainer defined explicitly in the 
 *      current office </li> 
 *      <li> federated office view: All methods in this session operate, 
 *      retrieve and pertain to all step constrainer defined in this office 
 *      and any other step constrainer implicitly available in this office 
 *      through office inheritence. </li> 
 *  </ul>
 *  
 */

public interface StepConstrainerRuleLookupSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Office </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Office Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getOfficeId();


    /**
     *  Gets the <code> Office </code> associated with this session. 
     *
     *  @return the office 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.Office getOffice()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can perform lookups of step constrainer/step 
     *  mappings. A return of true does not guarantee successful 
     *  authorization. A return of false indicates that it is known lookup 
     *  methods in this session will result in a <code> PERMISSION_DENIED. 
     *  </code> This is intended as a hint to an application that may opt not 
     *  to offer lookup operations to unauthorized users. 
     *
     *  @return <code> false </code> if looking up mappings is not authorized, 
     *          <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canLookupStepConstrainerRules();


    /**
     *  The returns from the lookup methods may omit or translate elements 
     *  based on this session, such as authorization, and not result in an 
     *  error. This view is used when greater interoperability is desired at 
     *  the expense of precision. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useComparativeStepConstrainerRuleView();


    /**
     *  A complete view of the <code> StepConstrainer </code> and <code> Step 
     *  </code> returns is desired. Methods will return what is requested or 
     *  result in an error. This view is used when greater precision is 
     *  desired at the expense of interoperability. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void usePlenaryStepConstrainerRuleView();


    /**
     *  Federates the view for methods in this session. A federated view will 
     *  include step constrainer in offices which are children of this office 
     *  in the office hierarchy. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useFederatedOfficeView();


    /**
     *  Isolates the view for methods in this session. An isolated view 
     *  restricts lookups to this office only. 
     *
     *  @compliance mandatory This method is must be implemented. 
     */

    public void useIsolatedOfficeView();


    /**
     *  Gets the <code> StepConstrainer Id </code> associated with a <code> 
     *  Step. </code> 
     *
     *  @param  stepId <code> Id </code> of the <code> Step </code> 
     *  @return the step constrainer <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> stepId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> stepId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getStepConstrainerIdsForStep(org.osid.id.Id stepId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> StepConstrainer </code> associated with a <code> Step. 
     *  </code> 
     *
     *  @param  stepId <code> Id </code> of the <code> Step </code> 
     *  @return the step constrainers 
     *  @throws org.osid.NotFoundException <code> stepId </code> is not found 
     *  @throws org.osid.NullArgumentException <code> stepId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.StepConstrainerList getStepConstrainersForStep(org.osid.id.Id stepId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Step </code> <code> Ids </code> mapped to a <code> 
     *  StepConstrainer. </code> 
     *
     *  @param  stepConstrainerId <code> Id </code> of a <code> 
     *          StepConstrainer </code> 
     *  @return list of step <code> Ids </code> 
     *  @throws org.osid.NotFoundException <code> stepConstrainerId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> stepConstrainerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getStepIdsForStepConstrainer(org.osid.id.Id stepConstrainerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets the <code> Steps </code> mapped to a <code> StepConstrainer. 
     *  </code> 
     *
     *  @param  stepConstrainerId <code> Id </code> of a <code> 
     *          StepConstrainer </code> 
     *  @return list of steps 
     *  @throws org.osid.NotFoundException <code> stepConstrainerId </code> is 
     *          not found 
     *  @throws org.osid.NullArgumentException <code> stepConstrainerId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.StepList getStepsForStepConstrainer(org.osid.id.Id stepConstrainerId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
