//
// org.osid.workflow.rules.StepConstrainerSearchSession
//
//     The OSID Java specification for org.osid.workflow.rules.StepConstrainerSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.workflow.rules;


/**
 *  <p>This session provides methods for searching among <code> 
 *  StepConstrainer </code> objects. The search query is constructed using the 
 *  <code> StepConstraineryQuery. </code> </p> 
 *  
 *  <p> <code> getStepConstrainersByQuery() </code> is the basic search method 
 *  and returns a list of <code> StepConstrainers. </code> A more advanced 
 *  search may be performed with <code> getStepConstrainersBySearch(). </code> 
 *  It accepts a <code> StepConstrainerSearch </code> in addition to the query 
 *  for the purpose of specifying additional options affecting the entire 
 *  search, such as workflow. <code> getStepConstrainersBySearch() </code> 
 *  returns a <code> StepConstrainerSearchResults </code> that can be used to 
 *  access the resulting <code> StepConstrainerList </code> or be used to 
 *  perform a search within the result set through <code> 
 *  StepConstrainerSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated office view: searches include step constrainer in 
 *      office of which this office is an ancestor in the office hierarchy 
 *      </li> 
 *      <li> isolated office view: searches are restricted to step constrainer 
 *      in this office </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> StepConstrainers </code> may have a query record indicated by 
 *  their respective record types. The query record is accessed via the <code> 
 *  StepConstrainerQuery. </code> </p>
 */

public interface StepConstrainerSearchSession
    extends org.osid.workflow.rules.StepConstrainerQuerySession {


    /**
     *  Gets a step constrainer search. 
     *
     *  @return the step constrainer search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.StepConstrainerSearch getStepConstrainerSearch();


    /**
     *  Gets a step constrainer search order. The <code> 
     *  StepConstrainerSearchOrder </code> is supplied to a <code> 
     *  StepConstrainerSearch </code> to specify the ordering of results. 
     *
     *  @return the step constrainer search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.StepConstrainerSearchOrder getStepConstrainerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  stepConstrainerQuery the step constrainer query 
     *  @param  stepConstrainerSearch the step constrainer search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> stepConstrainerQuery 
     *          </code> or <code> stepConstrainerSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> stepConstrainerQuery 
     *          </code> or <code> stepConstrainerSearch </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.StepConstrainerSearchResults getStepConstrainersBySearch(org.osid.workflow.rules.StepConstrainerQuery stepConstrainerQuery, 
                                                                                            org.osid.workflow.rules.StepConstrainerSearch stepConstrainerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a step constrainer query from an inspector. The inspector is 
     *  available from a <code> StepConstrainerSearchResults. </code> 
     *
     *  @param  stepConstrainerQueryInspector a step constrainer query 
     *          inspector 
     *  @return the step constrainer query 
     *  @throws org.osid.NullArgumentException <code> 
     *          stepConstrainerQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          stepConstrainerQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.StepConstrainerQuery getStepConstrainerQueryFromInspector(org.osid.workflow.rules.StepConstrainerQueryInspector stepConstrainerQueryInspector);
}
