//
// org.osid.workflow.rules.StepConstrainerSmartOfficeSession
//
//     The OSID Java specification for org.osid.workflow.rules.StepConstrainerSmartOfficeSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.workflow.rules;


/**
 *  <p>This session manages queries and sequencing to create "smart" dynamic 
 *  office. a <code> StepConstrainerQuery </code> can be retrieved from this 
 *  session and mapped to this <code> Office </code> to create a virtual 
 *  collection of step constrainers. The step constrainer may be sequenced 
 *  using the <code> StepConstrainerSearchOrder </code> from this session. 
 *  </p> 
 *  
 *  <p> This <code> Office </code> has a default query that matches any step 
 *  constrainer and a default search order that specifies no sequencing. The 
 *  queries may be examined using a <code> StepConstrainerQueryInspector. 
 *  </code> The query may be modified by converting the inspector back to a 
 *  <code> StepConstrainerQuery. </code> </p>
 */

public interface StepConstrainerSmartOfficeSession
    extends org.osid.OsidSession {


    /**
     *  Gets the <code> Office </code> <code> Id </code> associated with this 
     *  session. 
     *
     *  @return the <code> Office Id </code> associated with this session 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.Id getOfficeId();


    /**
     *  Gets the <code> Office </code> associated with this session. 
     *
     *  @return the office 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.Office getOffice()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Tests if this user can manage smart office. A return of true does not 
     *  guarantee successful authorization. A return of false indicates that 
     *  it is known methods in this session will result in a <code> 
     *  PERMISSION_DENIED. </code> This is intended as a hint to an 
     *  application that may opt not to offer operations to unauthorized 
     *  users. 
     *
     *  @return <code> false </code> if smart office management is not 
     *          authorized, <code> true </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canManageSmartOffices();


    /**
     *  Gets a step constrainer query. 
     *
     *  @return the step constrainer query 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.StepConstrainerQuery getStepConstrainerQuery();


    /**
     *  Gets a step constrainer search order. 
     *
     *  @return the step constrainer search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.StepConstrainerSearchOrder getStepConstrainerSearchOrder();


    /**
     *  Applies a step constrainer query to this office. 
     *
     *  @param  stepConstrainerQuery the step constrainer query 
     *  @throws org.osid.NullArgumentException <code> stepConstrainerQuery 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> stepConstrainerQuery 
     *          </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyStepConstrainerQuery(org.osid.workflow.rules.StepConstrainerQuery stepConstrainerQuery)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a step constrainer query inspector for this office. 
     *
     *  @return the step constrainer query inspector 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.StepConstrainerQueryInspector inspectStepConstrainerQuery()
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Applies a step constrainer search order to this office. 
     *
     *  @param  stepConstrainerSearchOrder the step constrainer search order 
     *  @throws org.osid.NullArgumentException <code> 
     *          stepConstrainerSearchOrder </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *          occurred 
     *  @throws org.osid.UnsupportedException <code> 
     *          stepConstrainerSearchOrder </code> not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public void applyStepConstrainerSequencing(org.osid.workflow.rules.StepConstrainerSearchOrder stepConstrainerSearchOrder)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a step constrainer query from an inspector. 
     *
     *  @param  stepConstrainerQueryInspector a step constrainer query 
     *          inspector 
     *  @return the step constrainer query 
     *  @throws org.osid.NullArgumentException <code> 
     *          stepConstrainerQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          stepConstrainerQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.StepConstrainerQuery getStepConstrainerQueryFromInspector(org.osid.workflow.rules.StepConstrainerQueryInspector stepConstrainerQueryInspector);
}
