//
// org.osid.workflow.rules.StepProcessorEnablerQuery
//
//     The OSID Java specification for org.osid.workflow.rules.StepProcessorEnablerQuery.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.workflow.rules;


/**
 *  <p>This is the query for searching step processor enablers. Each method 
 *  match specifies a <code> AND </code> term while multiple invocations of 
 *  the same method produce a nested <code> OR. </code> </p>
 */

public interface StepProcessorEnablerQuery
    extends org.osid.OsidEnablerQuery {


    /**
     *  Matches enablers mapped to the step processor. 
     *
     *  @param  stepProcessorId the step processor <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> stepProcessorId </code> 
     *          is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchRuledStepProcessorId(org.osid.id.Id stepProcessorId, 
                                          boolean match);


    /**
     *  Clears the step processor <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledStepProcessorIdTerms();


    /**
     *  Tests if a <code> StepProcessorQuery </code> is available. 
     *
     *  @return <code> true </code> if a step processor query is available, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsRuledStepProcessorQuery();


    /**
     *  Gets the query for a step processor. Multiple retrievals produce a 
     *  nested <code> OR </code> term. 
     *
     *  @return the step processor query 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsRuledStepProcessorQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsRuledStepProcessorQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.StepProcessorQuery getRuledStepProcessorQuery();


    /**
     *  Matches enablers mapped to any step processor. 
     *
     *  @param  match <code> true </code> for enablers mapped to any step 
     *          processor, <code> false </code> to match enablers mapped to no 
     *          step processors 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchAnyRuledStepProcessor(boolean match);


    /**
     *  Clears the step processor query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearRuledStepProcessorTerms();


    /**
     *  Matches enablers mapped to the office. 
     *
     *  @param  officeId the office <code> Id </code> 
     *  @param  match <code> true </code> for a positive match, <code> false 
     *          </code> for a negative match 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public void matchOfficeId(org.osid.id.Id officeId, boolean match);


    /**
     *  Clears the office <code> Id </code> query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOfficeIdTerms();


    /**
     *  Tests if an <code> OfficeQuery </code> is available. 
     *
     *  @return <code> true </code> if an office query is available, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsOfficeQuery();


    /**
     *  Gets the query for an office. Multiple retrievals produce a nested 
     *  <code> OR </code> term. 
     *
     *  @return the office query 
     *  @throws org.osid.UnimplementedException <code> supportsOfficeQuery() 
     *          </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsOfficeQuery() </code> is <code> true. </code> 
     */

    public org.osid.workflow.OfficeQuery getOfficeQuery();


    /**
     *  Clears the office query terms. 
     *
     *  @compliance mandatory This method must be implemented. 
     */

    public void clearOfficeTerms();


    /**
     *  Gets the step processor enabler query record corresponding to the 
     *  given <code> StepProcessorEnabler </code> record <code> Type. </code> 
     *  Multiple record retrievals produce a nested <code> OR </code> term. 
     *
     *  @param  stepProcessorEnablerRecordType a step processor enabler record 
     *          type 
     *  @return the step processor enabler query record 
     *  @throws org.osid.NullArgumentException <code> 
     *          stepProcessorEnablerRecordType </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnsupportedException <code> 
     *          hasRecordType(stepProcessorEnablerRecordType) </code> is 
     *          <code> false </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.records.StepProcessorEnablerQueryRecord getStepProcessorEnablerQueryRecord(org.osid.type.Type stepProcessorEnablerRecordType)
        throws org.osid.OperationFailedException;
}
