//
// org.osid.workflow.rules.StepProcessorEnablerSearchSession
//
//     The OSID Java specification for org.osid.workflow.rules.StepProcessorEnablerSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.workflow.rules;


/**
 *  <p>This session provides methods for searching among <code> 
 *  StepProcessorEnabler </code> objects. The search query is constructed 
 *  using the <code> StepProcessorEnableryQuery. </code> </p> 
 *  
 *  <p> <code> getStepProcessorEnablersByQuery() </code> is the basic search 
 *  method and returns a list of <code> StepProcessorEnablers. </code> A more 
 *  advanced search may be performed with <code> 
 *  getStepProcessorEnablersBySearch(). </code> It accepts a <code> 
 *  StepProcessorEnablerSearch </code> in addition to the query for the 
 *  purpose of specifying additional options affecting the entire search, such 
 *  as workflow. <code> getStepProcessorEnablersBySearch() </code> returns a 
 *  <code> StepProcessorEnablerSearchResults </code> that can be used to 
 *  access the resulting <code> StepProcessorEnablerList </code> or be used to 
 *  perform a search within the result set through <code> 
 *  StepProcessorEnablerSearch. </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated office view: searches include step processor enablers 
 *      in office of which this office is an ancestor in the office hierarchy 
 *      </li> 
 *      <li> isolated office view: searches are restricted to step processor 
 *      enablers in this office </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> StepProcessorEnablers </code> may have a query record indicated 
 *  by their respective query record types. The record is accessed via the 
 *  <code> StepProcessorEnablerQuery. </code> </p>
 */

public interface StepProcessorEnablerSearchSession
    extends org.osid.workflow.rules.StepProcessorEnablerQuerySession {


    /**
     *  Gets a step processor enabler search. 
     *
     *  @return the step processor enabler search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.StepProcessorEnablerSearch getStepProcessorEnablerSearch();


    /**
     *  Gets a step processor enabler search order. The <code> 
     *  StepProcessorEnablerSearchOrder </code> is supplied to a <code> 
     *  StepProcessorEnablerSearch </code> to specify the ordering of results. 
     *
     *  @return the step processor enabler search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.StepProcessorEnablerSearchOrder getStepProcessorEnablerSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  stepProcessorEnablerQuery the step processor enabler query 
     *  @param  stepProcessorEnablerSearch the step processor enabler search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> 
     *          stepProcessorEnablerQuery </code> or <code> 
     *          stepProcessorEnablerSearch </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> stepProcessorEnablerQuery 
     *          </code> or <code> stepProcessorEnablerSearch </code> is not of 
     *          this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.StepProcessorEnablerSearchResults getStepProcessorEnablersBySearch(org.osid.workflow.rules.StepProcessorEnablerQuery stepProcessorEnablerQuery, 
                                                                                                      org.osid.workflow.rules.StepProcessorEnablerSearch stepProcessorEnablerSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a step processor enabler query from an inspector. The inspector 
     *  is available from a <code> StepProcessorEnablerSearchResults. </code> 
     *
     *  @param  stepProcessorEnablerQueryInspector a step processor enabler 
     *          query inspector 
     *  @return the step processor enabler query 
     *  @throws org.osid.NullArgumentException <code> 
     *          stepProcessorEnablerQueryInspector </code> is <code> null 
     *          </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          stepProcessorEnablerQueryInspector </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.StepProcessorEnablerQuery getStepProcessorEnablerQueryFromInspector(org.osid.workflow.rules.StepProcessorEnablerQueryInspector stepProcessorEnablerQueryInspector);
}
