//
// org.osid.workflow.rules.StepProcessorOfficeAssignmentSession
//
//     The OSID Java specification for org.osid.workflow.rules.StepProcessorOfficeAssignmentSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.workflow.rules;


/**
 *  <p>This session provides methods to re-assign <code> StepProcessor </code> 
 *  to <code> Office </code> mappings. a <code> StepProcessor </code> may 
 *  appear in multiple <code> Office </code> objects and removing the last 
 *  reference to a <code> StepProcessor </code> is the equivalent of deleting 
 *  it. Each <code> Office </code> may have its own authorizations governing 
 *  who is allowed to operate on it. </p> 
 *  
 *  <p> Adding a reference of a <code> StepProcessor </code> to another <code> 
 *  Office </code> is not a copy operation (eg: does not change its <code> Id 
 *  </code> ). </p>
 */

public interface StepProcessorOfficeAssignmentSession
    extends org.osid.OsidSession {


    /**
     *  Tests if this user can alter step processor/office mappings. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignStepProcessors();


    /**
     *  Tests if this user can alter step processor/office mappings. A return 
     *  of true does not guarantee successful authorization. A return of false 
     *  indicates that it is known mapping methods in this session will result 
     *  in a <code> PERMISSION_DENIED. </code> This is intended as a hint to 
     *  an application that may opt not to offer lookup operations to 
     *  unauthorized users. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return <code> false </code> if mapping is not authorized, <code> true 
     *          </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean canAssignStepProcessorsToOffice(org.osid.id.Id officeId);


    /**
     *  Gets a list of office including and under the given office node in 
     *  which any step processor can be assigned. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return list of assignable office <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableOfficeIds(org.osid.id.Id officeId)
        throws org.osid.OperationFailedException;


    /**
     *  Gets a list of office including and under the given office node in 
     *  which a specific step processor can be assigned. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @param  stepProcessorId the <code> Id </code> of the <code> 
     *          StepProcessor </code> 
     *  @return list of assignable office <code> Ids </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> or 
     *          <code> stepProcessorId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.id.IdList getAssignableOfficeIdsForStepProcessor(org.osid.id.Id officeId, 
                                                                     org.osid.id.Id stepProcessorId)
        throws org.osid.OperationFailedException;


    /**
     *  Adds an existing <code> StepProcessor </code> to an <code> Office. 
     *  </code> 
     *
     *  @param  stepProcessorId the <code> Id </code> of the <code> 
     *          StepProcessor </code> 
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @throws org.osid.AlreadyExistsException <code> stepProcessorId </code> 
     *          is already assigned to <code> officeId </code> 
     *  @throws org.osid.NotFoundException <code> stepProcessorId </code> or 
     *          <code> officeId </code> not found 
     *  @throws org.osid.NullArgumentException <code> stepProcessorId </code> 
     *          or <code> officeId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void assignStepProcessorToOffice(org.osid.id.Id stepProcessorId, 
                                            org.osid.id.Id officeId)
        throws org.osid.AlreadyExistsException,
               org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Removes a <code> StepProcessor </code> from an <code> Office. </code> 
     *
     *  @param  stepProcessorId the <code> Id </code> of the <code> 
     *          StepProcessor </code> 
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @throws org.osid.NotFoundException <code> stepProcessorId </code> or 
     *          <code> officeId </code> not found or <code> stepProcessorId 
     *          </code> not assigned to <code> officeId </code> 
     *  @throws org.osid.NullArgumentException <code> stepProcessorId </code> 
     *          or <code> officeId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void unassignStepProcessorFromOffice(org.osid.id.Id stepProcessorId, 
                                                org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Moves a <code> StepProcessor </code> from one <code> Office </code> to 
     *  another. Mappings to other <code> Offices </code> are unaffected. 
     *
     *  @param  stepProcessorId the <code> Id </code> of the <code> 
     *          StepProcessor </code> 
     *  @param  fromOfficeId the <code> Id </code> of the current <code> 
     *          Office </code> 
     *  @param  toOfficeId the <code> Id </code> of the destination <code> 
     *          Office </code> 
     *  @throws org.osid.NotFoundException <code> stepProcessorId, 
     *          fromOfficeId, </code> or <code> toOfficeId </code> not found 
     *          or <code> stepProcessorId </code> not mapped to <code> 
     *          fromOfficeId </code> 
     *  @throws org.osid.NullArgumentException <code> stepProcessorId, 
     *          fromOfficeId, </code> or <code> toOfficeId </code> is <code> 
     *          null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @compliance mandatory This method must be implemented. 
     */

    public void reassignStepProcessorToOffice(org.osid.id.Id stepProcessorId, 
                                              org.osid.id.Id fromOfficeId, 
                                              org.osid.id.Id toOfficeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;
}
