//
// org.osid.workflow.rules.StepProcessorSearchSession
//
//     The OSID Java specification for org.osid.workflow.rules.StepProcessorSearchSession.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.workflow.rules;


/**
 *  <p>This session provides methods for searching among <code> StepProcessor 
 *  </code> objects. The search query is constructed using the <code> 
 *  StepProcessoryQuery. </code> </p> 
 *  
 *  <p> <code> getStepProcessorsByQuery() </code> is the basic search method 
 *  and returns a list of <code> StepProcessors. </code> A more advanced 
 *  search may be performed with <code> getStepProcessorsBySearch(). </code> 
 *  It accepts a <code> StepProcessorSearch </code> in addition to the query 
 *  for the purpose of specifying additional options affecting the entire 
 *  search, such as workflow. <code> getStepProcessorsBySearch() </code> 
 *  returns a <code> StepProcessorSearchResults </code> that can be used to 
 *  access the resulting <code> StepProcessorList </code> or be used to 
 *  perform a search within the result set through <code> StepProcessorSearch. 
 *  </code> </p> 
 *  
 *  <p> This session defines views that offer differing behaviors for 
 *  searching. </p> 
 *  
 *  <ul>
 *      <li> federated office view: searches include step processor in office 
 *      of which this office is an ancestor in the office hierarchy </li> 
 *      <li> isolated office view: searches are restricted to step processor 
 *      in this office </li> 
 *  </ul>
 *  
 *  
 *  <p> <code> StepProcessors </code> may have a query record indicated by 
 *  their respective record types. Thequery record is accessed via the <code> 
 *  StepProcessorQuery. </code> </p>
 */

public interface StepProcessorSearchSession
    extends org.osid.workflow.rules.StepProcessorQuerySession {


    /**
     *  Gets a step processor search. 
     *
     *  @return the step processor search 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.StepProcessorSearch getStepProcessorSearch();


    /**
     *  Gets a step processor search order. The <code> 
     *  StepProcessorSearchOrder </code> is supplied to a <code> 
     *  StepProcessorSearch </code> to specify the ordering of results. 
     *
     *  @return the step processor search order 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.StepProcessorSearchOrder getStepProcessorSearchOrder();


    /**
     *  Gets the search results matching the given search query using the 
     *  given search. 
     *
     *  @param  stepProcessorQuery the step processor query 
     *  @param  stepProcessorSearch the step processor search 
     *  @return the returned search results 
     *  @throws org.osid.NullArgumentException <code> stepProcessorQuery 
     *          </code> or <code> stepProcessorSearch </code> is <code> null 
     *          </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.PermissionDeniedException authorization failure 
     *  @throws org.osid.UnsupportedException <code> stepProcessorQuery 
     *          </code> or <code> stepProcessorSearch </code> is not of this 
     *          service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.StepProcessorSearchResults getStepProcessorsBySearch(org.osid.workflow.rules.StepProcessorQuery stepProcessorQuery, 
                                                                                        org.osid.workflow.rules.StepProcessorSearch stepProcessorSearch)
        throws org.osid.OperationFailedException,
               org.osid.PermissionDeniedException;


    /**
     *  Gets a step processor query from an inspector. The inspector is 
     *  available from a <code> StepProcessorSearchResults. </code> 
     *
     *  @param  stepProcessorQueryInspector a step processor query inspector 
     *  @return the step processor query 
     *  @throws org.osid.NullArgumentException <code> 
     *          stepProcessorQueryInspector </code> is <code> null </code> 
     *  @throws org.osid.UnsupportedException <code> 
     *          stepProcessorQueryInspector </code> is not of this service 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.workflow.rules.StepProcessorQuery getStepProcessorQueryFromInspector(org.osid.workflow.rules.StepProcessorQueryInspector stepProcessorQueryInspector);
}
