//
// org.osid.workflow.rules.WorkflowRulesManager
//
//     The OSID Java specification for org.osid.workflow.rules.WorkflowRulesManager.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.workflow.rules;


/**
 *  <p>The workflow rules manager provides access to workflow rules sessions 
 *  and provides interoperability tests for various aspects of this service. 
 *  The sessions included in this manager are: </p> 
 *  
 *  <ul>
 *      <li> <code> StepConstrainerLookupSession: </code> a session to 
 *      retrieve step constrainer </li> 
 *      <li> <code> StepConstrainerQuerySession: </code> a session to query 
 *      for step constrainer </li> 
 *      <li> <code> StepConstrainerSearchSession: </code> a session to search 
 *      for step constrainer </li> 
 *      <li> <code> StepConstrainerAdminSession: </code> a session to create 
 *      and delete step constrainer </li> 
 *      <li> <code> StepConstrainerNotificationSession: </code> a session to 
 *      receive notifications pertaining to step constrainer changes </li> 
 *      <li> <code> StepConstrainerOfficeSession: </code> a session to look up 
 *      step constrainer office mappings </li> 
 *      <li> <code> StepConstrainerOfficeAssignmentSession: </code> a session 
 *      to manage step constrainer to office mappings </li> 
 *      <li> <code> StepConstrainerSmartOfficeSession: </code> a session to 
 *      manage dynamic office of step constrainer </li> 
 *      <li> <code> StepConstrainerRuleLookupSession: </code> a session to 
 *      look up step constrainer to step mappings </li> 
 *      <li> <code> StepConstrainerRuleApplicationSession: </code> a session 
 *      to apply step constrainer to steps </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> StepConstrainerEnablerLookupSession: </code> a session to 
 *      retrieve step constrainer enablers </li> 
 *      <li> <code> StepConstrainerEnablerQuerySession: </code> a session to 
 *      query for step constrainer enablers </li> 
 *      <li> <code> StepConstrainerEnablerSearchSession: </code> a session to 
 *      search for step constrainer enablers </li> 
 *      <li> <code> StepConstrainerEnablerAdminSession: </code> a session to 
 *      create and delete step constrainer enablers </li> 
 *      <li> <code> StepConstrainerEnablerNotificationSession: </code> a 
 *      session to receive notifications pertaining to step constrainer 
 *      enabler changes </li> 
 *      <li> <code> StepConstrainerEnablerOfficeSession: </code> a session to 
 *      look up step constrainer enabler office mappings </li> 
 *      <li> <code> StepConstrainerEnablerOfficeAssignmentSession: </code> a 
 *      session to manage step constrainer enabler to office mappings </li> 
 *      <li> <code> StepConstrainerEnablerSmartOfficeSession: </code> a 
 *      session to manage dynamic office of step constrainer enablers </li> 
 *      <li> <code> StepConstrainerEnableRuleLookupSession: </code> a session 
 *      to look up step constrainer enabler mappings </li> 
 *      <li> <code> StepConstrainerEnablerRuleApplicationSession: </code> a 
 *      session to apply step constrainer enablers </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> StepProcessorLookupSession: </code> a session to retrieve 
 *      step processor </li> 
 *      <li> <code> StepProcessorQuerySession: </code> a session to query for 
 *      step processor </li> 
 *      <li> <code> StepProcessorSearchSession: </code> a session to search 
 *      for step processor </li> 
 *      <li> <code> StepProcessorAdminSession: </code> a session to create and 
 *      delete step processor </li> 
 *      <li> <code> StepProcessorNotificationSession: </code> a session to 
 *      receive notifications pertaining to step processor changes </li> 
 *      <li> <code> StepProcessorOfficeSession: </code> a session to look up 
 *      step processor office mappings </li> 
 *      <li> <code> StepProcessorOfficeAssignmentSession: </code> a session to 
 *      manage step processor to office mappings </li> 
 *      <li> <code> StepProcessorSmartOfficeSession: </code> a session to 
 *      manage dynamic office of step processor </li> 
 *      <li> <code> StepProcessorRuleLookupSession: </code> a session to look 
 *      up step processor to step mappings </li> 
 *      <li> <code> StepProcessorRuleApplicationSession: </code> a session to 
 *      apply step processor to steps </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> StepProcessorEnablerLookupSession: </code> a session to 
 *      retrieve step processor enablers </li> 
 *      <li> <code> StepProcessorEnablerQuerySession: </code> a session to 
 *      query for step processor enablers </li> 
 *      <li> <code> StepProcessorEnablerSearchSession: </code> a session to 
 *      search for step processor enablers </li> 
 *      <li> <code> StepProcessorEnablerAdminSession: </code> a session to 
 *      create and delete step processor enablers </li> 
 *      <li> <code> StepProcessorEnablerNotificationSession: </code> a session 
 *      to receive notifications pertaining to step processor enabler changes 
 *      </li> 
 *      <li> <code> StepProcessorEnablerOfficeSession: </code> a session to 
 *      look up step processor enabler office mappings </li> 
 *      <li> <code> StepProcessorEnablerOfficeAssignmentSession: </code> a 
 *      session to manage step processor enabler to office mappings </li> 
 *      <li> <code> StepProcessorEnablerSmartOfficeSession: </code> a session 
 *      to manage dynamic office of step processor enablers </li> 
 *      <li> <code> StepProcessorEnablerRuleLookupSession: </code> a session 
 *      to look up step processor enabler mappings </li> 
 *      <li> <code> StepProcessorEnablerRuleApplicationSession: </code> a 
 *      session to apply step processor enablers </li> 
 *  </ul>
 *  
 *  
 *  <ul>
 *      <li> <code> ProcessEnablerLookupSession: </code> a session to retrieve 
 *      process enabler </li> 
 *      <li> <code> ProcessEnablerQuerySession: </code> a session to query for 
 *      process enabler </li> 
 *      <li> <code> ProcessEnablerSearchSession: </code> a session to search 
 *      for process enabler </li> 
 *      <li> <code> ProcessEnablerAdminSession: </code> a session to create 
 *      and delete process enabler </li> 
 *      <li> <code> ProcessEnablerNotificationSession: </code> a session to 
 *      receive notifications pertaining to process enabler changes </li> 
 *      <li> <code> ProcessEnablerOfficeSession: </code> a session to look up 
 *      process enabler office mappings </li> 
 *      <li> <code> ProcessEnablerOfficeAssignmentSession: </code> a session 
 *      to manage process enabler to office mappings </li> 
 *      <li> <code> ProcessEnablerSmartOfficeSession: </code> a session to 
 *      manage dynamic office of process enabler </li> 
 *      <li> <code> ProcessEnablerRuleLookupSession: </code> a session to look 
 *      up process enabler to process mappings </li> 
 *      <li> <code> ProcessEnablerRuleApplicationSession: </code> a session to 
 *      apply process enabler to processs </li> 
 *  </ul>
 *  
 */

public interface WorkflowRulesManager
    extends org.osid.OsidManager,
            org.osid.workflow.rules.WorkflowRulesProfile {


    /**
     *  Gets the <code> OsidSession </code> associated with the step 
     *  constrainer lookup service. 
     *
     *  @return a <code> StepConstrainerLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepConstrainerLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepConstrainerLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.StepConstrainerLookupSession getStepConstrainerLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step 
     *  constrainer lookup service for the given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> StepConstrainerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Office </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepConstrainerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepConstrainerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.StepConstrainerLookupSession getStepConstrainerLookupSessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step 
     *  constrainer query service. 
     *
     *  @return a <code> StepConstrainerQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepConstrainerQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepConstrainerQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.StepConstrainerQuerySession getStepConstrainerQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step 
     *  constrainer query service for the given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> StepConstrainerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Office </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepConstrainerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepConstrainerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.StepConstrainerQuerySession getStepConstrainerQuerySessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step 
     *  constrainer search service. 
     *
     *  @return a <code> StepConstrainerSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepConstrainerSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepConstrainerSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.StepConstrainerSearchSession getStepConstrainerSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step 
     *  constrainer earch service for the given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> StepConstrainerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Office </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepConstrainerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepConstrainerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.StepConstrainerSearchSession getStepConstrainerSearchSessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step 
     *  constrainer administration service. 
     *
     *  @return a <code> StepConstrainerAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepConstrainerAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepConstrainerAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.StepConstrainerAdminSession getStepConstrainerAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step 
     *  constrainer administration service for the given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> StepConstrainerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Office </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepConstrainerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepConstrainerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.StepConstrainerAdminSession getStepConstrainerAdminSessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step 
     *  constrainer notification service. 
     *
     *  @param  stepConstrainerReceiver the notification callback 
     *  @return a <code> StepConstrainerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> stepConstrainerReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepConstrainerNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepConstrainerNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.workflow.rules.StepConstrainerNotificationSession getStepConstrainerNotificationSession(org.osid.workflow.rules.StepConstrainerReceiver stepConstrainerReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step 
     *  constrainer notification service for the given office. 
     *
     *  @param  stepConstrainerReceiver the notification callback 
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> StepConstrainerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no office found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> stepConstrainerReceiver 
     *          </code> or <code> officeId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepConstrainerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepConstrainerNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.StepConstrainerNotificationSession getStepConstrainerNotificationSessionForOffice(org.osid.workflow.rules.StepConstrainerReceiver stepConstrainerReceiver, 
                                                                                                                     org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup step constrainer/office 
     *  mappings for step constrainers. 
     *
     *  @return a <code> StepConstrainerOfficeSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepConstrainerOffice() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepConstrainerOffice() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.StepConstrainerOfficeSession getStepConstrainerOfficeSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning step 
     *  constrainer to office. 
     *
     *  @return a <code> StepConstrainerOfficeAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepConstrainerOfficeAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepConstrainerOfficeAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.workflow.rules.StepConstrainerOfficeAssignmentSession getStepConstrainerOfficeAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage step constrainer smart 
     *  office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> StepConstrainerSmartOfficeSession </code> 
     *  @throws org.osid.NotFoundException no <code> Office </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepConstrainerSmartOffice() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepConstrainerSmartOffice() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.workflow.rules.StepConstrainerSmartOfficeSession getStepConstrainerSmartOfficeSession(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step 
     *  constrainer mapping lookup service for looking up the rules applied to 
     *  a step. 
     *
     *  @return a <code> StepConstrainerRuleLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepConstrainerRuleLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepConstrainerRuleLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.workflow.rules.StepConstrainerRuleLookupSession getStepConstrainerRuleLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step 
     *  constrainer mapping lookup service for the given office for looking up 
     *  rules applied to a step. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> StepConstrainerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Office </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepConstrainerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepConstrainerRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.StepConstrainerRuleLookupSession getStepConstrainerRuleLookupSessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step 
     *  constrainer assignment service to apply to steps. 
     *
     *  @return a <code> StepConstrainerRuleApplicationSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepConstrainerRuleApplication() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepConstrainerRuleApplication() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.workflow.rules.StepConstrainerRuleApplicationSession getStepConstrainerRuleApplicationSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step 
     *  constrainer assignment service for the given office to apply to steps. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> StepConstrainerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Office </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepConstrainerRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepConstrainerRuleApplication() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.workflow.rules.StepConstrainerRuleApplicationSession getStepConstrainerRuleApplicationSessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step 
     *  constrainer enabler lookup service. 
     *
     *  @return a <code> StepConstrainerEnablerLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepConstrainerEnablerLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepConstrainerEnablerLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.workflow.rules.StepConstrainerEnablerLookupSession getStepConstrainerEnablerLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step 
     *  constrainer enabler lookup service for the given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> StepConstrainerEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Office </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepConstrainerEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepConstrainerEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.StepConstrainerEnablerLookupSession getStepConstrainerEnablerLookupSessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step 
     *  constrainer enabler query service. 
     *
     *  @return a <code> StepConstrainerEnablerQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepConstrainerEnablerQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepConstrainerEnablerQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.workflow.rules.StepConstrainerEnablerQuerySession getStepConstrainerEnablerQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step 
     *  constrainer enabler query service for the given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> StepConstrainerEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Office </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepConstrainerEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepConstrainerEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.StepConstrainerEnablerQuerySession getStepConstrainerEnablerQuerySessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step 
     *  constrainer enabler search service. 
     *
     *  @return a <code> StepConstrainerEnablerSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepConstrainerEnablerSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepConstrainerEnablerSearch() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.workflow.rules.StepConstrainerEnablerSearchSession getStepConstrainerEnablerSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step 
     *  constrainer enablers earch service for the given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> StepConstrainerEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Office </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepConstrainerEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepConstrainerEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.StepConstrainerEnablerSearchSession getStepConstrainerEnablerSearchSessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step 
     *  constrainer enabler administration service. 
     *
     *  @return a <code> StepConstrainerEnablerAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepConstrainerEnablerAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepConstrainerEnablerAdmin() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.workflow.rules.StepConstrainerEnablerAdminSession getStepConstrainerEnablerAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step 
     *  constrainer enabler administration service for the given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> StepConstrainerEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Office </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepConstrainerEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepConstrainerEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.StepConstrainerEnablerAdminSession getStepConstrainerEnablerAdminSessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step 
     *  constrainer enabler notification service. 
     *
     *  @param  stepConstrainerEnablerReceiver the notification callback 
     *  @return a <code> StepConstrainerEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          stepConstrainerEnablerReceiver </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepConstrainerEnablerNotification() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepConstrainerEnablerNotification() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.workflow.rules.StepConstrainerEnablerNotificationSession getStepConstrainerEnablerNotificationSession(org.osid.workflow.rules.StepConstrainerEnablerReceiver stepConstrainerEnablerReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step 
     *  constrainer enabler notification service for the given office. 
     *
     *  @param  stepConstrainerEnablerReceiver the notification callback 
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> StepConstrainerEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no office found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          stepConstrainerEnablerReceiver </code> or <code> officeId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepConstrainerEnablerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepConstrainerEnablerNotification() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.workflow.rules.StepConstrainerEnablerNotificationSession getStepConstrainerEnablerNotificationSessionForOffice(org.osid.workflow.rules.StepConstrainerEnablerReceiver stepConstrainerEnablerReceiver, 
                                                                                                                                   org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup step constrainer 
     *  enabler/office mappings for step constrainer enablers. 
     *
     *  @return a <code> StepConstrainerEnablerOfficeSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepConstrainerEnablerOffice() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepConstrainerEnablerOffice() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.workflow.rules.StepConstrainerEnablerOfficeSession getStepConstrainerEnablerOfficeSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning step 
     *  constrainer enablers to office. 
     *
     *  @return a <code> StepConstrainerEnablerOfficeAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepConstrainerEnablerOfficeAssignment() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepConstrainerEnablerOfficeAssignment() </code> 
     *              is <code> true. </code> 
     */

    public org.osid.workflow.rules.StepConstrainerEnablerOfficeAssignmentSession getStepConstrainerEnablerOfficeAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage step constrainer enabler 
     *  smart office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> StepConstrainerEnablerSmartOfficeSession </code> 
     *  @throws org.osid.NotFoundException no <code> Office </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepConstrainerEnablerSmartOffice() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepConstrainerEnablerSmartOffice() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.workflow.rules.StepConstrainerEnablerSmartOfficeSession getStepConstrainerEnablerSmartOfficeSession(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step 
     *  constrainer enabler mapping lookup service. 
     *
     *  @return a <code> StepConstrainerEnablerRuleLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepConstrainerEnablerRuleLookup() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepConstrainerEnablerRuleLookup() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.workflow.rules.StepConstrainerEnablerRuleLookupSession getStepConstrainerEnablerRuleLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step 
     *  constrainer enabler mapping lookup service for the given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> StepConstrainerEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Office </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepConstrainerEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepConstrainerEnablerRuleLookup() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.workflow.rules.StepConstrainerEnablerRuleLookupSession getStepConstrainerEnablerRuleLookupSessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step 
     *  constrainer enabler assignment service. 
     *
     *  @return a <code> StepConstrainerEnablerRuleApplicationSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepConstrainerEnablerRuleApplication() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepConstrainerEnablerRuleApplication() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.workflow.rules.StepConstrainerEnablerRuleApplicationSession getStepConstrainerEnablerRuleApplicationSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step 
     *  constrainer enabler assignment service for the given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> StepConstrainerEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Office </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepConstrainerEnablerRuleApplication() </code> or 
     *          <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepConstrainerEnablerRuleApplication() </code> 
     *              and <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.workflow.rules.StepConstrainerEnablerRuleApplicationSession getStepConstrainerEnablerRuleApplicationSessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step processor 
     *  lookup service. 
     *
     *  @return a <code> StepProcessorLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepProcessorLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepProcessorLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.StepProcessorLookupSession getStepProcessorLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step processor 
     *  lookup service for the given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> StepProcessorLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Office </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepProcessorLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepProcessorLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.StepProcessorLookupSession getStepProcessorLookupSessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step processor 
     *  query service. 
     *
     *  @return a <code> StepProcessorQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepProcessorQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepProcessorQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.StepProcessorQuerySession getStepProcessorQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step processor 
     *  query service for the given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> StepProcessorQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Office </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepProcessorQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepProcessorQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.StepProcessorQuerySession getStepProcessorQuerySessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step processor 
     *  search service. 
     *
     *  @return a <code> StepProcessorSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepProcessorSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepProcessorSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.StepProcessorSearchSession getStepProcessorSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step processor 
     *  earch service for the given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> StepProcessorSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Office </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepProcessorSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepProcessorSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.StepProcessorSearchSession getStepProcessorSearchSessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step processor 
     *  administration service. 
     *
     *  @return a <code> StepProcessorAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepProcessorAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepProcessorAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.StepProcessorAdminSession getStepProcessorAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step processor 
     *  administration service for the given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> StepProcessorAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Office </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepProcessorAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepProcessorAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.StepProcessorAdminSession getStepProcessorAdminSessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step processor 
     *  notification service. 
     *
     *  @param  stepProcessorReceiver the notification callback 
     *  @return a <code> StepProcessorNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> stepProcessorReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepProcessorNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepProcessorNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.workflow.rules.StepProcessorNotificationSession getStepProcessorNotificationSession(org.osid.workflow.rules.StepProcessorReceiver stepProcessorReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step processor 
     *  notification service for the given office. 
     *
     *  @param  stepProcessorReceiver the notification callback 
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> StepProcessorNotificationSession </code> 
     *  @throws org.osid.NotFoundException no office found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> stepProcessorReceiver 
     *          </code> or <code> officeId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepProcessorNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepProcessorNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.StepProcessorNotificationSession getStepProcessorNotificationSessionForOffice(org.osid.workflow.rules.StepProcessorReceiver stepProcessorReceiver, 
                                                                                                                 org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup step processor/office 
     *  mappings for step processors. 
     *
     *  @return a <code> StepProcessorOfficeSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepProcessorOffice() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepProcessorOffice() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.StepProcessorOfficeSession getStepProcessorOfficeSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning step 
     *  processor to office. 
     *
     *  @return a <code> StepProcessorOfficeAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepProcessorOfficeAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepProcessorOfficeAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.workflow.rules.StepProcessorOfficeAssignmentSession getStepProcessorOfficeAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage step processor smart 
     *  office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> StepProcessorSmartOfficeSession </code> 
     *  @throws org.osid.NotFoundException no <code> Office </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepProcessorSmartOffice() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepProcessorSmartOffice() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.StepProcessorSmartOfficeSession getStepProcessorSmartOfficeSession(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step processor 
     *  mapping lookup service for looking up the rules applied to a step. 
     *
     *  @return a <code> StepProcessorRuleLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepProcessorRuleLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepProcessorRuleLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.StepProcessorRuleLookupSession getStepProcessorRuleLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step processor 
     *  mapping lookup service for the given office for looking up rules 
     *  applied to a step. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> StepProcessorRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Office </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepProcessorRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepProcessorRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.StepProcessorRuleLookupSession getStepProcessorRuleLookupSessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step processor 
     *  assignment service. 
     *
     *  @return a <code> StepProcessorRuleApplicationSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepProcessorRuleApplication() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepProcessorRuleApplication() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.workflow.rules.StepProcessorRuleApplicationSession getStepProcessorRuleApplicationSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step processor 
     *  assignment service for the given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> StepProcessorRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Office </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepProcessorRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepProcessorRuleApplication() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.StepProcessorRuleApplicationSession getStepProcessorRuleApplicationSessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step processor 
     *  enabler lookup service. 
     *
     *  @return a <code> StepProcessorEnablerLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepProcessorEnablerLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepProcessorEnablerLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.workflow.rules.StepProcessorEnablerLookupSession getStepProcessorEnablerLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step processor 
     *  enabler lookup service for the given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> StepProcessorEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Office </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepProcessorEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepProcessorEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.StepProcessorEnablerLookupSession getStepProcessorEnablerLookupSessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step processor 
     *  enabler query service. 
     *
     *  @return a <code> StepProcessorEnablerQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepProcessorEnablerQuery() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepProcessorEnablerQuery() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.workflow.rules.StepProcessorEnablerQuerySession getStepProcessorEnablerQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step processor 
     *  enabler query service for the given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> StepProcessorEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Office </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepProcessorEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepProcessorEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.StepProcessorEnablerQuerySession getStepProcessorEnablerQuerySessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step processor 
     *  enabler search service. 
     *
     *  @return a <code> StepProcessorEnablerSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepProcessorEnablerSearch() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepProcessorEnablerSearch() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.workflow.rules.StepProcessorEnablerSearchSession getStepProcessorEnablerSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step processor 
     *  enablers earch service for the given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> StepProcessorEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Office </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepProcessorEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepProcessorEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.StepProcessorEnablerSearchSession getStepProcessorEnablerSearchSessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step processor 
     *  enabler administration service. 
     *
     *  @return a <code> StepProcessorEnablerAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepProcessorEnablerAdmin() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepProcessorEnablerAdmin() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.workflow.rules.StepProcessorEnablerAdminSession getStepProcessorEnablerAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step processor 
     *  enabler administration service for the given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> StepProcessorEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Office </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepProcessorEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepProcessorEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.StepProcessorEnablerAdminSession getStepProcessorEnablerAdminSessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step processor 
     *  enabler notification service. 
     *
     *  @param  stepProcessorEnablerReceiver the notification callback 
     *  @return a <code> StepProcessorEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          stepProcessorEnablerReceiver </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepProcessorEnablerNotification() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepProcessorEnablerNotification() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.workflow.rules.StepProcessorEnablerNotificationSession getStepProcessorEnablerNotificationSession(org.osid.workflow.rules.StepProcessorEnablerReceiver stepProcessorEnablerReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step processor 
     *  enabler notification service for the given office. 
     *
     *  @param  stepProcessorEnablerReceiver the notification callback 
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> StepProcessorEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no office found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> 
     *          stepProcessorEnablerReceiver </code> or <code> officeId 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepProcessorEnablerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepProcessorEnablerNotification() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.workflow.rules.StepProcessorEnablerNotificationSession getStepProcessorEnablerNotificationSessionForOffice(org.osid.workflow.rules.StepProcessorEnablerReceiver stepProcessorEnablerReceiver, 
                                                                                                                               org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup step processor 
     *  enabler/office mappings for step processor enablers. 
     *
     *  @return a <code> StepProcessorEnablerOfficeSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepProcessorEnablerOffice() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepProcessorEnablerOffice() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.workflow.rules.StepProcessorEnablerOfficeSession getStepProcessorEnablerOfficeSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning step 
     *  processor enablers to office. 
     *
     *  @return a <code> StepProcessorEnablerOfficeAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepProcessorEnablerOfficeAssignment() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepProcessorEnablerOfficeAssignment() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.workflow.rules.StepProcessorEnablerOfficeAssignmentSession getStepProcessorEnablerOfficeAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage step processor enabler 
     *  smart office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> StepProcessorEnablerSmartOfficeSession </code> 
     *  @throws org.osid.NotFoundException no <code> Office </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepProcessorEnablerSmartOffice() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepProcessorEnablerSmartOffice() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.workflow.rules.StepProcessorEnablerSmartOfficeSession getStepProcessorEnablerSmartOfficeSession(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step processor 
     *  enabler mapping lookup service. 
     *
     *  @return a <code> StepProcessorEnablerRuleLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepProcessorEnablerRuleLookup() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepProcessorEnablerRuleLookup() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.workflow.rules.StepProcessorEnablerRuleLookupSession getStepProcessorEnablerRuleLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step processor 
     *  enabler mapping lookup service. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> StepProcessorEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Office </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepProcessorEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepProcessorEnablerRuleLookup() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.workflow.rules.StepProcessorEnablerRuleLookupSession getStepProcessorEnablerRuleLookupSessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step processor 
     *  enabler assignment service. 
     *
     *  @return a <code> StepProcessorEnablerRuleApplicationSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepProcessorEnablerRuleApplication() </code> is 
     *          <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepProcessorEnablerRuleApplication() </code> is 
     *              <code> true. </code> 
     */

    public org.osid.workflow.rules.StepProcessorEnablerRuleApplicationSession getStepProcessorEnablerRuleApplicationSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the step processor 
     *  enabler assignment service for the given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> StepProcessorEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Office </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsStepProcessorEnablerRuleApplication() </code> or 
     *          <code> supportsVisibleFederation() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsStepProcessorEnablerRuleApplication() </code> and 
     *              <code> supportsVisibleFederation() </code> are <code> 
     *              true. </code> 
     */

    public org.osid.workflow.rules.StepProcessorEnablerRuleApplicationSession getStepProcessorEnablerRuleApplicationSessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the process 
     *  enabler lookup service. 
     *
     *  @return a <code> ProcessEnablerLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcessEnablerLookup() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessEnablerLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.ProcessEnablerLookupSession getProcessEnablerLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the process 
     *  enabler lookup service for the given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> ProcessEnablerLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Office </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcessEnablerLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessEnablerLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.ProcessEnablerLookupSession getProcessEnablerLookupSessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the process 
     *  enabler query service. 
     *
     *  @return a <code> ProcessEnablerQuerySession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcessEnablerQuery() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessEnablerQuery() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.ProcessEnablerQuerySession getProcessEnablerQuerySession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the process 
     *  enabler query service for the given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> ProcessEnablerQuerySession </code> 
     *  @throws org.osid.NotFoundException no <code> Office </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcessEnablerQuery() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessEnablerQuery() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.ProcessEnablerQuerySession getProcessEnablerQuerySessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the process 
     *  enabler search service. 
     *
     *  @return a <code> ProcessEnablerSearchSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcessEnablerSearch() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessEnablerSearch() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.ProcessEnablerSearchSession getProcessEnablerSearchSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the process 
     *  enabler earch service for the given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> ProcessEnablerSearchSession </code> 
     *  @throws org.osid.NotFoundException no <code> Office </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcessEnablerSearch() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessEnablerSearch() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.ProcessEnablerSearchSession getProcessEnablerSearchSessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the process 
     *  enabler administration service. 
     *
     *  @return a <code> ProcessEnablerAdminSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcessEnablerAdmin() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessEnablerAdmin() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.ProcessEnablerAdminSession getProcessEnablerAdminSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the process 
     *  enabler administration service for the given office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> ProcessEnablerAdminSession </code> 
     *  @throws org.osid.NotFoundException no <code> Office </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcessEnablerAdmin() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessEnablerAdmin() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.ProcessEnablerAdminSession getProcessEnablerAdminSessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the process 
     *  enabler notification service. 
     *
     *  @param  processEnablerReceiver the notification callback 
     *  @return a <code> ProcessEnablerNotificationSession </code> 
     *  @throws org.osid.NullArgumentException <code> processEnablerReceiver 
     *          </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcessEnablerNotification() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessEnablerNotification() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.workflow.rules.ProcessEnablerNotificationSession getProcessEnablerNotificationSession(org.osid.workflow.rules.ProcessEnablerReceiver processEnablerReceiver)
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the process 
     *  enabler notification service for the given office. 
     *
     *  @param  processEnablerReceiver the notification callback 
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> ProcessEnablerNotificationSession </code> 
     *  @throws org.osid.NotFoundException no office found by the given <code> 
     *          Id </code> 
     *  @throws org.osid.NullArgumentException <code> processEnablerReceiver 
     *          </code> or <code> officeId </code> is <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcessEnablerNotification() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessEnablerNotification() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.ProcessEnablerNotificationSession getProcessEnablerNotificationSessionForOffice(org.osid.workflow.rules.ProcessEnablerReceiver processEnablerReceiver, 
                                                                                                                   org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to lookup process enabler/office 
     *  mappings for process enablers. 
     *
     *  @return a <code> ProcessEnablerOfficeSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcessEnablerOffice() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessEnablerOffice() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.ProcessEnablerOfficeSession getProcessEnablerOfficeSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with assigning process 
     *  enabler to office. 
     *
     *  @return a <code> ProcessEnablerOfficeAssignmentSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcessEnablerOfficeAssignment() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessEnablerOfficeAssignment() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.workflow.rules.ProcessEnablerOfficeAssignmentSession getProcessEnablerOfficeAssignmentSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> to manage process enabler smart 
     *  office. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> ProcessEnablerSmartOfficeSession </code> 
     *  @throws org.osid.NotFoundException no <code> Office </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcessEnablerSmartOffice() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessEnablerSmartOffice() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.workflow.rules.ProcessEnablerSmartOfficeSession getProcessEnablerSmartOfficeSession(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the process 
     *  enabler mapping lookup service for looking up the rules applied to the 
     *  process. 
     *
     *  @return a <code> ProcessEnablerRuleLookupSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcessEnablerRuleLookup() </code> is <code> false 
     *          </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessEnablerRuleLookup() </code> is <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.ProcessEnablerRuleLookupSession getProcessEnablerRuleLookupSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the process 
     *  enabler mapping lookup service for the given office for looking up 
     *  rules applied to a process. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> ProcessEnablerRuleLookupSession </code> 
     *  @throws org.osid.NotFoundException no <code> Office </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcessEnablerRuleLookup() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessEnablerRuleLookup() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.ProcessEnablerRuleLookupSession getProcessEnablerRuleLookupSessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the process 
     *  enabler assignment service to apply to processs. 
     *
     *  @return a <code> ProcessEnablerRuleApplicationSession </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcessEnablerRuleApplication() </code> is <code> 
     *          false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessEnablerRuleApplication() </code> is <code> 
     *              true. </code> 
     */

    public org.osid.workflow.rules.ProcessEnablerRuleApplicationSession getProcessEnablerRuleApplicationSession()
        throws org.osid.OperationFailedException;


    /**
     *  Gets the <code> OsidSession </code> associated with the process 
     *  enabler assignment service for the given office to apply to processs. 
     *
     *  @param  officeId the <code> Id </code> of the <code> Office </code> 
     *  @return a <code> ProcessEnablerRuleApplicationSession </code> 
     *  @throws org.osid.NotFoundException no <code> Office </code> found by 
     *          the given <code> Id </code> 
     *  @throws org.osid.NullArgumentException <code> officeId </code> is 
     *          <code> null </code> 
     *  @throws org.osid.OperationFailedException unable to complete request 
     *  @throws org.osid.UnimplementedException <code> 
     *          supportsProcessEnablerRuleApplication() </code> or <code> 
     *          supportsVisibleFederation() </code> is <code> false </code> 
     *  @compliance optional This method must be implemented if <code> 
     *              supportsProcessEnablerRuleApplication() </code> and <code> 
     *              supportsVisibleFederation() </code> are <code> true. 
     *              </code> 
     */

    public org.osid.workflow.rules.ProcessEnablerRuleApplicationSession getProcessEnablerRuleApplicationSessionForOffice(org.osid.id.Id officeId)
        throws org.osid.NotFoundException,
               org.osid.OperationFailedException;
}
