//
// org.osid.workflow.rules.WorkflowRulesProfile
//
//     The OSID Java specification for org.osid.workflow.rules.WorkflowRulesProfile.
//
// Copyright (C) 2011 Ingenescus. All Rights Reserved. 
//
//     This Work is being provided by the copyright holder(s) subject to the 
//     following license. By obtaining, using and/or copying this Work, you 
//     agree that you have read, understand, and will comply with the 
//     following terms and conditions. 
//     
//     Permission to use, copy and distribute unmodified versions of this 
//     Work, for any purpose, without fee or royalty is hereby granted, 
//     provided that you include the above copyright notices and the terms of 
//     this license on ALL copies of the Work or portions thereof. 
//     
//     You may nodify or create Derivatives of this Work only for your 
//     internal purposes. You shall not distribute or transfer any such 
//     Derivative of this Work to any location or to any third party. For the 
//     purposes of this license, "Derivative" shall mean any derivative of the 
//     Work as defined in the United States Copyright Act of 1976, such as a 
//     translation or modification. 
//     
//     This Work and the information contained herein is provided on an "AS 
//     IS" basis WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING 
//     BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A 
//     PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS 
//     OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
//     LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
//     FROM, OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER 
//     DEALINGS IN THE WORK. 
//     
//     The export of software employing encryption technology may require a 
//     specific license from the United States Government. It is the 
//     responsibility of any person or organization contemplating export to 
//     obtain such a license before exporting this Work. 
//

package org.osid.workflow.rules;


/**
 *  <p>The workflow rules profile describes the interoperability among 
 *  workflow rules services. </p>
 */

public interface WorkflowRulesProfile
    extends org.osid.OsidProfile {


    /**
     *  Tests if any broker federation is exposed. Federation is exposed when 
     *  a specific broker may be identified, selected and used to create a 
     *  lookup or admin session. Federation is not exposed when a set of 
     *  brokers appears as a single broker. 
     *
     *  @return <code> true </code> if visible federation is supported, <code> 
     *          false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsVisibleFederation();


    /**
     *  Tests if looking up step constrainer is supported. 
     *
     *  @return <code> true </code> if step constrainer lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepConstrainerLookup();


    /**
     *  Tests if querying step constrainer is supported. 
     *
     *  @return <code> true </code> if step constrainer query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepConstrainerQuery();


    /**
     *  Tests if searching step constrainer is supported. 
     *
     *  @return <code> true </code> if step constrainer search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepConstrainerSearch();


    /**
     *  Tests if a step constrainer administrative service is supported. 
     *
     *  @return <code> true </code> if step constrainer administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepConstrainerAdmin();


    /**
     *  Tests if a step constrainer notification service is supported. 
     *
     *  @return <code> true </code> if step constrainer notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepConstrainerNotification();


    /**
     *  Tests if a step constrainer office lookup service is supported. 
     *
     *  @return <code> true </code> if a step constrainer office lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepConstrainerOffice();


    /**
     *  Tests if a step constrainer office service is supported. 
     *
     *  @return <code> true </code> if step constrainer office assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepConstrainerOfficeAssignment();


    /**
     *  Tests if a step constrainer office lookup service is supported. 
     *
     *  @return <code> true </code> if a step constrainer office service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepConstrainerSmartOffice();


    /**
     *  Tests if a step constrainer rule lookup service is supported. 
     *
     *  @return <code> true </code> if a step constrainer rule lookup service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepConstrainerRuleLookup();


    /**
     *  Tests if a step constrainer rule application service is supported. 
     *
     *  @return <code> true </code> if a step constrainer rule application 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepConstrainerRuleApplication();


    /**
     *  Tests if looking up step constrainer enablers is supported. 
     *
     *  @return <code> true </code> if step constrainer enabler lookup is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepConstrainerEnablerLookup();


    /**
     *  Tests if querying step constrainer enablers is supported. 
     *
     *  @return <code> true </code> if step constrainer enabler query is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepConstrainerEnablerQuery();


    /**
     *  Tests if searching step constrainer enablers is supported. 
     *
     *  @return <code> true </code> if step constrainer enabler search is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepConstrainerEnablerSearch();


    /**
     *  Tests if a step constrainer enabler administrative service is 
     *  supported. 
     *
     *  @return <code> true </code> if step constrainer enabler administration 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepConstrainerEnablerAdmin();


    /**
     *  Tests if a step constrainer enabler notification service is supported. 
     *
     *  @return <code> true </code> if step constrainer enabler notification 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepConstrainerEnablerNotification();


    /**
     *  Tests if a step constrainer enabler office lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if a step constrainer enabler office 
     *          lookup service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepConstrainerEnablerOffice();


    /**
     *  Tests if a step constrainer enabler office service is supported. 
     *
     *  @return <code> true </code> if step constrainer enabler office 
     *          assignment service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepConstrainerEnablerOfficeAssignment();


    /**
     *  Tests if a step constrainer enabler office lookup service is 
     *  supported. 
     *
     *  @return <code> true </code> if a step constrainer enabler office 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepConstrainerEnablerSmartOffice();


    /**
     *  Tests if a step constrainer enabler rule lookup service is supported. 
     *
     *  @return <code> true </code> if a step constrainer enabler rule lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepConstrainerEnablerRuleLookup();


    /**
     *  Tests if a step constrainer enabler rule application service is 
     *  supported. 
     *
     *  @return <code> true </code> if step constrainer enabler rule 
     *          application service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepConstrainerEnablerRuleApplication();


    /**
     *  Tests if looking up step processor is supported. 
     *
     *  @return <code> true </code> if step processor lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepProcessorLookup();


    /**
     *  Tests if querying step processor is supported. 
     *
     *  @return <code> true </code> if step processor query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepProcessorQuery();


    /**
     *  Tests if searching step processor is supported. 
     *
     *  @return <code> true </code> if step processor search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepProcessorSearch();


    /**
     *  Tests if a step processor administrative service is supported. 
     *
     *  @return <code> true </code> if step processor administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepProcessorAdmin();


    /**
     *  Tests if a step processor notification service is supported. 
     *
     *  @return <code> true </code> if step processor notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepProcessorNotification();


    /**
     *  Tests if a step processor office lookup service is supported. 
     *
     *  @return <code> true </code> if a step processor office lookup service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepProcessorOffice();


    /**
     *  Tests if a step processor office service is supported. 
     *
     *  @return <code> true </code> if step processor office assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepProcessorOfficeAssignment();


    /**
     *  Tests if a step processor office lookup service is supported. 
     *
     *  @return <code> true </code> if a step processor office service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepProcessorSmartOffice();


    /**
     *  Tests if a step processor rule lookup service is supported. 
     *
     *  @return <code> true </code> if a step processor rule lookup service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepProcessorRuleLookup();


    /**
     *  Tests if a step processor rule application service is supported. 
     *
     *  @return <code> true </code> if step processor rule application service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepProcessorRuleApplication();


    /**
     *  Tests if looking up step processor enablers is supported. 
     *
     *  @return <code> true </code> if step processor enabler lookup is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepProcessorEnablerLookup();


    /**
     *  Tests if querying step processor enablers is supported. 
     *
     *  @return <code> true </code> if step processor enabler query is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepProcessorEnablerQuery();


    /**
     *  Tests if searching step processor enablers is supported. 
     *
     *  @return <code> true </code> if step processor enabler search is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepProcessorEnablerSearch();


    /**
     *  Tests if a step processor enabler administrative service is supported. 
     *
     *  @return <code> true </code> if step processor enabler administration 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepProcessorEnablerAdmin();


    /**
     *  Tests if a step processor enabler notification service is supported. 
     *
     *  @return <code> true </code> if step processor enabler notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepProcessorEnablerNotification();


    /**
     *  Tests if a step processor enabler office lookup service is supported. 
     *
     *  @return <code> true </code> if a step processor enabler office lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepProcessorEnablerOffice();


    /**
     *  Tests if a step processor enabler office service is supported. 
     *
     *  @return <code> true </code> if step processor enabler office 
     *          assignment service is supported, <code> false </code> 
     *          otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepProcessorEnablerOfficeAssignment();


    /**
     *  Tests if a step processor enabler office lookup service is supported. 
     *
     *  @return <code> true </code> if a step processor enabler office service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepProcessorEnablerSmartOffice();


    /**
     *  Tests if a step processor enabler rule lookup service is supported. 
     *
     *  @return <code> true </code> if an processor enabler rule lookup 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepProcessorEnablerRuleLookup();


    /**
     *  Tests if a step processor enabler rule application service is 
     *  supported. 
     *
     *  @return <code> true </code> if step processor enabler rule application 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepProcessorEnablerRuleApplication();


    /**
     *  Tests if looking up process enabler is supported. 
     *
     *  @return <code> true </code> if process enabler lookup is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcessEnablerLookup();


    /**
     *  Tests if querying process enabler is supported. 
     *
     *  @return <code> true </code> if process enabler query is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcessEnablerQuery();


    /**
     *  Tests if searching process enabler is supported. 
     *
     *  @return <code> true </code> if process enabler search is supported, 
     *          <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcessEnablerSearch();


    /**
     *  Tests if a process enabler administrative service is supported. 
     *
     *  @return <code> true </code> if process enabler administration is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcessEnablerAdmin();


    /**
     *  Tests if a process enabler notification service is supported. 
     *
     *  @return <code> true </code> if process enabler notification is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcessEnablerNotification();


    /**
     *  Tests if a process enabler office lookup service is supported. 
     *
     *  @return <code> true </code> if a process enabler office lookup service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcessEnablerOffice();


    /**
     *  Tests if a process enabler office service is supported. 
     *
     *  @return <code> true </code> if process enabler office assignment 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcessEnablerOfficeAssignment();


    /**
     *  Tests if a process enabler office lookup service is supported. 
     *
     *  @return <code> true </code> if a process enabler office service is 
     *          supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcessEnablerSmartOffice();


    /**
     *  Tests if a process enabler rule lookup service is supported. 
     *
     *  @return <code> true </code> if a process enabler rule lookup service 
     *          is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcessEnablerRuleLookup();


    /**
     *  Tests if a process enabler rule application service is supported. 
     *
     *  @return <code> true </code> if a process enabler rule application 
     *          service is supported, <code> false </code> otherwise 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcessEnablerRuleApplication();


    /**
     *  Gets the supported <code> StepConstrainer </code> record types. 
     *
     *  @return a list containing the supported <code> StepConstrainer </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getStepConstrainerRecordTypes();


    /**
     *  Tests if the given <code> StepConstrainer </code> record type is 
     *  supported. 
     *
     *  @param  stepConstrainerRecordType a <code> Type </code> indicating a 
     *          <code> StepConstrainer </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          stepConstrainerRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepConstrainerRecordType(org.osid.type.Type stepConstrainerRecordType);


    /**
     *  Gets the supported <code> StepConstrainer </code> search record types. 
     *
     *  @return a list containing the supported <code> StepConstrainer </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getStepConstrainerSearchRecordTypes();


    /**
     *  Tests if the given <code> StepConstrainer </code> search record type 
     *  is supported. 
     *
     *  @param  stepConstrainerSearchRecordType a <code> Type </code> 
     *          indicating a <code> StepConstrainer </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          stepConstrainerSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepConstrainerSearchRecordType(org.osid.type.Type stepConstrainerSearchRecordType);


    /**
     *  Gets the supported <code> StepConstrainerEnabler </code> record types. 
     *
     *  @return a list containing the supported <code> StepConstrainerEnabler 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getStepConstrainerEnablerRecordTypes();


    /**
     *  Tests if the given <code> StepConstrainerEnabler </code> record type 
     *  is supported. 
     *
     *  @param  stepConstrainerEnablerRecordType a <code> Type </code> 
     *          indicating a <code> StepConstrainerEnabler </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          stepConstrainerEnablerRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepConstrainerEnablerRecordType(org.osid.type.Type stepConstrainerEnablerRecordType);


    /**
     *  Gets the supported <code> StepConstrainerEnabler </code> search record 
     *  types. 
     *
     *  @return a list containing the supported <code> StepConstrainerEnabler 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getStepConstrainerEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> StepConstrainerEnabler </code> search record 
     *  type is supported. 
     *
     *  @param  stepConstrainerEnablerSearchRecordType a <code> Type </code> 
     *          indicating a <code> StepConstrainerEnabler </code> search 
     *          record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          stepConstrainerEnablerSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepConstrainerEnablerSearchRecordType(org.osid.type.Type stepConstrainerEnablerSearchRecordType);


    /**
     *  Gets the supported <code> StepProcessor </code> record types. 
     *
     *  @return a list containing the supported <code> StepProcessor </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getStepProcessorRecordTypes();


    /**
     *  Tests if the given <code> StepProcessor </code> record type is 
     *  supported. 
     *
     *  @param  stepProcessorRecordType a <code> Type </code> indicating a 
     *          <code> StepProcessor </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> stepProcessorRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepProcessorRecordType(org.osid.type.Type stepProcessorRecordType);


    /**
     *  Gets the supported <code> StepProcessor </code> search record types. 
     *
     *  @return a list containing the supported <code> StepProcessor </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getStepProcessorSearchRecordTypes();


    /**
     *  Tests if the given <code> StepProcessor </code> search record type is 
     *  supported. 
     *
     *  @param  stepProcessorSearchRecordType a <code> Type </code> indicating 
     *          a <code> StepProcessor </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          stepProcessorSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepProcessorSearchRecordType(org.osid.type.Type stepProcessorSearchRecordType);


    /**
     *  Gets the supported <code> StepProcessorEnabler </code> record types. 
     *
     *  @return a list containing the supported <code> StepProcessorEnabler 
     *          </code> record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getStepProcessorEnablerRecordTypes();


    /**
     *  Tests if the given <code> StepProcessorEnabler </code> record type is 
     *  supported. 
     *
     *  @param  stepProcessorEnablerRecordType a <code> Type </code> 
     *          indicating a <code> StepProcessorEnabler </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          stepProcessorEnablerRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepProcessorEnablerRecordType(org.osid.type.Type stepProcessorEnablerRecordType);


    /**
     *  Gets the supported <code> StepProcessorEnabler </code> search record 
     *  types. 
     *
     *  @return a list containing the supported <code> StepProcessorEnabler 
     *          </code> search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getStepProcessorEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> StepProcessorEnabler </code> search record 
     *  type is supported. 
     *
     *  @param  stepProcessorEnablerSearchRecordType a <code> Type </code> 
     *          indicating a <code> StepProcessorEnabler </code> search record 
     *          type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          stepProcessorEnablerSearchRecordType </code> is <code> null 
     *          </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsStepProcessorEnablerSearchRecordType(org.osid.type.Type stepProcessorEnablerSearchRecordType);


    /**
     *  Gets the supported <code> ProcessEnabler </code> record types. 
     *
     *  @return a list containing the supported <code> ProcessEnabler </code> 
     *          record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getProcessEnablerRecordTypes();


    /**
     *  Tests if the given <code> ProcessEnabler </code> record type is 
     *  supported. 
     *
     *  @param  processEnablerRecordType a <code> Type </code> indicating a 
     *          <code> ProcessEnabler </code> record type 
     *  @return <code> true </code> if the given record type is supported, 
     *          <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> processEnablerRecordType 
     *          </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcessEnablerRecordType(org.osid.type.Type processEnablerRecordType);


    /**
     *  Gets the supported <code> ProcessEnabler </code> search record types. 
     *
     *  @return a list containing the supported <code> ProcessEnabler </code> 
     *          search record types 
     *  @compliance mandatory This method must be implemented. 
     */

    public org.osid.type.TypeList getProcessEnablerSearchRecordTypes();


    /**
     *  Tests if the given <code> ProcessEnabler </code> search record type is 
     *  supported. 
     *
     *  @param  processEnablerSearchRecordType a <code> Type </code> 
     *          indicating a <code> ProcessEnabler </code> search record type 
     *  @return <code> true </code> if the given search record type is 
     *          supported, <code> false </code> otherwise 
     *  @throws org.osid.NullArgumentException <code> 
     *          processEnablerSearchRecordType </code> is <code> null </code> 
     *  @compliance mandatory This method must be implemented. 
     */

    public boolean supportsProcessEnablerSearchRecordType(org.osid.type.Type processEnablerSearchRecordType);
}
